/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qabstracttransition_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractanimation.h>
#include <qabstractstate.h>
#include <qabstracttransition.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qstate.h>
#include <qstatemachine.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QAbstractTransitionWrapper::QAbstractTransitionWrapper(QState * sourceState) : QAbstractTransition(sourceState), m_metaObject(0) {
    // ... middle
}

void QAbstractTransitionWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractTransitionWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractTransitionWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractTransitionWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QAbstractTransitionWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QAbstractTransition::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTransition.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QAbstractTransitionWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTransition.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QAbstractTransitionWrapper::eventTest(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventTest"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTransition.eventTest()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTransition.eventTest", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractTransitionWrapper::onTransition(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "onTransition"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTransition.onTransition()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractTransitionWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QAbstractTransitionWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QAbstractTransition::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QAbstractTransitionWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAbstractTransition::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QAbstractTransitionWrapper::~QAbstractTransitionWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAbstractTransition_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractTransition >()))
        return -1;

    QAbstractTransitionWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTTRANSITION_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAbstractTransition' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "sourceState" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QAbstractTransition", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QAbstractTransition(QState*)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractTransition(QState*)
    } else if (Shiboken::Converter<QState * >::isConvertible(arg)) {
        overloadId = 0; // QAbstractTransition(QState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransition_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "sourceState");
                if (value) {
                    if (arg)
                        errorArgName = "sourceState";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QAbstractTransition(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QState* cpp_arg0 = arg ? Shiboken::Converter<QState* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QAbstractTransition(QState*)
            cptr = new QAbstractTransitionWrapper(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractTransition >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAbstractTransition_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQAbstractTransition_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QState = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QAbstractTransition", overloads);
        return -1;
}

static PyObject* SbkQAbstractTransitionFunc_addAnimation(PyObject* self, PyObject* arg)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addAnimation(QAbstractAnimation*)
    if (Shiboken::Converter<QAbstractAnimation * >::isConvertible(arg)) {
        overloadId = 0; // addAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransitionFunc_addAnimation_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractAnimation* cpp_arg0 = Shiboken::Converter<QAbstractAnimation* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addAnimation(QAbstractAnimation*)
            cppSelf->QAbstractTransition::addAnimation(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTransitionFunc_addAnimation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractAnimation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractTransition.addAnimation", overloads);
        return 0;
}

static PyObject* SbkQAbstractTransitionFunc_animations(PyObject* self)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // animations()const
            QList<QAbstractAnimation * > cppResult = cppSelf->QAbstractTransition::animations();
            pyResult = Shiboken::Converter<QList<QAbstractAnimation * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTransitionFunc_event(PyObject* self, PyObject* arg)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransitionFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QAbstractTransition::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTransitionFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractTransition.event", overloads);
        return 0;
}

static PyObject* SbkQAbstractTransitionFunc_eventTest(PyObject* self, PyObject* arg)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: eventTest(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // eventTest(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransitionFunc_eventTest_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // eventTest(QEvent*)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTransition.eventTest()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->eventTest(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTransitionFunc_eventTest_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractTransition.eventTest", overloads);
        return 0;
}

static PyObject* SbkQAbstractTransitionFunc_machine(PyObject* self)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // machine()const
            QStateMachine * cppResult = cppSelf->QAbstractTransition::machine();
            pyResult = Shiboken::Converter<QStateMachine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTransitionFunc_onTransition(PyObject* self, PyObject* arg)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onTransition(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onTransition(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransitionFunc_onTransition_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // onTransition(QEvent*)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTransition.onTransition()' not implemented.");
                return 0;
            }
            cppSelf->onTransition(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTransitionFunc_onTransition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractTransition.onTransition", overloads);
        return 0;
}

static PyObject* SbkQAbstractTransitionFunc_removeAnimation(PyObject* self, PyObject* arg)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAnimation(QAbstractAnimation*)
    if (Shiboken::Converter<QAbstractAnimation * >::isConvertible(arg)) {
        overloadId = 0; // removeAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransitionFunc_removeAnimation_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractAnimation* cpp_arg0 = Shiboken::Converter<QAbstractAnimation* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAnimation(QAbstractAnimation*)
            cppSelf->QAbstractTransition::removeAnimation(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTransitionFunc_removeAnimation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractAnimation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractTransition.removeAnimation", overloads);
        return 0;
}

static PyObject* SbkQAbstractTransitionFunc_setTargetState(PyObject* self, PyObject* arg)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTargetState(QAbstractState*)
    if (Shiboken::Converter<QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // setTargetState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransitionFunc_setTargetState_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractState* cpp_arg0 = Shiboken::Converter<QAbstractState* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTargetState(QAbstractState*)
            cppSelf->QAbstractTransition::setTargetState(cpp_arg0);
            Shiboken::keepReference(reinterpret_cast<SbkBaseWrapper*>(self), "setTargetState(QAbstractState*)1", arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTransitionFunc_setTargetState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractTransition.setTargetState", overloads);
        return 0;
}

static PyObject* SbkQAbstractTransitionFunc_setTargetStates(PyObject* self, PyObject* arg)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTargetStates(QList<QAbstractState*>)
    if (Shiboken::Converter< QList<QAbstractState * >  >::isConvertible(arg)) {
        overloadId = 0; // setTargetStates(QList<QAbstractState*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTransitionFunc_setTargetStates_TypeError;

    // Call function/method
    {
        {
            QList<QAbstractState * > cpp_arg0 = Shiboken::Converter<QList<QAbstractState * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTargetStates(QList<QAbstractState*>)
            cppSelf->QAbstractTransition::setTargetStates(cpp_arg0);
            Shiboken::keepReference(reinterpret_cast<SbkBaseWrapper*>(self), "setTargetState(QAbstractState*)1", arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTransitionFunc_setTargetStates_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QAbstractTransition.setTargetStates", overloads);
        return 0;
}

static PyObject* SbkQAbstractTransitionFunc_sourceState(PyObject* self)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sourceState()const
            QState * cppResult = cppSelf->QAbstractTransition::sourceState();
            pyResult = Shiboken::Converter<QState * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTransitionFunc_targetState(PyObject* self)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // targetState()const
            QAbstractState * cppResult = cppSelf->QAbstractTransition::targetState();
            pyResult = Shiboken::Converter<QAbstractState * >::toPython(cppResult);
            Shiboken::keepReference(reinterpret_cast<SbkBaseWrapper*>(self), "setTargetState(QAbstractState*)1", pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTransitionFunc_targetStates(PyObject* self)
{
    QAbstractTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // targetStates()const
            QList<QAbstractState * > cppResult = cppSelf->QAbstractTransition::targetStates();
            pyResult = Shiboken::Converter<QList<QAbstractState * > >::toPython(cppResult);
            Shiboken::keepReference(reinterpret_cast<SbkBaseWrapper*>(self), "setTargetState(QAbstractState*)1", pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQAbstractTransition_methods[] = {
    {"addAnimation", (PyCFunction)SbkQAbstractTransitionFunc_addAnimation, METH_O},
    {"animations", (PyCFunction)SbkQAbstractTransitionFunc_animations, METH_NOARGS},
    {"event", (PyCFunction)SbkQAbstractTransitionFunc_event, METH_O},
    {"eventTest", (PyCFunction)SbkQAbstractTransitionFunc_eventTest, METH_O},
    {"machine", (PyCFunction)SbkQAbstractTransitionFunc_machine, METH_NOARGS},
    {"onTransition", (PyCFunction)SbkQAbstractTransitionFunc_onTransition, METH_O},
    {"removeAnimation", (PyCFunction)SbkQAbstractTransitionFunc_removeAnimation, METH_O},
    {"setTargetState", (PyCFunction)SbkQAbstractTransitionFunc_setTargetState, METH_O},
    {"setTargetStates", (PyCFunction)SbkQAbstractTransitionFunc_setTargetStates, METH_O},
    {"sourceState", (PyCFunction)SbkQAbstractTransitionFunc_sourceState, METH_NOARGS},
    {"targetState", (PyCFunction)SbkQAbstractTransitionFunc_targetState, METH_NOARGS},
    {"targetStates", (PyCFunction)SbkQAbstractTransitionFunc_targetStates, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAbstractTransition_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QAbstractTransition",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAbstractTransition_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAbstractTransition_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAbstractTransition >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAbstractTransition*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQAbstractTransition_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAbstractTransition*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQAbstractTransition_Type;
    return 0;
}


void init_QAbstractTransition(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QABSTRACTTRANSITION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAbstractTransition_Type);

    SbkQAbstractTransition_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQAbstractTransition_Type.type_discovery = &SbkQAbstractTransition_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQAbstractTransition_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAbstractTransition_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAbstractTransition_Type));
    PyModule_AddObject(module, "QAbstractTransition",
        ((PyObject*)&SbkQAbstractTransition_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("triggered", "void", NULL);
    PyDict_SetItemString(SbkQAbstractTransition_Type.super.ht_type.tp_dict, "triggered", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractTransition >("QAbstractTransition*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractTransition >(typeid(QAbstractTransition).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractTransition >(typeid(QAbstractTransitionWrapper).name());
    PySide::initQtMetaType<QAbstractTransition* >();
}

