/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qbasictimer_wrapper.h"

// Extra includes
#include <qobject.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQBasicTimer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QBasicTimer >()))
        return -1;

    QBasicTimer* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QBasicTimer", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QBasicTimer(QBasicTimer)
    // 1: QBasicTimer()
    if (numArgs == 0) {
        overloadId = 1; // QBasicTimer()
    } else if (numArgs == 1 && Shiboken::Converter<const QBasicTimer & >::isConvertible(arg)) {
        overloadId = 0; // QBasicTimer(QBasicTimer)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBasicTimer_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QBasicTimer(QBasicTimer)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QBasicTimer* cpp_arg0 = Shiboken::Converter<QBasicTimer* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QBasicTimer(QBasicTimer)
                cptr = new QBasicTimer(*cpp_arg0);
                }
                break;
            }
            case 1: // QBasicTimer()
            {

                if(!PyErr_Occurred()) {
                // QBasicTimer()
                cptr = new QBasicTimer();
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QBasicTimer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQBasicTimer_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQBasicTimer_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QBasicTimer", "", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBasicTimer", overloads);
        return -1;
}

static PyObject* SbkQBasicTimerFunc_isActive(PyObject* self)
{
    QBasicTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBasicTimer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isActive()const
            bool cppResult = cppSelf->QBasicTimer::isActive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBasicTimerFunc_start(PyObject* self, PyObject* args)
{
    QBasicTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBasicTimer* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "start", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: start(int,QObject*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        overloadId = 0; // start(int,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBasicTimerFunc_start_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // start(int,QObject*)
            cppSelf->QBasicTimer::start(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQBasicTimerFunc_start_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBasicTimer.start", overloads);
        return 0;
}

static PyObject* SbkQBasicTimerFunc_stop(PyObject* self)
{
    QBasicTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBasicTimer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stop()
            cppSelf->QBasicTimer::stop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQBasicTimerFunc_timerId(PyObject* self)
{
    QBasicTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBasicTimer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // timerId()const
            int cppResult = cppSelf->QBasicTimer::timerId();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQBasicTimer_methods[] = {
    {"isActive", (PyCFunction)SbkQBasicTimerFunc_isActive, METH_NOARGS},
    {"start", (PyCFunction)SbkQBasicTimerFunc_start, METH_VARARGS},
    {"stop", (PyCFunction)SbkQBasicTimerFunc_stop, METH_NOARGS},
    {"timerId", (PyCFunction)SbkQBasicTimerFunc_timerId, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQBasicTimer_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QBasicTimer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQBasicTimer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQBasicTimer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QBasicTimer >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QBasicTimer",
    /*user_data*/           0
};
} //extern


void init_QBasicTimer(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QBASICTIMER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQBasicTimer_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQBasicTimer_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQBasicTimer_Type));
    PyModule_AddObject(module, "QBasicTimer",
        ((PyObject*)&SbkQBasicTimer_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QBasicTimer >("QBasicTimer");
    Shiboken::TypeResolver::createObjectTypeResolver<QBasicTimer >("QBasicTimer*");
    Shiboken::TypeResolver::createValueTypeResolver<QBasicTimer >(typeid(QBasicTimer).name());
    PySide::initQtMetaType<QBasicTimer >();
}

