/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qbytearraymatcher_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qbytearraymatcher.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQByteArrayMatcher_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QByteArrayMatcher >()))
        return -1;

    QByteArrayMatcher* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QByteArrayMatcher", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QByteArrayMatcher()
    // 1: QByteArrayMatcher(QByteArray)
    // 2: QByteArrayMatcher(QByteArrayMatcher)
    // 3: QByteArrayMatcher(const char*,int)
    if (numArgs == 0) {
        overloadId = 0; // QByteArrayMatcher()
    } else if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 3; // QByteArrayMatcher(const char*,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QByteArrayMatcher & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QByteArrayMatcher(QByteArrayMatcher)
    } else if (numArgs == 1 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QByteArrayMatcher(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayMatcher_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QByteArrayMatcher()
            {

                if(!PyErr_Occurred()) {
                // QByteArrayMatcher()
                cptr = new QByteArrayMatcher();
                }
                break;
            }
            case 1: // QByteArrayMatcher(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QByteArrayMatcher(QByteArray)
                cptr = new QByteArrayMatcher(*cpp_arg0);
                }
                break;
            }
            case 2: // QByteArrayMatcher(QByteArrayMatcher)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QByteArrayMatcher* cpp_arg0 = Shiboken::Converter<QByteArrayMatcher* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QByteArrayMatcher(QByteArrayMatcher)
                cptr = new QByteArrayMatcher(*cpp_arg0);
                }
                break;
            }
            case 3: // QByteArrayMatcher(const char*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QByteArrayMatcher(const char*,int)
                cptr = new QByteArrayMatcher(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QByteArrayMatcher >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQByteArrayMatcher_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQByteArrayMatcher_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", "PySide.QtCore.QByteArrayMatcher", "str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArrayMatcher", overloads);
        return -1;
}

static PyObject* SbkQByteArrayMatcherFunc_indexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArrayMatcher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArrayMatcher* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:indexIn", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: indexIn(QByteArray,int)const
    // 1: indexIn(const char*,int,int)const
    if (numArgs >= 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // indexIn(const char*,int,int)const
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // indexIn(const char*,int,int)const
        }
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexIn(QByteArray,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexIn(QByteArray,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayMatcherFunc_indexIn_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // indexIn(QByteArray,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // indexIn(QByteArray,int)const
                int cppResult = cppSelf->QByteArrayMatcher::indexIn(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // indexIn(const char*,int,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "from";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // indexIn(const char*,int,int)const
                int cppResult = cppSelf->QByteArrayMatcher::indexIn(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayMatcherFunc_indexIn_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int = 0", "str, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArrayMatcher.indexIn", overloads);
        return 0;
}

static PyObject* SbkQByteArrayMatcherFunc_pattern(PyObject* self)
{
    QByteArrayMatcher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArrayMatcher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pattern()const
            QByteArray cppResult = cppSelf->QByteArrayMatcher::pattern();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayMatcherFunc_setPattern(PyObject* self, PyObject* arg)
{
    QByteArrayMatcher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArrayMatcher* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPattern(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setPattern(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayMatcherFunc_setPattern_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPattern(QByteArray)
            cppSelf->QByteArrayMatcher::setPattern(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQByteArrayMatcherFunc_setPattern_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArrayMatcher.setPattern", overloads);
        return 0;
}

static PyMethodDef SbkQByteArrayMatcher_methods[] = {
    {"indexIn", (PyCFunction)SbkQByteArrayMatcherFunc_indexIn, METH_VARARGS|METH_KEYWORDS},
    {"pattern", (PyCFunction)SbkQByteArrayMatcherFunc_pattern, METH_NOARGS},
    {"setPattern", (PyCFunction)SbkQByteArrayMatcherFunc_setPattern, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQByteArrayMatcher_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QByteArrayMatcher",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQByteArrayMatcher_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQByteArrayMatcher_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QByteArrayMatcher >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QByteArrayMatcher",
    /*user_data*/           0
};
} //extern


void init_QByteArrayMatcher(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QBYTEARRAYMATCHER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQByteArrayMatcher_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQByteArrayMatcher_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQByteArrayMatcher_Type));
    PyModule_AddObject(module, "QByteArrayMatcher",
        ((PyObject*)&SbkQByteArrayMatcher_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QByteArrayMatcher >("QByteArrayMatcher");
    Shiboken::TypeResolver::createObjectTypeResolver<QByteArrayMatcher >("QByteArrayMatcher*");
    Shiboken::TypeResolver::createValueTypeResolver<QByteArrayMatcher >(typeid(QByteArrayMatcher).name());
    PySide::initQtMetaType<QByteArrayMatcher >();
}

