/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdatastream_wrapper.h"

// Extra includes
#include <QStringList>
#include <QtCore/QtCore>
#include <qbitarray.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qeasingcurve.h>
#include <qiodevice.h>
#include <qline.h>
#include <qlocale.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregexp.h>
#include <qsize.h>
#include <qurl.h>
#include <quuid.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDataStreamWrapper::QDataStreamWrapper() : QDataStream() {
    // ... middle
}

QDataStreamWrapper::QDataStreamWrapper(QByteArray * arg__1, QFlags<QIODevice::OpenModeFlag> flags) : QDataStream(arg__1, flags) {
    // ... middle
}

QDataStreamWrapper::QDataStreamWrapper(QIODevice * arg__1) : QDataStream(arg__1) {
    // ... middle
}

QDataStreamWrapper::QDataStreamWrapper(const QByteArray & arg__1) : QDataStream(arg__1) {
    // ... middle
}

QDataStreamWrapper::~QDataStreamWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDataStream_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDataStream >()))
        return -1;

    QDataStreamWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDataStream", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QDataStream()
    // 1: QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
    // 2: QDataStream(QIODevice*)
    // 3: QDataStream(QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QDataStream()
    } else if (numArgs == 1 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QDataStream(QIODevice*)
    } else if (Shiboken::Converter<QByteArray * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QDataStream(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 1; // QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStream_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDataStream()
            {

                if(!PyErr_Occurred()) {
                // QDataStream()
                cptr = new QDataStreamWrapper();
                }
                break;
            }
            case 1: // QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                QFlags<QIODevice::OpenModeFlag> cpp_arg1 = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QDataStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
                cptr = new QDataStreamWrapper(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QDataStream(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QDataStream(QIODevice*)
                cptr = new QDataStreamWrapper(cpp_arg0);
                }
                break;
            }
            case 3: // QDataStream(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QDataStream(QByteArray)
                cptr = new QDataStreamWrapper(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDataStream >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDataStream_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDataStream_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray, PySide.QtCore.QIODevice.OpenMode", "PySide.QtCore.QIODevice", "PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDataStream", overloads);
        return -1;
}

static PyObject* SbkQDataStreamFunc_atEnd(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QDataStream::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_device(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QDataStream::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_floatingPointPrecision(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // floatingPointPrecision()const
            QDataStream::FloatingPointPrecision cppResult = cppSelf->QDataStream::floatingPointPrecision();
            pyResult = Shiboken::Converter<QDataStream::FloatingPointPrecision >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readBool(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readBool()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            bool _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<bool >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readDouble(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readDouble()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            qreal _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<qreal >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readFloat(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readFloat()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            float _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<float >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readInt16(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readInt16()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            qint16 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<qint16 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readInt32(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readInt32()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            qint32 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<qint32 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readInt64(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readInt64()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            qint64 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<qint64 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readInt8(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readInt8()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            qint8 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<qint8 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readQChar(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readQChar()
            // Begin code injection
            
            QChar val;
            *(cppSelf) >> val;
            pyResult = Shiboken::Converter<QChar >::toPython(val);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readQString(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readQString()
            // Begin code injection
            
            QString val;
            *(cppSelf) >> val;
            pyResult = Shiboken::Converter<QString >::toPython(val);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readQStringList(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readQStringList()
            // Begin code injection
            
            QStringList val;
            *(cppSelf) >> val;
            pyResult = Shiboken::Converter<QStringList >::toPython(val);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readQVariant(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readQVariant()
            // Begin code injection
            
            QVariant val;
            *(cppSelf) >> val;
            pyResult = Shiboken::Converter<QVariant >::toPython(val);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readString(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readString()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            QString _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<QString >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readUInt16(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readUInt16()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            quint16 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<quint16 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readUInt32(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readUInt32()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            quint32 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<quint32 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readUInt64(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readUInt64()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            quint64 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<quint64 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_readUInt8(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readUInt8()


            // Begin code injection
            
            // TEMPLATE - stream_read_method - START
            quint8 _cpp_result;
            (*cppSelf) >> _cpp_result;
            pyResult = Shiboken::Converter<quint8 >::toPython(_cpp_result);
            // TEMPLATE - stream_read_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_resetStatus(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetStatus()
            cppSelf->QDataStream::resetStatus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDataStreamFunc_setDevice(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QDataStream::setDevice(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setDevice", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_setFloatingPointPrecision(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
    if (Shiboken::Converter<QDataStream::FloatingPointPrecision >::isConvertible(arg)) {
        overloadId = 0; // setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_setFloatingPointPrecision_TypeError;

    // Call function/method
    {
        {
            QDataStream::FloatingPointPrecision cpp_arg0 = Shiboken::Converter<QDataStream::FloatingPointPrecision >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFloatingPointPrecision(QDataStream::FloatingPointPrecision)
            cppSelf->QDataStream::setFloatingPointPrecision(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_setFloatingPointPrecision_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream.FloatingPointPrecision", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setFloatingPointPrecision", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_setStatus(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatus(QDataStream::Status)
    if (Shiboken::Converter<QDataStream::Status >::isConvertible(arg)) {
        overloadId = 0; // setStatus(QDataStream::Status)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_setStatus_TypeError;

    // Call function/method
    {
        {
            QDataStream::Status cpp_arg0 = Shiboken::Converter<QDataStream::Status >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStatus(QDataStream::Status)
            cppSelf->QDataStream::setStatus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_setStatus_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream.Status", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setStatus", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_setVersion(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVersion(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_setVersion_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVersion(int)
            cppSelf->QDataStream::setVersion(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_setVersion_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.setVersion", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_skipRawData(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: skipRawData(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // skipRawData(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_skipRawData_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // skipRawData(int)
            int cppResult = cppSelf->QDataStream::skipRawData(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDataStreamFunc_skipRawData_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.skipRawData", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_status(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // status()const
            QDataStream::Status cppResult = cppSelf->QDataStream::status();
            pyResult = Shiboken::Converter<QDataStream::Status >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_unsetDevice(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unsetDevice()
            cppSelf->QDataStream::unsetDevice();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDataStreamFunc_version(PyObject* self)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // version()const
            int cppResult = cppSelf->QDataStream::version();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataStreamFunc_writeBool(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeBool(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeBool(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeBool_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeBool(bool)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeBool_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeBool", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeDouble(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeDouble(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeDouble(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeDouble_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeDouble(qreal)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeDouble_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeDouble", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeFloat(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeFloat(float)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeFloat(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeFloat_TypeError;

    // Call function/method
    {
        {
            float cpp_arg0 = Shiboken::Converter<float >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeFloat(float)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeFloat_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeFloat", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeInt16(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt16(qint16)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeInt16(qint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeInt16_TypeError;

    // Call function/method
    {
        {
            qint16 cpp_arg0 = Shiboken::Converter<qint16 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeInt16(qint16)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeInt16_TypeError:
        const char* overloads[] = {"short", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt16", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeInt32(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt32(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeInt32(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeInt32_TypeError;

    // Call function/method
    {
        {
            qint32 cpp_arg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeInt32(qint32)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeInt32_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt32", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeInt64(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt64(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeInt64(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeInt64_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeInt64(qint64)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeInt64_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt64", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeInt8(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeInt8(qint8)
    if (Shiboken::Converter<signed char >::isConvertible(arg)) {
        overloadId = 0; // writeInt8(qint8)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeInt8_TypeError;

    // Call function/method
    {
        {
            qint8 cpp_arg0 = Shiboken::Converter<qint8 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeInt8(qint8)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeInt8_TypeError:
        const char* overloads[] = {"char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeInt8", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeQChar(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQChar(QChar)
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // writeQChar(QChar)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeQChar_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeQChar(QChar)
            // Begin code injection
            
            *(cppSelf) << cpp_arg0;
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeQChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQChar", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeQString(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQString(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeQString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeQString_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeQString(QString)
            // Begin code injection
            
            *(cppSelf) << cpp_arg0;
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeQString_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQString", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeQStringList(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQStringList(QStringList)
    if (Shiboken::Converter<QStringList >::isConvertible(arg)) {
        overloadId = 0; // writeQStringList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeQStringList_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeQStringList(QStringList)
            // Begin code injection
            
            *(cppSelf) << cpp_arg0;
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeQStringList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQStringList", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeQVariant(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeQVariant(QVariant)
    if (Shiboken::Converter<QVariant >::isConvertible(arg)) {
        overloadId = 0; // writeQVariant(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeQVariant_TypeError;

    // Call function/method
    {
        {
            QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeQVariant(QVariant)
            // Begin code injection
            
            *(cppSelf) << cpp_arg0;
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeQVariant_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeQVariant", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeString(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeString(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeString_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeString(QString)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeString_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeString", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeUInt16(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt16(quint16)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeUInt16(quint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeUInt16_TypeError;

    // Call function/method
    {
        {
            quint16 cpp_arg0 = Shiboken::Converter<quint16 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeUInt16(quint16)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeUInt16_TypeError:
        const char* overloads[] = {"unsigned short", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt16", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeUInt32(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt32(quint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeUInt32(quint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeUInt32_TypeError;

    // Call function/method
    {
        {
            quint32 cpp_arg0 = Shiboken::Converter<quint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeUInt32(quint32)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeUInt32_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt32", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeUInt64(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt64(quint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // writeUInt64(quint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeUInt64_TypeError;

    // Call function/method
    {
        {
            quint64 cpp_arg0 = Shiboken::Converter<quint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeUInt64(quint64)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeUInt64_TypeError:
        const char* overloads[] = {"unsigned long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt64", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc_writeUInt8(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeUInt8(quint8)
    if (Shiboken::Converter<unsigned char >::isConvertible(arg)) {
        overloadId = 0; // writeUInt8(quint8)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc_writeUInt8_TypeError;

    // Call function/method
    {
        {
            quint8 cpp_arg0 = Shiboken::Converter<quint8 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeUInt8(quint8)


            // Begin code injection
            
            // TEMPLATE - stream_write_method - START
            (*cppSelf) << cpp_arg0;
            // TEMPLATE - stream_write_method - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataStreamFunc_writeUInt8_TypeError:
        const char* overloads[] = {"unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.writeUInt8", overloads);
        return 0;
}

static PyMethodDef SbkQDataStream_methods[] = {
    {"atEnd", (PyCFunction)SbkQDataStreamFunc_atEnd, METH_NOARGS},
    {"device", (PyCFunction)SbkQDataStreamFunc_device, METH_NOARGS},
    {"floatingPointPrecision", (PyCFunction)SbkQDataStreamFunc_floatingPointPrecision, METH_NOARGS},
    {"readBool", (PyCFunction)SbkQDataStreamFunc_readBool, METH_NOARGS},
    {"readDouble", (PyCFunction)SbkQDataStreamFunc_readDouble, METH_NOARGS},
    {"readFloat", (PyCFunction)SbkQDataStreamFunc_readFloat, METH_NOARGS},
    {"readInt16", (PyCFunction)SbkQDataStreamFunc_readInt16, METH_NOARGS},
    {"readInt32", (PyCFunction)SbkQDataStreamFunc_readInt32, METH_NOARGS},
    {"readInt64", (PyCFunction)SbkQDataStreamFunc_readInt64, METH_NOARGS},
    {"readInt8", (PyCFunction)SbkQDataStreamFunc_readInt8, METH_NOARGS},
    {"readQChar", (PyCFunction)SbkQDataStreamFunc_readQChar, METH_NOARGS},
    {"readQString", (PyCFunction)SbkQDataStreamFunc_readQString, METH_NOARGS},
    {"readQStringList", (PyCFunction)SbkQDataStreamFunc_readQStringList, METH_NOARGS},
    {"readQVariant", (PyCFunction)SbkQDataStreamFunc_readQVariant, METH_NOARGS},
    {"readString", (PyCFunction)SbkQDataStreamFunc_readString, METH_NOARGS},
    {"readUInt16", (PyCFunction)SbkQDataStreamFunc_readUInt16, METH_NOARGS},
    {"readUInt32", (PyCFunction)SbkQDataStreamFunc_readUInt32, METH_NOARGS},
    {"readUInt64", (PyCFunction)SbkQDataStreamFunc_readUInt64, METH_NOARGS},
    {"readUInt8", (PyCFunction)SbkQDataStreamFunc_readUInt8, METH_NOARGS},
    {"resetStatus", (PyCFunction)SbkQDataStreamFunc_resetStatus, METH_NOARGS},
    {"setDevice", (PyCFunction)SbkQDataStreamFunc_setDevice, METH_O},
    {"setFloatingPointPrecision", (PyCFunction)SbkQDataStreamFunc_setFloatingPointPrecision, METH_O},
    {"setStatus", (PyCFunction)SbkQDataStreamFunc_setStatus, METH_O},
    {"setVersion", (PyCFunction)SbkQDataStreamFunc_setVersion, METH_O},
    {"skipRawData", (PyCFunction)SbkQDataStreamFunc_skipRawData, METH_O},
    {"status", (PyCFunction)SbkQDataStreamFunc_status, METH_NOARGS},
    {"unsetDevice", (PyCFunction)SbkQDataStreamFunc_unsetDevice, METH_NOARGS},
    {"version", (PyCFunction)SbkQDataStreamFunc_version, METH_NOARGS},
    {"writeBool", (PyCFunction)SbkQDataStreamFunc_writeBool, METH_O},
    {"writeDouble", (PyCFunction)SbkQDataStreamFunc_writeDouble, METH_O},
    {"writeFloat", (PyCFunction)SbkQDataStreamFunc_writeFloat, METH_O},
    {"writeInt16", (PyCFunction)SbkQDataStreamFunc_writeInt16, METH_O},
    {"writeInt32", (PyCFunction)SbkQDataStreamFunc_writeInt32, METH_O},
    {"writeInt64", (PyCFunction)SbkQDataStreamFunc_writeInt64, METH_O},
    {"writeInt8", (PyCFunction)SbkQDataStreamFunc_writeInt8, METH_O},
    {"writeQChar", (PyCFunction)SbkQDataStreamFunc_writeQChar, METH_O},
    {"writeQString", (PyCFunction)SbkQDataStreamFunc_writeQString, METH_O},
    {"writeQStringList", (PyCFunction)SbkQDataStreamFunc_writeQStringList, METH_O},
    {"writeQVariant", (PyCFunction)SbkQDataStreamFunc_writeQVariant, METH_O},
    {"writeString", (PyCFunction)SbkQDataStreamFunc_writeString, METH_O},
    {"writeUInt16", (PyCFunction)SbkQDataStreamFunc_writeUInt16, METH_O},
    {"writeUInt32", (PyCFunction)SbkQDataStreamFunc_writeUInt32, METH_O},
    {"writeUInt64", (PyCFunction)SbkQDataStreamFunc_writeUInt64, METH_O},
    {"writeUInt8", (PyCFunction)SbkQDataStreamFunc_writeUInt8, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQDataStreamFunc___lshift__(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QDataStream* >::checkType(arg) && !Shiboken::Converter<QDataStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QBitArray)
    // 1: operator<<(QDataStream&,QByteArray)
    // 2: operator<<(QDataStream&,QDate)
    // 3: operator<<(QDataStream&,QDateTime)
    // 4: operator<<(QDataStream&,QEasingCurve)
    // 5: operator<<(QDataStream&,QLine)
    // 6: operator<<(QDataStream&,QLineF)
    // 7: operator<<(QDataStream&,QLocale)
    // 8: operator<<(QDataStream&,QPoint)
    // 9: operator<<(QDataStream&,QPointF)
    // 10: operator<<(QDataStream&,QRect)
    // 11: operator<<(QDataStream&,QRectF)
    // 12: operator<<(QDataStream&,QRegExp)
    // 13: operator<<(QDataStream&,QSize)
    // 14: operator<<(QDataStream&,QSizeF)
    // 15: operator<<(QDataStream&,QTime)
    // 16: operator<<(QDataStream&,QUrl)
    // 17: operator<<(QDataStream&,QUuid)
    if (!isReverse && Shiboken::Converter<const QUuid & >::isConvertible(arg)) {
        overloadId = 17; // operator<<(QDataStream&,QUuid)
    } else if (!isReverse && Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 16; // operator<<(QDataStream&,QUrl)
    } else if (!isReverse && Shiboken::Converter<const QTime & >::isConvertible(arg)) {
        overloadId = 15; // operator<<(QDataStream&,QTime)
    } else if (!isReverse && Shiboken::Converter<const QSize & >::isConvertible(arg)) {
        overloadId = 13; // operator<<(QDataStream&,QSize)
    } else if (!isReverse && Shiboken::Converter<const QSizeF & >::isConvertible(arg)) {
        overloadId = 14; // operator<<(QDataStream&,QSizeF)
    } else if (!isReverse && Shiboken::Converter<const QRegExp & >::isConvertible(arg)) {
        overloadId = 12; // operator<<(QDataStream&,QRegExp)
    } else if (!isReverse && Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 10; // operator<<(QDataStream&,QRect)
    } else if (!isReverse && Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 11; // operator<<(QDataStream&,QRectF)
    } else if (!isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 8; // operator<<(QDataStream&,QPoint)
    } else if (!isReverse && Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 9; // operator<<(QDataStream&,QPointF)
    } else if (!isReverse && Shiboken::Converter<const QLocale & >::isConvertible(arg)) {
        overloadId = 7; // operator<<(QDataStream&,QLocale)
    } else if (!isReverse && Shiboken::Converter<const QLine & >::isConvertible(arg)) {
        overloadId = 5; // operator<<(QDataStream&,QLine)
    } else if (!isReverse && Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 6; // operator<<(QDataStream&,QLineF)
    } else if (!isReverse && Shiboken::Converter<const QEasingCurve & >::isConvertible(arg)) {
        overloadId = 4; // operator<<(QDataStream&,QEasingCurve)
    } else if (!isReverse && Shiboken::Converter<const QDateTime & >::isConvertible(arg)) {
        overloadId = 3; // operator<<(QDataStream&,QDateTime)
    } else if (!isReverse && Shiboken::Converter<const QDate & >::isConvertible(arg)) {
        overloadId = 2; // operator<<(QDataStream&,QDate)
    } else if (!isReverse && Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 1; // operator<<(QDataStream&,QByteArray)
    } else if (!isReverse && Shiboken::Converter<const QBitArray & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc___lshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator<<(QDataStream&,QBitArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QBitArray* cpp_arg0 = Shiboken::Converter<QBitArray* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QBitArray)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator<<(QDataStream&,QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QByteArray)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator<<(QDataStream&,QDate)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QDate* cpp_arg0 = Shiboken::Converter<QDate* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QDate)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator<<(QDataStream&,QDateTime)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QDateTime* cpp_arg0 = Shiboken::Converter<QDateTime* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QDateTime)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator<<(QDataStream&,QEasingCurve)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QEasingCurve > cpp_arg0_auto_ptr;
                QEasingCurve* cpp_arg0 = Shiboken::Converter<QEasingCurve* >::toCpp(arg);
                if (!Shiboken::Converter<QEasingCurve >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QEasingCurve >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QEasingCurve)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator<<(QDataStream&,QLine)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QLine)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 6: // operator<<(QDataStream&,QLineF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
                if (!Shiboken::Converter<QLineF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QLineF)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 7: // operator<<(QDataStream&,QLocale)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLocale > cpp_arg0_auto_ptr;
                QLocale* cpp_arg0 = Shiboken::Converter<QLocale* >::toCpp(arg);
                if (!Shiboken::Converter<QLocale >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLocale >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QLocale)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 8: // operator<<(QDataStream&,QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QPoint)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 9: // operator<<(QDataStream&,QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QPointF)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 10: // operator<<(QDataStream&,QRect)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QRect)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 11: // operator<<(QDataStream&,QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QRectF)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 12: // operator<<(QDataStream&,QRegExp)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRegExp* cpp_arg0 = Shiboken::Converter<QRegExp* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QRegExp)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 13: // operator<<(QDataStream&,QSize)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QSize)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 14: // operator<<(QDataStream&,QSizeF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
                QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(arg);
                if (!Shiboken::Converter<QSizeF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QSizeF)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 15: // operator<<(QDataStream&,QTime)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTime* cpp_arg0 = Shiboken::Converter<QTime* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QTime)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 16: // operator<<(QDataStream&,QUrl)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
                if (!Shiboken::Converter<QUrl >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QUrl)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 17: // operator<<(QDataStream&,QUuid)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QUuid > cpp_arg0_auto_ptr;
                QUuid* cpp_arg0 = Shiboken::Converter<QUuid* >::toCpp(arg);
                if (!Shiboken::Converter<QUuid >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUuid >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QUuid)
                QDataStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDataStreamFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", "PySide.QtCore.QByteArray", "PySide.QtCore.QDate", "PySide.QtCore.QDateTime", "PySide.QtCore.QEasingCurve", "PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QLocale", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtCore.QRect", "PySide.QtCore.QRectF", "PySide.QtCore.QRegExp", "PySide.QtCore.QSize", "PySide.QtCore.QSizeF", "PySide.QtCore.QTime", "PySide.QtCore.QUrl", "PySide.QtCore.QUuid", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQDataStreamFunc___rshift__(PyObject* self, PyObject* arg)
{
    QDataStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QDataStream* >::checkType(arg) && !Shiboken::Converter<QDataStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QBitArray&)
    // 1: operator>>(QDataStream&,QByteArray&)
    // 2: operator>>(QDataStream&,QDate&)
    // 3: operator>>(QDataStream&,QDateTime&)
    // 4: operator>>(QDataStream&,QEasingCurve&)
    // 5: operator>>(QDataStream&,QLine&)
    // 6: operator>>(QDataStream&,QLineF&)
    // 7: operator>>(QDataStream&,QLocale&)
    // 8: operator>>(QDataStream&,QPoint&)
    // 9: operator>>(QDataStream&,QPointF&)
    // 10: operator>>(QDataStream&,QRect&)
    // 11: operator>>(QDataStream&,QRectF&)
    // 12: operator>>(QDataStream&,QRegExp&)
    // 13: operator>>(QDataStream&,QSize&)
    // 14: operator>>(QDataStream&,QSizeF&)
    // 15: operator>>(QDataStream&,QTime&)
    // 16: operator>>(QDataStream&,QUrl&)
    // 17: operator>>(QDataStream&,QUuid&)
    if (!isReverse && Shiboken::Converter<QUuid & >::isConvertible(arg)) {
        overloadId = 17; // operator>>(QDataStream&,QUuid&)
    } else if (!isReverse && Shiboken::Converter<QUrl & >::isConvertible(arg)) {
        overloadId = 16; // operator>>(QDataStream&,QUrl&)
    } else if (!isReverse && Shiboken::Converter<QTime & >::isConvertible(arg)) {
        overloadId = 15; // operator>>(QDataStream&,QTime&)
    } else if (!isReverse && Shiboken::Converter<QSize & >::isConvertible(arg)) {
        overloadId = 13; // operator>>(QDataStream&,QSize&)
    } else if (!isReverse && Shiboken::Converter<QSizeF & >::isConvertible(arg)) {
        overloadId = 14; // operator>>(QDataStream&,QSizeF&)
    } else if (!isReverse && Shiboken::Converter<QRegExp & >::isConvertible(arg)) {
        overloadId = 12; // operator>>(QDataStream&,QRegExp&)
    } else if (!isReverse && Shiboken::Converter<QRect & >::isConvertible(arg)) {
        overloadId = 10; // operator>>(QDataStream&,QRect&)
    } else if (!isReverse && Shiboken::Converter<QRectF & >::isConvertible(arg)) {
        overloadId = 11; // operator>>(QDataStream&,QRectF&)
    } else if (!isReverse && Shiboken::Converter<QPoint & >::isConvertible(arg)) {
        overloadId = 8; // operator>>(QDataStream&,QPoint&)
    } else if (!isReverse && Shiboken::Converter<QPointF & >::isConvertible(arg)) {
        overloadId = 9; // operator>>(QDataStream&,QPointF&)
    } else if (!isReverse && Shiboken::Converter<QLocale & >::isConvertible(arg)) {
        overloadId = 7; // operator>>(QDataStream&,QLocale&)
    } else if (!isReverse && Shiboken::Converter<QLine & >::isConvertible(arg)) {
        overloadId = 5; // operator>>(QDataStream&,QLine&)
    } else if (!isReverse && Shiboken::Converter<QLineF & >::isConvertible(arg)) {
        overloadId = 6; // operator>>(QDataStream&,QLineF&)
    } else if (!isReverse && Shiboken::Converter<QEasingCurve & >::isConvertible(arg)) {
        overloadId = 4; // operator>>(QDataStream&,QEasingCurve&)
    } else if (!isReverse && Shiboken::Converter<QDateTime & >::isConvertible(arg)) {
        overloadId = 3; // operator>>(QDataStream&,QDateTime&)
    } else if (!isReverse && Shiboken::Converter<QDate & >::isConvertible(arg)) {
        overloadId = 2; // operator>>(QDataStream&,QDate&)
    } else if (!isReverse && Shiboken::Converter<QByteArray & >::isConvertible(arg)) {
        overloadId = 1; // operator>>(QDataStream&,QByteArray&)
    } else if (!isReverse && Shiboken::Converter<QBitArray & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QBitArray&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataStreamFunc___rshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator>>(QDataStream&,QBitArray&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QBitArray* cpp_arg0 = Shiboken::Converter<QBitArray* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QBitArray&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator>>(QDataStream&,QByteArray&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QByteArray&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator>>(QDataStream&,QDate&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QDate* cpp_arg0 = Shiboken::Converter<QDate* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QDate&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator>>(QDataStream&,QDateTime&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QDateTime* cpp_arg0 = Shiboken::Converter<QDateTime* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QDateTime&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator>>(QDataStream&,QEasingCurve&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QEasingCurve > cpp_arg0_auto_ptr;
                QEasingCurve* cpp_arg0 = Shiboken::Converter<QEasingCurve* >::toCpp(arg);
                if (!Shiboken::Converter<QEasingCurve >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QEasingCurve >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QEasingCurve&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator>>(QDataStream&,QLine&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QLine&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 6: // operator>>(QDataStream&,QLineF&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
                if (!Shiboken::Converter<QLineF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QLineF&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 7: // operator>>(QDataStream&,QLocale&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLocale > cpp_arg0_auto_ptr;
                QLocale* cpp_arg0 = Shiboken::Converter<QLocale* >::toCpp(arg);
                if (!Shiboken::Converter<QLocale >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLocale >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QLocale&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 8: // operator>>(QDataStream&,QPoint&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QPoint&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 9: // operator>>(QDataStream&,QPointF&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QPointF&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 10: // operator>>(QDataStream&,QRect&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QRect&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 11: // operator>>(QDataStream&,QRectF&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QRectF&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 12: // operator>>(QDataStream&,QRegExp&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRegExp* cpp_arg0 = Shiboken::Converter<QRegExp* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QRegExp&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 13: // operator>>(QDataStream&,QSize&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QSize&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 14: // operator>>(QDataStream&,QSizeF&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
                QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(arg);
                if (!Shiboken::Converter<QSizeF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QSizeF&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 15: // operator>>(QDataStream&,QTime&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTime* cpp_arg0 = Shiboken::Converter<QTime* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QTime&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 16: // operator>>(QDataStream&,QUrl&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
                if (!Shiboken::Converter<QUrl >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QUrl&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 17: // operator>>(QDataStream&,QUuid&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QUuid > cpp_arg0_auto_ptr;
                QUuid* cpp_arg0 = Shiboken::Converter<QUuid* >::toCpp(arg);
                if (!Shiboken::Converter<QUuid >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUuid >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QUuid&)
                QDataStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDataStreamFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", "PySide.QtCore.QByteArray", "PySide.QtCore.QDate", "PySide.QtCore.QDateTime", "PySide.QtCore.QEasingCurve", "PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QLocale", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtCore.QRect", "PySide.QtCore.QRectF", "PySide.QtCore.QRegExp", "PySide.QtCore.QSize", "PySide.QtCore.QSizeF", "PySide.QtCore.QTime", "PySide.QtCore.QUrl", "PySide.QtCore.QUuid", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDataStream.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQDataStream_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQDataStreamFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQDataStreamFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDataStream_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDataStream",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQDataStream_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDataStream_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDataStream_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDataStream >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDataStream*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QDataStream_FloatingPointPrecision_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QDataStream_FloatingPointPrecision_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FloatingPointPrecision",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QDataStream_FloatingPointPrecision_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QDataStream_FloatingPointPrecision_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QDataStream_FloatingPointPrecision_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QDataStream_Version_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QDataStream_Version_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QDataStream_Version_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Version",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QDataStream_Version_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QDataStream_Version_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QDataStream_Version_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QDataStream_Status_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QDataStream_Status_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QDataStream_Status_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Status",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QDataStream_Status_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QDataStream_Status_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QDataStream_Status_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDataStream(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDataStream_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQDataStream_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDataStream_Type));
    PyModule_AddObject(module, "QDataStream",
        ((PyObject*)&SbkQDataStream_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: FloatingPointPrecision
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_FLOATINGPOINTPRECISION_IDX] = &SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type);
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
            "FloatingPointPrecision",((PyObject*)&SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type,
        (long) QDataStream::SinglePrecision, "SinglePrecision");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "SinglePrecision", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type.tp_dict,
        "SinglePrecision", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type,
        (long) QDataStream::DoublePrecision, "DoublePrecision");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "DoublePrecision", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_FloatingPointPrecision_Type.tp_dict,
        "DoublePrecision", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataStream::FloatingPointPrecision");

    // init enum class: Version
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_VERSION_IDX] = &SbkPySide_QtCore_QDataStream_Version_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDataStream_Version_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QDataStream_Version_Type);
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
            "Version",((PyObject*)&SbkPySide_QtCore_QDataStream_Version_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_1_0, "Qt_1_0");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_1_0", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_1_0", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_2_0, "Qt_2_0");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_2_0", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_2_0", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_2_1, "Qt_2_1");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_2_1", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_2_1", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_3_0, "Qt_3_0");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_3_0", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_3_0", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_3_1, "Qt_3_1");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_3_1", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_3_1", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_3_3, "Qt_3_3");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_3_3", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_3_3", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_0, "Qt_4_0");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_0", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_0", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_1, "Qt_4_1");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_1", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_1", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_2, "Qt_4_2");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_2", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_2", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_3, "Qt_4_3");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_3", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_3", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_4, "Qt_4_4");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_4", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_4", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_5, "Qt_4_5");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_5", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_5", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_6, "Qt_4_6");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_6", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_6", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Version_Type,
        (long) QDataStream::Qt_4_7, "Qt_4_7");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Qt_4_7", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Version_Type.tp_dict,
        "Qt_4_7", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataStream::Version");

    // init enum class: Status
    SbkPySide_QtCoreTypes[SBK_QDATASTREAM_STATUS_IDX] = &SbkPySide_QtCore_QDataStream_Status_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDataStream_Status_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QDataStream_Status_Type);
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
            "Status",((PyObject*)&SbkPySide_QtCore_QDataStream_Status_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Status_Type,
        (long) QDataStream::Ok, "Ok");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "Ok", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Status_Type.tp_dict,
        "Ok", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Status_Type,
        (long) QDataStream::ReadPastEnd, "ReadPastEnd");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "ReadPastEnd", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Status_Type.tp_dict,
        "ReadPastEnd", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDataStream_Status_Type,
        (long) QDataStream::ReadCorruptData, "ReadCorruptData");
    PyDict_SetItemString(SbkQDataStream_Type.super.ht_type.tp_dict,
        "ReadCorruptData", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDataStream_Status_Type.tp_dict,
        "ReadCorruptData", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataStream::Status");


    Shiboken::TypeResolver::createObjectTypeResolver<QDataStream >("QDataStream*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDataStream >(typeid(QDataStream).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDataStream >(typeid(QDataStreamWrapper).name());
    PySide::initQtMetaType<QDataStream* >();
}

