/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdate_wrapper.h"

// Extra includes
#include <qdatetime.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDate_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDate >()))
        return -1;

    QDate* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQDate_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QDate", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDate(QDate)
    // 1: QDate()
    // 2: QDate(int,int,int)
    if (numArgs == 0) {
        overloadId = 1; // QDate()
    } else if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 2; // QDate(int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QDate & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDate_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDate(QDate)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDate* cpp_arg0 = Shiboken::Converter<QDate* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QDate(QDate)
                cptr = new QDate(*cpp_arg0);
                }
                break;
            }
            case 1: // QDate()
            {

                if(!PyErr_Occurred()) {
                // QDate()
                cptr = new QDate();
                }
                break;
            }
            case 2: // QDate(int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // QDate(int,int,int)
                cptr = new QDate(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDate >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDate_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDate_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDate", "", "int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate", overloads);
        return -1;
}

static PyObject* SbkQDateFunc_addDays(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addDays(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addDays(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_addDays_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addDays(int)const
            QDate cppResult = cppSelf->QDate::addDays(cpp_arg0);
            pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_addDays_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.addDays", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_addMonths(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addMonths(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addMonths(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_addMonths_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addMonths(int)const
            QDate cppResult = cppSelf->QDate::addMonths(cpp_arg0);
            pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_addMonths_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.addMonths", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_addYears(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addYears(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addYears(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_addYears_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addYears(int)const
            QDate cppResult = cppSelf->QDate::addYears(cpp_arg0);
            pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_addYears_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.addYears", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_currentDate(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentDate()
            QDate cppResult = QDate::currentDate();
            pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_day(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // day()const
            int cppResult = cppSelf->QDate::day();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_dayOfWeek(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dayOfWeek()const
            int cppResult = cppSelf->QDate::dayOfWeek();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_dayOfYear(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dayOfYear()const
            int cppResult = cppSelf->QDate::dayOfYear();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_daysInMonth(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // daysInMonth()const
            int cppResult = cppSelf->QDate::daysInMonth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_daysInYear(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // daysInYear()const
            int cppResult = cppSelf->QDate::daysInYear();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_daysTo(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: daysTo(QDate)const
    if (Shiboken::Converter<const QDate & >::isConvertible(arg)) {
        overloadId = 0; // daysTo(QDate)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_daysTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDate* cpp_arg0 = Shiboken::Converter<QDate* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // daysTo(QDate)const
            int cppResult = cppSelf->QDate::daysTo(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_daysTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.daysTo", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_fromJulianDay(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromJulianDay(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fromJulianDay(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_fromJulianDay_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromJulianDay(int)
            QDate cppResult = QDate::fromJulianDay(cpp_arg0);
            pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_fromJulianDay_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.fromJulianDay", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_fromString(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDate.fromString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDate.fromString(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDate.fromString(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromString", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromString(QString,Qt::DateFormat)
    // 1: fromString(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // fromString(QString,QString)
        } else if (Shiboken::Converter<Qt::DateFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_fromString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromString(QString,Qt::DateFormat)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "f";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDate.fromString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                Qt::DateFormat cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::DateFormat >::toCpp(pyargs[1]) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                // fromString(QString,Qt::DateFormat)
                QDate cppResult = QDate::fromString(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromString(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fromString(QString,QString)
                QDate cppResult = QDate::fromString(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_fromString_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.fromString", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_getDate(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getDate(int*,int*,int*)
            // Begin code injection
            
            int year, month, day;
            cppSelf->getDate(&year, &month, &day);
            pyResult = Shiboken::makeTuple(year, month, day);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_gregorianToJulian(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "gregorianToJulian", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: gregorianToJulian(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // gregorianToJulian(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_gregorianToJulian_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // gregorianToJulian(int,int,int)
            uint cppResult = QDate::gregorianToJulian(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_gregorianToJulian_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.gregorianToJulian", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_isLeapYear(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isLeapYear(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // isLeapYear(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_isLeapYear_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isLeapYear(int)
            bool cppResult = QDate::isLeapYear(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_isLeapYear_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.isLeapYear", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_isNull(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QDate::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_isValid(PyObject* self, PyObject* args)
{
    QDate* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDate* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 1 || numArgs == 2)
        goto SbkQDateFunc_isValid_TypeError;

    if (!PyArg_UnpackTuple(args, "isValid", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: isValid()const
    // 1: isValid(int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // isValid()const
    } else if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // isValid(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_isValid_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // isValid()const
            {

                if(!PyErr_Occurred()) {
                // isValid()const
                bool cppResult = cppSelf->QDate::isValid();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // isValid(int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // isValid(int,int,int)
                bool cppResult = QDate::isValid(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_isValid_TypeError:
        const char* overloads[] = {"", "int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.isValid", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_longDayName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "longDayName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: longDayName(int)
    // 1: longDayName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // longDayName(int)
        } else if (numArgs == 2 && Shiboken::Converter<QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // longDayName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_longDayName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // longDayName(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // longDayName(int)
                QString cppResult = QDate::longDayName(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // longDayName(int,QDate::MonthNameType)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cpp_arg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // longDayName(int,QDate::MonthNameType)
                QString cppResult = QDate::longDayName(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_longDayName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.longDayName", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_longMonthName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "longMonthName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: longMonthName(int)
    // 1: longMonthName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // longMonthName(int)
        } else if (numArgs == 2 && Shiboken::Converter<QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // longMonthName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_longMonthName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // longMonthName(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // longMonthName(int)
                QString cppResult = QDate::longMonthName(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // longMonthName(int,QDate::MonthNameType)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cpp_arg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // longMonthName(int,QDate::MonthNameType)
                QString cppResult = QDate::longMonthName(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_longMonthName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.longMonthName", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_month(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // month()const
            int cppResult = cppSelf->QDate::month();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_setDate(PyObject* self, PyObject* args)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDate", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setDate(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setDate(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_setDate_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setDate(int,int,int)
            bool cppResult = cppSelf->QDate::setDate(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_setDate_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.setDate", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_setYMD(PyObject* self, PyObject* args)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setYMD", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setYMD(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setYMD(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_setYMD_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setYMD(int,int,int)
            bool cppResult = cppSelf->QDate::setYMD(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_setYMD_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.setYMD", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_shortDayName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shortDayName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shortDayName(int)
    // 1: shortDayName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // shortDayName(int)
        } else if (numArgs == 2 && Shiboken::Converter<QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // shortDayName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_shortDayName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // shortDayName(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // shortDayName(int)
                QString cppResult = QDate::shortDayName(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // shortDayName(int,QDate::MonthNameType)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cpp_arg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // shortDayName(int,QDate::MonthNameType)
                QString cppResult = QDate::shortDayName(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_shortDayName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.shortDayName", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_shortMonthName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shortMonthName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shortMonthName(int)
    // 1: shortMonthName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // shortMonthName(int)
        } else if (numArgs == 2 && Shiboken::Converter<QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // shortMonthName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_shortMonthName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // shortMonthName(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // shortMonthName(int)
                QString cppResult = QDate::shortMonthName(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // shortMonthName(int,QDate::MonthNameType)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cpp_arg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // shortMonthName(int,QDate::MonthNameType)
                QString cppResult = QDate::shortMonthName(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_shortMonthName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.shortMonthName", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_toJulianDay(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toJulianDay()const
            int cppResult = cppSelf->QDate::toJulianDay();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDate.toString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDate.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toString(Qt::DateFormat)const
    // 1: toString(QString)const
    if (numArgs == 0) {
        overloadId = 0; // toString(Qt::DateFormat)const
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // toString(QString)const
    } else if (Shiboken::Converter<Qt::DateFormat >::isConvertible(arg)) {
        overloadId = 0; // toString(Qt::DateFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDateFunc_toString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toString(Qt::DateFormat)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (arg)
                            errorArgName = "f";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDate.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                Qt::DateFormat cpp_arg0 = arg ? Shiboken::Converter<Qt::DateFormat >::toCpp(arg) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                // toString(Qt::DateFormat)const
                QString cppResult = cppSelf->QDate::toString(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // toString(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // toString(QString)const
                QString cppResult = cppSelf->QDate::toString(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDateFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.toString", overloads);
        return 0;
}

static PyObject* SbkQDateFunc_weekNumber(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // weekNumber(int*)const
            // Begin code injection
            
            int yearNumber;
            int week = cppSelf->weekNumber(&yearNumber);
            pyResult = Shiboken::makeTuple(week, yearNumber);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDateFunc_year(PyObject* self)
{
    QDate* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // year()const
            int cppResult = cppSelf->QDate::year();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDateMethod_isValid = {
    "isValid", (PyCFunction)SbkQDateFunc_isValid, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQDate_methods[] = {
    {"addDays", (PyCFunction)SbkQDateFunc_addDays, METH_O},
    {"addMonths", (PyCFunction)SbkQDateFunc_addMonths, METH_O},
    {"addYears", (PyCFunction)SbkQDateFunc_addYears, METH_O},
    {"currentDate", (PyCFunction)SbkQDateFunc_currentDate, METH_NOARGS|METH_STATIC},
    {"day", (PyCFunction)SbkQDateFunc_day, METH_NOARGS},
    {"dayOfWeek", (PyCFunction)SbkQDateFunc_dayOfWeek, METH_NOARGS},
    {"dayOfYear", (PyCFunction)SbkQDateFunc_dayOfYear, METH_NOARGS},
    {"daysInMonth", (PyCFunction)SbkQDateFunc_daysInMonth, METH_NOARGS},
    {"daysInYear", (PyCFunction)SbkQDateFunc_daysInYear, METH_NOARGS},
    {"daysTo", (PyCFunction)SbkQDateFunc_daysTo, METH_O},
    {"fromJulianDay", (PyCFunction)SbkQDateFunc_fromJulianDay, METH_O|METH_STATIC},
    {"fromString", (PyCFunction)SbkQDateFunc_fromString, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getDate", (PyCFunction)SbkQDateFunc_getDate, METH_NOARGS},
    {"gregorianToJulian", (PyCFunction)SbkQDateFunc_gregorianToJulian, METH_VARARGS|METH_STATIC},
    {"isLeapYear", (PyCFunction)SbkQDateFunc_isLeapYear, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)SbkQDateFunc_isNull, METH_NOARGS},
    SbkQDateMethod_isValid,
    {"longDayName", (PyCFunction)SbkQDateFunc_longDayName, METH_VARARGS|METH_STATIC},
    {"longMonthName", (PyCFunction)SbkQDateFunc_longMonthName, METH_VARARGS|METH_STATIC},
    {"month", (PyCFunction)SbkQDateFunc_month, METH_NOARGS},
    {"setDate", (PyCFunction)SbkQDateFunc_setDate, METH_VARARGS},
    {"setYMD", (PyCFunction)SbkQDateFunc_setYMD, METH_VARARGS},
    {"shortDayName", (PyCFunction)SbkQDateFunc_shortDayName, METH_VARARGS|METH_STATIC},
    {"shortMonthName", (PyCFunction)SbkQDateFunc_shortMonthName, METH_VARARGS|METH_STATIC},
    {"toJulianDay", (PyCFunction)SbkQDateFunc_toJulianDay, METH_NOARGS},
    {"toString", (PyCFunction)SbkQDateFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {"weekNumber", (PyCFunction)SbkQDateFunc_weekNumber, METH_NOARGS},
    {"year", (PyCFunction)SbkQDateFunc_year, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQDate_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (SbkBaseWrapper_instanceDict(self)) {
            PyObject* meth = PyDict_GetItem(SbkBaseWrapper_instanceDict(self), name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "isValid") == 0)
            return PyCFunction_NewEx(&SbkQDateMethod_isValid, self, 0);
    }
    PyObject* attr = PyObject_GenericGetAttr(self, name);
    if (attr && PySide::isQPropertyType(attr)) {
        PyObject *value = PySide::qproperty_get(attr, self);
        Py_DECREF(attr);
        Py_INCREF(value);
        attr = value;
    }
    return attr;
}

// Rich comparison
static PyObject* SbkQDate_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QDate& cpp_self = *Shiboken::Converter<QDate* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QDate & >::isConvertible(other)) {
                // operator!=(const QDate & other) const
                QDate* cpp_other = Shiboken::Converter<QDate* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDate  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQDate_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QDate & >::isConvertible(other)) {
                // operator<(const QDate & other) const
                QDate* cpp_other = Shiboken::Converter<QDate* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDate  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else goto SbkQDate_RichComparison_TypeError;

            break;
        case Py_LE:
            if (Shiboken::Converter<const QDate & >::isConvertible(other)) {
                // operator<=(const QDate & other) const
                QDate* cpp_other = Shiboken::Converter<QDate* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDate  >::toCpp(other) : (cpp_self <= (*cpp_other));
            } else goto SbkQDate_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QDate & >::isConvertible(other)) {
                // operator==(const QDate & other) const
                QDate* cpp_other = Shiboken::Converter<QDate* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDate  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQDate_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter<const QDate & >::isConvertible(other)) {
                // operator>(const QDate & other) const
                QDate* cpp_other = Shiboken::Converter<QDate* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDate  >::toCpp(other) : (cpp_self > (*cpp_other));
            } else goto SbkQDate_RichComparison_TypeError;

            break;
        case Py_GE:
            if (Shiboken::Converter<const QDate & >::isConvertible(other)) {
                // operator>=(const QDate & other) const
                QDate* cpp_other = Shiboken::Converter<QDate* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDate  >::toCpp(other) : (cpp_self >= (*cpp_other));
            } else goto SbkQDate_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQDate_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQDate_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter<QDate >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDate_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDate",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQDate_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         SbkQDate_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQDate_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDate_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDate_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDate >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDate",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QDate_MonthNameType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QDate_MonthNameType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QDate_MonthNameType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MonthNameType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QDate_MonthNameType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QDate_MonthNameType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QDate_MonthNameType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDate(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDATE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDate_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDate_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDate_Type));
    PyModule_AddObject(module, "QDate",
        ((PyObject*)&SbkQDate_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: MonthNameType
    SbkPySide_QtCoreTypes[SBK_QDATE_MONTHNAMETYPE_IDX] = &SbkPySide_QtCore_QDate_MonthNameType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDate_MonthNameType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QDate_MonthNameType_Type);
    PyDict_SetItemString(SbkQDate_Type.super.ht_type.tp_dict,
            "MonthNameType",((PyObject*)&SbkPySide_QtCore_QDate_MonthNameType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDate_MonthNameType_Type,
        (long) QDate::DateFormat, "DateFormat");
    PyDict_SetItemString(SbkQDate_Type.super.ht_type.tp_dict,
        "DateFormat", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDate_MonthNameType_Type.tp_dict,
        "DateFormat", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QDate_MonthNameType_Type,
        (long) QDate::StandaloneFormat, "StandaloneFormat");
    PyDict_SetItemString(SbkQDate_Type.super.ht_type.tp_dict,
        "StandaloneFormat", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QDate_MonthNameType_Type.tp_dict,
        "StandaloneFormat", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDate::MonthNameType");


    Shiboken::TypeResolver::createValueTypeResolver<QDate >("QDate");
    Shiboken::TypeResolver::createObjectTypeResolver<QDate >("QDate*");
    Shiboken::TypeResolver::createValueTypeResolver<QDate >(typeid(QDate).name());
    PySide::initQtMetaType<QDate >();
}

