/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qelapsedtimer_wrapper.h"

// Extra includes
#include <qelapsedtimer.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQElapsedTimer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QElapsedTimer >()))
        return -1;

    QElapsedTimer* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QElapsedTimer", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QElapsedTimer()
    // 1: QElapsedTimer(QElapsedTimer)
    if (numArgs == 0) {
        overloadId = 0; // QElapsedTimer()
    } else if (numArgs == 1 && Shiboken::Converter<const QElapsedTimer & >::isConvertible(arg)) {
        overloadId = 1; // QElapsedTimer(QElapsedTimer)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQElapsedTimer_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QElapsedTimer()
            {

                if(!PyErr_Occurred()) {
                // QElapsedTimer()
                cptr = new QElapsedTimer();
                }
                break;
            }
            case 1: // QElapsedTimer(QElapsedTimer)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QElapsedTimer* cpp_arg0 = Shiboken::Converter<QElapsedTimer* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QElapsedTimer(QElapsedTimer)
                cptr = new QElapsedTimer(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QElapsedTimer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQElapsedTimer_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQElapsedTimer_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QElapsedTimer", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QElapsedTimer", overloads);
        return -1;
}

static PyObject* SbkQElapsedTimerFunc_clockType(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clockType()
            QElapsedTimer::ClockType cppResult = QElapsedTimer::clockType();
            pyResult = Shiboken::Converter<QElapsedTimer::ClockType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQElapsedTimerFunc_elapsed(PyObject* self)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // elapsed()const
            qint64 cppResult = cppSelf->QElapsedTimer::elapsed();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQElapsedTimerFunc_hasExpired(PyObject* self, PyObject* arg)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasExpired(qint64)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // hasExpired(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQElapsedTimerFunc_hasExpired_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasExpired(qint64)const
            bool cppResult = cppSelf->QElapsedTimer::hasExpired(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQElapsedTimerFunc_hasExpired_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QElapsedTimer.hasExpired", overloads);
        return 0;
}

static PyObject* SbkQElapsedTimerFunc_invalidate(PyObject* self)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // invalidate()
            cppSelf->QElapsedTimer::invalidate();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQElapsedTimerFunc_isMonotonic(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isMonotonic()
            bool cppResult = QElapsedTimer::isMonotonic();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQElapsedTimerFunc_isValid(PyObject* self)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QElapsedTimer::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQElapsedTimerFunc_msecsSinceReference(PyObject* self)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // msecsSinceReference()const
            qint64 cppResult = cppSelf->QElapsedTimer::msecsSinceReference();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQElapsedTimerFunc_msecsTo(PyObject* self, PyObject* arg)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: msecsTo(QElapsedTimer)const
    if (Shiboken::Converter<const QElapsedTimer & >::isConvertible(arg)) {
        overloadId = 0; // msecsTo(QElapsedTimer)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQElapsedTimerFunc_msecsTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QElapsedTimer* cpp_arg0 = Shiboken::Converter<QElapsedTimer* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // msecsTo(QElapsedTimer)const
            qint64 cppResult = cppSelf->QElapsedTimer::msecsTo(*cpp_arg0);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQElapsedTimerFunc_msecsTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QElapsedTimer", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QElapsedTimer.msecsTo", overloads);
        return 0;
}

static PyObject* SbkQElapsedTimerFunc_restart(PyObject* self)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // restart()
            qint64 cppResult = cppSelf->QElapsedTimer::restart();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQElapsedTimerFunc_secsTo(PyObject* self, PyObject* arg)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: secsTo(QElapsedTimer)const
    if (Shiboken::Converter<const QElapsedTimer & >::isConvertible(arg)) {
        overloadId = 0; // secsTo(QElapsedTimer)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQElapsedTimerFunc_secsTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QElapsedTimer* cpp_arg0 = Shiboken::Converter<QElapsedTimer* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // secsTo(QElapsedTimer)const
            qint64 cppResult = cppSelf->QElapsedTimer::secsTo(*cpp_arg0);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQElapsedTimerFunc_secsTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QElapsedTimer", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QElapsedTimer.secsTo", overloads);
        return 0;
}

static PyObject* SbkQElapsedTimerFunc_start(PyObject* self)
{
    QElapsedTimer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QElapsedTimer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // start()
            cppSelf->QElapsedTimer::start();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQElapsedTimer_methods[] = {
    {"clockType", (PyCFunction)SbkQElapsedTimerFunc_clockType, METH_NOARGS|METH_STATIC},
    {"elapsed", (PyCFunction)SbkQElapsedTimerFunc_elapsed, METH_NOARGS},
    {"hasExpired", (PyCFunction)SbkQElapsedTimerFunc_hasExpired, METH_O},
    {"invalidate", (PyCFunction)SbkQElapsedTimerFunc_invalidate, METH_NOARGS},
    {"isMonotonic", (PyCFunction)SbkQElapsedTimerFunc_isMonotonic, METH_NOARGS|METH_STATIC},
    {"isValid", (PyCFunction)SbkQElapsedTimerFunc_isValid, METH_NOARGS},
    {"msecsSinceReference", (PyCFunction)SbkQElapsedTimerFunc_msecsSinceReference, METH_NOARGS},
    {"msecsTo", (PyCFunction)SbkQElapsedTimerFunc_msecsTo, METH_O},
    {"restart", (PyCFunction)SbkQElapsedTimerFunc_restart, METH_NOARGS},
    {"secsTo", (PyCFunction)SbkQElapsedTimerFunc_secsTo, METH_O},
    {"start", (PyCFunction)SbkQElapsedTimerFunc_start, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQElapsedTimer_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QElapsedTimer& cpp_self = *Shiboken::Converter<QElapsedTimer* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QElapsedTimer & >::isConvertible(other)) {
                // operator!=(const QElapsedTimer & other) const
                QElapsedTimer* cpp_other = Shiboken::Converter<QElapsedTimer* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QElapsedTimer  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQElapsedTimer_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QElapsedTimer & >::isConvertible(other)) {
                // operator==(const QElapsedTimer & other) const
                QElapsedTimer* cpp_other = Shiboken::Converter<QElapsedTimer* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QElapsedTimer  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQElapsedTimer_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQElapsedTimer_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQElapsedTimer_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QElapsedTimer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQElapsedTimer_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQElapsedTimer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQElapsedTimer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QElapsedTimer >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QElapsedTimer",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QElapsedTimer_ClockType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QElapsedTimer_ClockType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QElapsedTimer_ClockType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ClockType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QElapsedTimer_ClockType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QElapsedTimer_ClockType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QElapsedTimer_ClockType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QElapsedTimer(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QELAPSEDTIMER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQElapsedTimer_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQElapsedTimer_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQElapsedTimer_Type));
    PyModule_AddObject(module, "QElapsedTimer",
        ((PyObject*)&SbkQElapsedTimer_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ClockType
    SbkPySide_QtCoreTypes[SBK_QELAPSEDTIMER_CLOCKTYPE_IDX] = &SbkPySide_QtCore_QElapsedTimer_ClockType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QElapsedTimer_ClockType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QElapsedTimer_ClockType_Type);
    PyDict_SetItemString(SbkQElapsedTimer_Type.super.ht_type.tp_dict,
            "ClockType",((PyObject*)&SbkPySide_QtCore_QElapsedTimer_ClockType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QElapsedTimer_ClockType_Type,
        (long) QElapsedTimer::SystemTime, "SystemTime");
    PyDict_SetItemString(SbkQElapsedTimer_Type.super.ht_type.tp_dict,
        "SystemTime", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QElapsedTimer_ClockType_Type.tp_dict,
        "SystemTime", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QElapsedTimer_ClockType_Type,
        (long) QElapsedTimer::MonotonicClock, "MonotonicClock");
    PyDict_SetItemString(SbkQElapsedTimer_Type.super.ht_type.tp_dict,
        "MonotonicClock", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QElapsedTimer_ClockType_Type.tp_dict,
        "MonotonicClock", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QElapsedTimer_ClockType_Type,
        (long) QElapsedTimer::TickCounter, "TickCounter");
    PyDict_SetItemString(SbkQElapsedTimer_Type.super.ht_type.tp_dict,
        "TickCounter", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QElapsedTimer_ClockType_Type.tp_dict,
        "TickCounter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QElapsedTimer_ClockType_Type,
        (long) QElapsedTimer::MachAbsoluteTime, "MachAbsoluteTime");
    PyDict_SetItemString(SbkQElapsedTimer_Type.super.ht_type.tp_dict,
        "MachAbsoluteTime", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QElapsedTimer_ClockType_Type.tp_dict,
        "MachAbsoluteTime", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QElapsedTimer::ClockType");


    Shiboken::TypeResolver::createValueTypeResolver<QElapsedTimer >("QElapsedTimer");
    Shiboken::TypeResolver::createObjectTypeResolver<QElapsedTimer >("QElapsedTimer*");
    Shiboken::TypeResolver::createValueTypeResolver<QElapsedTimer >(typeid(QElapsedTimer).name());
    PySide::initQtMetaType<QElapsedTimer >();
}

