/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qfile_wrapper.h"

// Extra includes
#include <QAbstractFileEngine>
#include <QList>
#include <qabstractfileengine.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qfile.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QFileWrapper::QFileWrapper() : QFile(), m_metaObject(0) {
    // ... middle
}

QFileWrapper::QFileWrapper(QObject * parent) : QFile(parent), m_metaObject(0) {
    // ... middle
}

QFileWrapper::QFileWrapper(const QString & name) : QFile(name), m_metaObject(0) {
    // ... middle
}

QFileWrapper::QFileWrapper(const QString & name, QObject * parent) : QFile(name, parent), m_metaObject(0) {
    // ... middle
}

bool QFileWrapper::atEnd() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "atEnd"));
    if (py_override.isNull()) {
        return this->QFile::atEnd();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.atEnd", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QFileWrapper::bytesAvailable() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesAvailable"));
    if (py_override.isNull()) {
        return this->QIODevice::bytesAvailable();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.bytesAvailable", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QFileWrapper::bytesToWrite() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesToWrite"));
    if (py_override.isNull()) {
        return this->QIODevice::bytesToWrite();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.bytesToWrite", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QFileWrapper::canReadLine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "canReadLine"));
    if (py_override.isNull()) {
        return this->QIODevice::canReadLine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.canReadLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QFileWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileWrapper::close()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QFile::close();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QFileWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QFileWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QAbstractFileEngine * QFileWrapper::fileEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "fileEngine"));
    if (py_override.isNull()) {
        return this->QFile::fileEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QAbstractFileEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.fileEngine", SbkType<QAbstractFileEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAbstractFileEngine * cppResult(Shiboken::Converter<QAbstractFileEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QFile.fileEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

bool QFileWrapper::isSequential() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isSequential"));
    if (py_override.isNull()) {
        return this->QFile::isSequential();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.isSequential", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QFileWrapper::open(QFlags<QIODevice::OpenModeFlag> flags)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QFile::open(flags);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toPython(flags)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QFileWrapper::pos() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pos"));
    if (py_override.isNull()) {
        return this->QFile::pos();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.pos", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QFileWrapper::readData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readData"));
    if (py_override.isNull()) {
        return this->QFile::readData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.readData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QFileWrapper::readLineData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readLineData"));
    if (py_override.isNull()) {
        return this->QFile::readLineData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.readLineData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QFileWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QIODevice::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.reset", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QFileWrapper::seek(qint64 offset)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QFile::seek(offset);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(offset)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.seek", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QFileWrapper::size() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "size"));
    if (py_override.isNull()) {
        return this->QFile::size();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.size", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

void QFileWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QFileWrapper::waitForBytesWritten(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForBytesWritten"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::waitForBytesWritten(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.waitForBytesWritten", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QFileWrapper::waitForReadyRead(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForReadyRead"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::waitForReadyRead(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.waitForReadyRead", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QFileWrapper::writeData(const char * data, qint64 len)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "writeData"));
    if (py_override.isNull()) {
        return this->QFile::writeData(data, len);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<const char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(len)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFile.writeData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QFileWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QFile::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QFileWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QFile::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QFileWrapper::~QFileWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFile_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFile >()))
        return -1;

    QFileWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFile", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QFile()
    // 1: QFile(QObject*)
    // 2: QFile(QString)
    // 3: QFile(QString,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QFile()
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QFile(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 3; // QFile(QString,QObject*)
        }
    } else if (numArgs == 1 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QFile(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFile_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFile()
            {

                if(!PyErr_Occurred()) {
                // QFile()
                cptr = new QFileWrapper();
                }
                break;
            }
            case 1: // QFile(QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QFile(QObject*)
                cptr = new QFileWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 2: // QFile(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QFile(QString)
                cptr = new QFileWrapper(cpp_arg0);
                }
                break;
            }
            case 3: // QFile(QString,QObject*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QFile(QString,QObject*)
                cptr = new QFileWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFile >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFile_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQFile_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject", "QString", "QString, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile", overloads);
        return -1;
}

static PyObject* SbkQFileFunc_atEnd(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QFile::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_close(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // close()
            threadStateSaver.save();
            cppSelf->QFile::close();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQFileFunc_copy(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "copy", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: copy(QString,QString)
    // 1: copy(QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // copy(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // copy(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_copy_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // copy(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // copy(QString,QString)
                threadStateSaver.save();
                bool cppResult = QFile::copy(cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // copy(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // copy(QString)
                threadStateSaver.save();
                bool cppResult = cppSelf->QFile::copy(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_copy_TypeError:
        const char* overloads[] = {"QString, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.copy", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_decodeName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: decodeName(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // decodeName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_decodeName_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // decodeName(QByteArray)
            QString cppResult = QFile::decodeName(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_decodeName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.decodeName", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_encodeName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: encodeName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // encodeName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_encodeName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // encodeName(QString)
            QByteArray cppResult = QFile::encodeName(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_encodeName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.encodeName", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_error(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QFile::FileError cppResult = cppSelf->QFile::error();
            pyResult = Shiboken::Converter<QFile::FileError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_exists(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: exists()const
    // 1: exists(QString)
    if (numArgs == 0) {
        overloadId = 0; // exists()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // exists(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_exists_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // exists()const
            {

                if(!PyErr_Occurred()) {
                // exists()const
                bool cppResult = cppSelf->QFile::exists();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // exists(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // exists(QString)
                bool cppResult = QFile::exists(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_exists_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.exists", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_fileEngine(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileEngine()const
            QAbstractFileEngine * cppResult = cppSelf->QFile::fileEngine();
            pyResult = Shiboken::Converter<QAbstractFileEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_fileName(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QFile::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_flush(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // flush()
            threadStateSaver.save();
            bool cppResult = cppSelf->QFile::flush();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_handle(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // handle()const
            int cppResult = cppSelf->QFile::handle();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_isSequential(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSequential()const
            bool cppResult = cppSelf->QFile::isSequential();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_link(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "link", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: link(QString)
    // 1: link(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // link(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // link(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_link_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // link(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // link(QString)
                threadStateSaver.save();
                bool cppResult = cppSelf->QFile::link(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // link(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // link(QString,QString)
                threadStateSaver.save();
                bool cppResult = QFile::link(cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_link_TypeError:
        const char* overloads[] = {"QString", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.link", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_open(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: open(QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(arg)) {
        overloadId = 0; // open(QFlags<QIODevice::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_open_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QFlags<QIODevice::OpenModeFlag> cpp_arg0 = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // open(QFlags<QIODevice::OpenModeFlag>)
            threadStateSaver.save();
            bool cppResult = cppSelf->QFile::open(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_open_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice.OpenMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.open", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_permissions(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: permissions()const
    // 1: permissions(QString)
    if (numArgs == 0) {
        overloadId = 0; // permissions()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // permissions(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_permissions_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // permissions()const
            {

                if(!PyErr_Occurred()) {
                // permissions()const
                QFlags<QFile::Permission> cppResult = cppSelf->QFile::permissions();
                pyResult = Shiboken::Converter<QFlags<QFile::Permission> >::toPython(cppResult);
                }
                break;
            }
            case 1: // permissions(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // permissions(QString)
                QFlags<QFile::Permission> cppResult = QFile::permissions(cpp_arg0);
                pyResult = Shiboken::Converter<QFlags<QFile::Permission> >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_permissions_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.permissions", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_pos(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            qint64 cppResult = cppSelf->QFile::pos();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_readData(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_readData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readData(char*,qint64)
            qint64 cppResult = cppSelf->QFile::readData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_readData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.readData", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_readLineData(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readLineData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readLineData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readLineData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_readLineData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readLineData(char*,qint64)
            qint64 cppResult = cppSelf->QFile::readLineData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_readLineData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.readLineData", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_readLink(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: readLink()const
    // 1: readLink(QString)
    if (numArgs == 0) {
        overloadId = 0; // readLink()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // readLink(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_readLink_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // readLink()const
            {

                if(!PyErr_Occurred()) {
                // readLink()const
                QString cppResult = cppSelf->QFile::readLink();
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // readLink(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // readLink(QString)
                QString cppResult = QFile::readLink(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_readLink_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.readLink", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_remove(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: remove()
    // 1: remove(QString)
    if (numArgs == 0) {
        overloadId = 0; // remove()
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_remove_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // remove()
            {

                if(!PyErr_Occurred()) {
                // remove()
                threadStateSaver.save();
                bool cppResult = cppSelf->QFile::remove();
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // remove(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // remove(QString)
                threadStateSaver.save();
                bool cppResult = QFile::remove(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_remove_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.remove", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_rename(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rename", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rename(QString)
    // 1: rename(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // rename(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // rename(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_rename_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // rename(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // rename(QString)
                threadStateSaver.save();
                bool cppResult = cppSelf->QFile::rename(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // rename(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // rename(QString,QString)
                threadStateSaver.save();
                bool cppResult = QFile::rename(cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_rename_TypeError:
        const char* overloads[] = {"QString", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.rename", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_resize(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resize(QString,qint64)
    // 1: resize(qint64)
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // resize(qint64)
    } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // resize(QString,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_resize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // resize(QString,qint64)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // resize(QString,qint64)
                bool cppResult = QFile::resize(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // resize(qint64)
            {
                qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // resize(qint64)
                bool cppResult = cppSelf->QFile::resize(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_resize_TypeError:
        const char* overloads[] = {"QString, long long", "long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.resize", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_seek(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_seek_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // seek(qint64)
            threadStateSaver.save();
            bool cppResult = cppSelf->QFile::seek(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.seek", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_setFileName(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFileName(QString)
            cppSelf->QFile::setFileName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.setFileName", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_setPermissions(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPermissions", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPermissions(QFlags<QFile::Permission>)
    // 1: setPermissions(QString,QFlags<QFile::Permission>)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QFlags<QFile::Permission> >::isConvertible(pyargs[1])) {
        overloadId = 1; // setPermissions(QString,QFlags<QFile::Permission>)
    } else if (numArgs == 1 && Shiboken::Converter<QFlags<QFile::Permission> >::isConvertible(pyargs[0])) {
        overloadId = 0; // setPermissions(QFlags<QFile::Permission>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_setPermissions_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPermissions(QFlags<QFile::Permission>)
            {
                QFlags<QFile::Permission> cpp_arg0 = Shiboken::Converter<QFlags<QFile::Permission> >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setPermissions(QFlags<QFile::Permission>)
                bool cppResult = cppSelf->QFile::setPermissions(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // setPermissions(QString,QFlags<QFile::Permission>)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QFlags<QFile::Permission> cpp_arg1 = Shiboken::Converter<QFlags<QFile::Permission> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setPermissions(QString,QFlags<QFile::Permission>)
                bool cppResult = QFile::setPermissions(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_setPermissions_TypeError:
        const char* overloads[] = {"PySide.QtCore.QFile.Permissions", "QString, PySide.QtCore.QFile.Permissions", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.setPermissions", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_size(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            qint64 cppResult = cppSelf->QFile::size();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileFunc_symLinkTarget(PyObject* self, PyObject* arg)
{
    QFile* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFile* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: symLinkTarget()const
    // 1: symLinkTarget(QString)
    if (numArgs == 0) {
        overloadId = 0; // symLinkTarget()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // symLinkTarget(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_symLinkTarget_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // symLinkTarget()const
            {

                if(!PyErr_Occurred()) {
                // symLinkTarget()const
                QString cppResult = cppSelf->QFile::symLinkTarget();
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // symLinkTarget(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // symLinkTarget(QString)
                QString cppResult = QFile::symLinkTarget(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_symLinkTarget_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFile.symLinkTarget", overloads);
        return 0;
}

static PyObject* SbkQFileFunc_unsetError(PyObject* self)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unsetError()
            cppSelf->QFile::unsetError();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQFileFunc_writeData(PyObject* self, PyObject* args)
{
    QFile* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFile* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeData(const char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileFunc_writeData_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // writeData(const char*,qint64)
            qint64 cppResult = cppSelf->QFile::writeData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileFunc_writeData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFile.writeData", overloads);
        return 0;
}

static PyMethodDef SbkQFileMethod_copy = {
    "copy", (PyCFunction)SbkQFileFunc_copy, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQFileMethod_exists = {
    "exists", (PyCFunction)SbkQFileFunc_exists, METH_NOARGS|METH_O|METH_STATIC
};

static PyMethodDef SbkQFileMethod_link = {
    "link", (PyCFunction)SbkQFileFunc_link, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQFileMethod_permissions = {
    "permissions", (PyCFunction)SbkQFileFunc_permissions, METH_NOARGS|METH_O|METH_STATIC
};

static PyMethodDef SbkQFileMethod_readLink = {
    "readLink", (PyCFunction)SbkQFileFunc_readLink, METH_NOARGS|METH_O|METH_STATIC
};

static PyMethodDef SbkQFileMethod_remove = {
    "remove", (PyCFunction)SbkQFileFunc_remove, METH_NOARGS|METH_O|METH_STATIC
};

static PyMethodDef SbkQFileMethod_rename = {
    "rename", (PyCFunction)SbkQFileFunc_rename, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQFileMethod_resize = {
    "resize", (PyCFunction)SbkQFileFunc_resize, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQFileMethod_setPermissions = {
    "setPermissions", (PyCFunction)SbkQFileFunc_setPermissions, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQFileMethod_symLinkTarget = {
    "symLinkTarget", (PyCFunction)SbkQFileFunc_symLinkTarget, METH_NOARGS|METH_O|METH_STATIC
};

static PyMethodDef SbkQFile_methods[] = {
    {"atEnd", (PyCFunction)SbkQFileFunc_atEnd, METH_NOARGS},
    {"close", (PyCFunction)SbkQFileFunc_close, METH_NOARGS},
    SbkQFileMethod_copy,
    {"decodeName", (PyCFunction)SbkQFileFunc_decodeName, METH_O|METH_STATIC},
    {"encodeName", (PyCFunction)SbkQFileFunc_encodeName, METH_O|METH_STATIC},
    {"error", (PyCFunction)SbkQFileFunc_error, METH_NOARGS},
    SbkQFileMethod_exists,
    {"fileEngine", (PyCFunction)SbkQFileFunc_fileEngine, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQFileFunc_fileName, METH_NOARGS},
    {"flush", (PyCFunction)SbkQFileFunc_flush, METH_NOARGS},
    {"handle", (PyCFunction)SbkQFileFunc_handle, METH_NOARGS},
    {"isSequential", (PyCFunction)SbkQFileFunc_isSequential, METH_NOARGS},
    SbkQFileMethod_link,
    {"open", (PyCFunction)SbkQFileFunc_open, METH_O},
    SbkQFileMethod_permissions,
    {"pos", (PyCFunction)SbkQFileFunc_pos, METH_NOARGS},
    {"readData", (PyCFunction)SbkQFileFunc_readData, METH_VARARGS},
    {"readLineData", (PyCFunction)SbkQFileFunc_readLineData, METH_VARARGS},
    SbkQFileMethod_readLink,
    SbkQFileMethod_remove,
    SbkQFileMethod_rename,
    SbkQFileMethod_resize,
    {"seek", (PyCFunction)SbkQFileFunc_seek, METH_O},
    {"setFileName", (PyCFunction)SbkQFileFunc_setFileName, METH_O},
    SbkQFileMethod_setPermissions,
    {"size", (PyCFunction)SbkQFileFunc_size, METH_NOARGS},
    SbkQFileMethod_symLinkTarget,
    {"unsetError", (PyCFunction)SbkQFileFunc_unsetError, METH_NOARGS},
    {"writeData", (PyCFunction)SbkQFileFunc_writeData, METH_VARARGS},
    {0} // Sentinel
};

static PyObject* SbkQFile_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (SbkBaseWrapper_instanceDict(self)) {
            PyObject* meth = PyDict_GetItem(SbkBaseWrapper_instanceDict(self), name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "copy") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_copy, self, 0);
        if (strcmp(cname, "exists") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_exists, self, 0);
        if (strcmp(cname, "link") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_link, self, 0);
        if (strcmp(cname, "permissions") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_permissions, self, 0);
        if (strcmp(cname, "readLink") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_readLink, self, 0);
        if (strcmp(cname, "remove") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_remove, self, 0);
        if (strcmp(cname, "rename") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_rename, self, 0);
        if (strcmp(cname, "resize") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_resize, self, 0);
        if (strcmp(cname, "setPermissions") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_setPermissions, self, 0);
        if (strcmp(cname, "symLinkTarget") == 0)
            return PyCFunction_NewEx(&SbkQFileMethod_symLinkTarget, self, 0);
    }
    PyObject* attr = PyObject_GenericGetAttr(self, name);
    if (attr && PySide::isQPropertyType(attr)) {
        PyObject *value = PySide::qproperty_get(attr, self);
        Py_DECREF(attr);
        Py_INCREF(value);
        attr = value;
    }
    return attr;
}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFile_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QFile",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         SbkQFile_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFile_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFile_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFile >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFile*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQFile_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QFile*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQFile_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtCore_QFile_FileError_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QFile_FileError_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QFile_FileError_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FileError",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QFile_FileError_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QFile_FileError_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QFile_FileError_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QFile_MemoryMapFlags_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QFile_MemoryMapFlags_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QFile_MemoryMapFlags_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MemoryMapFlags",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QFile_MemoryMapFlags_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QFile_MemoryMapFlags_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QFile_MemoryMapFlags_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtCore_QFile_Permission___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QFile::Permissions >::checkType(self) && Shiboken::Converter<QFile::Permissions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QFile::Permissions >::toPython(
        Shiboken::Converter<QFile::Permissions>::toCpp(self)
        & Shiboken::Converter< QFile::Permissions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QFile_Permission___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QFile::Permissions >::checkType(self) && Shiboken::Converter<QFile::Permissions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QFile::Permissions >::toPython(
        Shiboken::Converter<QFile::Permissions>::toCpp(self)
        | Shiboken::Converter< QFile::Permissions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QFile_Permission___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QFile::Permissions >::checkType(self) && Shiboken::Converter<QFile::Permissions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QFile::Permissions >::toPython(
        Shiboken::Converter<QFile::Permissions>::toCpp(self)
        ^ Shiboken::Converter< QFile::Permissions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QFile_Permission___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QFile::Permissions >::toPython(
        ~Shiboken::Converter<QFile::Permissions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QFile_Permission_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QFile_Permission___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QFile_Permission___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QFile_Permission___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QFile_Permission___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtCore_QFile_Permission_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QFile_Permission_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QFile_Permission_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Permission",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtCore_QFile_Permission_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QFile_Permission_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QFile_Permission_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QFile_Permission_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QFile_Permissions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Permissions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtCore_QFile_Permission_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QFile(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QFILE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFile_Type);

    SbkQFile_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX];
    // Fill type discovery information
    SbkQFile_Type.type_discovery = &SbkQFile_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX]), &SbkQFile_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFile_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFile_Type));
    PyModule_AddObject(module, "QFile",
        ((PyObject*)&SbkQFile_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: FileError
    SbkPySide_QtCoreTypes[SBK_QFILE_FILEERROR_IDX] = &SbkPySide_QtCore_QFile_FileError_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QFile_FileError_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QFile_FileError_Type);
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
            "FileError",((PyObject*)&SbkPySide_QtCore_QFile_FileError_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::NoError, "NoError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::ReadError, "ReadError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ReadError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "ReadError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::WriteError, "WriteError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "WriteError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "WriteError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::FatalError, "FatalError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "FatalError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "FatalError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::ResourceError, "ResourceError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ResourceError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "ResourceError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::OpenError, "OpenError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "OpenError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "OpenError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::AbortError, "AbortError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "AbortError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "AbortError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::TimeOutError, "TimeOutError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "TimeOutError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "TimeOutError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::UnspecifiedError, "UnspecifiedError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "UnspecifiedError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "UnspecifiedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::RemoveError, "RemoveError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "RemoveError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "RemoveError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::RenameError, "RenameError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "RenameError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "RenameError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::PositionError, "PositionError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "PositionError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "PositionError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::ResizeError, "ResizeError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ResizeError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "ResizeError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::PermissionsError, "PermissionsError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "PermissionsError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "PermissionsError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_FileError_Type,
        (long) QFile::CopyError, "CopyError");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "CopyError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_FileError_Type.tp_dict,
        "CopyError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFile::FileError");

    // init enum class: MemoryMapFlags
    SbkPySide_QtCoreTypes[SBK_QFILE_MEMORYMAPFLAGS_IDX] = &SbkPySide_QtCore_QFile_MemoryMapFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QFile_MemoryMapFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QFile_MemoryMapFlags_Type);
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
            "MemoryMapFlags",((PyObject*)&SbkPySide_QtCore_QFile_MemoryMapFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_MemoryMapFlags_Type,
        (long) QFile::NoOptions, "NoOptions");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "NoOptions", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_MemoryMapFlags_Type.tp_dict,
        "NoOptions", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFile::MemoryMapFlags");

    // init enum class: Permission
    SbkPySide_QtCoreTypes[SBK_QFILE_PERMISSION_IDX] = &SbkPySide_QtCore_QFile_Permission_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QFile_Permission_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QFile_Permission_Type);
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
            "Permission",((PyObject*)&SbkPySide_QtCore_QFile_Permission_Type));

    // init flags class: QFlags<QFile::Permission>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QFILE_PERMISSION__IDX] = &SbkPySide_QtCore_QFile_Permissions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QFile_Permissions_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QFile_Permissions_Type);
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
            "Permissions",((PyObject*)&SbkPySide_QtCore_QFile_Permissions_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ReadOwner, "ReadOwner");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ReadOwner", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ReadOwner", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::WriteOwner, "WriteOwner");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "WriteOwner", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "WriteOwner", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ExeOwner, "ExeOwner");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ExeOwner", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ExeOwner", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ReadUser, "ReadUser");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ReadUser", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ReadUser", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::WriteUser, "WriteUser");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "WriteUser", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "WriteUser", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ExeUser, "ExeUser");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ExeUser", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ExeUser", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ReadGroup, "ReadGroup");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ReadGroup", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ReadGroup", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::WriteGroup, "WriteGroup");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "WriteGroup", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "WriteGroup", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ExeGroup, "ExeGroup");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ExeGroup", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ExeGroup", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ReadOther, "ReadOther");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ReadOther", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ReadOther", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::WriteOther, "WriteOther");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "WriteOther", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "WriteOther", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QFile_Permission_Type,
        (long) QFile::ExeOther, "ExeOther");
    PyDict_SetItemString(SbkQFile_Type.super.ht_type.tp_dict,
        "ExeOther", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QFile_Permission_Type.tp_dict,
        "ExeOther", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFile::Permission");


    Shiboken::TypeResolver::createObjectTypeResolver<QFile >("QFile*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFile >(typeid(QFile).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFile >(typeid(QFileWrapper).name());
    PySide::initQtMetaType<QFile* >();
}

