/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qfileinfo_wrapper.h"

// Extra includes
#include <QDateTime>
#include <QDir>
#include <qdatetime.h>
#include <qdir.h>
#include <qfile.h>
#include <qfileinfo.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFileInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFileInfo >()))
        return -1;

    QFileInfo* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFileInfo", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QFileInfo()
    // 1: QFileInfo(QDir,QString)
    // 2: QFileInfo(QFile)
    // 3: QFileInfo(QFileInfo)
    // 4: QFileInfo(QString)
    if (numArgs == 0) {
        overloadId = 0; // QFileInfo()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 4; // QFileInfo(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QFile & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QFileInfo(QFile)
    } else if (numArgs == 1 && Shiboken::Converter<const QFileInfo & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QFileInfo(QFileInfo)
    } else if (numArgs == 2 && Shiboken::Converter<const QDir & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // QFileInfo(QDir,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileInfo_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFileInfo()
            {

                if(!PyErr_Occurred()) {
                // QFileInfo()
                cptr = new QFileInfo();
                }
                break;
            }
            case 1: // QFileInfo(QDir,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QDir > cpp_arg0_auto_ptr;
                QDir* cpp_arg0 = Shiboken::Converter<QDir* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QDir >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QDir >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QFileInfo(QDir,QString)
                cptr = new QFileInfo(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QFileInfo(QFile)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QFile* cpp_arg0 = Shiboken::Converter<QFile* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QFileInfo(QFile)
                cptr = new QFileInfo(*cpp_arg0);
                }
                break;
            }
            case 3: // QFileInfo(QFileInfo)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFileInfo > cpp_arg0_auto_ptr;
                QFileInfo* cpp_arg0 = Shiboken::Converter<QFileInfo* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFileInfo >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFileInfo >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFileInfo(QFileInfo)
                cptr = new QFileInfo(*cpp_arg0);
                }
                break;
            }
            case 4: // QFileInfo(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QFileInfo(QString)
                cptr = new QFileInfo(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFileInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFileInfo_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQFileInfo_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QDir, QString", "PySide.QtCore.QFile", "PySide.QtCore.QFileInfo", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFileInfo", overloads);
        return -1;
}

static PyObject* SbkQFileInfoFunc_absoluteDir(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // absoluteDir()const
            QDir cppResult = cppSelf->QFileInfo::absoluteDir();
            pyResult = Shiboken::Converter<QDir >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_absoluteFilePath(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // absoluteFilePath()const
            QString cppResult = cppSelf->QFileInfo::absoluteFilePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_absolutePath(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // absolutePath()const
            QString cppResult = cppSelf->QFileInfo::absolutePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_baseName(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // baseName()const
            QString cppResult = cppSelf->QFileInfo::baseName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_bundleName(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bundleName()const
            QString cppResult = cppSelf->QFileInfo::bundleName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_caching(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // caching()const
            bool cppResult = cppSelf->QFileInfo::caching();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_canonicalFilePath(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canonicalFilePath()const
            QString cppResult = cppSelf->QFileInfo::canonicalFilePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_canonicalPath(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canonicalPath()const
            QString cppResult = cppSelf->QFileInfo::canonicalPath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_completeBaseName(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completeBaseName()const
            QString cppResult = cppSelf->QFileInfo::completeBaseName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_completeSuffix(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completeSuffix()const
            QString cppResult = cppSelf->QFileInfo::completeSuffix();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_created(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // created()const
            QDateTime cppResult = cppSelf->QFileInfo::created();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_dir(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dir()const
            QDir cppResult = cppSelf->QFileInfo::dir();
            pyResult = Shiboken::Converter<QDir >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_exists(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // exists()const
            bool cppResult = cppSelf->QFileInfo::exists();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_fileName(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QFileInfo::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_filePath(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // filePath()const
            QString cppResult = cppSelf->QFileInfo::filePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_group(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // group()const
            QString cppResult = cppSelf->QFileInfo::group();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_groupId(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // groupId()const
            uint cppResult = cppSelf->QFileInfo::groupId();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isAbsolute(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAbsolute()const
            bool cppResult = cppSelf->QFileInfo::isAbsolute();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isBundle(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isBundle()const
            bool cppResult = cppSelf->QFileInfo::isBundle();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isDir(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDir()const
            bool cppResult = cppSelf->QFileInfo::isDir();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isExecutable(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isExecutable()const
            bool cppResult = cppSelf->QFileInfo::isExecutable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isFile(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isFile()const
            bool cppResult = cppSelf->QFileInfo::isFile();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isHidden(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isHidden()const
            bool cppResult = cppSelf->QFileInfo::isHidden();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isReadable(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isReadable()const
            bool cppResult = cppSelf->QFileInfo::isReadable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isRelative(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRelative()const
            bool cppResult = cppSelf->QFileInfo::isRelative();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isRoot(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRoot()const
            bool cppResult = cppSelf->QFileInfo::isRoot();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isSymLink(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSymLink()const
            bool cppResult = cppSelf->QFileInfo::isSymLink();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_isWritable(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWritable()const
            bool cppResult = cppSelf->QFileInfo::isWritable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_lastModified(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastModified()const
            QDateTime cppResult = cppSelf->QFileInfo::lastModified();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_lastRead(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastRead()const
            QDateTime cppResult = cppSelf->QFileInfo::lastRead();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_makeAbsolute(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // makeAbsolute()
            bool cppResult = cppSelf->QFileInfo::makeAbsolute();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_owner(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // owner()const
            QString cppResult = cppSelf->QFileInfo::owner();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_ownerId(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ownerId()const
            uint cppResult = cppSelf->QFileInfo::ownerId();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_path(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // path()const
            QString cppResult = cppSelf->QFileInfo::path();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_permission(PyObject* self, PyObject* arg)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: permission(QFlags<QFile::Permission>)const
    if (Shiboken::Converter<QFlags<QFile::Permission> >::isConvertible(arg)) {
        overloadId = 0; // permission(QFlags<QFile::Permission>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileInfoFunc_permission_TypeError;

    // Call function/method
    {
        {
            QFlags<QFile::Permission> cpp_arg0 = Shiboken::Converter<QFlags<QFile::Permission> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // permission(QFlags<QFile::Permission>)const
            bool cppResult = cppSelf->QFileInfo::permission(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileInfoFunc_permission_TypeError:
        const char* overloads[] = {"PySide.QtCore.QFile.Permissions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFileInfo.permission", overloads);
        return 0;
}

static PyObject* SbkQFileInfoFunc_permissions(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // permissions()const
            QFlags<QFile::Permission> cppResult = cppSelf->QFileInfo::permissions();
            pyResult = Shiboken::Converter<QFlags<QFile::Permission> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_readLink(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readLink()const
            QString cppResult = cppSelf->QFileInfo::readLink();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_refresh(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // refresh()
            cppSelf->QFileInfo::refresh();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQFileInfoFunc_setCaching(PyObject* self, PyObject* arg)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCaching(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCaching(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileInfoFunc_setCaching_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCaching(bool)
            cppSelf->QFileInfo::setCaching(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileInfoFunc_setCaching_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QFileInfo.setCaching", overloads);
        return 0;
}

static PyObject* SbkQFileInfoFunc_setFile(PyObject* self, PyObject* args)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFile", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFile(QDir,QString)
    // 1: setFile(QFile)
    // 2: setFile(QString)
    if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 2; // setFile(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QFile & >::isConvertible(pyargs[0])) {
        overloadId = 1; // setFile(QFile)
    } else if (numArgs == 2 && Shiboken::Converter<const QDir & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setFile(QDir,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileInfoFunc_setFile_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFile(QDir,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QDir > cpp_arg0_auto_ptr;
                QDir* cpp_arg0 = Shiboken::Converter<QDir* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QDir >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QDir >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setFile(QDir,QString)
                cppSelf->QFileInfo::setFile(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // setFile(QFile)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QFile* cpp_arg0 = Shiboken::Converter<QFile* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setFile(QFile)
                cppSelf->QFileInfo::setFile(*cpp_arg0);
                }
                break;
            }
            case 2: // setFile(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setFile(QString)
                cppSelf->QFileInfo::setFile(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileInfoFunc_setFile_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir, QString", "PySide.QtCore.QFile", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QFileInfo.setFile", overloads);
        return 0;
}

static PyObject* SbkQFileInfoFunc_size(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            qint64 cppResult = cppSelf->QFileInfo::size();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_suffix(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // suffix()const
            QString cppResult = cppSelf->QFileInfo::suffix();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileInfoFunc_symLinkTarget(PyObject* self)
{
    QFileInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // symLinkTarget()const
            QString cppResult = cppSelf->QFileInfo::symLinkTarget();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFileInfo_methods[] = {
    {"absoluteDir", (PyCFunction)SbkQFileInfoFunc_absoluteDir, METH_NOARGS},
    {"absoluteFilePath", (PyCFunction)SbkQFileInfoFunc_absoluteFilePath, METH_NOARGS},
    {"absolutePath", (PyCFunction)SbkQFileInfoFunc_absolutePath, METH_NOARGS},
    {"baseName", (PyCFunction)SbkQFileInfoFunc_baseName, METH_NOARGS},
    {"bundleName", (PyCFunction)SbkQFileInfoFunc_bundleName, METH_NOARGS},
    {"caching", (PyCFunction)SbkQFileInfoFunc_caching, METH_NOARGS},
    {"canonicalFilePath", (PyCFunction)SbkQFileInfoFunc_canonicalFilePath, METH_NOARGS},
    {"canonicalPath", (PyCFunction)SbkQFileInfoFunc_canonicalPath, METH_NOARGS},
    {"completeBaseName", (PyCFunction)SbkQFileInfoFunc_completeBaseName, METH_NOARGS},
    {"completeSuffix", (PyCFunction)SbkQFileInfoFunc_completeSuffix, METH_NOARGS},
    {"created", (PyCFunction)SbkQFileInfoFunc_created, METH_NOARGS},
    {"dir", (PyCFunction)SbkQFileInfoFunc_dir, METH_NOARGS},
    {"exists", (PyCFunction)SbkQFileInfoFunc_exists, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQFileInfoFunc_fileName, METH_NOARGS},
    {"filePath", (PyCFunction)SbkQFileInfoFunc_filePath, METH_NOARGS},
    {"group", (PyCFunction)SbkQFileInfoFunc_group, METH_NOARGS},
    {"groupId", (PyCFunction)SbkQFileInfoFunc_groupId, METH_NOARGS},
    {"isAbsolute", (PyCFunction)SbkQFileInfoFunc_isAbsolute, METH_NOARGS},
    {"isBundle", (PyCFunction)SbkQFileInfoFunc_isBundle, METH_NOARGS},
    {"isDir", (PyCFunction)SbkQFileInfoFunc_isDir, METH_NOARGS},
    {"isExecutable", (PyCFunction)SbkQFileInfoFunc_isExecutable, METH_NOARGS},
    {"isFile", (PyCFunction)SbkQFileInfoFunc_isFile, METH_NOARGS},
    {"isHidden", (PyCFunction)SbkQFileInfoFunc_isHidden, METH_NOARGS},
    {"isReadable", (PyCFunction)SbkQFileInfoFunc_isReadable, METH_NOARGS},
    {"isRelative", (PyCFunction)SbkQFileInfoFunc_isRelative, METH_NOARGS},
    {"isRoot", (PyCFunction)SbkQFileInfoFunc_isRoot, METH_NOARGS},
    {"isSymLink", (PyCFunction)SbkQFileInfoFunc_isSymLink, METH_NOARGS},
    {"isWritable", (PyCFunction)SbkQFileInfoFunc_isWritable, METH_NOARGS},
    {"lastModified", (PyCFunction)SbkQFileInfoFunc_lastModified, METH_NOARGS},
    {"lastRead", (PyCFunction)SbkQFileInfoFunc_lastRead, METH_NOARGS},
    {"makeAbsolute", (PyCFunction)SbkQFileInfoFunc_makeAbsolute, METH_NOARGS},
    {"owner", (PyCFunction)SbkQFileInfoFunc_owner, METH_NOARGS},
    {"ownerId", (PyCFunction)SbkQFileInfoFunc_ownerId, METH_NOARGS},
    {"path", (PyCFunction)SbkQFileInfoFunc_path, METH_NOARGS},
    {"permission", (PyCFunction)SbkQFileInfoFunc_permission, METH_O},
    {"permissions", (PyCFunction)SbkQFileInfoFunc_permissions, METH_NOARGS},
    {"readLink", (PyCFunction)SbkQFileInfoFunc_readLink, METH_NOARGS},
    {"refresh", (PyCFunction)SbkQFileInfoFunc_refresh, METH_NOARGS},
    {"setCaching", (PyCFunction)SbkQFileInfoFunc_setCaching, METH_O},
    {"setFile", (PyCFunction)SbkQFileInfoFunc_setFile, METH_VARARGS},
    {"size", (PyCFunction)SbkQFileInfoFunc_size, METH_NOARGS},
    {"suffix", (PyCFunction)SbkQFileInfoFunc_suffix, METH_NOARGS},
    {"symLinkTarget", (PyCFunction)SbkQFileInfoFunc_symLinkTarget, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQFileInfo_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QFileInfo& cpp_self = *Shiboken::Converter<QFileInfo* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QFileInfo & >::isConvertible(other)) {
                // operator!=(const QFileInfo & fileinfo)
                QFileInfo* cpp_other = Shiboken::Converter<QFileInfo* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFileInfo  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<const QFileInfo & >::isConvertible(other)) {
                // operator!=(const QFileInfo & fileinfo) const
                QFileInfo* cpp_other = Shiboken::Converter<QFileInfo* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFileInfo  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QFileInfo >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QFileInfo > cpp_other_auto_ptr;
                QFileInfo* cpp_other = Shiboken::Converter<QFileInfo* >::toCpp(other);
                if (!Shiboken::Converter<QFileInfo >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QFileInfo >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQFileInfo_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QFileInfo & >::isConvertible(other)) {
                // operator==(const QFileInfo & fileinfo)
                QFileInfo* cpp_other = Shiboken::Converter<QFileInfo* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFileInfo  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<const QFileInfo & >::isConvertible(other)) {
                // operator==(const QFileInfo & fileinfo) const
                QFileInfo* cpp_other = Shiboken::Converter<QFileInfo* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFileInfo  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QFileInfo >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QFileInfo > cpp_other_auto_ptr;
                QFileInfo* cpp_other = Shiboken::Converter<QFileInfo* >::toCpp(other);
                if (!Shiboken::Converter<QFileInfo >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QFileInfo >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQFileInfo_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQFileInfo_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFileInfo_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QFileInfo",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQFileInfo_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFileInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFileInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFileInfo >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFileInfo",
    /*user_data*/           0
};
} //extern


void init_QFileInfo(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QFILEINFO_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFileInfo_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFileInfo_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFileInfo_Type));
    PyModule_AddObject(module, "QFileInfo",
        ((PyObject*)&SbkQFileInfo_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QFileInfo >("QFileInfo");
    Shiboken::TypeResolver::createObjectTypeResolver<QFileInfo >("QFileInfo*");
    Shiboken::TypeResolver::createValueTypeResolver<QFileInfo >(typeid(QFileInfo).name());
    PySide::initQtMetaType<QFileInfo >();
}

