/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qiodevice_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QIODeviceWrapper::QIODeviceWrapper() : QIODevice(), m_metaObject(0) {
    // ... middle
}

QIODeviceWrapper::QIODeviceWrapper(QObject * parent) : QIODevice(parent), m_metaObject(0) {
    // ... middle
}

bool QIODeviceWrapper::atEnd() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "atEnd"));
    if (py_override.isNull()) {
        return this->QIODevice::atEnd();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.atEnd", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QIODeviceWrapper::bytesAvailable() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesAvailable"));
    if (py_override.isNull()) {
        return this->QIODevice::bytesAvailable();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.bytesAvailable", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QIODeviceWrapper::bytesToWrite() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesToWrite"));
    if (py_override.isNull()) {
        return this->QIODevice::bytesToWrite();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.bytesToWrite", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QIODeviceWrapper::canReadLine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "canReadLine"));
    if (py_override.isNull()) {
        return this->QIODevice::canReadLine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.canReadLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QIODeviceWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QIODeviceWrapper::close()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::close();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QIODeviceWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QIODeviceWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QIODeviceWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QIODeviceWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QIODeviceWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QIODeviceWrapper::isSequential() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isSequential"));
    if (py_override.isNull()) {
        return this->QIODevice::isSequential();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.isSequential", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QIODeviceWrapper::open(QFlags<QIODevice::OpenModeFlag> mode)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::open(mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QIODeviceWrapper::pos() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pos"));
    if (py_override.isNull()) {
        return this->QIODevice::pos();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.pos", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QIODeviceWrapper::readData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readData"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QIODevice.readData()' not implemented.");
        return qint64(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.readData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QIODeviceWrapper::readLineData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readLineData"));
    if (py_override.isNull()) {
        return this->QIODevice::readLineData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.readLineData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QIODeviceWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QIODevice::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.reset", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QIODeviceWrapper::seek(qint64 pos)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::seek(pos);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(pos)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.seek", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QIODeviceWrapper::size() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "size"));
    if (py_override.isNull()) {
        return this->QIODevice::size();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.size", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

void QIODeviceWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QIODeviceWrapper::waitForBytesWritten(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForBytesWritten"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::waitForBytesWritten(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.waitForBytesWritten", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QIODeviceWrapper::waitForReadyRead(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForReadyRead"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::waitForReadyRead(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.waitForReadyRead", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QIODeviceWrapper::writeData(const char * data, qint64 len)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "writeData"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QIODevice.writeData()' not implemented.");
        return qint64(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<const char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(len)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIODevice.writeData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QIODeviceWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QIODevice::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QIODeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QIODevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QIODeviceWrapper::~QIODeviceWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQIODevice_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QIODevice >()))
        return -1;

    QIODeviceWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QIODevice' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QIODevice", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QIODevice()
    // 1: QIODevice(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QIODevice()
    } else if (numArgs == 1 && Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 1; // QIODevice(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODevice_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QIODevice()
            {

                if(!PyErr_Occurred()) {
                // QIODevice()
                cptr = new QIODeviceWrapper();
                }
                break;
            }
            case 1: // QIODevice(QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QIODevice(QObject*)
                cptr = new QIODeviceWrapper(cpp_arg0);
                Shiboken::setParent(arg, self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QIODevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQIODevice_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQIODevice_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QIODevice", overloads);
        return -1;
}

static PyObject* SbkQIODeviceFunc_atEnd(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QIODevice::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_bytesAvailable(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesAvailable()const
            qint64 cppResult = cppSelf->QIODevice::bytesAvailable();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_bytesToWrite(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesToWrite()const
            qint64 cppResult = cppSelf->QIODevice::bytesToWrite();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_canReadLine(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canReadLine()const
            bool cppResult = cppSelf->QIODevice::canReadLine();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_close(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // close()
            threadStateSaver.save();
            cppSelf->QIODevice::close();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQIODeviceFunc_errorString(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QIODevice::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_getChar(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getChar(char*)
            // Begin code injection
            
            // TEMPLATE - fix_char* - START
            char val_;
            bool retval_ = cppSelf->getChar(&val_);
            pyResult = Shiboken::makeTuple(retval_, val_);
            // TEMPLATE - fix_char* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_isOpen(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isOpen()const
            bool cppResult = cppSelf->QIODevice::isOpen();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_isReadable(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isReadable()const
            bool cppResult = cppSelf->QIODevice::isReadable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_isSequential(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSequential()const
            bool cppResult = cppSelf->QIODevice::isSequential();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_isTextModeEnabled(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isTextModeEnabled()const
            bool cppResult = cppSelf->QIODevice::isTextModeEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_isWritable(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWritable()const
            bool cppResult = cppSelf->QIODevice::isWritable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_open(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: open(QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(arg)) {
        overloadId = 0; // open(QFlags<QIODevice::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_open_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QFlags<QIODevice::OpenModeFlag> cpp_arg0 = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // open(QFlags<QIODevice::OpenModeFlag>)
            threadStateSaver.save();
            bool cppResult = cppSelf->QIODevice::open(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_open_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice.OpenMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.open", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_openMode(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // openMode()const
            QFlags<QIODevice::OpenModeFlag> cppResult = cppSelf->QIODevice::openMode();
            pyResult = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_peek(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: peek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // peek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_peek_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // peek(qint64)
            threadStateSaver.save();
            QByteArray cppResult = cppSelf->QIODevice::peek(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_peek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.peek", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_pos(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            qint64 cppResult = cppSelf->QIODevice::pos();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_putChar(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: putChar(char)
    if (Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // putChar(char)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_putChar_TypeError;

    // Call function/method
    {
        {
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // putChar(char)
            bool cppResult = cppSelf->QIODevice::putChar(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_putChar_TypeError:
        const char* overloads[] = {"char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.putChar", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_read(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_read_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // read(qint64)
            QByteArray cppResult = cppSelf->QIODevice::read(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_read_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.read", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_readAll(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // readAll()
            threadStateSaver.save();
            QByteArray cppResult = cppSelf->QIODevice::readAll();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_readData(PyObject* self, PyObject* args)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_readData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readData(char*,qint64)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QIODevice.readData()' not implemented.");
                return 0;
            }
            qint64 cppResult = cppSelf->readData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_readData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QIODevice.readData", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_readLine(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "maxlen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QIODevice.readLine(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QIODevice.readLine(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:readLine", &arg))
        return 0;


    // Overloaded function decisor
    // 0: readLine(qint64)
    if (numArgs == 0) {
        overloadId = 0; // readLine(qint64)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // readLine(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_readLine_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "maxlen");
                if (value) {
                    if (arg)
                        errorArgName = "maxlen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QIODevice.readLine(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qint64 cpp_arg0 = arg ? Shiboken::Converter<qint64 >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // readLine(qint64)
            QByteArray cppResult = cppSelf->QIODevice::readLine(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_readLine_TypeError:
        const char* overloads[] = {"long long = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.readLine", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_readLineData(PyObject* self, PyObject* args)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readLineData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readLineData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readLineData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_readLineData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readLineData(char*,qint64)
            qint64 cppResult = cppSelf->QIODevice::readLineData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_readLineData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QIODevice.readLineData", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_reset(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            bool cppResult = cppSelf->QIODevice::reset();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_seek(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_seek_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // seek(qint64)
            threadStateSaver.save();
            bool cppResult = cppSelf->QIODevice::seek(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.seek", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_setErrorString(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setErrorString(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setErrorString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_setErrorString_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setErrorString(QString)
            cppSelf->QIODevice::setErrorString(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIODeviceFunc_setErrorString_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.setErrorString", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_setOpenMode(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpenMode(QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(arg)) {
        overloadId = 0; // setOpenMode(QFlags<QIODevice::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_setOpenMode_TypeError;

    // Call function/method
    {
        {
            QFlags<QIODevice::OpenModeFlag> cpp_arg0 = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOpenMode(QFlags<QIODevice::OpenModeFlag>)
            cppSelf->QIODevice::setOpenMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIODeviceFunc_setOpenMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice.OpenMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.setOpenMode", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_setTextModeEnabled(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextModeEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextModeEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_setTextModeEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextModeEnabled(bool)
            cppSelf->QIODevice::setTextModeEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIODeviceFunc_setTextModeEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.setTextModeEnabled", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_size(PyObject* self)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            qint64 cppResult = cppSelf->QIODevice::size();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIODeviceFunc_ungetChar(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: ungetChar(char)
    if (Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // ungetChar(char)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_ungetChar_TypeError;

    // Call function/method
    {
        {
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // ungetChar(char)
            cppSelf->QIODevice::ungetChar(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIODeviceFunc_ungetChar_TypeError:
        const char* overloads[] = {"char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.ungetChar", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_waitForBytesWritten(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: waitForBytesWritten(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_waitForBytesWritten_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // waitForBytesWritten(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QIODevice::waitForBytesWritten(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_waitForBytesWritten_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.waitForBytesWritten", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_waitForReadyRead(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: waitForReadyRead(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_waitForReadyRead_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // waitForReadyRead(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QIODevice::waitForReadyRead(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_waitForReadyRead_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.waitForReadyRead", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_write(PyObject* self, PyObject* arg)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: write(QByteArray)
    // 1: write(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 1; // write(const char*)
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // write(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_write_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // write(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // write(QByteArray)
                threadStateSaver.save();
                qint64 cppResult = cppSelf->QIODevice::write(*cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<long long >::toPython(cppResult);
                }
                break;
            }
            case 1: // write(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // write(const char*)
                qint64 cppResult = cppSelf->QIODevice::write(cpp_arg0);
                pyResult = Shiboken::Converter<long long >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QIODevice.write", overloads);
        return 0;
}

static PyObject* SbkQIODeviceFunc_writeData(PyObject* self, PyObject* args)
{
    QIODevice* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIODevice* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeData(const char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIODeviceFunc_writeData_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // writeData(const char*,qint64)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QIODevice.writeData()' not implemented.");
                return 0;
            }
            qint64 cppResult = cppSelf->writeData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIODeviceFunc_writeData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QIODevice.writeData", overloads);
        return 0;
}

static PyMethodDef SbkQIODevice_methods[] = {
    {"atEnd", (PyCFunction)SbkQIODeviceFunc_atEnd, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)SbkQIODeviceFunc_bytesAvailable, METH_NOARGS},
    {"bytesToWrite", (PyCFunction)SbkQIODeviceFunc_bytesToWrite, METH_NOARGS},
    {"canReadLine", (PyCFunction)SbkQIODeviceFunc_canReadLine, METH_NOARGS},
    {"close", (PyCFunction)SbkQIODeviceFunc_close, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQIODeviceFunc_errorString, METH_NOARGS},
    {"getChar", (PyCFunction)SbkQIODeviceFunc_getChar, METH_NOARGS},
    {"isOpen", (PyCFunction)SbkQIODeviceFunc_isOpen, METH_NOARGS},
    {"isReadable", (PyCFunction)SbkQIODeviceFunc_isReadable, METH_NOARGS},
    {"isSequential", (PyCFunction)SbkQIODeviceFunc_isSequential, METH_NOARGS},
    {"isTextModeEnabled", (PyCFunction)SbkQIODeviceFunc_isTextModeEnabled, METH_NOARGS},
    {"isWritable", (PyCFunction)SbkQIODeviceFunc_isWritable, METH_NOARGS},
    {"open", (PyCFunction)SbkQIODeviceFunc_open, METH_O},
    {"openMode", (PyCFunction)SbkQIODeviceFunc_openMode, METH_NOARGS},
    {"peek", (PyCFunction)SbkQIODeviceFunc_peek, METH_O},
    {"pos", (PyCFunction)SbkQIODeviceFunc_pos, METH_NOARGS},
    {"putChar", (PyCFunction)SbkQIODeviceFunc_putChar, METH_O},
    {"read", (PyCFunction)SbkQIODeviceFunc_read, METH_O},
    {"readAll", (PyCFunction)SbkQIODeviceFunc_readAll, METH_NOARGS},
    {"readData", (PyCFunction)SbkQIODeviceFunc_readData, METH_VARARGS},
    {"readLine", (PyCFunction)SbkQIODeviceFunc_readLine, METH_VARARGS|METH_KEYWORDS},
    {"readLineData", (PyCFunction)SbkQIODeviceFunc_readLineData, METH_VARARGS},
    {"reset", (PyCFunction)SbkQIODeviceFunc_reset, METH_NOARGS},
    {"seek", (PyCFunction)SbkQIODeviceFunc_seek, METH_O},
    {"setErrorString", (PyCFunction)SbkQIODeviceFunc_setErrorString, METH_O},
    {"setOpenMode", (PyCFunction)SbkQIODeviceFunc_setOpenMode, METH_O},
    {"setTextModeEnabled", (PyCFunction)SbkQIODeviceFunc_setTextModeEnabled, METH_O},
    {"size", (PyCFunction)SbkQIODeviceFunc_size, METH_NOARGS},
    {"ungetChar", (PyCFunction)SbkQIODeviceFunc_ungetChar, METH_O},
    {"waitForBytesWritten", (PyCFunction)SbkQIODeviceFunc_waitForBytesWritten, METH_O},
    {"waitForReadyRead", (PyCFunction)SbkQIODeviceFunc_waitForReadyRead, METH_O},
    {"write", (PyCFunction)SbkQIODeviceFunc_write, METH_O},
    {"writeData", (PyCFunction)SbkQIODeviceFunc_writeData, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQIODevice_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QIODevice",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQIODevice_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQIODevice_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QIODevice >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QIODevice*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQIODevice_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QIODevice*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQIODevice_Type;
    return 0;
}

PyObject* SbkPySide_QtCore_QIODevice_OpenModeFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QIODevice::OpenMode >::checkType(self) && Shiboken::Converter<QIODevice::OpenMode >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QIODevice::OpenMode >::toPython(
        Shiboken::Converter<QIODevice::OpenMode>::toCpp(self)
        & Shiboken::Converter< QIODevice::OpenMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QIODevice_OpenModeFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QIODevice::OpenMode >::checkType(self) && Shiboken::Converter<QIODevice::OpenMode >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QIODevice::OpenMode >::toPython(
        Shiboken::Converter<QIODevice::OpenMode>::toCpp(self)
        | Shiboken::Converter< QIODevice::OpenMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QIODevice_OpenModeFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QIODevice::OpenMode >::checkType(self) && Shiboken::Converter<QIODevice::OpenMode >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QIODevice::OpenMode >::toPython(
        Shiboken::Converter<QIODevice::OpenMode>::toCpp(self)
        ^ Shiboken::Converter< QIODevice::OpenMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QIODevice_OpenModeFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QIODevice::OpenMode >::toPython(
        ~Shiboken::Converter<QIODevice::OpenMode >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QIODevice_OpenModeFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QIODevice_OpenModeFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QIODevice_OpenModeFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QIODevice_OpenModeFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QIODevice_OpenModeFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtCore_QIODevice_OpenModeFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QIODevice_OpenModeFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QIODevice_OpenModeFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "OpenModeFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtCore_QIODevice_OpenModeFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QIODevice_OpenModeFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QIODevice_OpenModeFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QIODevice_OpenModeFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QIODevice_OpenMode_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "OpenMode",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QIODevice(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQIODevice_Type);

    SbkQIODevice_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQIODevice_Type.type_discovery = &SbkQIODevice_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQIODevice_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQIODevice_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQIODevice_Type));
    PyModule_AddObject(module, "QIODevice",
        ((PyObject*)&SbkQIODevice_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: OpenModeFlag
    SbkPySide_QtCoreTypes[SBK_QIODEVICE_OPENMODEFLAG_IDX] = &SbkPySide_QtCore_QIODevice_OpenModeFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type);
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
            "OpenModeFlag",((PyObject*)&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type));

    // init flags class: QFlags<QIODevice::OpenModeFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QIODEVICE_OPENMODEFLAG__IDX] = &SbkPySide_QtCore_QIODevice_OpenMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QIODevice_OpenMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QIODevice_OpenMode_Type);
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
            "OpenMode",((PyObject*)&SbkPySide_QtCore_QIODevice_OpenMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::NotOpen, "NotOpen");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "NotOpen", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "NotOpen", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::ReadOnly, "ReadOnly");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "ReadOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "ReadOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::WriteOnly, "WriteOnly");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "WriteOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "WriteOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::ReadWrite, "ReadWrite");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "ReadWrite", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "ReadWrite", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::Append, "Append");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "Append", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "Append", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::Truncate, "Truncate");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "Truncate", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "Truncate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::Text, "Text");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "Text", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "Text", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QIODevice_OpenModeFlag_Type,
        (long) QIODevice::Unbuffered, "Unbuffered");
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict,
        "Unbuffered", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QIODevice_OpenModeFlag_Type.tp_dict,
        "Unbuffered", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QIODevice::OpenModeFlag");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("bytesWritten", "qint64", NULL);
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict, "bytesWritten", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("aboutToClose", "void", NULL);
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict, "aboutToClose", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("readChannelFinished", "void", NULL);
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict, "readChannelFinished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("readyRead", "void", NULL);
    PyDict_SetItemString(SbkQIODevice_Type.super.ht_type.tp_dict, "readyRead", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QIODevice >("QIODevice*");
    Shiboken::TypeResolver::createObjectTypeResolver<QIODevice >(typeid(QIODevice).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QIODevice >(typeid(QIODeviceWrapper).name());
    PySide::initQtMetaType<QIODevice* >();
}

