/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qlibraryinfo_wrapper.h"

// Extra includes
#include <qdatetime.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQLibraryInfoFunc_buildDate(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // buildDate()
            QDate cppResult = QLibraryInfo::buildDate();
            pyResult = Shiboken::Converter<QDate >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLibraryInfoFunc_buildKey(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // buildKey()
            QString cppResult = QLibraryInfo::buildKey();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLibraryInfoFunc_licensedProducts(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // licensedProducts()
            QString cppResult = QLibraryInfo::licensedProducts();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLibraryInfoFunc_licensee(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // licensee()
            QString cppResult = QLibraryInfo::licensee();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLibraryInfoFunc_location(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: location(QLibraryInfo::LibraryLocation)
    if (Shiboken::Converter<QLibraryInfo::LibraryLocation >::isConvertible(arg)) {
        overloadId = 0; // location(QLibraryInfo::LibraryLocation)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLibraryInfoFunc_location_TypeError;

    // Call function/method
    {
        {
            QLibraryInfo::LibraryLocation cpp_arg0 = Shiboken::Converter<QLibraryInfo::LibraryLocation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // location(QLibraryInfo::LibraryLocation)
            QString cppResult = QLibraryInfo::location(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQLibraryInfoFunc_location_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLibraryInfo.LibraryLocation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLibraryInfo.location", overloads);
        return 0;
}

static PyMethodDef SbkQLibraryInfo_methods[] = {
    {"buildDate", (PyCFunction)SbkQLibraryInfoFunc_buildDate, METH_NOARGS|METH_STATIC},
    {"buildKey", (PyCFunction)SbkQLibraryInfoFunc_buildKey, METH_NOARGS|METH_STATIC},
    {"licensedProducts", (PyCFunction)SbkQLibraryInfoFunc_licensedProducts, METH_NOARGS|METH_STATIC},
    {"licensee", (PyCFunction)SbkQLibraryInfoFunc_licensee, METH_NOARGS|METH_STATIC},
    {"location", (PyCFunction)SbkQLibraryInfoFunc_location, METH_O|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQLibraryInfo_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QLibraryInfo",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQLibraryInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QLibraryInfo >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QLibraryInfo*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QLibraryInfo_LibraryLocation_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QLibraryInfo_LibraryLocation_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "LibraryLocation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QLibraryInfo_LibraryLocation_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QLibraryInfo_LibraryLocation_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QLibraryInfo_LibraryLocation_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QLibraryInfo(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QLIBRARYINFO_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQLibraryInfo_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQLibraryInfo_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQLibraryInfo_Type));
    PyModule_AddObject(module, "QLibraryInfo",
        ((PyObject*)&SbkQLibraryInfo_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: LibraryLocation
    SbkPySide_QtCoreTypes[SBK_QLIBRARYINFO_LIBRARYLOCATION_IDX] = &SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type);
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
            "LibraryLocation",((PyObject*)&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::PrefixPath, "PrefixPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "PrefixPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "PrefixPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::DocumentationPath, "DocumentationPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "DocumentationPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "DocumentationPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::HeadersPath, "HeadersPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "HeadersPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "HeadersPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::LibrariesPath, "LibrariesPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "LibrariesPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "LibrariesPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::BinariesPath, "BinariesPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "BinariesPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "BinariesPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::PluginsPath, "PluginsPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "PluginsPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "PluginsPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::DataPath, "DataPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "DataPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "DataPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::TranslationsPath, "TranslationsPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "TranslationsPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "TranslationsPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::SettingsPath, "SettingsPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "SettingsPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "SettingsPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::DemosPath, "DemosPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "DemosPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "DemosPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::ExamplesPath, "ExamplesPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "ExamplesPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "ExamplesPath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type,
        (long) QLibraryInfo::ImportsPath, "ImportsPath");
    PyDict_SetItemString(SbkQLibraryInfo_Type.super.ht_type.tp_dict,
        "ImportsPath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLibraryInfo_LibraryLocation_Type.tp_dict,
        "ImportsPath", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLibraryInfo::LibraryLocation");


    Shiboken::TypeResolver::createObjectTypeResolver<QLibraryInfo >("QLibraryInfo*");
    Shiboken::TypeResolver::createObjectTypeResolver<QLibraryInfo >(typeid(QLibraryInfo).name());
    PySide::initQtMetaType<QLibraryInfo* >();
}

