/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qlinef_wrapper.h"

// Extra includes
#include <qline.h>
#include <qpoint.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQLineF_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QLineF >()))
        return -1;

    QLineF* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQLineF_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QLineF", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QLineF(QLineF)
    // 1: QLineF()
    // 2: QLineF(QLine)
    // 3: QLineF(QPointF,QPointF)
    // 4: QLineF(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 1; // QLineF()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 4; // QLineF(qreal,qreal,qreal,qreal)
    } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 3; // QLineF(QPointF,QPointF)
    } else if (numArgs == 1 && Shiboken::Converter<const QLine & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QLineF(QLine)
    } else if (numArgs == 1 && Shiboken::Converter<const QLineF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QLineF(QLineF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineF_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QLineF(QLineF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QLineF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QLineF(QLineF)
                cptr = new QLineF(*cpp_arg0);
                }
                break;
            }
            case 1: // QLineF()
            {

                if(!PyErr_Occurred()) {
                // QLineF()
                cptr = new QLineF();
                }
                break;
            }
            case 2: // QLineF(QLine)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QLineF(QLine)
                cptr = new QLineF(*cpp_arg0);
                }
                break;
            }
            case 3: // QLineF(QPointF,QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QLineF(QPointF,QPointF)
                cptr = new QLineF(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // QLineF(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // QLineF(qreal,qreal,qreal,qreal)
                cptr = new QLineF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QLineF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQLineF_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQLineF_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLineF", "", "PySide.QtCore.QLine", "PySide.QtCore.QPointF, PySide.QtCore.QPointF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLineF", overloads);
        return -1;
}

static PyObject* SbkQLineFFunc_angle(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: angle()const
    // 1: angle(QLineF)const
    if (numArgs == 0) {
        overloadId = 0; // angle()const
    } else if (Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 1; // angle(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_angle_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // angle()const
            {

                if(!PyErr_Occurred()) {
                // angle()const
                qreal cppResult = cppSelf->QLineF::angle();
                pyResult = Shiboken::Converter<double >::toPython(cppResult);
                }
                break;
            }
            case 1: // angle(QLineF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
                if (!Shiboken::Converter<QLineF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // angle(QLineF)const
                qreal cppResult = cppSelf->QLineF::angle(*cpp_arg0);
                pyResult = Shiboken::Converter<double >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQLineFFunc_angle_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QLineF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.angle", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_angleTo(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: angleTo(QLineF)const
    if (Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 0; // angleTo(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_angleTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
            QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
            if (!Shiboken::Converter<QLineF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // angleTo(QLineF)const
            qreal cppResult = cppSelf->QLineF::angleTo(*cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQLineFFunc_angleTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLineF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.angleTo", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_dx(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dx()const
            qreal cppResult = cppSelf->QLineF::dx();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_dy(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dy()const
            qreal cppResult = cppSelf->QLineF::dy();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_fromPolar(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromPolar", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromPolar(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // fromPolar(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_fromPolar_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // fromPolar(qreal,qreal)
            QLineF cppResult = QLineF::fromPolar(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQLineFFunc_fromPolar_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLineF.fromPolar", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_intersect(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersect(QLineF,QPointF*)const
    if (Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 0; // intersect(QLineF,QPointF*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_intersect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
            QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
            if (!Shiboken::Converter<QLineF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // intersect(QLineF,QPointF*)const
            // Begin code injection
            
            QPointF p;
            QLineF::IntersectType retval = cppSelf->intersect(*cpp_arg0, &p);
            pyResult = Shiboken::makeTuple(retval, p);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQLineFFunc_intersect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLineF, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.intersect", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_isNull(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QLineF::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_length(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            qreal cppResult = cppSelf->QLineF::length();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_normalVector(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalVector()const
            QLineF cppResult = cppSelf->QLineF::normalVector();
            pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_p1(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // p1()const
            QPointF cppResult = cppSelf->QLineF::p1();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_p2(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // p2()const
            QPointF cppResult = cppSelf->QLineF::p2();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_pointAt(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pointAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // pointAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_pointAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // pointAt(qreal)const
            QPointF cppResult = cppSelf->QLineF::pointAt(cpp_arg0);
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQLineFFunc_pointAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.pointAt", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_setAngle(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_setAngle_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAngle(qreal)
            cppSelf->QLineF::setAngle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQLineFFunc_setAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.setAngle", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_setLength(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLength(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLength(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_setLength_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLength(qreal)
            cppSelf->QLineF::setLength(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQLineFFunc_setLength_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.setLength", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_setLine(PyObject* self, PyObject* args)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setLine", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setLine(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // setLine(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_setLine_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // setLine(qreal,qreal,qreal,qreal)
            cppSelf->QLineF::setLine(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQLineFFunc_setLine_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLineF.setLine", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_setP1(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setP1(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setP1(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_setP1_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setP1(QPointF)
            cppSelf->QLineF::setP1(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQLineFFunc_setP1_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.setP1", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_setP2(PyObject* self, PyObject* arg)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setP2(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setP2(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_setP2_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setP2(QPointF)
            cppSelf->QLineF::setP2(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQLineFFunc_setP2_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QLineF.setP2", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_setPoints(PyObject* self, PyObject* args)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPoints", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPoints(QPointF,QPointF)
    if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPoints(QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_setPoints_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
            QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setPoints(QPointF,QPointF)
            cppSelf->QLineF::setPoints(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQLineFFunc_setPoints_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLineF.setPoints", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_toLine(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toLine()const
            QLine cppResult = cppSelf->QLineF::toLine();
            pyResult = Shiboken::Converter<QLine >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_translate(PyObject* self, PyObject* args)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPointF)
    // 1: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translate(QPointF)
                cppSelf->QLineF::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                cppSelf->QLineF::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQLineFFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLineF.translate", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_translated(PyObject* self, PyObject* args)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPointF)const
    // 1: translated(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQLineFFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translated(QPointF)const
                QLineF cppResult = cppSelf->QLineF::translated(*cpp_arg0);
                pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translated(qreal,qreal)const
                QLineF cppResult = cppSelf->QLineF::translated(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQLineFFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QLineF.translated", overloads);
        return 0;
}

static PyObject* SbkQLineFFunc_unitVector(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unitVector()const
            QLineF cppResult = cppSelf->QLineF::unitVector();
            pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_x1(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x1()const
            qreal cppResult = cppSelf->QLineF::x1();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_x2(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x2()const
            qreal cppResult = cppSelf->QLineF::x2();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_y1(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y1()const
            qreal cppResult = cppSelf->QLineF::y1();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQLineFFunc_y2(PyObject* self)
{
    QLineF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QLineF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y2()const
            qreal cppResult = cppSelf->QLineF::y2();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQLineF_methods[] = {
    {"angle", (PyCFunction)SbkQLineFFunc_angle, METH_NOARGS|METH_O},
    {"angleTo", (PyCFunction)SbkQLineFFunc_angleTo, METH_O},
    {"dx", (PyCFunction)SbkQLineFFunc_dx, METH_NOARGS},
    {"dy", (PyCFunction)SbkQLineFFunc_dy, METH_NOARGS},
    {"fromPolar", (PyCFunction)SbkQLineFFunc_fromPolar, METH_VARARGS|METH_STATIC},
    {"intersect", (PyCFunction)SbkQLineFFunc_intersect, METH_O},
    {"isNull", (PyCFunction)SbkQLineFFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)SbkQLineFFunc_length, METH_NOARGS},
    {"normalVector", (PyCFunction)SbkQLineFFunc_normalVector, METH_NOARGS},
    {"p1", (PyCFunction)SbkQLineFFunc_p1, METH_NOARGS},
    {"p2", (PyCFunction)SbkQLineFFunc_p2, METH_NOARGS},
    {"pointAt", (PyCFunction)SbkQLineFFunc_pointAt, METH_O},
    {"setAngle", (PyCFunction)SbkQLineFFunc_setAngle, METH_O},
    {"setLength", (PyCFunction)SbkQLineFFunc_setLength, METH_O},
    {"setLine", (PyCFunction)SbkQLineFFunc_setLine, METH_VARARGS},
    {"setP1", (PyCFunction)SbkQLineFFunc_setP1, METH_O},
    {"setP2", (PyCFunction)SbkQLineFFunc_setP2, METH_O},
    {"setPoints", (PyCFunction)SbkQLineFFunc_setPoints, METH_VARARGS},
    {"toLine", (PyCFunction)SbkQLineFFunc_toLine, METH_NOARGS},
    {"translate", (PyCFunction)SbkQLineFFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)SbkQLineFFunc_translated, METH_VARARGS},
    {"unitVector", (PyCFunction)SbkQLineFFunc_unitVector, METH_NOARGS},
    {"x1", (PyCFunction)SbkQLineFFunc_x1, METH_NOARGS},
    {"x2", (PyCFunction)SbkQLineFFunc_x2, METH_NOARGS},
    {"y1", (PyCFunction)SbkQLineFFunc_y1, METH_NOARGS},
    {"y2", (PyCFunction)SbkQLineFFunc_y2, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQLineF_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QLineF& cpp_self = *Shiboken::Converter<QLineF* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QLineF & >::isConvertible(other)) {
                // operator!=(const QLineF & d) const
                QLineF* cpp_other = Shiboken::Converter<QLineF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QLineF  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QLineF >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QLineF > cpp_other_auto_ptr;
                QLineF* cpp_other = Shiboken::Converter<QLineF* >::toCpp(other);
                if (!Shiboken::Converter<QLineF >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QLineF >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQLineF_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QLineF & >::isConvertible(other)) {
                // operator==(const QLineF & d) const
                QLineF* cpp_other = Shiboken::Converter<QLineF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QLineF  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QLineF >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QLineF > cpp_other_auto_ptr;
                QLineF* cpp_other = Shiboken::Converter<QLineF* >::toCpp(other);
                if (!Shiboken::Converter<QLineF >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QLineF >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQLineF_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQLineF_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQLineF_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QLineF",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQLineF_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQLineF_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQLineF_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QLineF >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QLineF",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QLineF_IntersectType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QLineF_IntersectType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QLineF_IntersectType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "IntersectType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QLineF_IntersectType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QLineF_IntersectType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QLineF_IntersectType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QLineF(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QLINEF_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQLineF_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQLineF_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQLineF_Type));
    PyModule_AddObject(module, "QLineF",
        ((PyObject*)&SbkQLineF_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: IntersectType
    SbkPySide_QtCoreTypes[SBK_QLINEF_INTERSECTTYPE_IDX] = &SbkPySide_QtCore_QLineF_IntersectType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QLineF_IntersectType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QLineF_IntersectType_Type);
    PyDict_SetItemString(SbkQLineF_Type.super.ht_type.tp_dict,
            "IntersectType",((PyObject*)&SbkPySide_QtCore_QLineF_IntersectType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLineF_IntersectType_Type,
        (long) QLineF::NoIntersection, "NoIntersection");
    PyDict_SetItemString(SbkQLineF_Type.super.ht_type.tp_dict,
        "NoIntersection", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLineF_IntersectType_Type.tp_dict,
        "NoIntersection", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLineF_IntersectType_Type,
        (long) QLineF::BoundedIntersection, "BoundedIntersection");
    PyDict_SetItemString(SbkQLineF_Type.super.ht_type.tp_dict,
        "BoundedIntersection", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLineF_IntersectType_Type.tp_dict,
        "BoundedIntersection", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QLineF_IntersectType_Type,
        (long) QLineF::UnboundedIntersection, "UnboundedIntersection");
    PyDict_SetItemString(SbkQLineF_Type.super.ht_type.tp_dict,
        "UnboundedIntersection", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QLineF_IntersectType_Type.tp_dict,
        "UnboundedIntersection", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLineF::IntersectType");


    Shiboken::TypeResolver::createValueTypeResolver<QLineF >("QLineF");
    Shiboken::TypeResolver::createObjectTypeResolver<QLineF >("QLineF*");
    Shiboken::TypeResolver::createValueTypeResolver<QLineF >(typeid(QLineF).name());
    PySide::initQtMetaType<QLineF >();
}

