/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmargins_wrapper.h"

// Extra includes

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMargins_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMargins >()))
        return -1;

    QMargins* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQMargins_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QMargins", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QMargins(QMargins)
    // 1: QMargins()
    // 2: QMargins(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 1; // QMargins()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // QMargins(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QMargins & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QMargins(QMargins)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMargins_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMargins(QMargins)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QMargins* cpp_arg0 = Shiboken::Converter<QMargins* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QMargins(QMargins)
                cptr = new QMargins(*cpp_arg0);
                }
                break;
            }
            case 1: // QMargins()
            {

                if(!PyErr_Occurred()) {
                // QMargins()
                cptr = new QMargins();
                }
                break;
            }
            case 2: // QMargins(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // QMargins(int,int,int,int)
                cptr = new QMargins(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMargins >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMargins_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQMargins_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMargins", "", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMargins", overloads);
        return -1;
}

static PyObject* SbkQMarginsFunc_bottom(PyObject* self)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottom()const
            int cppResult = cppSelf->QMargins::bottom();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMarginsFunc_isNull(PyObject* self)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QMargins::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMarginsFunc_left(PyObject* self)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // left()const
            int cppResult = cppSelf->QMargins::left();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMarginsFunc_right(PyObject* self)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // right()const
            int cppResult = cppSelf->QMargins::right();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMarginsFunc_setBottom(PyObject* self, PyObject* arg)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottom(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottom(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMarginsFunc_setBottom_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBottom(int)
            cppSelf->QMargins::setBottom(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMarginsFunc_setBottom_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMargins.setBottom", overloads);
        return 0;
}

static PyObject* SbkQMarginsFunc_setLeft(PyObject* self, PyObject* arg)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeft(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeft(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMarginsFunc_setLeft_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLeft(int)
            cppSelf->QMargins::setLeft(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMarginsFunc_setLeft_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMargins.setLeft", overloads);
        return 0;
}

static PyObject* SbkQMarginsFunc_setRight(PyObject* self, PyObject* arg)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMarginsFunc_setRight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRight(int)
            cppSelf->QMargins::setRight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMarginsFunc_setRight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMargins.setRight", overloads);
        return 0;
}

static PyObject* SbkQMarginsFunc_setTop(PyObject* self, PyObject* arg)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTop(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTop(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMarginsFunc_setTop_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTop(int)
            cppSelf->QMargins::setTop(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMarginsFunc_setTop_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMargins.setTop", overloads);
        return 0;
}

static PyObject* SbkQMarginsFunc_top(PyObject* self)
{
    QMargins* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMargins* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // top()const
            int cppResult = cppSelf->QMargins::top();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQMargins_methods[] = {
    {"bottom", (PyCFunction)SbkQMarginsFunc_bottom, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQMarginsFunc_isNull, METH_NOARGS},
    {"left", (PyCFunction)SbkQMarginsFunc_left, METH_NOARGS},
    {"right", (PyCFunction)SbkQMarginsFunc_right, METH_NOARGS},
    {"setBottom", (PyCFunction)SbkQMarginsFunc_setBottom, METH_O},
    {"setLeft", (PyCFunction)SbkQMarginsFunc_setLeft, METH_O},
    {"setRight", (PyCFunction)SbkQMarginsFunc_setRight, METH_O},
    {"setTop", (PyCFunction)SbkQMarginsFunc_setTop, METH_O},
    {"top", (PyCFunction)SbkQMarginsFunc_top, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQMargins_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QMargins& cpp_self = *Shiboken::Converter<QMargins* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QMargins & >::isConvertible(other)) {
                // operator!=(const QMargins & m2)
                QMargins* cpp_other = Shiboken::Converter<QMargins* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QMargins  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQMargins_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QMargins & >::isConvertible(other)) {
                // operator==(const QMargins & m2)
                QMargins* cpp_other = Shiboken::Converter<QMargins* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QMargins  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQMargins_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQMargins_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMargins_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QMargins",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQMargins_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMargins_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMargins_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMargins >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMargins",
    /*user_data*/           0
};
} //extern


void init_QMargins(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMARGINS_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMargins_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMargins_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMargins_Type));
    PyModule_AddObject(module, "QMargins",
        ((PyObject*)&SbkQMargins_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QMargins >("QMargins");
    Shiboken::TypeResolver::createObjectTypeResolver<QMargins >("QMargins*");
    Shiboken::TypeResolver::createValueTypeResolver<QMargins >(typeid(QMargins).name());
    PySide::initQtMetaType<QMargins >();
}

