/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmetamethod_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMetaMethod_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMetaMethod >()))
        return -1;

    QMetaMethod* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QMetaMethod", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QMetaMethod(QMetaMethod)
    // 1: QMetaMethod()
    if (numArgs == 0) {
        overloadId = 1; // QMetaMethod()
    } else if (numArgs == 1 && Shiboken::Converter<const QMetaMethod & >::isConvertible(arg)) {
        overloadId = 0; // QMetaMethod(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaMethod_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMetaMethod(QMetaMethod)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QMetaMethod* cpp_arg0 = Shiboken::Converter<QMetaMethod* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QMetaMethod(QMetaMethod)
                cptr = new QMetaMethod(*cpp_arg0);
                }
                break;
            }
            case 1: // QMetaMethod()
            {

                if(!PyErr_Occurred()) {
                // QMetaMethod()
                cptr = new QMetaMethod();
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMetaMethod >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMetaMethod_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQMetaMethod_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMetaMethod", "", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaMethod", overloads);
        return -1;
}

static PyObject* SbkQMetaMethodFunc_access(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // access()const
            QMetaMethod::Access cppResult = cppSelf->QMetaMethod::access();
            pyResult = Shiboken::Converter<QMetaMethod::Access >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_attributes(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // attributes()const
            int cppResult = cppSelf->QMetaMethod::attributes();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_enclosingMetaObject(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // enclosingMetaObject()const
            const QMetaObject * cppResult = cppSelf->QMetaMethod::enclosingMetaObject();
            pyResult = Shiboken::Converter< QMetaObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_invoke(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "val0", "val1", "val2", "val3", "val4", "val5", "val6", "val7", "val8", "val9" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 10, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaMethod.invoke(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 13) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaMethod.invoke(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaMethod.invoke(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOOOOOOO:invoke", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9]), &(pyargs[10]), &(pyargs[11]), &(pyargs[12])))
        return 0;


    // Overloaded function decisor
    // 0: invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    // 1: invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    // 2: invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    // 3: invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
        } else if (Shiboken::Converter<Qt::ConnectionType >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (Shiboken::Converter<QGenericReturnArgument >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                            if (numArgs == 6) {
                                overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                                if (numArgs == 7) {
                                    overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                    if (numArgs == 8) {
                                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                        if (numArgs == 9) {
                                            overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                            if (numArgs == 10) {
                                                overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                                if (numArgs == 11) {
                                                    overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[11])) {
                                                    if (numArgs == 12) {
                                                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[12])) {
                                                        overloadId = 3; // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                            if (numArgs == 6) {
                                overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                                if (numArgs == 7) {
                                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                    if (numArgs == 8) {
                                        overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                        if (numArgs == 9) {
                                            overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                            if (numArgs == 10) {
                                                overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                                if (numArgs == 11) {
                                                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[11])) {
                                                    overloadId = 2; // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (Shiboken::Converter<QGenericReturnArgument >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                            if (numArgs == 6) {
                                overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                                if (numArgs == 7) {
                                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                    if (numArgs == 8) {
                                        overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                        if (numArgs == 9) {
                                            overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                            if (numArgs == 10) {
                                                overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                                if (numArgs == 11) {
                                                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[11])) {
                                                    overloadId = 1; // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                            if (numArgs == 6) {
                                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                                if (numArgs == 7) {
                                    overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                    if (numArgs == 8) {
                                        overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                        if (numArgs == 9) {
                                            overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                            if (numArgs == 10) {
                                                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                                overloadId = 0; // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaMethodFunc_invoke_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "val0";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "val1";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val2";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val3";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val4";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val5";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val6";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val7";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val8";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val9";
                        else
                            pyargs[10] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaMethod.invoke(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QGenericArgument cpp_arg1_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QGenericArgument cpp_arg2_tmp = QGenericArgument();
                QGenericArgument* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericArgument cpp_arg3_tmp = QGenericArgument();
                QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument();
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;

                if(!PyErr_Occurred()) {
                // invoke(QObject*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = cppSelf->QMetaMethod::invoke(cpp_arg0, *cpp_arg1, *cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "val0";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val1";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val2";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val3";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val4";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val5";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val6";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val7";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val8";
                        else
                            pyargs[10] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val9";
                        else
                            pyargs[11] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaMethod.invoke(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QGenericReturnArgument* cpp_arg1 = Shiboken::Converter<QGenericReturnArgument* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QGenericArgument cpp_arg2_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericArgument cpp_arg3_tmp = QGenericArgument();
                QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument();
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[11]))
                    return 0;
                QGenericArgument cpp_arg11_tmp = QGenericArgument();
                QGenericArgument* cpp_arg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[11]) : &cpp_arg11_tmp;

                if(!PyErr_Occurred()) {
                // invoke(QObject*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = cppSelf->QMetaMethod::invoke(cpp_arg0, *cpp_arg1, *cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10, *cpp_arg11);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "val0";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val1";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val2";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val3";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val4";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val5";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val6";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val7";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val8";
                        else
                            pyargs[10] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val9";
                        else
                            pyargs[11] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaMethod.invoke(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                Qt::ConnectionType cpp_arg1 = Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QGenericArgument cpp_arg2_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericArgument cpp_arg3_tmp = QGenericArgument();
                QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument();
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[11]))
                    return 0;
                QGenericArgument cpp_arg11_tmp = QGenericArgument();
                QGenericArgument* cpp_arg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[11]) : &cpp_arg11_tmp;

                if(!PyErr_Occurred()) {
                // invoke(QObject*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = cppSelf->QMetaMethod::invoke(cpp_arg0, cpp_arg1, *cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10, *cpp_arg11);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val0";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val1";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val2";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val3";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val4";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val5";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val6";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val7";
                        else
                            pyargs[10] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val8";
                        else
                            pyargs[11] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[12])
                            errorArgName = "val9";
                        else
                            pyargs[12] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaMethod.invoke(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                Qt::ConnectionType cpp_arg1 = Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QGenericReturnArgument* cpp_arg2 = Shiboken::Converter<QGenericReturnArgument* >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericArgument cpp_arg3_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument();
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[11]))
                    return 0;
                QGenericArgument cpp_arg11_tmp = QGenericArgument();
                QGenericArgument* cpp_arg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[11]) : &cpp_arg11_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[12]))
                    return 0;
                QGenericArgument cpp_arg12_tmp = QGenericArgument();
                QGenericArgument* cpp_arg12 = pyargs[12] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[12]) : &cpp_arg12_tmp;

                if(!PyErr_Occurred()) {
                // invoke(QObject*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                bool cppResult = cppSelf->QMetaMethod::invoke(cpp_arg0, cpp_arg1, *cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10, *cpp_arg11, *cpp_arg12);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaMethodFunc_invoke_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, PySide.QtCore.QGenericReturnArgument, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, PySide.QtCore.Qt.ConnectionType, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, PySide.QtCore.Qt.ConnectionType, PySide.QtCore.QGenericReturnArgument, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaMethod.invoke", overloads);
        return 0;
}

static PyObject* SbkQMetaMethodFunc_methodIndex(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // methodIndex()const
            int cppResult = cppSelf->QMetaMethod::methodIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_methodType(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // methodType()const
            QMetaMethod::MethodType cppResult = cppSelf->QMetaMethod::methodType();
            pyResult = Shiboken::Converter<QMetaMethod::MethodType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_parameterNames(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parameterNames()const
            QList<QByteArray > cppResult = cppSelf->QMetaMethod::parameterNames();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_parameterTypes(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parameterTypes()const
            QList<QByteArray > cppResult = cppSelf->QMetaMethod::parameterTypes();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_signature(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // signature()const
            const char * cppResult = cppSelf->QMetaMethod::signature();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_tag(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tag()const
            const char * cppResult = cppSelf->QMetaMethod::tag();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaMethodFunc_typeName(PyObject* self)
{
    QMetaMethod* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaMethod* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // typeName()const
            const char * cppResult = cppSelf->QMetaMethod::typeName();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQMetaMethod_methods[] = {
    {"access", (PyCFunction)SbkQMetaMethodFunc_access, METH_NOARGS},
    {"attributes", (PyCFunction)SbkQMetaMethodFunc_attributes, METH_NOARGS},
    {"enclosingMetaObject", (PyCFunction)SbkQMetaMethodFunc_enclosingMetaObject, METH_NOARGS},
    {"invoke", (PyCFunction)SbkQMetaMethodFunc_invoke, METH_VARARGS|METH_KEYWORDS},
    {"methodIndex", (PyCFunction)SbkQMetaMethodFunc_methodIndex, METH_NOARGS},
    {"methodType", (PyCFunction)SbkQMetaMethodFunc_methodType, METH_NOARGS},
    {"parameterNames", (PyCFunction)SbkQMetaMethodFunc_parameterNames, METH_NOARGS},
    {"parameterTypes", (PyCFunction)SbkQMetaMethodFunc_parameterTypes, METH_NOARGS},
    {"signature", (PyCFunction)SbkQMetaMethodFunc_signature, METH_NOARGS},
    {"tag", (PyCFunction)SbkQMetaMethodFunc_tag, METH_NOARGS},
    {"typeName", (PyCFunction)SbkQMetaMethodFunc_typeName, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMetaMethod_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QMetaMethod",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMetaMethod_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMetaMethod_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMetaMethod >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMetaMethod",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QMetaMethod_Access_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QMetaMethod_Access_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QMetaMethod_Access_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Access",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QMetaMethod_Access_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QMetaMethod_Access_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QMetaMethod_Access_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QMetaMethod_MethodType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QMetaMethod_MethodType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QMetaMethod_MethodType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MethodType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QMetaMethod_MethodType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QMetaMethod_MethodType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QMetaMethod_MethodType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QMetaMethod(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMETAMETHOD_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMetaMethod_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMetaMethod_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMetaMethod_Type));
    PyModule_AddObject(module, "QMetaMethod",
        ((PyObject*)&SbkQMetaMethod_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Access
    SbkPySide_QtCoreTypes[SBK_QMETAMETHOD_ACCESS_IDX] = &SbkPySide_QtCore_QMetaMethod_Access_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QMetaMethod_Access_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QMetaMethod_Access_Type);
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
            "Access",((PyObject*)&SbkPySide_QtCore_QMetaMethod_Access_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaMethod_Access_Type,
        (long) QMetaMethod::Private, "Private");
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
        "Private", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaMethod_Access_Type.tp_dict,
        "Private", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaMethod_Access_Type,
        (long) QMetaMethod::Protected, "Protected");
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
        "Protected", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaMethod_Access_Type.tp_dict,
        "Protected", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaMethod_Access_Type,
        (long) QMetaMethod::Public, "Public");
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
        "Public", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaMethod_Access_Type.tp_dict,
        "Public", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMetaMethod::Access");

    // init enum class: MethodType
    SbkPySide_QtCoreTypes[SBK_QMETAMETHOD_METHODTYPE_IDX] = &SbkPySide_QtCore_QMetaMethod_MethodType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QMetaMethod_MethodType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QMetaMethod_MethodType_Type);
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
            "MethodType",((PyObject*)&SbkPySide_QtCore_QMetaMethod_MethodType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaMethod_MethodType_Type,
        (long) QMetaMethod::Method, "Method");
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
        "Method", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaMethod_MethodType_Type.tp_dict,
        "Method", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaMethod_MethodType_Type,
        (long) QMetaMethod::Signal, "Signal");
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
        "Signal", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaMethod_MethodType_Type.tp_dict,
        "Signal", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaMethod_MethodType_Type,
        (long) QMetaMethod::Slot, "Slot");
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
        "Slot", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaMethod_MethodType_Type.tp_dict,
        "Slot", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaMethod_MethodType_Type,
        (long) QMetaMethod::Constructor, "Constructor");
    PyDict_SetItemString(SbkQMetaMethod_Type.super.ht_type.tp_dict,
        "Constructor", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaMethod_MethodType_Type.tp_dict,
        "Constructor", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMetaMethod::MethodType");


    Shiboken::TypeResolver::createValueTypeResolver<QMetaMethod >("QMetaMethod");
    Shiboken::TypeResolver::createObjectTypeResolver<QMetaMethod >("QMetaMethod*");
    Shiboken::TypeResolver::createValueTypeResolver<QMetaMethod >(typeid(QMetaMethod).name());
    PySide::initQtMetaType<QMetaMethod >();
}

