/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmetaobject_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMetaObject_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMetaObject >()))
        return -1;

    QMetaObject* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QMetaObject()
            cptr = new QMetaObject();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMetaObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQMetaObjectFunc_cast(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cast(QObject*)const
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // cast(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_cast_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // cast(QObject*)const
            QObject * cppResult = cppSelf->QMetaObject::cast(cpp_arg0);
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_cast_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.cast", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_checkConnectArgs(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "checkConnectArgs", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: checkConnectArgs(const char*,const char*)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        overloadId = 0; // checkConnectArgs(const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_checkConnectArgs_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // checkConnectArgs(const char*,const char*)
            bool cppResult = QMetaObject::checkConnectArgs(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_checkConnectArgs_TypeError:
        const char* overloads[] = {"str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.checkConnectArgs", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_classInfo(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: classInfo(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // classInfo(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_classInfo_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // classInfo(int)const
            QMetaClassInfo cppResult = cppSelf->QMetaObject::classInfo(cpp_arg0);
            pyResult = Shiboken::Converter<QMetaClassInfo >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_classInfo_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.classInfo", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_classInfoCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // classInfoCount()const
            int cppResult = cppSelf->QMetaObject::classInfoCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_classInfoOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // classInfoOffset()const
            int cppResult = cppSelf->QMetaObject::classInfoOffset();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_className(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // className()const
            const char * cppResult = cppSelf->QMetaObject::className();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_connectSlotsByName(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: connectSlotsByName(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // connectSlotsByName(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_connectSlotsByName_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // connectSlotsByName(QObject*)
            QMetaObject::connectSlotsByName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMetaObjectFunc_connectSlotsByName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.connectSlotsByName", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_constructor(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: constructor(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // constructor(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_constructor_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // constructor(int)const
            QMetaMethod cppResult = cppSelf->QMetaObject::constructor(cpp_arg0);
            pyResult = Shiboken::Converter<QMetaMethod >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_constructor_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.constructor", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_constructorCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // constructorCount()const
            int cppResult = cppSelf->QMetaObject::constructorCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_disconnect(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "disconnect", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: disconnect(const QObject*,int,const QObject*,int)
    if (numArgs == 4 && Shiboken::Converter<const QObject * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QObject * >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // disconnect(const QObject*,int,const QObject*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_disconnect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QObject* cpp_arg2 = Shiboken::Converter<QObject* >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // disconnect(const QObject*,int,const QObject*,int)
            bool cppResult = QMetaObject::disconnect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_disconnect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, int, PySide.QtCore.QObject, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.disconnect", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_enumerator(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: enumerator(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // enumerator(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_enumerator_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // enumerator(int)const
            QMetaEnum cppResult = cppSelf->QMetaObject::enumerator(cpp_arg0);
            pyResult = Shiboken::Converter<QMetaEnum >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_enumerator_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.enumerator", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_enumeratorCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // enumeratorCount()const
            int cppResult = cppSelf->QMetaObject::enumeratorCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_enumeratorOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // enumeratorOffset()const
            int cppResult = cppSelf->QMetaObject::enumeratorOffset();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_indexOfClassInfo(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfClassInfo(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfClassInfo(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_indexOfClassInfo_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfClassInfo(const char*)const
            int cppResult = cppSelf->QMetaObject::indexOfClassInfo(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_indexOfClassInfo_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfClassInfo", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_indexOfConstructor(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfConstructor(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfConstructor(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_indexOfConstructor_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfConstructor(const char*)const
            int cppResult = cppSelf->QMetaObject::indexOfConstructor(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_indexOfConstructor_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfConstructor", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_indexOfEnumerator(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfEnumerator(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfEnumerator(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_indexOfEnumerator_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfEnumerator(const char*)const
            int cppResult = cppSelf->QMetaObject::indexOfEnumerator(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_indexOfEnumerator_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfEnumerator", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_indexOfMethod(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfMethod(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfMethod(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_indexOfMethod_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfMethod(const char*)const
            int cppResult = cppSelf->QMetaObject::indexOfMethod(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_indexOfMethod_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfMethod", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_indexOfProperty(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfProperty(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfProperty(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_indexOfProperty_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfProperty(const char*)const
            int cppResult = cppSelf->QMetaObject::indexOfProperty(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_indexOfProperty_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfProperty", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_indexOfSignal(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfSignal(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfSignal(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_indexOfSignal_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfSignal(const char*)const
            int cppResult = cppSelf->QMetaObject::indexOfSignal(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_indexOfSignal_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfSignal", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_indexOfSlot(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfSlot(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfSlot(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_indexOfSlot_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexOfSlot(const char*)const
            int cppResult = cppSelf->QMetaObject::indexOfSlot(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_indexOfSlot_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfSlot", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_invokeMethod(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "val0", "val1", "val2", "val3", "val4", "val5", "val6", "val7", "val8", "val9" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 10, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 14) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOOOOOOOO:invokeMethod", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9]), &(pyargs[10]), &(pyargs[11]), &(pyargs[12]), &(pyargs[13])))
        return 0;


    // Overloaded function decisor
    // 0: invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    // 1: invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    // 2: invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    // 3: invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    if (numArgs >= 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
        } else if (Shiboken::Converter<Qt::ConnectionType >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[11])) {
                                                if (numArgs == 12) {
                                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[12])) {
                                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (Shiboken::Converter<QGenericReturnArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[11])) {
                                                if (numArgs == 12) {
                                                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[12])) {
                                                    if (numArgs == 13) {
                                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[13])) {
                                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (Shiboken::Converter<QGenericReturnArgument >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[11])) {
                                                if (numArgs == 12) {
                                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[12])) {
                                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[11])) {
                                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_invokeMethod_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "val0";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val1";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val2";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val3";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val4";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val5";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val6";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val7";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val8";
                        else
                            pyargs[10] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val9";
                        else
                            pyargs[11] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QGenericArgument cpp_arg2_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericArgument cpp_arg3_tmp = QGenericArgument();
                QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument();
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[11]))
                    return 0;
                QGenericArgument cpp_arg11_tmp = QGenericArgument();
                QGenericArgument* cpp_arg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[11]) : &cpp_arg11_tmp;

                if(!PyErr_Occurred()) {
                // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                bool cppResult = QMetaObject::invokeMethod(cpp_arg0, cpp_arg1, *cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10, *cpp_arg11);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val0";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val1";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val2";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val3";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val4";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val5";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val6";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val7";
                        else
                            pyargs[10] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val8";
                        else
                            pyargs[11] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[12])
                            errorArgName = "val9";
                        else
                            pyargs[12] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QGenericReturnArgument* cpp_arg2 = Shiboken::Converter<QGenericReturnArgument* >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericArgument cpp_arg3_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument();
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[11]))
                    return 0;
                QGenericArgument cpp_arg11_tmp = QGenericArgument();
                QGenericArgument* cpp_arg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[11]) : &cpp_arg11_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[12]))
                    return 0;
                QGenericArgument cpp_arg12_tmp = QGenericArgument();
                QGenericArgument* cpp_arg12 = pyargs[12] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[12]) : &cpp_arg12_tmp;

                if(!PyErr_Occurred()) {
                // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                bool cppResult = QMetaObject::invokeMethod(cpp_arg0, cpp_arg1, *cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10, *cpp_arg11, *cpp_arg12);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val0";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val1";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val2";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val3";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val4";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val5";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val6";
                        else
                            pyargs[10] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val7";
                        else
                            pyargs[11] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[12])
                            errorArgName = "val8";
                        else
                            pyargs[12] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[13])
                            errorArgName = "val9";
                        else
                            pyargs[13] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                Qt::ConnectionType cpp_arg2 = Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericReturnArgument* cpp_arg3 = Shiboken::Converter<QGenericReturnArgument* >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[11]))
                    return 0;
                QGenericArgument cpp_arg11_tmp = QGenericArgument();
                QGenericArgument* cpp_arg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[11]) : &cpp_arg11_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[12]))
                    return 0;
                QGenericArgument cpp_arg12_tmp = QGenericArgument();
                QGenericArgument* cpp_arg12 = pyargs[12] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[12]) : &cpp_arg12_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[13]))
                    return 0;
                QGenericArgument cpp_arg13_tmp = QGenericArgument();
                QGenericArgument* cpp_arg13 = pyargs[13] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[13]) : &cpp_arg13_tmp;

                if(!PyErr_Occurred()) {
                // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                bool cppResult = QMetaObject::invokeMethod(cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10, *cpp_arg11, *cpp_arg12, *cpp_arg13);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val0";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val1";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val2";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val3";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val4";
                        else
                            pyargs[7] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val5";
                        else
                            pyargs[8] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val6";
                        else
                            pyargs[9] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val7";
                        else
                            pyargs[10] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val8";
                        else
                            pyargs[11] = value;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[12])
                            errorArgName = "val9";
                        else
                            pyargs[12] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                Qt::ConnectionType cpp_arg2 = Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QGenericArgument cpp_arg3_tmp = QGenericArgument(0);
                QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                QGenericArgument cpp_arg4_tmp = QGenericArgument();
                QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                QGenericArgument cpp_arg5_tmp = QGenericArgument();
                QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QGenericArgument cpp_arg6_tmp = QGenericArgument();
                QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                    return 0;
                QGenericArgument cpp_arg7_tmp = QGenericArgument();
                QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                    return 0;
                QGenericArgument cpp_arg8_tmp = QGenericArgument();
                QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                    return 0;
                QGenericArgument cpp_arg9_tmp = QGenericArgument();
                QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[10]))
                    return 0;
                QGenericArgument cpp_arg10_tmp = QGenericArgument();
                QGenericArgument* cpp_arg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[10]) : &cpp_arg10_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[11]))
                    return 0;
                QGenericArgument cpp_arg11_tmp = QGenericArgument();
                QGenericArgument* cpp_arg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[11]) : &cpp_arg11_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[12]))
                    return 0;
                QGenericArgument cpp_arg12_tmp = QGenericArgument();
                QGenericArgument* cpp_arg12 = pyargs[12] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[12]) : &cpp_arg12_tmp;

                if(!PyErr_Occurred()) {
                // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                bool cppResult = QMetaObject::invokeMethod(cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9, *cpp_arg10, *cpp_arg11, *cpp_arg12);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_invokeMethod_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, str, PySide.QtCore.QGenericReturnArgument, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, str, PySide.QtCore.Qt.ConnectionType, PySide.QtCore.QGenericReturnArgument, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, str, PySide.QtCore.Qt.ConnectionType, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.invokeMethod", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_method(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: method(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // method(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_method_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // method(int)const
            QMetaMethod cppResult = cppSelf->QMetaObject::method(cpp_arg0);
            pyResult = Shiboken::Converter<QMetaMethod >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_method_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.method", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_methodCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // methodCount()const
            int cppResult = cppSelf->QMetaObject::methodCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_methodOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // methodOffset()const
            int cppResult = cppSelf->QMetaObject::methodOffset();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_newInstance(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "val0", "val1", "val2", "val3", "val4", "val5", "val6", "val7", "val8", "val9" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 10, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.newInstance(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 10) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaObject.newInstance(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOOOO:newInstance", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9])))
        return 0;


    // Overloaded function decisor
    // 0: newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    if (numArgs == 0) {
        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[5])) {
                            if (numArgs == 6) {
                                overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[6])) {
                                if (numArgs == 7) {
                                    overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[7])) {
                                    if (numArgs == 8) {
                                        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[8])) {
                                        if (numArgs == 9) {
                                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (Shiboken::Converter<QGenericArgument >::isConvertible(pyargs[9])) {
                                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_newInstance_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "val0");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "val0";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "val1");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "val1";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "val2");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "val2";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "val3");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "val3";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "val4");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "val4";
                    else
                        pyargs[4] = value;
                }
                value = PyDict_GetItemString(kwds, "val5");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "val5";
                    else
                        pyargs[5] = value;
                }
                value = PyDict_GetItemString(kwds, "val6");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "val6";
                    else
                        pyargs[6] = value;
                }
                value = PyDict_GetItemString(kwds, "val7");
                if (value) {
                    if (pyargs[7])
                        errorArgName = "val7";
                    else
                        pyargs[7] = value;
                }
                value = PyDict_GetItemString(kwds, "val8");
                if (value) {
                    if (pyargs[8])
                        errorArgName = "val8";
                    else
                        pyargs[8] = value;
                }
                value = PyDict_GetItemString(kwds, "val9");
                if (value) {
                    if (pyargs[9])
                        errorArgName = "val9";
                    else
                        pyargs[9] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.newInstance(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGenericArgument cpp_arg0_tmp = QGenericArgument(0);
            QGenericArgument* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QGenericArgument cpp_arg1_tmp = QGenericArgument();
            QGenericArgument* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QGenericArgument cpp_arg2_tmp = QGenericArgument();
            QGenericArgument* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                return 0;
            QGenericArgument cpp_arg3_tmp = QGenericArgument();
            QGenericArgument* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                return 0;
            QGenericArgument cpp_arg4_tmp = QGenericArgument();
            QGenericArgument* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                return 0;
            QGenericArgument cpp_arg5_tmp = QGenericArgument();
            QGenericArgument* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                return 0;
            QGenericArgument cpp_arg6_tmp = QGenericArgument();
            QGenericArgument* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[7]))
                return 0;
            QGenericArgument cpp_arg7_tmp = QGenericArgument();
            QGenericArgument* cpp_arg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[7]) : &cpp_arg7_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[8]))
                return 0;
            QGenericArgument cpp_arg8_tmp = QGenericArgument();
            QGenericArgument* cpp_arg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[8]) : &cpp_arg8_tmp;
            if (Shiboken::cppObjectIsInvalid(pyargs[9]))
                return 0;
            QGenericArgument cpp_arg9_tmp = QGenericArgument();
            QGenericArgument* cpp_arg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument* >::toCpp(pyargs[9]) : &cpp_arg9_tmp;

            if(!PyErr_Occurred()) {
            // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            QObject * cppResult = cppSelf->QMetaObject::newInstance(*cpp_arg0, *cpp_arg1, *cpp_arg2, *cpp_arg3, *cpp_arg4, *cpp_arg5, *cpp_arg6, *cpp_arg7, *cpp_arg8, *cpp_arg9);
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_newInstance_TypeError:
        const char* overloads[] = {"PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.newInstance", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_normalizedSignature(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: normalizedSignature(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // normalizedSignature(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_normalizedSignature_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // normalizedSignature(const char*)
            QByteArray cppResult = QMetaObject::normalizedSignature(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_normalizedSignature_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.normalizedSignature", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_normalizedType(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: normalizedType(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // normalizedType(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_normalizedType_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // normalizedType(const char*)
            QByteArray cppResult = QMetaObject::normalizedType(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_normalizedType_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.normalizedType", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_property(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // property(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaObjectFunc_property_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // property(int)const
            QMetaProperty cppResult = cppSelf->QMetaObject::property(cpp_arg0);
            pyResult = Shiboken::Converter<QMetaProperty >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaObjectFunc_property_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.property", overloads);
        return 0;
}

static PyObject* SbkQMetaObjectFunc_propertyCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // propertyCount()const
            int cppResult = cppSelf->QMetaObject::propertyCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_propertyOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // propertyOffset()const
            int cppResult = cppSelf->QMetaObject::propertyOffset();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_superClass(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // superClass()const
            const QMetaObject * cppResult = cppSelf->QMetaObject::superClass();
            pyResult = Shiboken::Converter< QMetaObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaObjectFunc_userProperty(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userProperty()const
            QMetaProperty cppResult = cppSelf->QMetaObject::userProperty();
            pyResult = Shiboken::Converter<QMetaProperty >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQMetaObject_methods[] = {
    {"cast", (PyCFunction)SbkQMetaObjectFunc_cast, METH_O},
    {"checkConnectArgs", (PyCFunction)SbkQMetaObjectFunc_checkConnectArgs, METH_VARARGS|METH_STATIC},
    {"classInfo", (PyCFunction)SbkQMetaObjectFunc_classInfo, METH_O},
    {"classInfoCount", (PyCFunction)SbkQMetaObjectFunc_classInfoCount, METH_NOARGS},
    {"classInfoOffset", (PyCFunction)SbkQMetaObjectFunc_classInfoOffset, METH_NOARGS},
    {"className", (PyCFunction)SbkQMetaObjectFunc_className, METH_NOARGS},
    {"connectSlotsByName", (PyCFunction)SbkQMetaObjectFunc_connectSlotsByName, METH_O|METH_STATIC},
    {"constructor", (PyCFunction)SbkQMetaObjectFunc_constructor, METH_O},
    {"constructorCount", (PyCFunction)SbkQMetaObjectFunc_constructorCount, METH_NOARGS},
    {"disconnect", (PyCFunction)SbkQMetaObjectFunc_disconnect, METH_VARARGS|METH_STATIC},
    {"enumerator", (PyCFunction)SbkQMetaObjectFunc_enumerator, METH_O},
    {"enumeratorCount", (PyCFunction)SbkQMetaObjectFunc_enumeratorCount, METH_NOARGS},
    {"enumeratorOffset", (PyCFunction)SbkQMetaObjectFunc_enumeratorOffset, METH_NOARGS},
    {"indexOfClassInfo", (PyCFunction)SbkQMetaObjectFunc_indexOfClassInfo, METH_O},
    {"indexOfConstructor", (PyCFunction)SbkQMetaObjectFunc_indexOfConstructor, METH_O},
    {"indexOfEnumerator", (PyCFunction)SbkQMetaObjectFunc_indexOfEnumerator, METH_O},
    {"indexOfMethod", (PyCFunction)SbkQMetaObjectFunc_indexOfMethod, METH_O},
    {"indexOfProperty", (PyCFunction)SbkQMetaObjectFunc_indexOfProperty, METH_O},
    {"indexOfSignal", (PyCFunction)SbkQMetaObjectFunc_indexOfSignal, METH_O},
    {"indexOfSlot", (PyCFunction)SbkQMetaObjectFunc_indexOfSlot, METH_O},
    {"invokeMethod", (PyCFunction)SbkQMetaObjectFunc_invokeMethod, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"method", (PyCFunction)SbkQMetaObjectFunc_method, METH_O},
    {"methodCount", (PyCFunction)SbkQMetaObjectFunc_methodCount, METH_NOARGS},
    {"methodOffset", (PyCFunction)SbkQMetaObjectFunc_methodOffset, METH_NOARGS},
    {"newInstance", (PyCFunction)SbkQMetaObjectFunc_newInstance, METH_VARARGS|METH_KEYWORDS},
    {"normalizedSignature", (PyCFunction)SbkQMetaObjectFunc_normalizedSignature, METH_O|METH_STATIC},
    {"normalizedType", (PyCFunction)SbkQMetaObjectFunc_normalizedType, METH_O|METH_STATIC},
    {"property", (PyCFunction)SbkQMetaObjectFunc_property, METH_O},
    {"propertyCount", (PyCFunction)SbkQMetaObjectFunc_propertyCount, METH_NOARGS},
    {"propertyOffset", (PyCFunction)SbkQMetaObjectFunc_propertyOffset, METH_NOARGS},
    {"superClass", (PyCFunction)SbkQMetaObjectFunc_superClass, METH_NOARGS},
    {"userProperty", (PyCFunction)SbkQMetaObjectFunc_userProperty, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMetaObject_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QMetaObject",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMetaObject_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMetaObject_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMetaObject >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMetaObject*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QMetaObject_Call_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QMetaObject_Call_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QMetaObject_Call_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Call",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QMetaObject_Call_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QMetaObject_Call_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QMetaObject_Call_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QMetaObject(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMETAOBJECT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMetaObject_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMetaObject_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMetaObject_Type));
    PyModule_AddObject(module, "QMetaObject",
        ((PyObject*)&SbkQMetaObject_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Call
    SbkPySide_QtCoreTypes[SBK_QMETAOBJECT_CALL_IDX] = &SbkPySide_QtCore_QMetaObject_Call_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QMetaObject_Call_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QMetaObject_Call_Type);
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
            "Call",((PyObject*)&SbkPySide_QtCore_QMetaObject_Call_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::InvokeMetaMethod, "InvokeMetaMethod");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "InvokeMetaMethod", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "InvokeMetaMethod", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::ReadProperty, "ReadProperty");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "ReadProperty", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "ReadProperty", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::WriteProperty, "WriteProperty");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "WriteProperty", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "WriteProperty", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::ResetProperty, "ResetProperty");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "ResetProperty", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "ResetProperty", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::QueryPropertyDesignable, "QueryPropertyDesignable");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "QueryPropertyDesignable", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "QueryPropertyDesignable", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::QueryPropertyScriptable, "QueryPropertyScriptable");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "QueryPropertyScriptable", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "QueryPropertyScriptable", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::QueryPropertyStored, "QueryPropertyStored");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "QueryPropertyStored", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "QueryPropertyStored", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::QueryPropertyEditable, "QueryPropertyEditable");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "QueryPropertyEditable", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "QueryPropertyEditable", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::QueryPropertyUser, "QueryPropertyUser");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "QueryPropertyUser", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "QueryPropertyUser", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMetaObject_Call_Type,
        (long) QMetaObject::CreateInstance, "CreateInstance");
    PyDict_SetItemString(SbkQMetaObject_Type.super.ht_type.tp_dict,
        "CreateInstance", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call_Type.tp_dict,
        "CreateInstance", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMetaObject::Call");


    Shiboken::TypeResolver::createObjectTypeResolver<QMetaObject >("QMetaObject*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMetaObject >(typeid(QMetaObject).name());
    PySide::initQtMetaType<QMetaObject* >();
}

