/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmetaproperty_wrapper.h"

// Extra includes
#include <qmetaobject.h>
#include <qobject.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMetaProperty_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMetaProperty >()))
        return -1;

    QMetaProperty* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QMetaProperty", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QMetaProperty(QMetaProperty)
    // 1: QMetaProperty()
    if (numArgs == 0) {
        overloadId = 1; // QMetaProperty()
    } else if (numArgs == 1 && Shiboken::Converter<const QMetaProperty & >::isConvertible(arg)) {
        overloadId = 0; // QMetaProperty(QMetaProperty)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaProperty_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMetaProperty(QMetaProperty)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QMetaProperty* cpp_arg0 = Shiboken::Converter<QMetaProperty* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QMetaProperty(QMetaProperty)
                cptr = new QMetaProperty(*cpp_arg0);
                }
                break;
            }
            case 1: // QMetaProperty()
            {

                if(!PyErr_Occurred()) {
                // QMetaProperty()
                cptr = new QMetaProperty();
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMetaProperty >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMetaProperty_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQMetaProperty_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMetaProperty", "", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaProperty", overloads);
        return -1;
}

static PyObject* SbkQMetaPropertyFunc_enumerator(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // enumerator()const
            QMetaEnum cppResult = cppSelf->QMetaProperty::enumerator();
            pyResult = Shiboken::Converter<QMetaEnum >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_hasNotifySignal(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasNotifySignal()const
            bool cppResult = cppSelf->QMetaProperty::hasNotifySignal();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_hasStdCppSet(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasStdCppSet()const
            bool cppResult = cppSelf->QMetaProperty::hasStdCppSet();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isConstant(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isConstant()const
            bool cppResult = cppSelf->QMetaProperty::isConstant();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isDesignable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "obj" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isDesignable(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isDesignable(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:isDesignable", &arg))
        return 0;


    // Overloaded function decisor
    // 0: isDesignable(const QObject*)const
    if (numArgs == 0) {
        overloadId = 0; // isDesignable(const QObject*)const
    } else if (Shiboken::Converter<const QObject * >::isConvertible(arg)) {
        overloadId = 0; // isDesignable(const QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_isDesignable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "obj");
                if (value) {
                    if (arg)
                        errorArgName = "obj";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isDesignable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // isDesignable(const QObject*)const
            bool cppResult = cppSelf->QMetaProperty::isDesignable(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_isDesignable_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaProperty.isDesignable", overloads);
        return 0;
}

static PyObject* SbkQMetaPropertyFunc_isEditable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "obj" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isEditable(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isEditable(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:isEditable", &arg))
        return 0;


    // Overloaded function decisor
    // 0: isEditable(const QObject*)const
    if (numArgs == 0) {
        overloadId = 0; // isEditable(const QObject*)const
    } else if (Shiboken::Converter<const QObject * >::isConvertible(arg)) {
        overloadId = 0; // isEditable(const QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_isEditable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "obj");
                if (value) {
                    if (arg)
                        errorArgName = "obj";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isEditable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // isEditable(const QObject*)const
            bool cppResult = cppSelf->QMetaProperty::isEditable(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_isEditable_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaProperty.isEditable", overloads);
        return 0;
}

static PyObject* SbkQMetaPropertyFunc_isEnumType(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEnumType()const
            bool cppResult = cppSelf->QMetaProperty::isEnumType();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isFinal(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isFinal()const
            bool cppResult = cppSelf->QMetaProperty::isFinal();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isFlagType(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isFlagType()const
            bool cppResult = cppSelf->QMetaProperty::isFlagType();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isReadable(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isReadable()const
            bool cppResult = cppSelf->QMetaProperty::isReadable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isResettable(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isResettable()const
            bool cppResult = cppSelf->QMetaProperty::isResettable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isScriptable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "obj" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isScriptable(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isScriptable(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:isScriptable", &arg))
        return 0;


    // Overloaded function decisor
    // 0: isScriptable(const QObject*)const
    if (numArgs == 0) {
        overloadId = 0; // isScriptable(const QObject*)const
    } else if (Shiboken::Converter<const QObject * >::isConvertible(arg)) {
        overloadId = 0; // isScriptable(const QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_isScriptable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "obj");
                if (value) {
                    if (arg)
                        errorArgName = "obj";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isScriptable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // isScriptable(const QObject*)const
            bool cppResult = cppSelf->QMetaProperty::isScriptable(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_isScriptable_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaProperty.isScriptable", overloads);
        return 0;
}

static PyObject* SbkQMetaPropertyFunc_isStored(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "obj" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isStored(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isStored(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:isStored", &arg))
        return 0;


    // Overloaded function decisor
    // 0: isStored(const QObject*)const
    if (numArgs == 0) {
        overloadId = 0; // isStored(const QObject*)const
    } else if (Shiboken::Converter<const QObject * >::isConvertible(arg)) {
        overloadId = 0; // isStored(const QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_isStored_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "obj");
                if (value) {
                    if (arg)
                        errorArgName = "obj";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isStored(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // isStored(const QObject*)const
            bool cppResult = cppSelf->QMetaProperty::isStored(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_isStored_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaProperty.isStored", overloads);
        return 0;
}

static PyObject* SbkQMetaPropertyFunc_isUser(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "obj" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isUser(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isUser(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:isUser", &arg))
        return 0;


    // Overloaded function decisor
    // 0: isUser(const QObject*)const
    if (numArgs == 0) {
        overloadId = 0; // isUser(const QObject*)const
    } else if (Shiboken::Converter<const QObject * >::isConvertible(arg)) {
        overloadId = 0; // isUser(const QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_isUser_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "obj");
                if (value) {
                    if (arg)
                        errorArgName = "obj";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaProperty.isUser(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // isUser(const QObject*)const
            bool cppResult = cppSelf->QMetaProperty::isUser(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_isUser_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaProperty.isUser", overloads);
        return 0;
}

static PyObject* SbkQMetaPropertyFunc_isValid(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QMetaProperty::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_isWritable(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWritable()const
            bool cppResult = cppSelf->QMetaProperty::isWritable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_name(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            const char * cppResult = cppSelf->QMetaProperty::name();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_notifySignal(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // notifySignal()const
            QMetaMethod cppResult = cppSelf->QMetaProperty::notifySignal();
            pyResult = Shiboken::Converter<QMetaMethod >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_notifySignalIndex(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // notifySignalIndex()const
            int cppResult = cppSelf->QMetaProperty::notifySignalIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_propertyIndex(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // propertyIndex()const
            int cppResult = cppSelf->QMetaProperty::propertyIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_read(PyObject* self, PyObject* arg)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(const QObject*)const
    if (Shiboken::Converter<const QObject * >::isConvertible(arg)) {
        overloadId = 0; // read(const QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_read_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // read(const QObject*)const
            QVariant cppResult = cppSelf->QMetaProperty::read(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_read_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaProperty.read", overloads);
        return 0;
}

static PyObject* SbkQMetaPropertyFunc_reset(PyObject* self, PyObject* arg)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: reset(QObject*)const
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // reset(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_reset_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // reset(QObject*)const
            bool cppResult = cppSelf->QMetaProperty::reset(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_reset_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaProperty.reset", overloads);
        return 0;
}

static PyObject* SbkQMetaPropertyFunc_type(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            QVariant::Type cppResult = cppSelf->QMetaProperty::type();
            pyResult = Shiboken::Converter<QVariant::Type >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_typeName(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // typeName()const
            const char * cppResult = cppSelf->QMetaProperty::typeName();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_userType(PyObject* self)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userType()const
            int cppResult = cppSelf->QMetaProperty::userType();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMetaPropertyFunc_write(PyObject* self, PyObject* args)
{
    QMetaProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMetaProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "write", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: write(QObject*,QVariant)const
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // write(QObject*,QVariant)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMetaPropertyFunc_write_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // write(QObject*,QVariant)const
            bool cppResult = cppSelf->QMetaProperty::write(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMetaPropertyFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaProperty.write", overloads);
        return 0;
}

static PyMethodDef SbkQMetaProperty_methods[] = {
    {"enumerator", (PyCFunction)SbkQMetaPropertyFunc_enumerator, METH_NOARGS},
    {"hasNotifySignal", (PyCFunction)SbkQMetaPropertyFunc_hasNotifySignal, METH_NOARGS},
    {"hasStdCppSet", (PyCFunction)SbkQMetaPropertyFunc_hasStdCppSet, METH_NOARGS},
    {"isConstant", (PyCFunction)SbkQMetaPropertyFunc_isConstant, METH_NOARGS},
    {"isDesignable", (PyCFunction)SbkQMetaPropertyFunc_isDesignable, METH_VARARGS|METH_KEYWORDS},
    {"isEditable", (PyCFunction)SbkQMetaPropertyFunc_isEditable, METH_VARARGS|METH_KEYWORDS},
    {"isEnumType", (PyCFunction)SbkQMetaPropertyFunc_isEnumType, METH_NOARGS},
    {"isFinal", (PyCFunction)SbkQMetaPropertyFunc_isFinal, METH_NOARGS},
    {"isFlagType", (PyCFunction)SbkQMetaPropertyFunc_isFlagType, METH_NOARGS},
    {"isReadable", (PyCFunction)SbkQMetaPropertyFunc_isReadable, METH_NOARGS},
    {"isResettable", (PyCFunction)SbkQMetaPropertyFunc_isResettable, METH_NOARGS},
    {"isScriptable", (PyCFunction)SbkQMetaPropertyFunc_isScriptable, METH_VARARGS|METH_KEYWORDS},
    {"isStored", (PyCFunction)SbkQMetaPropertyFunc_isStored, METH_VARARGS|METH_KEYWORDS},
    {"isUser", (PyCFunction)SbkQMetaPropertyFunc_isUser, METH_VARARGS|METH_KEYWORDS},
    {"isValid", (PyCFunction)SbkQMetaPropertyFunc_isValid, METH_NOARGS},
    {"isWritable", (PyCFunction)SbkQMetaPropertyFunc_isWritable, METH_NOARGS},
    {"name", (PyCFunction)SbkQMetaPropertyFunc_name, METH_NOARGS},
    {"notifySignal", (PyCFunction)SbkQMetaPropertyFunc_notifySignal, METH_NOARGS},
    {"notifySignalIndex", (PyCFunction)SbkQMetaPropertyFunc_notifySignalIndex, METH_NOARGS},
    {"propertyIndex", (PyCFunction)SbkQMetaPropertyFunc_propertyIndex, METH_NOARGS},
    {"read", (PyCFunction)SbkQMetaPropertyFunc_read, METH_O},
    {"reset", (PyCFunction)SbkQMetaPropertyFunc_reset, METH_O},
    {"type", (PyCFunction)SbkQMetaPropertyFunc_type, METH_NOARGS},
    {"typeName", (PyCFunction)SbkQMetaPropertyFunc_typeName, METH_NOARGS},
    {"userType", (PyCFunction)SbkQMetaPropertyFunc_userType, METH_NOARGS},
    {"write", (PyCFunction)SbkQMetaPropertyFunc_write, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMetaProperty_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QMetaProperty",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMetaProperty_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMetaProperty_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMetaProperty >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMetaProperty",
    /*user_data*/           0
};
} //extern


void init_QMetaProperty(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMETAPROPERTY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMetaProperty_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMetaProperty_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMetaProperty_Type));
    PyModule_AddObject(module, "QMetaProperty",
        ((PyObject*)&SbkQMetaProperty_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QMetaProperty >("QMetaProperty");
    Shiboken::TypeResolver::createObjectTypeResolver<QMetaProperty >("QMetaProperty*");
    Shiboken::TypeResolver::createValueTypeResolver<QMetaProperty >(typeid(QMetaProperty).name());
    PySide::initQtMetaType<QMetaProperty >();
}

