/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmutex_wrapper.h"

// Extra includes
#include <qmutex.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMutex_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMutex >()))
        return -1;

    QMutex* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMutex(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMutex(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QMutex", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QMutex(QMutex::RecursionMode)
    if (numArgs == 0) {
        overloadId = 0; // QMutex(QMutex::RecursionMode)
    } else if (Shiboken::Converter<QMutex::RecursionMode >::isConvertible(arg)) {
        overloadId = 0; // QMutex(QMutex::RecursionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMutex_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (arg)
                        errorArgName = "mode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMutex(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QMutex::RecursionMode cpp_arg0 = arg ? Shiboken::Converter<QMutex::RecursionMode >::toCpp(arg) : QMutex::NonRecursive;

            if(!PyErr_Occurred()) {
            // QMutex(QMutex::RecursionMode)
            cptr = new QMutex(cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMutex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMutex_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQMutex_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMutex.RecursionMode = NonRecursive", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMutex", overloads);
        return -1;
}

static PyObject* SbkQMutexFunc_lock(PyObject* self)
{
    QMutex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMutex* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // lock()
            threadStateSaver.save();
            cppSelf->QMutex::lock();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQMutexFunc_tryLock(PyObject* self, PyObject* arg)
{
    QMutex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMutex* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: tryLock()
    // 1: tryLock(int)
    if (numArgs == 0) {
        overloadId = 0; // tryLock()
    } else if (SbkNumber_Check(arg)) {
        overloadId = 1; // tryLock(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMutexFunc_tryLock_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // tryLock()
            {

                if(!PyErr_Occurred()) {
                // tryLock()
                bool cppResult = cppSelf->QMutex::tryLock();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // tryLock(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // tryLock(int)
                threadStateSaver.save();
                bool cppResult = cppSelf->QMutex::tryLock(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMutexFunc_tryLock_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMutex.tryLock", overloads);
        return 0;
}

static PyObject* SbkQMutexFunc_unlock(PyObject* self)
{
    QMutex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMutex* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unlock()
            cppSelf->QMutex::unlock();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQMutex_methods[] = {
    {"lock", (PyCFunction)SbkQMutexFunc_lock, METH_NOARGS},
    {"tryLock", (PyCFunction)SbkQMutexFunc_tryLock, METH_NOARGS|METH_O},
    {"unlock", (PyCFunction)SbkQMutexFunc_unlock, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMutex_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QMutex",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMutex_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMutex_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMutex >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMutex*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QMutex_RecursionMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QMutex_RecursionMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QMutex_RecursionMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RecursionMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QMutex_RecursionMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QMutex_RecursionMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QMutex_RecursionMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QMutex(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMUTEX_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMutex_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMutex_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMutex_Type));
    PyModule_AddObject(module, "QMutex",
        ((PyObject*)&SbkQMutex_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: RecursionMode
    SbkPySide_QtCoreTypes[SBK_QMUTEX_RECURSIONMODE_IDX] = &SbkPySide_QtCore_QMutex_RecursionMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QMutex_RecursionMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QMutex_RecursionMode_Type);
    PyDict_SetItemString(SbkQMutex_Type.super.ht_type.tp_dict,
            "RecursionMode",((PyObject*)&SbkPySide_QtCore_QMutex_RecursionMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMutex_RecursionMode_Type,
        (long) QMutex::NonRecursive, "NonRecursive");
    PyDict_SetItemString(SbkQMutex_Type.super.ht_type.tp_dict,
        "NonRecursive", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMutex_RecursionMode_Type.tp_dict,
        "NonRecursive", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QMutex_RecursionMode_Type,
        (long) QMutex::Recursive, "Recursive");
    PyDict_SetItemString(SbkQMutex_Type.super.ht_type.tp_dict,
        "Recursive", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QMutex_RecursionMode_Type.tp_dict,
        "Recursive", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMutex::RecursionMode");


    Shiboken::TypeResolver::createObjectTypeResolver<QMutex >("QMutex*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMutex >(typeid(QMutex).name());
    PySide::initQtMetaType<QMutex* >();
}

