/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qpersistentmodelindex_wrapper.h"

// Extra includes
#include <qabstractitemmodel.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPersistentModelIndex_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPersistentModelIndex >()))
        return -1;

    QPersistentModelIndex* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPersistentModelIndex", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QPersistentModelIndex()
    // 1: QPersistentModelIndex(QModelIndex)
    // 2: QPersistentModelIndex(QPersistentModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QPersistentModelIndex()
    } else if (numArgs == 1 && Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 1; // QPersistentModelIndex(QModelIndex)
    } else if (numArgs == 1 && Shiboken::Converter<const QPersistentModelIndex & >::isConvertible(arg)) {
        overloadId = 2; // QPersistentModelIndex(QPersistentModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPersistentModelIndex_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPersistentModelIndex()
            {

                if(!PyErr_Occurred()) {
                // QPersistentModelIndex()
                cptr = new QPersistentModelIndex();
                }
                break;
            }
            case 1: // QPersistentModelIndex(QModelIndex)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QPersistentModelIndex(QModelIndex)
                cptr = new QPersistentModelIndex(*cpp_arg0);
                }
                break;
            }
            case 2: // QPersistentModelIndex(QPersistentModelIndex)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QPersistentModelIndex > cpp_arg0_auto_ptr;
                QPersistentModelIndex* cpp_arg0 = Shiboken::Converter<QPersistentModelIndex* >::toCpp(arg);
                if (!Shiboken::Converter<QPersistentModelIndex >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPersistentModelIndex >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPersistentModelIndex(QPersistentModelIndex)
                cptr = new QPersistentModelIndex(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPersistentModelIndex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPersistentModelIndex_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPersistentModelIndex_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QModelIndex", "PySide.QtCore.QPersistentModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QPersistentModelIndex", overloads);
        return -1;
}

static PyObject* SbkQPersistentModelIndexFunc_child(PyObject* self, PyObject* args)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "child", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: child(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // child(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPersistentModelIndexFunc_child_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // child(int,int)const
            QModelIndex cppResult = cppSelf->QPersistentModelIndex::child(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPersistentModelIndexFunc_child_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QPersistentModelIndex.child", overloads);
        return 0;
}

static PyObject* SbkQPersistentModelIndexFunc_column(PyObject* self)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // column()const
            int cppResult = cppSelf->QPersistentModelIndex::column();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPersistentModelIndexFunc_data(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "role" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QPersistentModelIndex.data(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QPersistentModelIndex.data(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:data", &arg))
        return 0;


    // Overloaded function decisor
    // 0: data(int)const
    if (numArgs == 0) {
        overloadId = 0; // data(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // data(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPersistentModelIndexFunc_data_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "role");
                if (value) {
                    if (arg)
                        errorArgName = "role";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QPersistentModelIndex.data(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : Qt::DisplayRole;

            if(!PyErr_Occurred()) {
            // data(int)const
            QVariant cppResult = cppSelf->QPersistentModelIndex::data(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPersistentModelIndexFunc_data_TypeError:
        const char* overloads[] = {"int = Qt.DisplayRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPersistentModelIndex.data", overloads);
        return 0;
}

static PyObject* SbkQPersistentModelIndexFunc_flags(PyObject* self)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flags()const
            QFlags<Qt::ItemFlag> cppResult = cppSelf->QPersistentModelIndex::flags();
            pyResult = Shiboken::Converter<QFlags<Qt::ItemFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPersistentModelIndexFunc_internalId(PyObject* self)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // internalId()const
            qint64 cppResult = cppSelf->QPersistentModelIndex::internalId();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPersistentModelIndexFunc_isValid(PyObject* self)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QPersistentModelIndex::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPersistentModelIndexFunc_model(PyObject* self)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // model()const
            const QAbstractItemModel * cppResult = cppSelf->QPersistentModelIndex::model();
            pyResult = Shiboken::Converter<const QAbstractItemModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPersistentModelIndexFunc_parent(PyObject* self)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parent()const
            QModelIndex cppResult = cppSelf->QPersistentModelIndex::parent();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPersistentModelIndexFunc_row(PyObject* self)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // row()const
            int cppResult = cppSelf->QPersistentModelIndex::row();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPersistentModelIndexFunc_sibling(PyObject* self, PyObject* args)
{
    QPersistentModelIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sibling", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sibling(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // sibling(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPersistentModelIndexFunc_sibling_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // sibling(int,int)const
            QModelIndex cppResult = cppSelf->QPersistentModelIndex::sibling(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPersistentModelIndexFunc_sibling_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QPersistentModelIndex.sibling", overloads);
        return 0;
}

static PyMethodDef SbkQPersistentModelIndex_methods[] = {
    {"child", (PyCFunction)SbkQPersistentModelIndexFunc_child, METH_VARARGS},
    {"column", (PyCFunction)SbkQPersistentModelIndexFunc_column, METH_NOARGS},
    {"data", (PyCFunction)SbkQPersistentModelIndexFunc_data, METH_VARARGS|METH_KEYWORDS},
    {"flags", (PyCFunction)SbkQPersistentModelIndexFunc_flags, METH_NOARGS},
    {"internalId", (PyCFunction)SbkQPersistentModelIndexFunc_internalId, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQPersistentModelIndexFunc_isValid, METH_NOARGS},
    {"model", (PyCFunction)SbkQPersistentModelIndexFunc_model, METH_NOARGS},
    {"parent", (PyCFunction)SbkQPersistentModelIndexFunc_parent, METH_NOARGS},
    {"row", (PyCFunction)SbkQPersistentModelIndexFunc_row, METH_NOARGS},
    {"sibling", (PyCFunction)SbkQPersistentModelIndexFunc_sibling, METH_VARARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQPersistentModelIndex_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QPersistentModelIndex& cpp_self = *Shiboken::Converter<QPersistentModelIndex* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QModelIndex & >::isConvertible(other)) {
                // operator!=(const QModelIndex & other) const
                QModelIndex* cpp_other = Shiboken::Converter<QModelIndex* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QModelIndex  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<const QPersistentModelIndex & >::isConvertible(other)) {
                // operator!=(const QPersistentModelIndex & other) const
                QPersistentModelIndex* cpp_other = Shiboken::Converter<QPersistentModelIndex* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPersistentModelIndex  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QPersistentModelIndex >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QPersistentModelIndex > cpp_other_auto_ptr;
                QPersistentModelIndex* cpp_other = Shiboken::Converter<QPersistentModelIndex* >::toCpp(other);
                if (!Shiboken::Converter<QPersistentModelIndex >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QPersistentModelIndex >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQPersistentModelIndex_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QPersistentModelIndex & >::isConvertible(other)) {
                // operator<(const QPersistentModelIndex & other) const
                QPersistentModelIndex* cpp_other = Shiboken::Converter<QPersistentModelIndex* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPersistentModelIndex  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else if (Shiboken::Converter<QPersistentModelIndex >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QPersistentModelIndex > cpp_other_auto_ptr;
                QPersistentModelIndex* cpp_other = Shiboken::Converter<QPersistentModelIndex* >::toCpp(other);
                if (!Shiboken::Converter<QPersistentModelIndex >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QPersistentModelIndex >(cpp_other);
                result = (cpp_self < (*cpp_other));
            } else goto SbkQPersistentModelIndex_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QModelIndex & >::isConvertible(other)) {
                // operator==(const QModelIndex & other) const
                QModelIndex* cpp_other = Shiboken::Converter<QModelIndex* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QModelIndex  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<const QPersistentModelIndex & >::isConvertible(other)) {
                // operator==(const QPersistentModelIndex & other) const
                QPersistentModelIndex* cpp_other = Shiboken::Converter<QPersistentModelIndex* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPersistentModelIndex  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QPersistentModelIndex >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QPersistentModelIndex > cpp_other_auto_ptr;
                QPersistentModelIndex* cpp_other = Shiboken::Converter<QPersistentModelIndex* >::toCpp(other);
                if (!Shiboken::Converter<QPersistentModelIndex >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QPersistentModelIndex >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQPersistentModelIndex_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQPersistentModelIndex_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPersistentModelIndex_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QPersistentModelIndex",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQPersistentModelIndex_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPersistentModelIndex_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPersistentModelIndex_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPersistentModelIndex >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPersistentModelIndex",
    /*user_data*/           0
};
} //extern


void init_QPersistentModelIndex(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QPERSISTENTMODELINDEX_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPersistentModelIndex_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPersistentModelIndex_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPersistentModelIndex_Type));
    PyModule_AddObject(module, "QPersistentModelIndex",
        ((PyObject*)&SbkQPersistentModelIndex_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QPersistentModelIndex >("QPersistentModelIndex");
    Shiboken::TypeResolver::createObjectTypeResolver<QPersistentModelIndex >("QPersistentModelIndex*");
    Shiboken::TypeResolver::createValueTypeResolver<QPersistentModelIndex >(typeid(QPersistentModelIndex).name());
    PySide::initQtMetaType<QPersistentModelIndex >();
}

