/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qpoint_wrapper.h"

// Extra includes
#include <qpoint.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPoint_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPoint >()))
        return -1;

    QPoint* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPoint", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QPoint(QPoint)
    // 1: QPoint()
    // 2: QPoint(int,int)
    if (numArgs == 0) {
        overloadId = 1; // QPoint()
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // QPoint(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QPoint(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPoint_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPoint(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QPoint(QPoint)
                cptr = new QPoint(*cpp_arg0);
                }
                break;
            }
            case 1: // QPoint()
            {

                if(!PyErr_Occurred()) {
                // QPoint()
                cptr = new QPoint();
                }
                break;
            }
            case 2: // QPoint(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QPoint(int,int)
                cptr = new QPoint(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPoint >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPoint_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPoint_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QPoint", overloads);
        return -1;
}

static PyObject* SbkQPointFunc_isNull(PyObject* self)
{
    QPoint* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QPoint::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPointFunc_manhattanLength(PyObject* self)
{
    QPoint* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // manhattanLength()const
            int cppResult = cppSelf->QPoint::manhattanLength();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPointFunc_setX(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc_setX_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setX(int)
            cppSelf->QPoint::setX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPointFunc_setX_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.setX", overloads);
        return 0;
}

static PyObject* SbkQPointFunc_setY(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc_setY_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setY(int)
            cppSelf->QPoint::setY(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPointFunc_setY_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.setY", overloads);
        return 0;
}

static PyObject* SbkQPointFunc_x(PyObject* self)
{
    QPoint* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x()const
            int cppResult = cppSelf->QPoint::x();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPointFunc_y(PyObject* self)
{
    QPoint* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y()const
            int cppResult = cppSelf->QPoint::y();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPoint_methods[] = {
    {"isNull", (PyCFunction)SbkQPointFunc_isNull, METH_NOARGS},
    {"manhattanLength", (PyCFunction)SbkQPointFunc_manhattanLength, METH_NOARGS},
    {"setX", (PyCFunction)SbkQPointFunc_setX, METH_O},
    {"setY", (PyCFunction)SbkQPointFunc_setY, METH_O},
    {"x", (PyCFunction)SbkQPointFunc_x, METH_NOARGS},
    {"y", (PyCFunction)SbkQPointFunc_y, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQPointFunc___mul__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QPoint,qreal)
    // 1: operator*(qreal,QPoint)
    if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*(qreal,QPoint)
    } else if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator*(QPoint,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QPoint,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPoint,qreal)
                const QPoint cppResult = (*cppSelf) * cpp_arg0;
                pyResult = Shiboken::Converter< QPoint >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(qreal,QPoint)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(qreal,QPoint) [reverse operator]
                const QPoint cppResult = cpp_arg0 * (*cppSelf);
                pyResult = Shiboken::Converter< QPoint >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPointFunc___mul___TypeError:
        const char* overloads[] = {"float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__mul__", overloads);
        return 0;
}

static PyObject* SbkQPointFunc___imul__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator*=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___imul___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator*=(qreal)
            (*cppSelf) *= cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPointFunc___imul___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__imul__", overloads);
        return 0;
}

static PyObject* SbkQPointFunc___add__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QPoint,QPoint)
    if (!isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // operator+(QPoint,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___add___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+(QPoint,QPoint)
            const QPoint cppResult = (*cppSelf) + (*cpp_arg0);
            pyResult = Shiboken::Converter< QPoint >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPointFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__add__", overloads);
        return 0;
}

static PyObject* SbkQPointFunc___iadd__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QPoint)
    if (!isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+=(QPoint)
            (*cppSelf) += (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPointFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__iadd__", overloads);
        return 0;
}

static PyObject* SbkQPointFunc___neg__(PyObject* self)
{
    QPoint* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // operator-(QPoint)
            const QPoint cppResult = - (*cppSelf);
            pyResult = Shiboken::Converter< QPoint >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPointFunc___sub__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QPoint,QPoint)
    if (!isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // operator-(QPoint,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-(QPoint,QPoint)
            const QPoint cppResult = (*cppSelf) - (*cpp_arg0);
            pyResult = Shiboken::Converter< QPoint >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPointFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__sub__", overloads);
        return 0;
}

static PyObject* SbkQPointFunc___isub__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QPoint)
    if (!isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-=(QPoint)
            (*cppSelf) -= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPointFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__isub__", overloads);
        return 0;
}

static PyObject* SbkQPointFunc___div__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QPoint,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QPoint,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/(QPoint,qreal)
            const QPoint cppResult = (*cppSelf) / cpp_arg0;
            pyResult = Shiboken::Converter< QPoint >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPointFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__div__", overloads);
        return 0;
}

static PyObject* SbkQPointFunc___idiv__(PyObject* self, PyObject* arg)
{
    QPoint* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPoint >::checkType(arg) && !Shiboken::Converter<QPoint >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPoint* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPointFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/=(qreal)
            (*cppSelf) /= cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPointFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QPoint.__idiv__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQPoint_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQPointFunc___add__,
    /*nb_subtract*/             (binaryfunc)SbkQPointFunc___sub__,
    /*nb_multiply*/             (binaryfunc)SbkQPointFunc___mul__,
    /*nb_divide*/               (binaryfunc)SbkQPointFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)SbkQPointFunc___neg__,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQPointFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)SbkQPointFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)SbkQPointFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)SbkQPointFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQPoint_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QPoint& cpp_self = *Shiboken::Converter<QPoint* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QPoint & >::isConvertible(other)) {
                // operator!=(const QPoint & p2)
                QPoint* cpp_other = Shiboken::Converter<QPoint* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPoint  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQPoint_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QPoint & >::isConvertible(other)) {
                // operator==(const QPoint & p2)
                QPoint* cpp_other = Shiboken::Converter<QPoint* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPoint  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQPoint_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQPoint_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPoint_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QPoint",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQPoint_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQPoint_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPoint_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPoint_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPoint >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPoint",
    /*user_data*/           0
};
} //extern


void init_QPoint(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QPOINT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPoint_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPoint_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPoint_Type));
    PyModule_AddObject(module, "QPoint",
        ((PyObject*)&SbkQPoint_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QPoint >("QPoint");
    Shiboken::TypeResolver::createObjectTypeResolver<QPoint >("QPoint*");
    Shiboken::TypeResolver::createValueTypeResolver<QPoint >(typeid(QPoint).name());
    PySide::initQtMetaType<QPoint >();
}

