/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qprocess_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qprocess.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QProcessWrapper::QProcessWrapper(QObject * parent) : QProcess(parent), m_metaObject(0) {
    // ... middle
}

bool QProcessWrapper::atEnd() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "atEnd"));
    if (py_override.isNull()) {
        return this->QProcess::atEnd();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.atEnd", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::bytesAvailable() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesAvailable"));
    if (py_override.isNull()) {
        return this->QProcess::bytesAvailable();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.bytesAvailable", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::bytesToWrite() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesToWrite"));
    if (py_override.isNull()) {
        return this->QProcess::bytesToWrite();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.bytesToWrite", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::canReadLine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "canReadLine"));
    if (py_override.isNull()) {
        return this->QProcess::canReadLine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.canReadLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QProcessWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QProcessWrapper::close()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QProcess::close();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QProcessWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QProcessWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QProcessWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QProcessWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QProcessWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QProcessWrapper::isSequential() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isSequential"));
    if (py_override.isNull()) {
        return this->QProcess::isSequential();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.isSequential", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::open(QFlags<QIODevice::OpenModeFlag> mode)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::open(mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::pos() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pos"));
    if (py_override.isNull()) {
        return this->QIODevice::pos();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.pos", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::readData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readData"));
    if (py_override.isNull()) {
        return this->QProcess::readData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.readData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::readLineData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readLineData"));
    if (py_override.isNull()) {
        return this->QIODevice::readLineData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.readLineData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QIODevice::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.reset", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::seek(qint64 pos)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::seek(pos);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(pos)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.seek", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QProcessWrapper::setupChildProcess()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setupChildProcess"));
    if (py_override.isNull()) {
        return this->QProcess::setupChildProcess();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

qint64 QProcessWrapper::size() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "size"));
    if (py_override.isNull()) {
        return this->QIODevice::size();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.size", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

void QProcessWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QProcessWrapper::waitForBytesWritten(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForBytesWritten"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QProcess::waitForBytesWritten(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.waitForBytesWritten", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::waitForReadyRead(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForReadyRead"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QProcess::waitForReadyRead(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.waitForReadyRead", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::writeData(const char * data, qint64 len)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "writeData"));
    if (py_override.isNull()) {
        return this->QProcess::writeData(data, len);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<const char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(len)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.writeData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QProcessWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QProcess::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QProcessWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QProcess::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QProcessWrapper::~QProcessWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQProcess_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QProcess >()))
        return -1;

    QProcessWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QProcess", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QProcess(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QProcess(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QProcess(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcess_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QProcess(QObject*)
            cptr = new QProcessWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QProcess >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQProcess_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQProcess_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess", overloads);
        return -1;
}

static PyObject* SbkQProcessFunc_atEnd(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QProcess::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_bytesAvailable(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesAvailable()const
            qint64 cppResult = cppSelf->QProcess::bytesAvailable();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_bytesToWrite(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesToWrite()const
            qint64 cppResult = cppSelf->QProcess::bytesToWrite();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_canReadLine(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canReadLine()const
            bool cppResult = cppSelf->QProcess::canReadLine();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_close(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // close()
            threadStateSaver.save();
            cppSelf->QProcess::close();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQProcessFunc_closeReadChannel(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: closeReadChannel(QProcess::ProcessChannel)
    if (Shiboken::Converter<QProcess::ProcessChannel >::isConvertible(arg)) {
        overloadId = 0; // closeReadChannel(QProcess::ProcessChannel)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_closeReadChannel_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessChannel cpp_arg0 = Shiboken::Converter<QProcess::ProcessChannel >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // closeReadChannel(QProcess::ProcessChannel)
            cppSelf->QProcess::closeReadChannel(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_closeReadChannel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessChannel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.closeReadChannel", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_closeWriteChannel(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // closeWriteChannel()
            cppSelf->QProcess::closeWriteChannel();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQProcessFunc_environment(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // environment()const
            QStringList cppResult = cppSelf->QProcess::environment();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_error(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QProcess::ProcessError cppResult = cppSelf->QProcess::error();
            pyResult = Shiboken::Converter<QProcess::ProcessError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_execute(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "execute", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: execute(QString)
    // 1: execute(QString,QStringList)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // execute(QString)
        } else if (numArgs == 2 && Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
            overloadId = 1; // execute(QString,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_execute_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // execute(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // execute(QString)
                threadStateSaver.save();
                int cppResult = QProcess::execute(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // execute(QString,QStringList)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // execute(QString,QStringList)
                threadStateSaver.save();
                int cppResult = QProcess::execute(cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_execute_TypeError:
        const char* overloads[] = {"QString", "QString, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.execute", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_exitCode(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // exitCode()const
            int cppResult = cppSelf->QProcess::exitCode();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_exitStatus(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // exitStatus()const
            QProcess::ExitStatus cppResult = cppSelf->QProcess::exitStatus();
            pyResult = Shiboken::Converter<QProcess::ExitStatus >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_isSequential(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSequential()const
            bool cppResult = cppSelf->QProcess::isSequential();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_kill(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // kill()
            cppSelf->QProcess::kill();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQProcessFunc_processChannelMode(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // processChannelMode()const
            QProcess::ProcessChannelMode cppResult = cppSelf->QProcess::processChannelMode();
            pyResult = Shiboken::Converter<QProcess::ProcessChannelMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_processEnvironment(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // processEnvironment()const
            QProcessEnvironment cppResult = cppSelf->QProcess::processEnvironment();
            pyResult = Shiboken::Converter<QProcessEnvironment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_readAllStandardError(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // readAllStandardError()
            threadStateSaver.save();
            QByteArray cppResult = cppSelf->QProcess::readAllStandardError();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_readAllStandardOutput(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // readAllStandardOutput()
            threadStateSaver.save();
            QByteArray cppResult = cppSelf->QProcess::readAllStandardOutput();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_readChannel(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readChannel()const
            QProcess::ProcessChannel cppResult = cppSelf->QProcess::readChannel();
            pyResult = Shiboken::Converter<QProcess::ProcessChannel >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_readData(PyObject* self, PyObject* args)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_readData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readData(char*,qint64)
            qint64 cppResult = cppSelf->QProcess::readData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_readData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.readData", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setEnvironment(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnvironment(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setEnvironment(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setEnvironment_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEnvironment(QStringList)
            cppSelf->QProcess::setEnvironment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setEnvironment_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setEnvironment", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setProcessChannelMode(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessChannelMode(QProcess::ProcessChannelMode)
    if (Shiboken::Converter<QProcess::ProcessChannelMode >::isConvertible(arg)) {
        overloadId = 0; // setProcessChannelMode(QProcess::ProcessChannelMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setProcessChannelMode_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessChannelMode cpp_arg0 = Shiboken::Converter<QProcess::ProcessChannelMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setProcessChannelMode(QProcess::ProcessChannelMode)
            cppSelf->QProcess::setProcessChannelMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setProcessChannelMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessChannelMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setProcessChannelMode", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setProcessEnvironment(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessEnvironment(QProcessEnvironment)
    if (Shiboken::Converter<const QProcessEnvironment & >::isConvertible(arg)) {
        overloadId = 0; // setProcessEnvironment(QProcessEnvironment)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setProcessEnvironment_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QProcessEnvironment* cpp_arg0 = Shiboken::Converter<QProcessEnvironment* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setProcessEnvironment(QProcessEnvironment)
            cppSelf->QProcess::setProcessEnvironment(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setProcessEnvironment_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcessEnvironment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setProcessEnvironment", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setProcessState(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessState(QProcess::ProcessState)
    if (Shiboken::Converter<QProcess::ProcessState >::isConvertible(arg)) {
        overloadId = 0; // setProcessState(QProcess::ProcessState)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setProcessState_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessState cpp_arg0 = Shiboken::Converter<QProcess::ProcessState >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setProcessState(QProcess::ProcessState)
            cppSelf->QProcess::setProcessState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setProcessState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setProcessState", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setReadChannel(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadChannel(QProcess::ProcessChannel)
    if (Shiboken::Converter<QProcess::ProcessChannel >::isConvertible(arg)) {
        overloadId = 0; // setReadChannel(QProcess::ProcessChannel)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setReadChannel_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessChannel cpp_arg0 = Shiboken::Converter<QProcess::ProcessChannel >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setReadChannel(QProcess::ProcessChannel)
            cppSelf->QProcess::setReadChannel(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setReadChannel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessChannel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setReadChannel", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setStandardErrorFile(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardErrorFile(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardErrorFile(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardErrorFile(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setStandardErrorFile", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setStandardErrorFile_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardErrorFile(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<QIODevice::OpenModeFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::Truncate;

            if(!PyErr_Occurred()) {
            // setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
            cppSelf->QProcess::setStandardErrorFile(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setStandardErrorFile_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.Truncate", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.setStandardErrorFile", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setStandardInputFile(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStandardInputFile(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setStandardInputFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setStandardInputFile_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStandardInputFile(QString)
            cppSelf->QProcess::setStandardInputFile(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setStandardInputFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setStandardInputFile", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setStandardOutputFile(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardOutputFile(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardOutputFile(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardOutputFile(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setStandardOutputFile", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setStandardOutputFile_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardOutputFile(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<QIODevice::OpenModeFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::Truncate;

            if(!PyErr_Occurred()) {
            // setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
            cppSelf->QProcess::setStandardOutputFile(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setStandardOutputFile_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.Truncate", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.setStandardOutputFile", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setStandardOutputProcess(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStandardOutputProcess(QProcess*)
    if (Shiboken::Converter<QProcess * >::isConvertible(arg)) {
        overloadId = 0; // setStandardOutputProcess(QProcess*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setStandardOutputProcess_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QProcess* cpp_arg0 = Shiboken::Converter<QProcess* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStandardOutputProcess(QProcess*)
            cppSelf->QProcess::setStandardOutputProcess(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setStandardOutputProcess_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setStandardOutputProcess", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setWorkingDirectory(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWorkingDirectory(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWorkingDirectory(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_setWorkingDirectory_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWorkingDirectory(QString)
            cppSelf->QProcess::setWorkingDirectory(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_setWorkingDirectory_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setWorkingDirectory", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_setupChildProcess(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // setupChildProcess()
            cppSelf->QProcess::setupChildProcess();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQProcessFunc_start(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.start(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.start(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.start(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:start", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: start(QString,QFlags<QIODevice::OpenModeFlag>)
    // 1: start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // start(QString,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
            } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
            }
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // start(QString,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_start_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // start(QString,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.start(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QFlags<QIODevice::OpenModeFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // start(QString,QFlags<QIODevice::OpenModeFlag>)
                cppSelf->QProcess::start(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.start(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
                QFlags<QIODevice::OpenModeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
                cppSelf->QProcess::start(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQProcessFunc_start_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", "QString, list, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.start", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_startDetached(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "startDetached", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: startDetached(QString)
    // 1: startDetached(QString,QStringList)
    // 2: startDetached(QString,QStringList,QString,qint64*)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // startDetached(QString)
        } else if (Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // startDetached(QString,QStringList)
            } else if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
                overloadId = 2; // startDetached(QString,QStringList,QString,qint64*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_startDetached_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // startDetached(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // startDetached(QString)
                bool cppResult = QProcess::startDetached(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // startDetached(QString,QStringList)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // startDetached(QString,QStringList)
                bool cppResult = QProcess::startDetached(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // startDetached(QString,QStringList,QString,qint64*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // startDetached(QString,QStringList,QString,qint64*)
                // Begin code injection
                
                qint64 pid;
                bool retval = QProcess::startDetached(cpp_arg0, cpp_arg1, cpp_arg2, &pid);
                pyResult = Shiboken::makeTuple(retval, pid);
                
                // End of code injection


                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_startDetached_TypeError:
        const char* overloads[] = {"QString", "QString, list", "QString, list, QString, qint64 = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.startDetached", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_state(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QProcess::ProcessState cppResult = cppSelf->QProcess::state();
            pyResult = Shiboken::Converter<QProcess::ProcessState >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_systemEnvironment(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // systemEnvironment()
            QStringList cppResult = QProcess::systemEnvironment();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_terminate(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // terminate()
            cppSelf->QProcess::terminate();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQProcessFunc_waitForBytesWritten(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForBytesWritten(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForBytesWritten(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForBytesWritten", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForBytesWritten(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForBytesWritten(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_waitForBytesWritten_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForBytesWritten(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForBytesWritten(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QProcess::waitForBytesWritten(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_waitForBytesWritten_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.waitForBytesWritten", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_waitForFinished(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForFinished(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForFinished(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForFinished", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForFinished(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForFinished(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForFinished(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_waitForFinished_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForFinished(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForFinished(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QProcess::waitForFinished(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_waitForFinished_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.waitForFinished", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_waitForReadyRead(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForReadyRead(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForReadyRead(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForReadyRead", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForReadyRead(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForReadyRead(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_waitForReadyRead_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForReadyRead(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForReadyRead(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QProcess::waitForReadyRead(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_waitForReadyRead_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.waitForReadyRead", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_waitForStarted(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForStarted(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForStarted(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForStarted", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForStarted(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForStarted(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForStarted(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_waitForStarted_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForStarted(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForStarted(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QProcess::waitForStarted(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_waitForStarted_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.waitForStarted", overloads);
        return 0;
}

static PyObject* SbkQProcessFunc_workingDirectory(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // workingDirectory()const
            QString cppResult = cppSelf->QProcess::workingDirectory();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQProcessFunc_writeData(PyObject* self, PyObject* args)
{
    QProcess* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeData(const char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQProcessFunc_writeData_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // writeData(const char*,qint64)
            qint64 cppResult = cppSelf->QProcess::writeData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQProcessFunc_writeData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.writeData", overloads);
        return 0;
}

static PyMethodDef SbkQProcess_methods[] = {
    {"atEnd", (PyCFunction)SbkQProcessFunc_atEnd, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)SbkQProcessFunc_bytesAvailable, METH_NOARGS},
    {"bytesToWrite", (PyCFunction)SbkQProcessFunc_bytesToWrite, METH_NOARGS},
    {"canReadLine", (PyCFunction)SbkQProcessFunc_canReadLine, METH_NOARGS},
    {"close", (PyCFunction)SbkQProcessFunc_close, METH_NOARGS},
    {"closeReadChannel", (PyCFunction)SbkQProcessFunc_closeReadChannel, METH_O},
    {"closeWriteChannel", (PyCFunction)SbkQProcessFunc_closeWriteChannel, METH_NOARGS},
    {"environment", (PyCFunction)SbkQProcessFunc_environment, METH_NOARGS},
    {"error", (PyCFunction)SbkQProcessFunc_error, METH_NOARGS},
    {"execute", (PyCFunction)SbkQProcessFunc_execute, METH_VARARGS|METH_STATIC},
    {"exitCode", (PyCFunction)SbkQProcessFunc_exitCode, METH_NOARGS},
    {"exitStatus", (PyCFunction)SbkQProcessFunc_exitStatus, METH_NOARGS},
    {"isSequential", (PyCFunction)SbkQProcessFunc_isSequential, METH_NOARGS},
    {"kill", (PyCFunction)SbkQProcessFunc_kill, METH_NOARGS},
    {"processChannelMode", (PyCFunction)SbkQProcessFunc_processChannelMode, METH_NOARGS},
    {"processEnvironment", (PyCFunction)SbkQProcessFunc_processEnvironment, METH_NOARGS},
    {"readAllStandardError", (PyCFunction)SbkQProcessFunc_readAllStandardError, METH_NOARGS},
    {"readAllStandardOutput", (PyCFunction)SbkQProcessFunc_readAllStandardOutput, METH_NOARGS},
    {"readChannel", (PyCFunction)SbkQProcessFunc_readChannel, METH_NOARGS},
    {"readData", (PyCFunction)SbkQProcessFunc_readData, METH_VARARGS},
    {"setEnvironment", (PyCFunction)SbkQProcessFunc_setEnvironment, METH_O},
    {"setProcessChannelMode", (PyCFunction)SbkQProcessFunc_setProcessChannelMode, METH_O},
    {"setProcessEnvironment", (PyCFunction)SbkQProcessFunc_setProcessEnvironment, METH_O},
    {"setProcessState", (PyCFunction)SbkQProcessFunc_setProcessState, METH_O},
    {"setReadChannel", (PyCFunction)SbkQProcessFunc_setReadChannel, METH_O},
    {"setStandardErrorFile", (PyCFunction)SbkQProcessFunc_setStandardErrorFile, METH_VARARGS|METH_KEYWORDS},
    {"setStandardInputFile", (PyCFunction)SbkQProcessFunc_setStandardInputFile, METH_O},
    {"setStandardOutputFile", (PyCFunction)SbkQProcessFunc_setStandardOutputFile, METH_VARARGS|METH_KEYWORDS},
    {"setStandardOutputProcess", (PyCFunction)SbkQProcessFunc_setStandardOutputProcess, METH_O},
    {"setWorkingDirectory", (PyCFunction)SbkQProcessFunc_setWorkingDirectory, METH_O},
    {"setupChildProcess", (PyCFunction)SbkQProcessFunc_setupChildProcess, METH_NOARGS},
    {"start", (PyCFunction)SbkQProcessFunc_start, METH_VARARGS|METH_KEYWORDS},
    {"startDetached", (PyCFunction)SbkQProcessFunc_startDetached, METH_VARARGS|METH_STATIC},
    {"state", (PyCFunction)SbkQProcessFunc_state, METH_NOARGS},
    {"systemEnvironment", (PyCFunction)SbkQProcessFunc_systemEnvironment, METH_NOARGS|METH_STATIC},
    {"terminate", (PyCFunction)SbkQProcessFunc_terminate, METH_NOARGS},
    {"waitForBytesWritten", (PyCFunction)SbkQProcessFunc_waitForBytesWritten, METH_VARARGS|METH_KEYWORDS},
    {"waitForFinished", (PyCFunction)SbkQProcessFunc_waitForFinished, METH_VARARGS|METH_KEYWORDS},
    {"waitForReadyRead", (PyCFunction)SbkQProcessFunc_waitForReadyRead, METH_VARARGS|METH_KEYWORDS},
    {"waitForStarted", (PyCFunction)SbkQProcessFunc_waitForStarted, METH_VARARGS|METH_KEYWORDS},
    {"workingDirectory", (PyCFunction)SbkQProcessFunc_workingDirectory, METH_NOARGS},
    {"writeData", (PyCFunction)SbkQProcessFunc_writeData, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQProcess_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QProcess",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQProcess_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQProcess_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QProcess >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QProcess*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQProcess_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QProcess*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQProcess_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtCore_QProcess_ProcessError_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QProcess_ProcessError_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QProcess_ProcessError_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ProcessError",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QProcess_ProcessError_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QProcess_ProcessError_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QProcess_ProcessError_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QProcess_ProcessChannelMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QProcess_ProcessChannelMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QProcess_ProcessChannelMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ProcessChannelMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QProcess_ProcessChannelMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QProcess_ProcessChannelMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QProcess_ProcessChannelMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QProcess_ProcessChannel_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QProcess_ProcessChannel_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QProcess_ProcessChannel_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ProcessChannel",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QProcess_ProcessChannel_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QProcess_ProcessChannel_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QProcess_ProcessChannel_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QProcess_ProcessState_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QProcess_ProcessState_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QProcess_ProcessState_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ProcessState",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QProcess_ProcessState_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QProcess_ProcessState_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QProcess_ProcessState_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QProcess_ExitStatus_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QProcess_ExitStatus_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QProcess_ExitStatus_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ExitStatus",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QProcess_ExitStatus_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QProcess_ExitStatus_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QProcess_ExitStatus_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QProcess(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QPROCESS_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQProcess_Type);

    SbkQProcess_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX];
    // Fill type discovery information
    SbkQProcess_Type.type_discovery = &SbkQProcess_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX]), &SbkQProcess_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQProcess_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQProcess_Type));
    PyModule_AddObject(module, "QProcess",
        ((PyObject*)&SbkQProcess_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ProcessError
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSERROR_IDX] = &SbkPySide_QtCore_QProcess_ProcessError_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QProcess_ProcessError_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QProcess_ProcessError_Type);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
            "ProcessError",((PyObject*)&SbkPySide_QtCore_QProcess_ProcessError_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessError_Type,
        (long) QProcess::FailedToStart, "FailedToStart");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "FailedToStart", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError_Type.tp_dict,
        "FailedToStart", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessError_Type,
        (long) QProcess::Crashed, "Crashed");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "Crashed", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError_Type.tp_dict,
        "Crashed", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessError_Type,
        (long) QProcess::Timedout, "Timedout");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "Timedout", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError_Type.tp_dict,
        "Timedout", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessError_Type,
        (long) QProcess::ReadError, "ReadError");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "ReadError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError_Type.tp_dict,
        "ReadError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessError_Type,
        (long) QProcess::WriteError, "WriteError");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "WriteError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError_Type.tp_dict,
        "WriteError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessError_Type,
        (long) QProcess::UnknownError, "UnknownError");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "UnknownError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError_Type.tp_dict,
        "UnknownError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessError");

    // init enum class: ProcessChannelMode
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSCHANNELMODE_IDX] = &SbkPySide_QtCore_QProcess_ProcessChannelMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QProcess_ProcessChannelMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QProcess_ProcessChannelMode_Type);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
            "ProcessChannelMode",((PyObject*)&SbkPySide_QtCore_QProcess_ProcessChannelMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessChannelMode_Type,
        (long) QProcess::SeparateChannels, "SeparateChannels");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "SeparateChannels", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannelMode_Type.tp_dict,
        "SeparateChannels", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessChannelMode_Type,
        (long) QProcess::MergedChannels, "MergedChannels");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "MergedChannels", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannelMode_Type.tp_dict,
        "MergedChannels", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessChannelMode_Type,
        (long) QProcess::ForwardedChannels, "ForwardedChannels");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "ForwardedChannels", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannelMode_Type.tp_dict,
        "ForwardedChannels", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessChannelMode");

    // init enum class: ProcessChannel
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSCHANNEL_IDX] = &SbkPySide_QtCore_QProcess_ProcessChannel_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QProcess_ProcessChannel_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QProcess_ProcessChannel_Type);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
            "ProcessChannel",((PyObject*)&SbkPySide_QtCore_QProcess_ProcessChannel_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessChannel_Type,
        (long) QProcess::StandardOutput, "StandardOutput");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "StandardOutput", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannel_Type.tp_dict,
        "StandardOutput", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessChannel_Type,
        (long) QProcess::StandardError, "StandardError");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "StandardError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannel_Type.tp_dict,
        "StandardError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessChannel");

    // init enum class: ProcessState
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSSTATE_IDX] = &SbkPySide_QtCore_QProcess_ProcessState_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QProcess_ProcessState_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QProcess_ProcessState_Type);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
            "ProcessState",((PyObject*)&SbkPySide_QtCore_QProcess_ProcessState_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessState_Type,
        (long) QProcess::NotRunning, "NotRunning");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "NotRunning", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessState_Type.tp_dict,
        "NotRunning", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessState_Type,
        (long) QProcess::Starting, "Starting");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "Starting", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessState_Type.tp_dict,
        "Starting", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ProcessState_Type,
        (long) QProcess::Running, "Running");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "Running", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessState_Type.tp_dict,
        "Running", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessState");

    // init enum class: ExitStatus
    SbkPySide_QtCoreTypes[SBK_QPROCESS_EXITSTATUS_IDX] = &SbkPySide_QtCore_QProcess_ExitStatus_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QProcess_ExitStatus_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QProcess_ExitStatus_Type);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
            "ExitStatus",((PyObject*)&SbkPySide_QtCore_QProcess_ExitStatus_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ExitStatus_Type,
        (long) QProcess::NormalExit, "NormalExit");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "NormalExit", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ExitStatus_Type.tp_dict,
        "NormalExit", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QProcess_ExitStatus_Type,
        (long) QProcess::CrashExit, "CrashExit");
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict,
        "CrashExit", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ExitStatus_Type.tp_dict,
        "CrashExit", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ExitStatus");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("error", "QProcess::ProcessError", NULL);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict, "error", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("started", "void", NULL);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict, "started", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("finished", "int", "int,QProcess::ExitStatus", NULL);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict, "finished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("readyReadStandardError", "void", NULL);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict, "readyReadStandardError", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("readyReadStandardOutput", "void", NULL);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict, "readyReadStandardOutput", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "QProcess::ProcessState", NULL);
    PyDict_SetItemString(SbkQProcess_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QProcess >("QProcess*");
    Shiboken::TypeResolver::createObjectTypeResolver<QProcess >(typeid(QProcess).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QProcess >(typeid(QProcessWrapper).name());
    PySide::initQtMetaType<QProcess* >();
}

