/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qreadwritelock_wrapper.h"

// Extra includes
#include <qreadwritelock.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQReadWriteLock_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QReadWriteLock >()))
        return -1;

    QReadWriteLock* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QReadWriteLock", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QReadWriteLock()
    // 1: QReadWriteLock(QReadWriteLock::RecursionMode)
    if (numArgs == 0) {
        overloadId = 0; // QReadWriteLock()
    } else if (numArgs == 1 && Shiboken::Converter<QReadWriteLock::RecursionMode >::isConvertible(arg)) {
        overloadId = 1; // QReadWriteLock(QReadWriteLock::RecursionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQReadWriteLock_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QReadWriteLock()
            {

                if(!PyErr_Occurred()) {
                // QReadWriteLock()
                cptr = new QReadWriteLock();
                }
                break;
            }
            case 1: // QReadWriteLock(QReadWriteLock::RecursionMode)
            {
                QReadWriteLock::RecursionMode cpp_arg0 = Shiboken::Converter<QReadWriteLock::RecursionMode >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QReadWriteLock(QReadWriteLock::RecursionMode)
                cptr = new QReadWriteLock(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QReadWriteLock >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQReadWriteLock_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQReadWriteLock_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QReadWriteLock.RecursionMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QReadWriteLock", overloads);
        return -1;
}

static PyObject* SbkQReadWriteLockFunc_lockForRead(PyObject* self)
{
    QReadWriteLock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QReadWriteLock* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // lockForRead()
            threadStateSaver.save();
            cppSelf->QReadWriteLock::lockForRead();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQReadWriteLockFunc_lockForWrite(PyObject* self)
{
    QReadWriteLock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QReadWriteLock* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // lockForWrite()
            threadStateSaver.save();
            cppSelf->QReadWriteLock::lockForWrite();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQReadWriteLockFunc_tryLockForRead(PyObject* self, PyObject* arg)
{
    QReadWriteLock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QReadWriteLock* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: tryLockForRead()
    // 1: tryLockForRead(int)
    if (numArgs == 0) {
        overloadId = 0; // tryLockForRead()
    } else if (SbkNumber_Check(arg)) {
        overloadId = 1; // tryLockForRead(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQReadWriteLockFunc_tryLockForRead_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // tryLockForRead()
            {

                if(!PyErr_Occurred()) {
                // tryLockForRead()
                bool cppResult = cppSelf->QReadWriteLock::tryLockForRead();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // tryLockForRead(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // tryLockForRead(int)
                threadStateSaver.save();
                bool cppResult = cppSelf->QReadWriteLock::tryLockForRead(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQReadWriteLockFunc_tryLockForRead_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QReadWriteLock.tryLockForRead", overloads);
        return 0;
}

static PyObject* SbkQReadWriteLockFunc_tryLockForWrite(PyObject* self, PyObject* arg)
{
    QReadWriteLock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QReadWriteLock* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: tryLockForWrite()
    // 1: tryLockForWrite(int)
    if (numArgs == 0) {
        overloadId = 0; // tryLockForWrite()
    } else if (SbkNumber_Check(arg)) {
        overloadId = 1; // tryLockForWrite(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQReadWriteLockFunc_tryLockForWrite_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // tryLockForWrite()
            {

                if(!PyErr_Occurred()) {
                // tryLockForWrite()
                bool cppResult = cppSelf->QReadWriteLock::tryLockForWrite();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // tryLockForWrite(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // tryLockForWrite(int)
                threadStateSaver.save();
                bool cppResult = cppSelf->QReadWriteLock::tryLockForWrite(cpp_arg0);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQReadWriteLockFunc_tryLockForWrite_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QReadWriteLock.tryLockForWrite", overloads);
        return 0;
}

static PyObject* SbkQReadWriteLockFunc_unlock(PyObject* self)
{
    QReadWriteLock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QReadWriteLock* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unlock()
            cppSelf->QReadWriteLock::unlock();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQReadWriteLock_methods[] = {
    {"lockForRead", (PyCFunction)SbkQReadWriteLockFunc_lockForRead, METH_NOARGS},
    {"lockForWrite", (PyCFunction)SbkQReadWriteLockFunc_lockForWrite, METH_NOARGS},
    {"tryLockForRead", (PyCFunction)SbkQReadWriteLockFunc_tryLockForRead, METH_NOARGS|METH_O},
    {"tryLockForWrite", (PyCFunction)SbkQReadWriteLockFunc_tryLockForWrite, METH_NOARGS|METH_O},
    {"unlock", (PyCFunction)SbkQReadWriteLockFunc_unlock, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQReadWriteLock_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QReadWriteLock",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQReadWriteLock_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQReadWriteLock_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QReadWriteLock >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QReadWriteLock*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QReadWriteLock_RecursionMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QReadWriteLock_RecursionMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RecursionMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QReadWriteLock_RecursionMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QReadWriteLock_RecursionMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QReadWriteLock_RecursionMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QReadWriteLock(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QREADWRITELOCK_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQReadWriteLock_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQReadWriteLock_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQReadWriteLock_Type));
    PyModule_AddObject(module, "QReadWriteLock",
        ((PyObject*)&SbkQReadWriteLock_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: RecursionMode
    SbkPySide_QtCoreTypes[SBK_QREADWRITELOCK_RECURSIONMODE_IDX] = &SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type);
    PyDict_SetItemString(SbkQReadWriteLock_Type.super.ht_type.tp_dict,
            "RecursionMode",((PyObject*)&SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type,
        (long) QReadWriteLock::NonRecursive, "NonRecursive");
    PyDict_SetItemString(SbkQReadWriteLock_Type.super.ht_type.tp_dict,
        "NonRecursive", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type.tp_dict,
        "NonRecursive", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type,
        (long) QReadWriteLock::Recursive, "Recursive");
    PyDict_SetItemString(SbkQReadWriteLock_Type.super.ht_type.tp_dict,
        "Recursive", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QReadWriteLock_RecursionMode_Type.tp_dict,
        "Recursive", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QReadWriteLock::RecursionMode");


    Shiboken::TypeResolver::createObjectTypeResolver<QReadWriteLock >("QReadWriteLock*");
    Shiboken::TypeResolver::createObjectTypeResolver<QReadWriteLock >(typeid(QReadWriteLock).name());
    PySide::initQtMetaType<QReadWriteLock* >();
}

