/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qrect_wrapper.h"

// Extra includes
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQRect_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QRect >()))
        return -1;

    QRect* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQRect_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QRect", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QRect(QRect)
    // 1: QRect()
    // 2: QRect(QPoint,QPoint)
    // 3: QRect(QPoint,QSize)
    // 4: QRect(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 1; // QRect()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 4; // QRect(int,int,int,int)
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[1])) {
            overloadId = 3; // QRect(QPoint,QSize)
        } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
            overloadId = 2; // QRect(QPoint,QPoint)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRect_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QRect(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QRect(QRect)
                cptr = new QRect(*cpp_arg0);
                }
                break;
            }
            case 1: // QRect()
            {

                if(!PyErr_Occurred()) {
                // QRect()
                cptr = new QRect();
                }
                break;
            }
            case 2: // QRect(QPoint,QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QRect(QPoint,QPoint)
                cptr = new QRect(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // QRect(QPoint,QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QSize* cpp_arg1 = Shiboken::Converter<QSize* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QRect(QPoint,QSize)
                cptr = new QRect(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // QRect(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // QRect(int,int,int,int)
                cptr = new QRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QRect >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQRect_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQRect_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "", "PySide.QtCore.QPoint, PySide.QtCore.QPoint", "PySide.QtCore.QPoint, PySide.QtCore.QSize", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect", overloads);
        return -1;
}

static PyObject* SbkQRectFunc_adjust(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjust", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjust(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // adjust(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_adjust_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // adjust(int,int,int,int)
            cppSelf->QRect::adjust(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_adjust_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.adjust", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_adjusted(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjusted", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjusted(int,int,int,int)const
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // adjusted(int,int,int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_adjusted_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // adjusted(int,int,int,int)const
            QRect cppResult = cppSelf->QRect::adjusted(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_adjusted_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.adjusted", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_bottom(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottom()const
            int cppResult = cppSelf->QRect::bottom();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_bottomLeft(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottomLeft()const
            QPoint cppResult = cppSelf->QRect::bottomLeft();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_bottomRight(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottomRight()const
            QPoint cppResult = cppSelf->QRect::bottomRight();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_center(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // center()const
            QPoint cppResult = cppSelf->QRect::center();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_contains(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "proper" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRect.contains(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRect.contains(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRect.contains(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:contains", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: contains(QPoint,bool)const
    // 1: contains(QRect,bool)const
    // 2: contains(int,int)const
    // 3: contains(int,int,bool)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // contains(int,int)const
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 3; // contains(int,int,bool)const
        }
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // contains(QRect,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // contains(QRect,bool)const
        }
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // contains(QPoint,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // contains(QPoint,bool)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_contains_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // contains(QPoint,bool)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "proper");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "proper";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRect.contains(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

                if(!PyErr_Occurred()) {
                // contains(QPoint,bool)const
                bool cppResult = cppSelf->QRect::contains(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // contains(QRect,bool)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "proper");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "proper";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRect.contains(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

                if(!PyErr_Occurred()) {
                // contains(QRect,bool)const
                bool cppResult = cppSelf->QRect::contains(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // contains(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // contains(int,int)const
                bool cppResult = cppSelf->QRect::contains(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // contains(int,int,bool)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                bool cpp_arg2 = Shiboken::Converter<bool >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // contains(int,int,bool)const
                bool cppResult = cppSelf->QRect::contains(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, bool = false", "PySide.QtCore.QRect, bool = false", "int, int", "int, int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.contains", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_height(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            int cppResult = cppSelf->QRect::height();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_intersect(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersect(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // intersect(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_intersect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // intersect(QRect)const
            QRect cppResult = cppSelf->QRect::intersect(*cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_intersect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.intersect", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_intersected(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // intersected(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // intersected(QRect)const
            QRect cppResult = cppSelf->QRect::intersected(*cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.intersected", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_intersects(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // intersects(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_intersects_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // intersects(QRect)const
            bool cppResult = cppSelf->QRect::intersects(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.intersects", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_isEmpty(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QRect::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_isNull(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QRect::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_isValid(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QRect::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_left(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // left()const
            int cppResult = cppSelf->QRect::left();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_moveBottom(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottom(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveBottom(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveBottom_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveBottom(int)
            cppSelf->QRect::moveBottom(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveBottom_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveBottom", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveBottomLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomLeft(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // moveBottomLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveBottomLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveBottomLeft(QPoint)
            cppSelf->QRect::moveBottomLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveBottomLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveBottomRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomRight(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // moveBottomRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveBottomRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveBottomRight(QPoint)
            cppSelf->QRect::moveBottomRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveBottomRight", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveCenter(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveCenter(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // moveCenter(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveCenter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveCenter(QPoint)
            cppSelf->QRect::moveCenter(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveCenter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveCenter", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveLeft(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveLeft(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveLeft_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveLeft(int)
            cppSelf->QRect::moveLeft(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveLeft_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveRight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveRight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveRight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveRight(int)
            cppSelf->QRect::moveRight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveRight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveRight", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveTo(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveTo", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveTo(QPoint)
    // 1: moveTo(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // moveTo(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // moveTo(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // moveTo(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // moveTo(QPoint)
                cppSelf->QRect::moveTo(*cpp_arg0);
                }
                break;
            }
            case 1: // moveTo(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // moveTo(int,int)
                cppSelf->QRect::moveTo(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.moveTo", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveTop(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTop(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveTop(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveTop_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveTop(int)
            cppSelf->QRect::moveTop(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveTop_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveTop", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveTopLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopLeft(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // moveTopLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveTopLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveTopLeft(QPoint)
            cppSelf->QRect::moveTopLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveTopLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_moveTopRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopRight(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // moveTopRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_moveTopRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveTopRight(QPoint)
            cppSelf->QRect::moveTopRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_moveTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveTopRight", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_normalized(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalized()const
            QRect cppResult = cppSelf->QRect::normalized();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_right(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // right()const
            int cppResult = cppSelf->QRect::right();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_setBottom(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottom(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottom(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setBottom_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBottom(int)
            cppSelf->QRect::setBottom(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setBottom_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setBottom", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setBottomLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomLeft(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setBottomLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setBottomLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBottomLeft(QPoint)
            cppSelf->QRect::setBottomLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setBottomLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setBottomRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomRight(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setBottomRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setBottomRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBottomRight(QPoint)
            cppSelf->QRect::setBottomRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setBottomRight", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setCoords(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCoords", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setCoords(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // setCoords(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setCoords_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // setCoords(int,int,int,int)
            cppSelf->QRect::setCoords(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setCoords_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.setCoords", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setHeight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setHeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHeight(int)
            cppSelf->QRect::setHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setHeight", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeft(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeft(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setLeft_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLeft(int)
            cppSelf->QRect::setLeft(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setLeft_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setRect(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRect", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRect(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // setRect(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setRect_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // setRect(int,int,int,int)
            cppSelf->QRect::setRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setRect_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.setRect", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setRight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRight(int)
            cppSelf->QRect::setRight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setRight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setRight", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setSize(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSize(QSize)
    if (Shiboken::Converter<const QSize & >::isConvertible(arg)) {
        overloadId = 0; // setSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSize(QSize)
            cppSelf->QRect::setSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setSize", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setTop(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTop(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTop(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setTop_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTop(int)
            cppSelf->QRect::setTop(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setTop_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setTop", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setTopLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopLeft(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setTopLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setTopLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTopLeft(QPoint)
            cppSelf->QRect::setTopLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setTopLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setTopRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopRight(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setTopRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setTopRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTopRight(QPoint)
            cppSelf->QRect::setTopRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setTopRight", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setWidth(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidth(int)
            cppSelf->QRect::setWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setWidth", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setX(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setX_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setX(int)
            cppSelf->QRect::setX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setX_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setX", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_setY(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_setY_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setY(int)
            cppSelf->QRect::setY(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_setY_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setY", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_size(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSize cppResult = cppSelf->QRect::size();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_top(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // top()const
            int cppResult = cppSelf->QRect::top();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_topLeft(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topLeft()const
            QPoint cppResult = cppSelf->QRect::topLeft();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_topRight(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topRight()const
            QPoint cppResult = cppSelf->QRect::topRight();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_translate(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPoint)
    // 1: translate(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // translate(QPoint)
                cppSelf->QRect::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(int,int)
                cppSelf->QRect::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.translate", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_translated(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPoint)const
    // 1: translated(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // translated(QPoint)const
                QRect cppResult = cppSelf->QRect::translated(*cpp_arg0);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translated(int,int)const
                QRect cppResult = cppSelf->QRect::translated(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.translated", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_unite(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unite(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // unite(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_unite_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // unite(QRect)const
            QRect cppResult = cppSelf->QRect::unite(*cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_unite_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.unite", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_united(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // united(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc_united_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // united(QRect)const
            QRect cppResult = cppSelf->QRect::united(*cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.united", overloads);
        return 0;
}

static PyObject* SbkQRectFunc_width(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            int cppResult = cppSelf->QRect::width();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_x(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x()const
            int cppResult = cppSelf->QRect::x();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFunc_y(PyObject* self)
{
    QRect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y()const
            int cppResult = cppSelf->QRect::y();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQRect_methods[] = {
    {"adjust", (PyCFunction)SbkQRectFunc_adjust, METH_VARARGS},
    {"adjusted", (PyCFunction)SbkQRectFunc_adjusted, METH_VARARGS},
    {"bottom", (PyCFunction)SbkQRectFunc_bottom, METH_NOARGS},
    {"bottomLeft", (PyCFunction)SbkQRectFunc_bottomLeft, METH_NOARGS},
    {"bottomRight", (PyCFunction)SbkQRectFunc_bottomRight, METH_NOARGS},
    {"center", (PyCFunction)SbkQRectFunc_center, METH_NOARGS},
    {"contains", (PyCFunction)SbkQRectFunc_contains, METH_VARARGS|METH_KEYWORDS},
    {"height", (PyCFunction)SbkQRectFunc_height, METH_NOARGS},
    {"intersect", (PyCFunction)SbkQRectFunc_intersect, METH_O},
    {"intersected", (PyCFunction)SbkQRectFunc_intersected, METH_O},
    {"intersects", (PyCFunction)SbkQRectFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)SbkQRectFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQRectFunc_isNull, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQRectFunc_isValid, METH_NOARGS},
    {"left", (PyCFunction)SbkQRectFunc_left, METH_NOARGS},
    {"moveBottom", (PyCFunction)SbkQRectFunc_moveBottom, METH_O},
    {"moveBottomLeft", (PyCFunction)SbkQRectFunc_moveBottomLeft, METH_O},
    {"moveBottomRight", (PyCFunction)SbkQRectFunc_moveBottomRight, METH_O},
    {"moveCenter", (PyCFunction)SbkQRectFunc_moveCenter, METH_O},
    {"moveLeft", (PyCFunction)SbkQRectFunc_moveLeft, METH_O},
    {"moveRight", (PyCFunction)SbkQRectFunc_moveRight, METH_O},
    {"moveTo", (PyCFunction)SbkQRectFunc_moveTo, METH_VARARGS},
    {"moveTop", (PyCFunction)SbkQRectFunc_moveTop, METH_O},
    {"moveTopLeft", (PyCFunction)SbkQRectFunc_moveTopLeft, METH_O},
    {"moveTopRight", (PyCFunction)SbkQRectFunc_moveTopRight, METH_O},
    {"normalized", (PyCFunction)SbkQRectFunc_normalized, METH_NOARGS},
    {"right", (PyCFunction)SbkQRectFunc_right, METH_NOARGS},
    {"setBottom", (PyCFunction)SbkQRectFunc_setBottom, METH_O},
    {"setBottomLeft", (PyCFunction)SbkQRectFunc_setBottomLeft, METH_O},
    {"setBottomRight", (PyCFunction)SbkQRectFunc_setBottomRight, METH_O},
    {"setCoords", (PyCFunction)SbkQRectFunc_setCoords, METH_VARARGS},
    {"setHeight", (PyCFunction)SbkQRectFunc_setHeight, METH_O},
    {"setLeft", (PyCFunction)SbkQRectFunc_setLeft, METH_O},
    {"setRect", (PyCFunction)SbkQRectFunc_setRect, METH_VARARGS},
    {"setRight", (PyCFunction)SbkQRectFunc_setRight, METH_O},
    {"setSize", (PyCFunction)SbkQRectFunc_setSize, METH_O},
    {"setTop", (PyCFunction)SbkQRectFunc_setTop, METH_O},
    {"setTopLeft", (PyCFunction)SbkQRectFunc_setTopLeft, METH_O},
    {"setTopRight", (PyCFunction)SbkQRectFunc_setTopRight, METH_O},
    {"setWidth", (PyCFunction)SbkQRectFunc_setWidth, METH_O},
    {"setX", (PyCFunction)SbkQRectFunc_setX, METH_O},
    {"setY", (PyCFunction)SbkQRectFunc_setY, METH_O},
    {"size", (PyCFunction)SbkQRectFunc_size, METH_NOARGS},
    {"top", (PyCFunction)SbkQRectFunc_top, METH_NOARGS},
    {"topLeft", (PyCFunction)SbkQRectFunc_topLeft, METH_NOARGS},
    {"topRight", (PyCFunction)SbkQRectFunc_topRight, METH_NOARGS},
    {"translate", (PyCFunction)SbkQRectFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)SbkQRectFunc_translated, METH_VARARGS},
    {"unite", (PyCFunction)SbkQRectFunc_unite, METH_O},
    {"united", (PyCFunction)SbkQRectFunc_united, METH_O},
    {"width", (PyCFunction)SbkQRectFunc_width, METH_NOARGS},
    {"x", (PyCFunction)SbkQRectFunc_x, METH_NOARGS},
    {"y", (PyCFunction)SbkQRectFunc_y, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQRectFunc___and__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRect >::checkType(arg) && !Shiboken::Converter<QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QRect)const
    if (!isReverse && Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // operator&(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc___and___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator&(QRect)const
            QRect cppResult = (*cppSelf) & (*cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__and__", overloads);
        return 0;
}

static PyObject* SbkQRectFunc___iand__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRect >::checkType(arg) && !Shiboken::Converter<QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QRect)
    if (!isReverse && Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // operator&=(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc___iand___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator&=(QRect)
            (*cppSelf) &= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRectFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__iand__", overloads);
        return 0;
}

static PyObject* SbkQRectFunc___or__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRect >::checkType(arg) && !Shiboken::Converter<QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QRect)const
    if (!isReverse && Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // operator|(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc___or___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator|(QRect)const
            QRect cppResult = (*cppSelf) | (*cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__or__", overloads);
        return 0;
}

static PyObject* SbkQRectFunc___ior__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRect >::checkType(arg) && !Shiboken::Converter<QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QRect)
    if (!isReverse && Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // operator|=(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFunc___ior___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator|=(QRect)
            (*cppSelf) |= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRectFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__ior__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQRect_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)SbkQRectFunc___and__,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)SbkQRectFunc___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)SbkQRectFunc___iand__,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)SbkQRectFunc___ior__,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQRect_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QRect& cpp_self = *Shiboken::Converter<QRect* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QRect & >::isConvertible(other)) {
                // operator!=(const QRect & arg__2)
                QRect* cpp_other = Shiboken::Converter<QRect* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRect  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQRect_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QRect & >::isConvertible(other)) {
                // operator==(const QRect & arg__2)
                QRect* cpp_other = Shiboken::Converter<QRect* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRect  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQRect_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQRect_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQRect_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QRect",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQRect_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQRect_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQRect_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQRect_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QRect >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QRect",
    /*user_data*/           0
};
} //extern


void init_QRect(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QRECT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQRect_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQRect_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQRect_Type));
    PyModule_AddObject(module, "QRect",
        ((PyObject*)&SbkQRect_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QRect >("QRect");
    Shiboken::TypeResolver::createObjectTypeResolver<QRect >("QRect*");
    Shiboken::TypeResolver::createValueTypeResolver<QRect >(typeid(QRect).name());
    PySide::initQtMetaType<QRect >();
}

