/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qrectf_wrapper.h"

// Extra includes
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQRectF_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QRectF >()))
        return -1;

    QRectF* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQRectF_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QRectF", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QRectF(QRectF)
    // 1: QRectF()
    // 2: QRectF(QPointF,QPointF)
    // 3: QRectF(QPointF,QSizeF)
    // 4: QRectF(QRect)
    // 5: QRectF(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 1; // QRectF()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 5; // QRectF(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 4; // QRectF(QRect)
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[1])) {
            overloadId = 3; // QRectF(QPointF,QSizeF)
        } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
            overloadId = 2; // QRectF(QPointF,QPointF)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QRectF(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectF_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QRectF(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QRectF(QRectF)
                cptr = new QRectF(*cpp_arg0);
                }
                break;
            }
            case 1: // QRectF()
            {

                if(!PyErr_Occurred()) {
                // QRectF()
                cptr = new QRectF();
                }
                break;
            }
            case 2: // QRectF(QPointF,QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QRectF(QPointF,QPointF)
                cptr = new QRectF(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // QRectF(QPointF,QSizeF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QSizeF > cpp_arg1_auto_ptr;
                QSizeF* cpp_arg1 = Shiboken::Converter<QSizeF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QSizeF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QRectF(QPointF,QSizeF)
                cptr = new QRectF(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // QRectF(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QRectF(QRect)
                cptr = new QRectF(*cpp_arg0);
                }
                break;
            }
            case 5: // QRectF(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // QRectF(qreal,qreal,qreal,qreal)
                cptr = new QRectF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QRectF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQRectF_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQRectF_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "", "PySide.QtCore.QPointF, PySide.QtCore.QPointF", "PySide.QtCore.QPointF, PySide.QtCore.QSizeF", "PySide.QtCore.QRect", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF", overloads);
        return -1;
}

static PyObject* SbkQRectFFunc_adjust(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjust", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjust(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // adjust(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_adjust_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // adjust(qreal,qreal,qreal,qreal)
            cppSelf->QRectF::adjust(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_adjust_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.adjust", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_adjusted(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjusted", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjusted(qreal,qreal,qreal,qreal)const
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // adjusted(qreal,qreal,qreal,qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_adjusted_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // adjusted(qreal,qreal,qreal,qreal)const
            QRectF cppResult = cppSelf->QRectF::adjusted(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_adjusted_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.adjusted", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_bottom(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottom()const
            qreal cppResult = cppSelf->QRectF::bottom();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_bottomLeft(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottomLeft()const
            QPointF cppResult = cppSelf->QRectF::bottomLeft();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_bottomRight(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottomRight()const
            QPointF cppResult = cppSelf->QRectF::bottomRight();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_center(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // center()const
            QPointF cppResult = cppSelf->QRectF::center();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_contains(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "contains", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: contains(QPointF)const
    // 1: contains(QRectF)const
    // 2: contains(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // contains(qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // contains(QRectF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // contains(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_contains_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // contains(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // contains(QPointF)const
                bool cppResult = cppSelf->QRectF::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // contains(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // contains(QRectF)const
                bool cppResult = cppSelf->QRectF::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // contains(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // contains(qreal,qreal)const
                bool cppResult = cppSelf->QRectF::contains(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "PySide.QtCore.QRectF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.contains", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_height(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            qreal cppResult = cppSelf->QRectF::height();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_intersect(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersect(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // intersect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_intersect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // intersect(QRectF)const
            QRectF cppResult = cppSelf->QRectF::intersect(*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_intersect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.intersect", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_intersected(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // intersected(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // intersected(QRectF)const
            QRectF cppResult = cppSelf->QRectF::intersected(*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.intersected", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_intersects(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // intersects(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_intersects_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // intersects(QRectF)const
            bool cppResult = cppSelf->QRectF::intersects(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.intersects", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_isEmpty(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QRectF::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_isNull(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QRectF::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_isValid(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QRectF::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_left(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // left()const
            qreal cppResult = cppSelf->QRectF::left();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_moveBottom(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottom(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveBottom(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveBottom_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveBottom(qreal)
            cppSelf->QRectF::moveBottom(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveBottom_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveBottom", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveBottomLeft(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomLeft(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // moveBottomLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveBottomLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // moveBottomLeft(QPointF)
            cppSelf->QRectF::moveBottomLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveBottomLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveBottomRight(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomRight(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // moveBottomRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveBottomRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // moveBottomRight(QPointF)
            cppSelf->QRectF::moveBottomRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveBottomRight", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveCenter(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveCenter(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // moveCenter(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveCenter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // moveCenter(QPointF)
            cppSelf->QRectF::moveCenter(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveCenter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveCenter", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveLeft(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveLeft(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveLeft(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveLeft_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveLeft(qreal)
            cppSelf->QRectF::moveLeft(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveLeft_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveRight(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveRight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveRight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveRight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveRight(qreal)
            cppSelf->QRectF::moveRight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveRight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveRight", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveTo(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveTo", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveTo(QPointF)
    // 1: moveTo(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // moveTo(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // moveTo(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // moveTo(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // moveTo(QPointF)
                cppSelf->QRectF::moveTo(*cpp_arg0);
                }
                break;
            }
            case 1: // moveTo(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // moveTo(qreal,qreal)
                cppSelf->QRectF::moveTo(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.moveTo", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveTop(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTop(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveTop(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveTop_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveTop(qreal)
            cppSelf->QRectF::moveTop(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveTop_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveTop", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveTopLeft(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopLeft(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // moveTopLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveTopLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // moveTopLeft(QPointF)
            cppSelf->QRectF::moveTopLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveTopLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_moveTopRight(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopRight(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // moveTopRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_moveTopRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // moveTopRight(QPointF)
            cppSelf->QRectF::moveTopRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_moveTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.moveTopRight", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_normalized(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalized()const
            QRectF cppResult = cppSelf->QRectF::normalized();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_right(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // right()const
            qreal cppResult = cppSelf->QRectF::right();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_setBottom(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottom(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottom(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setBottom_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBottom(qreal)
            cppSelf->QRectF::setBottom(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setBottom_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setBottom", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setBottomLeft(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomLeft(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setBottomLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setBottomLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBottomLeft(QPointF)
            cppSelf->QRectF::setBottomLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setBottomLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setBottomRight(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomRight(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setBottomRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setBottomRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBottomRight(QPointF)
            cppSelf->QRectF::setBottomRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setBottomRight", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setCoords(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCoords", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setCoords(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // setCoords(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setCoords_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // setCoords(qreal,qreal,qreal,qreal)
            cppSelf->QRectF::setCoords(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setCoords_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.setCoords", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setHeight(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setHeight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHeight(qreal)
            cppSelf->QRectF::setHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setHeight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setHeight", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setLeft(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeft(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeft(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setLeft_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLeft(qreal)
            cppSelf->QRectF::setLeft(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setLeft_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setRect(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRect", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // setRect(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setRect_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // setRect(qreal,qreal,qreal,qreal)
            cppSelf->QRectF::setRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setRect_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.setRect", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setRight(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setRight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRight(qreal)
            cppSelf->QRectF::setRight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setRight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setRight", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setSize(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSize(QSizeF)
    if (Shiboken::Converter<const QSizeF & >::isConvertible(arg)) {
        overloadId = 0; // setSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
            QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(arg);
            if (!Shiboken::Converter<QSizeF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setSize(QSizeF)
            cppSelf->QRectF::setSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setSize", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setTop(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTop(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTop(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setTop_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTop(qreal)
            cppSelf->QRectF::setTop(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setTop_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setTop", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setTopLeft(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopLeft(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setTopLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setTopLeft_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setTopLeft(QPointF)
            cppSelf->QRectF::setTopLeft(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setTopLeft", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setTopRight(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopRight(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setTopRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setTopRight_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setTopRight(QPointF)
            cppSelf->QRectF::setTopRight(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setTopRight", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setWidth(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidth(qreal)
            cppSelf->QRectF::setWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setWidth", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setX(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setX_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setX(qreal)
            cppSelf->QRectF::setX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setX", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_setY(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_setY_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setY(qreal)
            cppSelf->QRectF::setY(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.setY", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_size(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSizeF cppResult = cppSelf->QRectF::size();
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_toAlignedRect(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toAlignedRect()const
            QRect cppResult = cppSelf->QRectF::toAlignedRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_toRect(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toRect()const
            QRect cppResult = cppSelf->QRectF::toRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_top(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // top()const
            qreal cppResult = cppSelf->QRectF::top();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_topLeft(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topLeft()const
            QPointF cppResult = cppSelf->QRectF::topLeft();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_topRight(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topRight()const
            QPointF cppResult = cppSelf->QRectF::topRight();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_translate(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPointF)
    // 1: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translate(QPointF)
                cppSelf->QRectF::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                cppSelf->QRectF::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRectFFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.translate", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_translated(PyObject* self, PyObject* args)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPointF)const
    // 1: translated(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translated(QPointF)const
                QRectF cppResult = cppSelf->QRectF::translated(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translated(qreal,qreal)const
                QRectF cppResult = cppSelf->QRectF::translated(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.translated", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_unite(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unite(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // unite(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_unite_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // unite(QRectF)const
            QRectF cppResult = cppSelf->QRectF::unite(*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_unite_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.unite", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_united(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // united(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc_united_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // united(QRectF)const
            QRectF cppResult = cppSelf->QRectF::united(*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.united", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc_width(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            qreal cppResult = cppSelf->QRectF::width();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_x(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x()const
            qreal cppResult = cppSelf->QRectF::x();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRectFFunc_y(PyObject* self)
{
    QRectF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y()const
            qreal cppResult = cppSelf->QRectF::y();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQRectF_methods[] = {
    {"adjust", (PyCFunction)SbkQRectFFunc_adjust, METH_VARARGS},
    {"adjusted", (PyCFunction)SbkQRectFFunc_adjusted, METH_VARARGS},
    {"bottom", (PyCFunction)SbkQRectFFunc_bottom, METH_NOARGS},
    {"bottomLeft", (PyCFunction)SbkQRectFFunc_bottomLeft, METH_NOARGS},
    {"bottomRight", (PyCFunction)SbkQRectFFunc_bottomRight, METH_NOARGS},
    {"center", (PyCFunction)SbkQRectFFunc_center, METH_NOARGS},
    {"contains", (PyCFunction)SbkQRectFFunc_contains, METH_VARARGS},
    {"height", (PyCFunction)SbkQRectFFunc_height, METH_NOARGS},
    {"intersect", (PyCFunction)SbkQRectFFunc_intersect, METH_O},
    {"intersected", (PyCFunction)SbkQRectFFunc_intersected, METH_O},
    {"intersects", (PyCFunction)SbkQRectFFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)SbkQRectFFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQRectFFunc_isNull, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQRectFFunc_isValid, METH_NOARGS},
    {"left", (PyCFunction)SbkQRectFFunc_left, METH_NOARGS},
    {"moveBottom", (PyCFunction)SbkQRectFFunc_moveBottom, METH_O},
    {"moveBottomLeft", (PyCFunction)SbkQRectFFunc_moveBottomLeft, METH_O},
    {"moveBottomRight", (PyCFunction)SbkQRectFFunc_moveBottomRight, METH_O},
    {"moveCenter", (PyCFunction)SbkQRectFFunc_moveCenter, METH_O},
    {"moveLeft", (PyCFunction)SbkQRectFFunc_moveLeft, METH_O},
    {"moveRight", (PyCFunction)SbkQRectFFunc_moveRight, METH_O},
    {"moveTo", (PyCFunction)SbkQRectFFunc_moveTo, METH_VARARGS},
    {"moveTop", (PyCFunction)SbkQRectFFunc_moveTop, METH_O},
    {"moveTopLeft", (PyCFunction)SbkQRectFFunc_moveTopLeft, METH_O},
    {"moveTopRight", (PyCFunction)SbkQRectFFunc_moveTopRight, METH_O},
    {"normalized", (PyCFunction)SbkQRectFFunc_normalized, METH_NOARGS},
    {"right", (PyCFunction)SbkQRectFFunc_right, METH_NOARGS},
    {"setBottom", (PyCFunction)SbkQRectFFunc_setBottom, METH_O},
    {"setBottomLeft", (PyCFunction)SbkQRectFFunc_setBottomLeft, METH_O},
    {"setBottomRight", (PyCFunction)SbkQRectFFunc_setBottomRight, METH_O},
    {"setCoords", (PyCFunction)SbkQRectFFunc_setCoords, METH_VARARGS},
    {"setHeight", (PyCFunction)SbkQRectFFunc_setHeight, METH_O},
    {"setLeft", (PyCFunction)SbkQRectFFunc_setLeft, METH_O},
    {"setRect", (PyCFunction)SbkQRectFFunc_setRect, METH_VARARGS},
    {"setRight", (PyCFunction)SbkQRectFFunc_setRight, METH_O},
    {"setSize", (PyCFunction)SbkQRectFFunc_setSize, METH_O},
    {"setTop", (PyCFunction)SbkQRectFFunc_setTop, METH_O},
    {"setTopLeft", (PyCFunction)SbkQRectFFunc_setTopLeft, METH_O},
    {"setTopRight", (PyCFunction)SbkQRectFFunc_setTopRight, METH_O},
    {"setWidth", (PyCFunction)SbkQRectFFunc_setWidth, METH_O},
    {"setX", (PyCFunction)SbkQRectFFunc_setX, METH_O},
    {"setY", (PyCFunction)SbkQRectFFunc_setY, METH_O},
    {"size", (PyCFunction)SbkQRectFFunc_size, METH_NOARGS},
    {"toAlignedRect", (PyCFunction)SbkQRectFFunc_toAlignedRect, METH_NOARGS},
    {"toRect", (PyCFunction)SbkQRectFFunc_toRect, METH_NOARGS},
    {"top", (PyCFunction)SbkQRectFFunc_top, METH_NOARGS},
    {"topLeft", (PyCFunction)SbkQRectFFunc_topLeft, METH_NOARGS},
    {"topRight", (PyCFunction)SbkQRectFFunc_topRight, METH_NOARGS},
    {"translate", (PyCFunction)SbkQRectFFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)SbkQRectFFunc_translated, METH_VARARGS},
    {"unite", (PyCFunction)SbkQRectFFunc_unite, METH_O},
    {"united", (PyCFunction)SbkQRectFFunc_united, METH_O},
    {"width", (PyCFunction)SbkQRectFFunc_width, METH_NOARGS},
    {"x", (PyCFunction)SbkQRectFFunc_x, METH_NOARGS},
    {"y", (PyCFunction)SbkQRectFFunc_y, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQRectFFunc___and__(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRectF >::checkType(arg) && !Shiboken::Converter<QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QRectF)const
    if (!isReverse && Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // operator&(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc___and___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator&(QRectF)const
            QRectF cppResult = (*cppSelf) & (*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.__and__", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc___iand__(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRectF >::checkType(arg) && !Shiboken::Converter<QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QRectF)
    if (!isReverse && Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // operator&=(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc___iand___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator&=(QRectF)
            (*cppSelf) &= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRectFFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.__iand__", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc___or__(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRectF >::checkType(arg) && !Shiboken::Converter<QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QRectF)const
    if (!isReverse && Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // operator|(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc___or___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator|(QRectF)const
            QRectF cppResult = (*cppSelf) | (*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRectFFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.__or__", overloads);
        return 0;
}

static PyObject* SbkQRectFFunc___ior__(PyObject* self, PyObject* arg)
{
    QRectF* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRectF >::checkType(arg) && !Shiboken::Converter<QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRectF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QRectF)
    if (!isReverse && Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // operator|=(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRectFFunc___ior___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator|=(QRectF)
            (*cppSelf) |= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRectFFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRectF.__ior__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQRectF_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)SbkQRectFFunc___and__,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)SbkQRectFFunc___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)SbkQRectFFunc___iand__,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)SbkQRectFFunc___ior__,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQRectF_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QRectF& cpp_self = *Shiboken::Converter<QRectF* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QRectF & >::isConvertible(other)) {
                // operator!=(const QRectF & arg__2)
                QRectF* cpp_other = Shiboken::Converter<QRectF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRectF  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QRectF >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QRectF > cpp_other_auto_ptr;
                QRectF* cpp_other = Shiboken::Converter<QRectF* >::toCpp(other);
                if (!Shiboken::Converter<QRectF >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QRectF >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQRectF_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QRectF & >::isConvertible(other)) {
                // operator==(const QRectF & arg__2)
                QRectF* cpp_other = Shiboken::Converter<QRectF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRectF  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QRectF >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QRectF > cpp_other_auto_ptr;
                QRectF* cpp_other = Shiboken::Converter<QRectF* >::toCpp(other);
                if (!Shiboken::Converter<QRectF >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QRectF >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQRectF_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQRectF_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQRectF_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QRectF",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQRectF_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQRectF_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQRectF_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQRectF_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QRectF >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QRectF",
    /*user_data*/           0
};
} //extern


void init_QRectF(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QRECTF_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQRectF_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQRectF_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQRectF_Type));
    PyModule_AddObject(module, "QRectF",
        ((PyObject*)&SbkQRectF_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QRectF >("QRectF");
    Shiboken::TypeResolver::createObjectTypeResolver<QRectF >("QRectF*");
    Shiboken::TypeResolver::createValueTypeResolver<QRectF >(typeid(QRectF).name());
    PySide::initQtMetaType<QRectF >();
}

