/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qregexp_wrapper.h"

// Extra includes
#include <QStringList>
#include <qregexp.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQRegExp_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QRegExp >()))
        return -1;

    QRegExp* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "cs", "syntax" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QRegExp", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QRegExp()
    // 1: QRegExp(QRegExp)
    // 2: QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
    if (numArgs == 0) {
        overloadId = 0; // QRegExp()
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
        } else if (Shiboken::Converter<Qt::CaseSensitivity >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            } else if (Shiboken::Converter<QRegExp::PatternSyntax >::isConvertible(pyargs[2])) {
                overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRegExp & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QRegExp(QRegExp)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExp_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QRegExp()
            {

                if(!PyErr_Occurred()) {
                // QRegExp()
                cptr = new QRegExp();
                }
                break;
            }
            case 1: // QRegExp(QRegExp)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QRegExp* cpp_arg0 = Shiboken::Converter<QRegExp* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QRegExp(QRegExp)
                cptr = new QRegExp(*cpp_arg0);
                }
                break;
            }
            case 2: // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "cs");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "cs";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "syntax");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "syntax";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                Qt::CaseSensitivity cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::CaseSensitivity >::toCpp(pyargs[1]) : Qt::CaseSensitive;
                QRegExp::PatternSyntax cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegExp::PatternSyntax >::toCpp(pyargs[2]) : QRegExp::RegExp;

                if(!PyErr_Occurred()) {
                // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
                cptr = new QRegExp(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QRegExp >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQRegExp_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQRegExp_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRegExp", "QString, PySide.QtCore.Qt.CaseSensitivity = Qt.CaseSensitive, PySide.QtCore.QRegExp.PatternSyntax = RegExp", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp", overloads);
        return -1;
}

static PyObject* SbkQRegExpFunc_cap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "nth" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.cap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.cap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:cap", &arg))
        return 0;


    // Overloaded function decisor
    // 0: cap(int)
    if (numArgs == 0) {
        overloadId = 0; // cap(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // cap(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_cap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "nth");
                if (value) {
                    if (arg)
                        errorArgName = "nth";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.cap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // cap(int)
            QString cppResult = cppSelf->QRegExp::cap(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegExpFunc_cap_TypeError:
        const char* overloads[] = {"int = 0", "int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.cap", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_captureCount(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // captureCount()const
            int cppResult = cppSelf->QRegExp::captureCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_capturedTexts(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // capturedTexts()
            QStringList cppResult = cppSelf->QRegExp::capturedTexts();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_caseSensitivity(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // caseSensitivity()const
            Qt::CaseSensitivity cppResult = cppSelf->QRegExp::caseSensitivity();
            pyResult = Shiboken::Converter<Qt::CaseSensitivity >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_errorString(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()
            QString cppResult = cppSelf->QRegExp::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_escape(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: escape(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // escape(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_escape_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // escape(QString)
            QString cppResult = QRegExp::escape(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegExpFunc_escape_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.escape", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_exactMatch(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: exactMatch(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // exactMatch(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_exactMatch_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // exactMatch(QString)const
            bool cppResult = cppSelf->QRegExp::exactMatch(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegExpFunc_exactMatch_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.exactMatch", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_indexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "caretMode", "offset" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:indexIn", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: indexIn(QString,int,QRegExp::CaretMode)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
            } else if (Shiboken::Converter<QRegExp::CaretMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_indexIn_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "offset");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "offset";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "caretMode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "caretMode";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
            QRegExp::CaretMode cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegExp::CaretMode >::toCpp(pyargs[2]) : QRegExp::CaretAtZero;

            if(!PyErr_Occurred()) {
            // indexIn(QString,int,QRegExp::CaretMode)const
            int cppResult = cppSelf->QRegExp::indexIn(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegExpFunc_indexIn_TypeError:
        const char* overloads[] = {"QString, int = 0, PySide.QtCore.QRegExp.CaretMode = CaretAtZero", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.indexIn", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_isEmpty(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QRegExp::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_isMinimal(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isMinimal()const
            bool cppResult = cppSelf->QRegExp::isMinimal();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_isValid(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QRegExp::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_lastIndexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "caretMode", "offset" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:lastIndexIn", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexIn(QString,int,QRegExp::CaretMode)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
            } else if (Shiboken::Converter<QRegExp::CaretMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_lastIndexIn_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "offset");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "offset";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "caretMode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "caretMode";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;
            QRegExp::CaretMode cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegExp::CaretMode >::toCpp(pyargs[2]) : QRegExp::CaretAtZero;

            if(!PyErr_Occurred()) {
            // lastIndexIn(QString,int,QRegExp::CaretMode)const
            int cppResult = cppSelf->QRegExp::lastIndexIn(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegExpFunc_lastIndexIn_TypeError:
        const char* overloads[] = {"QString, int = -1, PySide.QtCore.QRegExp.CaretMode = CaretAtZero", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.lastIndexIn", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_matchedLength(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // matchedLength()const
            int cppResult = cppSelf->QRegExp::matchedLength();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_numCaptures(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numCaptures()const
            int cppResult = cppSelf->QRegExp::numCaptures();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_pattern(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pattern()const
            QString cppResult = cppSelf->QRegExp::pattern();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_patternSyntax(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // patternSyntax()const
            QRegExp::PatternSyntax cppResult = cppSelf->QRegExp::patternSyntax();
            pyResult = Shiboken::Converter<QRegExp::PatternSyntax >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegExpFunc_pos(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "nth" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.pos(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.pos(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:pos", &arg))
        return 0;


    // Overloaded function decisor
    // 0: pos(int)
    if (numArgs == 0) {
        overloadId = 0; // pos(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // pos(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_pos_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "nth");
                if (value) {
                    if (arg)
                        errorArgName = "nth";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.pos(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // pos(int)
            int cppResult = cppSelf->QRegExp::pos(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegExpFunc_pos_TypeError:
        const char* overloads[] = {"int = 0", "int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.pos", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_setCaseSensitivity(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCaseSensitivity(Qt::CaseSensitivity)
    if (Shiboken::Converter<Qt::CaseSensitivity >::isConvertible(arg)) {
        overloadId = 0; // setCaseSensitivity(Qt::CaseSensitivity)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_setCaseSensitivity_TypeError;

    // Call function/method
    {
        {
            Qt::CaseSensitivity cpp_arg0 = Shiboken::Converter<Qt::CaseSensitivity >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCaseSensitivity(Qt::CaseSensitivity)
            cppSelf->QRegExp::setCaseSensitivity(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRegExpFunc_setCaseSensitivity_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CaseSensitivity", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setCaseSensitivity", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_setMinimal(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimal(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimal(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_setMinimal_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMinimal(bool)
            cppSelf->QRegExp::setMinimal(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRegExpFunc_setMinimal_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setMinimal", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_setPattern(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPattern(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPattern(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_setPattern_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPattern(QString)
            cppSelf->QRegExp::setPattern(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRegExpFunc_setPattern_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setPattern", overloads);
        return 0;
}

static PyObject* SbkQRegExpFunc_setPatternSyntax(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPatternSyntax(QRegExp::PatternSyntax)
    if (Shiboken::Converter<QRegExp::PatternSyntax >::isConvertible(arg)) {
        overloadId = 0; // setPatternSyntax(QRegExp::PatternSyntax)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegExpFunc_setPatternSyntax_TypeError;

    // Call function/method
    {
        {
            QRegExp::PatternSyntax cpp_arg0 = Shiboken::Converter<QRegExp::PatternSyntax >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPatternSyntax(QRegExp::PatternSyntax)
            cppSelf->QRegExp::setPatternSyntax(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRegExpFunc_setPatternSyntax_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp.PatternSyntax", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setPatternSyntax", overloads);
        return 0;
}

static PyMethodDef SbkQRegExp_methods[] = {
    {"cap", (PyCFunction)SbkQRegExpFunc_cap, METH_VARARGS|METH_KEYWORDS},
    {"captureCount", (PyCFunction)SbkQRegExpFunc_captureCount, METH_NOARGS},
    {"capturedTexts", (PyCFunction)SbkQRegExpFunc_capturedTexts, METH_NOARGS},
    {"caseSensitivity", (PyCFunction)SbkQRegExpFunc_caseSensitivity, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQRegExpFunc_errorString, METH_NOARGS},
    {"escape", (PyCFunction)SbkQRegExpFunc_escape, METH_O|METH_STATIC},
    {"exactMatch", (PyCFunction)SbkQRegExpFunc_exactMatch, METH_O},
    {"indexIn", (PyCFunction)SbkQRegExpFunc_indexIn, METH_VARARGS|METH_KEYWORDS},
    {"isEmpty", (PyCFunction)SbkQRegExpFunc_isEmpty, METH_NOARGS},
    {"isMinimal", (PyCFunction)SbkQRegExpFunc_isMinimal, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQRegExpFunc_isValid, METH_NOARGS},
    {"lastIndexIn", (PyCFunction)SbkQRegExpFunc_lastIndexIn, METH_VARARGS|METH_KEYWORDS},
    {"matchedLength", (PyCFunction)SbkQRegExpFunc_matchedLength, METH_NOARGS},
    {"numCaptures", (PyCFunction)SbkQRegExpFunc_numCaptures, METH_NOARGS},
    {"pattern", (PyCFunction)SbkQRegExpFunc_pattern, METH_NOARGS},
    {"patternSyntax", (PyCFunction)SbkQRegExpFunc_patternSyntax, METH_NOARGS},
    {"pos", (PyCFunction)SbkQRegExpFunc_pos, METH_VARARGS|METH_KEYWORDS},
    {"setCaseSensitivity", (PyCFunction)SbkQRegExpFunc_setCaseSensitivity, METH_O},
    {"setMinimal", (PyCFunction)SbkQRegExpFunc_setMinimal, METH_O},
    {"setPattern", (PyCFunction)SbkQRegExpFunc_setPattern, METH_O},
    {"setPatternSyntax", (PyCFunction)SbkQRegExpFunc_setPatternSyntax, METH_O},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQRegExp_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QRegExp& cpp_self = *Shiboken::Converter<QRegExp* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QRegExp & >::isConvertible(other)) {
                // operator!=(const QRegExp & rx) const
                QRegExp* cpp_other = Shiboken::Converter<QRegExp* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRegExp  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQRegExp_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QRegExp & >::isConvertible(other)) {
                // operator==(const QRegExp & rx) const
                QRegExp* cpp_other = Shiboken::Converter<QRegExp* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRegExp  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQRegExp_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQRegExp_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQRegExp_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QRegExp",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQRegExp_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQRegExp_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQRegExp_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QRegExp >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QRegExp",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QRegExp_PatternSyntax_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QRegExp_PatternSyntax_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QRegExp_PatternSyntax_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PatternSyntax",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QRegExp_PatternSyntax_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QRegExp_PatternSyntax_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QRegExp_PatternSyntax_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QRegExp_CaretMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QRegExp_CaretMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QRegExp_CaretMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CaretMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QRegExp_CaretMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QRegExp_CaretMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QRegExp_CaretMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QRegExp(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QREGEXP_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQRegExp_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQRegExp_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQRegExp_Type));
    PyModule_AddObject(module, "QRegExp",
        ((PyObject*)&SbkQRegExp_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: PatternSyntax
    SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX] = &SbkPySide_QtCore_QRegExp_PatternSyntax_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QRegExp_PatternSyntax_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QRegExp_PatternSyntax_Type);
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
            "PatternSyntax",((PyObject*)&SbkPySide_QtCore_QRegExp_PatternSyntax_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_PatternSyntax_Type,
        (long) QRegExp::RegExp, "RegExp");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "RegExp", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax_Type.tp_dict,
        "RegExp", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_PatternSyntax_Type,
        (long) QRegExp::Wildcard, "Wildcard");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "Wildcard", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax_Type.tp_dict,
        "Wildcard", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_PatternSyntax_Type,
        (long) QRegExp::FixedString, "FixedString");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "FixedString", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax_Type.tp_dict,
        "FixedString", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_PatternSyntax_Type,
        (long) QRegExp::RegExp2, "RegExp2");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "RegExp2", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax_Type.tp_dict,
        "RegExp2", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_PatternSyntax_Type,
        (long) QRegExp::WildcardUnix, "WildcardUnix");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "WildcardUnix", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax_Type.tp_dict,
        "WildcardUnix", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_PatternSyntax_Type,
        (long) QRegExp::W3CXmlSchema11, "W3CXmlSchema11");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "W3CXmlSchema11", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax_Type.tp_dict,
        "W3CXmlSchema11", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QRegExp::PatternSyntax");

    // init enum class: CaretMode
    SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX] = &SbkPySide_QtCore_QRegExp_CaretMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QRegExp_CaretMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QRegExp_CaretMode_Type);
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
            "CaretMode",((PyObject*)&SbkPySide_QtCore_QRegExp_CaretMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_CaretMode_Type,
        (long) QRegExp::CaretAtZero, "CaretAtZero");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "CaretAtZero", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_CaretMode_Type.tp_dict,
        "CaretAtZero", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_CaretMode_Type,
        (long) QRegExp::CaretAtOffset, "CaretAtOffset");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "CaretAtOffset", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_CaretMode_Type.tp_dict,
        "CaretAtOffset", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QRegExp_CaretMode_Type,
        (long) QRegExp::CaretWontMatch, "CaretWontMatch");
    PyDict_SetItemString(SbkQRegExp_Type.super.ht_type.tp_dict,
        "CaretWontMatch", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_CaretMode_Type.tp_dict,
        "CaretWontMatch", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QRegExp::CaretMode");


    Shiboken::TypeResolver::createValueTypeResolver<QRegExp >("QRegExp");
    Shiboken::TypeResolver::createObjectTypeResolver<QRegExp >("QRegExp*");
    Shiboken::TypeResolver::createValueTypeResolver<QRegExp >(typeid(QRegExp).name());
    PySide::initQtMetaType<QRegExp >();
}

