/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qsettings_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsettings.h>
#include <qtextcodec.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QSettingsWrapper::QSettingsWrapper(QObject * parent) : QSettings(parent), m_metaObject(0) {
    // ... middle
}

QSettingsWrapper::QSettingsWrapper(QSettings::Format format, QSettings::Scope scope, const QString & organization, const QString & application, QObject * parent) : QSettings(format, scope, organization, application, parent), m_metaObject(0) {
    // ... middle
}

QSettingsWrapper::QSettingsWrapper(QSettings::Scope scope, const QString & organization, const QString & application, QObject * parent) : QSettings(scope, organization, application, parent), m_metaObject(0) {
    // ... middle
}

QSettingsWrapper::QSettingsWrapper(const QString & fileName, QSettings::Format format, QObject * parent) : QSettings(fileName, format, parent), m_metaObject(0) {
    // ... middle
}

QSettingsWrapper::QSettingsWrapper(const QString & organization, const QString & application, QObject * parent) : QSettings(organization, application, parent), m_metaObject(0) {
    // ... middle
}

void QSettingsWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSettingsWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSettingsWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSettingsWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QSettingsWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QSettings::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSettings.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QSettingsWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSettings.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QSettingsWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QSettingsWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QSettings::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QSettingsWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QSettings::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QSettingsWrapper::~QSettingsWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSettings_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSettings >()))
        return -1;

    QSettingsWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "application", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOOOO:QSettings", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QSettings(QObject*)
    // 1: QSettings(QSettings::Format,QSettings::Scope,QString,QString,QObject*)
    // 2: QSettings(QSettings::Scope,QString,QString,QObject*)
    // 3: QSettings(QString,QSettings::Format,QObject*)
    // 4: QSettings(QString,QString,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSettings(QObject*)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // QSettings(QString,QString,QObject*)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // QSettings(QString,QString,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 4; // QSettings(QString,QString,QObject*)
            }
        } else if (Shiboken::Converter<QSettings::Format >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // QSettings(QString,QSettings::Format,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 3; // QSettings(QString,QSettings::Format,QObject*)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<QSettings::Scope >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QSettings(QSettings::Scope,QString,QString,QObject*)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QSettings(QSettings::Scope,QString,QString,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[3])) {
                overloadId = 2; // QSettings(QSettings::Scope,QString,QString,QObject*)
            }
        }
    } else if (numArgs >= 3 && Shiboken::Converter<QSettings::Format >::isConvertible(pyargs[0]) && Shiboken::Converter<QSettings::Scope >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 1; // QSettings(QSettings::Format,QSettings::Scope,QString,QString,QObject*)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 1; // QSettings(QSettings::Format,QSettings::Scope,QString,QString,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[4])) {
                overloadId = 1; // QSettings(QSettings::Format,QSettings::Scope,QString,QString,QObject*)
            }
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QSettings(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettings_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSettings(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QSettings(QObject*)
                cptr = new QSettingsWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QSettings(QSettings::Format,QSettings::Scope,QString,QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "application");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "application";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "parent";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QSettings::Format cpp_arg0 = Shiboken::Converter<QSettings::Format >::toCpp(pyargs[0]);
                QSettings::Scope cpp_arg1 = Shiboken::Converter<QSettings::Scope >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return -1;
                QObject* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QObject* >::toCpp(pyargs[4]) : 0;

                if(!PyErr_Occurred()) {
                // QSettings(QSettings::Format,QSettings::Scope,QString,QString,QObject*)
                cptr = new QSettingsWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                Shiboken::setParent(pyargs[4], self);
                }
                break;
            }
            case 2: // QSettings(QSettings::Scope,QString,QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "application");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "application";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "parent";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QSettings::Scope cpp_arg0 = Shiboken::Converter<QSettings::Scope >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return -1;
                QObject* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QObject* >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // QSettings(QSettings::Scope,QString,QString,QObject*)
                cptr = new QSettingsWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                Shiboken::setParent(pyargs[3], self);
                }
                break;
            }
            case 3: // QSettings(QString,QSettings::Format,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QSettings::Format cpp_arg1 = Shiboken::Converter<QSettings::Format >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QSettings(QString,QSettings::Format,QObject*)
                cptr = new QSettingsWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
            case 4: // QSettings(QString,QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "application");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "application";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QSettings(QString,QString,QObject*)
                cptr = new QSettingsWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSettings >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSettings_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQSettings_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "PySide.QtCore.QSettings.Format, PySide.QtCore.QSettings.Scope, QString, QString = QString(), PySide.QtCore.QObject = None", "PySide.QtCore.QSettings.Scope, QString, QString = QString(), PySide.QtCore.QObject = None", "QString, PySide.QtCore.QSettings.Format, PySide.QtCore.QObject = None", "QString, QString = QString(), PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSettings", overloads);
        return -1;
}

static PyObject* SbkQSettingsFunc_allKeys(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // allKeys()const
            QStringList cppResult = cppSelf->QSettings::allKeys();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_applicationName(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // applicationName()const
            QString cppResult = cppSelf->QSettings::applicationName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_beginGroup(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginGroup(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // beginGroup(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_beginGroup_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // beginGroup(QString)
            cppSelf->QSettings::beginGroup(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_beginGroup_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.beginGroup", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_beginReadArray(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginReadArray(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // beginReadArray(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_beginReadArray_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // beginReadArray(QString)
            int cppResult = cppSelf->QSettings::beginReadArray(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSettingsFunc_beginReadArray_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.beginReadArray", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_beginWriteArray(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "size" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings.beginWriteArray(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSettings.beginWriteArray(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSettings.beginWriteArray(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:beginWriteArray", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: beginWriteArray(QString,int)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // beginWriteArray(QString,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // beginWriteArray(QString,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_beginWriteArray_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "size";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings.beginWriteArray(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // beginWriteArray(QString,int)
            cppSelf->QSettings::beginWriteArray(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_beginWriteArray_TypeError:
        const char* overloads[] = {"QString, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSettings.beginWriteArray", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_childGroups(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childGroups()const
            QStringList cppResult = cppSelf->QSettings::childGroups();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_childKeys(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childKeys()const
            QStringList cppResult = cppSelf->QSettings::childKeys();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_clear(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QSettings::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSettingsFunc_contains(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // contains(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_contains_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contains(QString)const
            bool cppResult = cppSelf->QSettings::contains(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSettingsFunc_contains_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.contains", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_defaultFormat(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultFormat()
            QSettings::Format cppResult = QSettings::defaultFormat();
            pyResult = Shiboken::Converter<QSettings::Format >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_endArray(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endArray()
            cppSelf->QSettings::endArray();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSettingsFunc_endGroup(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endGroup()
            cppSelf->QSettings::endGroup();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSettingsFunc_event(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QSettings::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSettingsFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.event", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_fallbacksEnabled(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fallbacksEnabled()const
            bool cppResult = cppSelf->QSettings::fallbacksEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_fileName(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QSettings::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_format(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QSettings::Format cppResult = cppSelf->QSettings::format();
            pyResult = Shiboken::Converter<QSettings::Format >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_group(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // group()const
            QString cppResult = cppSelf->QSettings::group();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_isWritable(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWritable()const
            bool cppResult = cppSelf->QSettings::isWritable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_organizationName(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // organizationName()const
            QString cppResult = cppSelf->QSettings::organizationName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_remove(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: remove(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_remove_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // remove(QString)
            cppSelf->QSettings::remove(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_remove_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.remove", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_scope(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scope()const
            QSettings::Scope cppResult = cppSelf->QSettings::scope();
            pyResult = Shiboken::Converter<QSettings::Scope >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_setArrayIndex(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setArrayIndex(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setArrayIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_setArrayIndex_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setArrayIndex(int)
            cppSelf->QSettings::setArrayIndex(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_setArrayIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.setArrayIndex", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_setDefaultFormat(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultFormat(QSettings::Format)
    if (Shiboken::Converter<QSettings::Format >::isConvertible(arg)) {
        overloadId = 0; // setDefaultFormat(QSettings::Format)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_setDefaultFormat_TypeError;

    // Call function/method
    {
        {
            QSettings::Format cpp_arg0 = Shiboken::Converter<QSettings::Format >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultFormat(QSettings::Format)
            QSettings::setDefaultFormat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_setDefaultFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSettings.Format", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.setDefaultFormat", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_setFallbacksEnabled(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFallbacksEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFallbacksEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_setFallbacksEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFallbacksEnabled(bool)
            cppSelf->QSettings::setFallbacksEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_setFallbacksEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.setFallbacksEnabled", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_setIniCodec(PyObject* self, PyObject* arg)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIniCodec(QTextCodec*)
    // 1: setIniCodec(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 1; // setIniCodec(const char*)
    } else if (Shiboken::Converter<QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setIniCodec(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_setIniCodec_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setIniCodec(QTextCodec*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setIniCodec(QTextCodec*)
                cppSelf->QSettings::setIniCodec(cpp_arg0);
                }
                break;
            }
            case 1: // setIniCodec(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setIniCodec(const char*)
                cppSelf->QSettings::setIniCodec(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_setIniCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QSettings.setIniCodec", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_setPath(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPath", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setPath(QSettings::Format,QSettings::Scope,QString)
    if (numArgs == 3 && Shiboken::Converter<QSettings::Format >::isConvertible(pyargs[0]) && Shiboken::Converter<QSettings::Scope >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // setPath(QSettings::Format,QSettings::Scope,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_setPath_TypeError;

    // Call function/method
    {
        {
            QSettings::Format cpp_arg0 = Shiboken::Converter<QSettings::Format >::toCpp(pyargs[0]);
            QSettings::Scope cpp_arg1 = Shiboken::Converter<QSettings::Scope >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setPath(QSettings::Format,QSettings::Scope,QString)
            QSettings::setPath(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_setPath_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSettings.Format, PySide.QtCore.QSettings.Scope, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSettings.setPath", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_setValue(PyObject* self, PyObject* args)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setValue", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setValue(QString,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setValue(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_setValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setValue(QString,QVariant)
            cppSelf->QSettings::setValue(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSettingsFunc_setValue_TypeError:
        const char* overloads[] = {"QString, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSettings.setValue", overloads);
        return 0;
}

static PyObject* SbkQSettingsFunc_status(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // status()const
            QSettings::Status cppResult = cppSelf->QSettings::status();
            pyResult = Shiboken::Converter<QSettings::Status >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSettingsFunc_sync(PyObject* self)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sync()
            cppSelf->QSettings::sync();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSettingsFunc_value(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "defaultValue" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings.value(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSettings.value(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSettings.value(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:value", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(QString,QVariant)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // value(QString,QVariant)const
        } else if (Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
            overloadId = 0; // value(QString,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSettingsFunc_value_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "defaultValue";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSettings.value(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = pyargs[1] ? Shiboken::Converter<QVariant >::toCpp(pyargs[1]) : QVariant();

            if(!PyErr_Occurred()) {
            // value(QString,QVariant)const
            QVariant cppResult = cppSelf->QSettings::value(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSettingsFunc_value_TypeError:
        const char* overloads[] = {"QString, QVariant = QVariant()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSettings.value", overloads);
        return 0;
}

static PyMethodDef SbkQSettings_methods[] = {
    {"allKeys", (PyCFunction)SbkQSettingsFunc_allKeys, METH_NOARGS},
    {"applicationName", (PyCFunction)SbkQSettingsFunc_applicationName, METH_NOARGS},
    {"beginGroup", (PyCFunction)SbkQSettingsFunc_beginGroup, METH_O},
    {"beginReadArray", (PyCFunction)SbkQSettingsFunc_beginReadArray, METH_O},
    {"beginWriteArray", (PyCFunction)SbkQSettingsFunc_beginWriteArray, METH_VARARGS|METH_KEYWORDS},
    {"childGroups", (PyCFunction)SbkQSettingsFunc_childGroups, METH_NOARGS},
    {"childKeys", (PyCFunction)SbkQSettingsFunc_childKeys, METH_NOARGS},
    {"clear", (PyCFunction)SbkQSettingsFunc_clear, METH_NOARGS},
    {"contains", (PyCFunction)SbkQSettingsFunc_contains, METH_O},
    {"defaultFormat", (PyCFunction)SbkQSettingsFunc_defaultFormat, METH_NOARGS|METH_STATIC},
    {"endArray", (PyCFunction)SbkQSettingsFunc_endArray, METH_NOARGS},
    {"endGroup", (PyCFunction)SbkQSettingsFunc_endGroup, METH_NOARGS},
    {"event", (PyCFunction)SbkQSettingsFunc_event, METH_O},
    {"fallbacksEnabled", (PyCFunction)SbkQSettingsFunc_fallbacksEnabled, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQSettingsFunc_fileName, METH_NOARGS},
    {"format", (PyCFunction)SbkQSettingsFunc_format, METH_NOARGS},
    {"group", (PyCFunction)SbkQSettingsFunc_group, METH_NOARGS},
    {"isWritable", (PyCFunction)SbkQSettingsFunc_isWritable, METH_NOARGS},
    {"organizationName", (PyCFunction)SbkQSettingsFunc_organizationName, METH_NOARGS},
    {"remove", (PyCFunction)SbkQSettingsFunc_remove, METH_O},
    {"scope", (PyCFunction)SbkQSettingsFunc_scope, METH_NOARGS},
    {"setArrayIndex", (PyCFunction)SbkQSettingsFunc_setArrayIndex, METH_O},
    {"setDefaultFormat", (PyCFunction)SbkQSettingsFunc_setDefaultFormat, METH_O|METH_STATIC},
    {"setFallbacksEnabled", (PyCFunction)SbkQSettingsFunc_setFallbacksEnabled, METH_O},
    {"setIniCodec", (PyCFunction)SbkQSettingsFunc_setIniCodec, METH_O},
    {"setPath", (PyCFunction)SbkQSettingsFunc_setPath, METH_VARARGS|METH_STATIC},
    {"setValue", (PyCFunction)SbkQSettingsFunc_setValue, METH_VARARGS},
    {"status", (PyCFunction)SbkQSettingsFunc_status, METH_NOARGS},
    {"sync", (PyCFunction)SbkQSettingsFunc_sync, METH_NOARGS},
    {"value", (PyCFunction)SbkQSettingsFunc_value, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSettings_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QSettings",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSettings_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSettings_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSettings >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSettings*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQSettings_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QSettings*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQSettings_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtCore_QSettings_Format_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QSettings_Format_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QSettings_Format_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Format",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QSettings_Format_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QSettings_Format_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QSettings_Format_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QSettings_Status_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QSettings_Status_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QSettings_Status_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Status",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QSettings_Status_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QSettings_Status_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QSettings_Status_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QSettings_Scope_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QSettings_Scope_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QSettings_Scope_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Scope",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QSettings_Scope_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QSettings_Scope_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QSettings_Scope_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QSettings(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSETTINGS_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSettings_Type);

    SbkQSettings_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQSettings_Type.type_discovery = &SbkQSettings_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQSettings_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSettings_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSettings_Type));
    PyModule_AddObject(module, "QSettings",
        ((PyObject*)&SbkQSettings_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Format
    SbkPySide_QtCoreTypes[SBK_QSETTINGS_FORMAT_IDX] = &SbkPySide_QtCore_QSettings_Format_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QSettings_Format_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QSettings_Format_Type);
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
            "Format",((PyObject*)&SbkPySide_QtCore_QSettings_Format_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::NativeFormat, "NativeFormat");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "NativeFormat", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "NativeFormat", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::IniFormat, "IniFormat");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "IniFormat", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "IniFormat", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::InvalidFormat, "InvalidFormat");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "InvalidFormat", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "InvalidFormat", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat1, "CustomFormat1");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat1", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat1", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat2, "CustomFormat2");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat2", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat2", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat3, "CustomFormat3");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat3", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat3", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat4, "CustomFormat4");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat4", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat4", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat5, "CustomFormat5");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat5", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat5", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat6, "CustomFormat6");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat6", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat6", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat7, "CustomFormat7");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat7", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat7", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat8, "CustomFormat8");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat8", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat8", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat9, "CustomFormat9");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat9", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat9", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat10, "CustomFormat10");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat10", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat10", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat11, "CustomFormat11");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat11", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat11", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat12, "CustomFormat12");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat12", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat12", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat13, "CustomFormat13");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat13", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat13", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat14, "CustomFormat14");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat14", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat14", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat15, "CustomFormat15");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat15", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat15", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Format_Type,
        (long) QSettings::CustomFormat16, "CustomFormat16");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "CustomFormat16", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Format_Type.tp_dict,
        "CustomFormat16", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSettings::Format");

    // init enum class: Status
    SbkPySide_QtCoreTypes[SBK_QSETTINGS_STATUS_IDX] = &SbkPySide_QtCore_QSettings_Status_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QSettings_Status_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QSettings_Status_Type);
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
            "Status",((PyObject*)&SbkPySide_QtCore_QSettings_Status_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Status_Type,
        (long) QSettings::NoError, "NoError");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Status_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Status_Type,
        (long) QSettings::AccessError, "AccessError");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "AccessError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Status_Type.tp_dict,
        "AccessError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Status_Type,
        (long) QSettings::FormatError, "FormatError");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "FormatError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Status_Type.tp_dict,
        "FormatError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSettings::Status");

    // init enum class: Scope
    SbkPySide_QtCoreTypes[SBK_QSETTINGS_SCOPE_IDX] = &SbkPySide_QtCore_QSettings_Scope_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QSettings_Scope_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QSettings_Scope_Type);
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
            "Scope",((PyObject*)&SbkPySide_QtCore_QSettings_Scope_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Scope_Type,
        (long) QSettings::UserScope, "UserScope");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "UserScope", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Scope_Type.tp_dict,
        "UserScope", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QSettings_Scope_Type,
        (long) QSettings::SystemScope, "SystemScope");
    PyDict_SetItemString(SbkQSettings_Type.super.ht_type.tp_dict,
        "SystemScope", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QSettings_Scope_Type.tp_dict,
        "SystemScope", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSettings::Scope");


    Shiboken::TypeResolver::createObjectTypeResolver<QSettings >("QSettings*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSettings >(typeid(QSettings).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSettings >(typeid(QSettingsWrapper).name());
    PySide::initQtMetaType<QSettings* >();
}

