/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qstate_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractstate.h>
#include <qabstracttransition.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsignaltransition.h>
#include <qstate.h>
#include <qstatemachine.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QStateWrapper::QStateWrapper(QState * parent) : QState(parent), m_metaObject(0) {
    // ... middle
}

QStateWrapper::QStateWrapper(QState::ChildMode childMode, QState * parent) : QState(childMode, parent), m_metaObject(0) {
    // ... middle
}

void QStateWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QStateWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QState::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QState.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QStateWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QState.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QStateWrapper::onEntry(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "onEntry"));
    if (py_override.isNull()) {
        return this->QState::onEntry(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateWrapper::onExit(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "onExit"));
    if (py_override.isNull()) {
        return this->QState::onExit(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QStateWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QState::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QStateWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QState::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QStateWrapper::~QStateWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQState_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QState >()))
        return -1;

    QStateWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QState", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QState(QState*)
    // 1: QState(QState::ChildMode,QState*)
    if (numArgs == 0) {
        overloadId = 0; // QState(QState*)
    } else if (Shiboken::Converter<QState::ChildMode >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QState(QState::ChildMode,QState*)
        } else if (Shiboken::Converter<QState * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QState(QState::ChildMode,QState*)
        }
    } else if (Shiboken::Converter<QState * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QState(QState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQState_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QState(QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QState(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QState* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QState* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QState(QState*)
                cptr = new QStateWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QState(QState::ChildMode,QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QState(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QState::ChildMode cpp_arg0 = Shiboken::Converter<QState::ChildMode >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QState* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QState* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QState(QState::ChildMode,QState*)
                cptr = new QStateWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QState >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQState_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQState_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QState = None", "PySide.QtCore.QState.ChildMode, PySide.QtCore.QState = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QState", overloads);
        return -1;
}

static PyObject* SbkQStateFunc_addTransition(PyObject* self, PyObject* args)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQStateFunc_addTransition_TypeError;

    if (!PyArg_UnpackTuple(args, "addTransition", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addTransition(QAbstractState*)
    // 1: addTransition(QAbstractTransition*)
    // 2: addTransition(QObject*,const char*,QAbstractState*)
    if (numArgs == 3 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1]) && Shiboken::Converter<QAbstractState * >::isConvertible(pyargs[2])) {
        overloadId = 2; // addTransition(QObject*,const char*,QAbstractState*)
    } else if (numArgs == 1 && Shiboken::Converter<QAbstractTransition * >::isConvertible(pyargs[0])) {
        overloadId = 1; // addTransition(QAbstractTransition*)
    } else if (numArgs == 1 && Shiboken::Converter<QAbstractState * >::isConvertible(pyargs[0])) {
        overloadId = 0; // addTransition(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_addTransition_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addTransition(QAbstractState*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QAbstractState* cpp_arg0 = Shiboken::Converter<QAbstractState* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addTransition(QAbstractState*)
                QAbstractTransition * cppResult = cppSelf->QState::addTransition(cpp_arg0);
                pyResult = Shiboken::Converter<QAbstractTransition * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // addTransition(QAbstractTransition*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QAbstractTransition* cpp_arg0 = Shiboken::Converter<QAbstractTransition* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addTransition(QAbstractTransition*)
                cppSelf->QState::addTransition(cpp_arg0);
                Shiboken::setParent(self, pyargs[0]);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 2: // addTransition(QObject*,const char*,QAbstractState*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QAbstractState* cpp_arg2 = Shiboken::Converter<QAbstractState* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // addTransition(QObject*,const char*,QAbstractState*)
                // Begin code injection
                
                QString signalName(cpp_arg1);
                if (PySide::SignalManager::registerMetaMethod(cpp_arg0, signalName.mid(1).toAscii().data(), QMetaMethod::Signal)) {
                  pyResult = Shiboken::Converter<QSignalTransition* >::toPython(cppSelf->addTransition(cpp_arg0, cpp_arg1, cpp_arg2));
                } else {
                  pyResult = Py_None;
                }
                
                // End of code injection


                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQStateFunc_addTransition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", "PySide.QtCore.QAbstractTransition", "PySide.QtCore.QObject, str, PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QState.addTransition", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_assignProperty(PyObject* self, PyObject* args)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "assignProperty", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: assignProperty(QObject*,const char*,QVariant)
    if (numArgs == 3 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[2])) {
        overloadId = 0; // assignProperty(QObject*,const char*,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_assignProperty_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // assignProperty(QObject*,const char*,QVariant)
            cppSelf->QState::assignProperty(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateFunc_assignProperty_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QState.assignProperty", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_childMode(PyObject* self)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childMode()const
            QState::ChildMode cppResult = cppSelf->QState::childMode();
            pyResult = Shiboken::Converter<QState::ChildMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateFunc_errorState(PyObject* self)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorState()const
            QAbstractState * cppResult = cppSelf->QState::errorState();
            pyResult = Shiboken::Converter<QAbstractState * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateFunc_event(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QState::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQStateFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.event", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_initialState(PyObject* self)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // initialState()const
            QAbstractState * cppResult = cppSelf->QState::initialState();
            pyResult = Shiboken::Converter<QAbstractState * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateFunc_onEntry(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onEntry(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onEntry(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_onEntry_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // onEntry(QEvent*)
            cppSelf->QState::onEntry(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateFunc_onEntry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.onEntry", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_onExit(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onExit(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onExit(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_onExit_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // onExit(QEvent*)
            cppSelf->QState::onExit(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateFunc_onExit_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.onExit", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_removeTransition(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeTransition(QAbstractTransition*)
    if (Shiboken::Converter<QAbstractTransition * >::isConvertible(arg)) {
        overloadId = 0; // removeTransition(QAbstractTransition*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_removeTransition_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractTransition* cpp_arg0 = Shiboken::Converter<QAbstractTransition* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeTransition(QAbstractTransition*)
            cppSelf->QState::removeTransition(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateFunc_removeTransition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractTransition", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.removeTransition", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_setChildMode(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChildMode(QState::ChildMode)
    if (Shiboken::Converter<QState::ChildMode >::isConvertible(arg)) {
        overloadId = 0; // setChildMode(QState::ChildMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_setChildMode_TypeError;

    // Call function/method
    {
        {
            QState::ChildMode cpp_arg0 = Shiboken::Converter<QState::ChildMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setChildMode(QState::ChildMode)
            cppSelf->QState::setChildMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateFunc_setChildMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QState.ChildMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.setChildMode", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_setErrorState(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setErrorState(QAbstractState*)
    if (Shiboken::Converter<QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // setErrorState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_setErrorState_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractState* cpp_arg0 = Shiboken::Converter<QAbstractState* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setErrorState(QAbstractState*)
            cppSelf->QState::setErrorState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateFunc_setErrorState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.setErrorState", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_setInitialState(PyObject* self, PyObject* arg)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInitialState(QAbstractState*)
    if (Shiboken::Converter<QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // setInitialState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateFunc_setInitialState_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractState* cpp_arg0 = Shiboken::Converter<QAbstractState* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInitialState(QAbstractState*)
            cppSelf->QState::setInitialState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateFunc_setInitialState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QState.setInitialState", overloads);
        return 0;
}

static PyObject* SbkQStateFunc_transitions(PyObject* self)
{
    QState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transitions()const
            QList<QAbstractTransition * > cppResult = cppSelf->QState::transitions();
            pyResult = Shiboken::Converter<QList<QAbstractTransition * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQState_methods[] = {
    {"addTransition", (PyCFunction)SbkQStateFunc_addTransition, METH_VARARGS},
    {"assignProperty", (PyCFunction)SbkQStateFunc_assignProperty, METH_VARARGS},
    {"childMode", (PyCFunction)SbkQStateFunc_childMode, METH_NOARGS},
    {"errorState", (PyCFunction)SbkQStateFunc_errorState, METH_NOARGS},
    {"event", (PyCFunction)SbkQStateFunc_event, METH_O},
    {"initialState", (PyCFunction)SbkQStateFunc_initialState, METH_NOARGS},
    {"onEntry", (PyCFunction)SbkQStateFunc_onEntry, METH_O},
    {"onExit", (PyCFunction)SbkQStateFunc_onExit, METH_O},
    {"removeTransition", (PyCFunction)SbkQStateFunc_removeTransition, METH_O},
    {"setChildMode", (PyCFunction)SbkQStateFunc_setChildMode, METH_O},
    {"setErrorState", (PyCFunction)SbkQStateFunc_setErrorState, METH_O},
    {"setInitialState", (PyCFunction)SbkQStateFunc_setInitialState, METH_O},
    {"transitions", (PyCFunction)SbkQStateFunc_transitions, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQState_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QState",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQState_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQState_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QState >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QState*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQState_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QState*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQState_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtCore_QState_ChildMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QState_ChildMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QState_ChildMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ChildMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QState_ChildMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QState_ChildMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QState_ChildMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QState(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSTATE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQState_Type);

    SbkQState_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QABSTRACTSTATE_IDX];
    // Fill type discovery information
    SbkQState_Type.type_discovery = &SbkQState_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QABSTRACTSTATE_IDX]), &SbkQState_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQState_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQState_Type));
    PyModule_AddObject(module, "QState",
        ((PyObject*)&SbkQState_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ChildMode
    SbkPySide_QtCoreTypes[SBK_QSTATE_CHILDMODE_IDX] = &SbkPySide_QtCore_QState_ChildMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QState_ChildMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QState_ChildMode_Type);
    PyDict_SetItemString(SbkQState_Type.super.ht_type.tp_dict,
            "ChildMode",((PyObject*)&SbkPySide_QtCore_QState_ChildMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QState_ChildMode_Type,
        (long) QState::ExclusiveStates, "ExclusiveStates");
    PyDict_SetItemString(SbkQState_Type.super.ht_type.tp_dict,
        "ExclusiveStates", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QState_ChildMode_Type.tp_dict,
        "ExclusiveStates", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QState_ChildMode_Type,
        (long) QState::ParallelStates, "ParallelStates");
    PyDict_SetItemString(SbkQState_Type.super.ht_type.tp_dict,
        "ParallelStates", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QState_ChildMode_Type.tp_dict,
        "ParallelStates", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QState::ChildMode");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("propertiesAssigned", "void", NULL);
    PyDict_SetItemString(SbkQState_Type.super.ht_type.tp_dict, "propertiesAssigned", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("finished", "void", NULL);
    PyDict_SetItemString(SbkQState_Type.super.ht_type.tp_dict, "finished", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QState >("QState*");
    Shiboken::TypeResolver::createObjectTypeResolver<QState >(typeid(QState).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QState >(typeid(QStateWrapper).name());
    PySide::initQtMetaType<QState* >();
}

