/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qstatemachine_wrapper.h"
#include "qstatemachine_wrappedevent_wrapper.h"
#include "qstatemachine_signalevent_wrapper.h"

// Extra includes
#include <QList>
#include <QSet>
#include <qabstractanimation.h>
#include <qabstractstate.h>
#include <qabstracttransition.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsignaltransition.h>
#include <qstate.h>
#include <qstatemachine.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QStateMachineWrapper::QStateMachineWrapper(QObject * parent) : QStateMachine(parent), m_metaObject(0) {
    // ... middle
}

void QStateMachineWrapper::beginMicrostep(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "beginMicrostep"));
    if (py_override.isNull()) {
        return this->QStateMachine::beginMicrostep(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateMachineWrapper::beginSelectTransitions(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "beginSelectTransitions"));
    if (py_override.isNull()) {
        return this->QStateMachine::beginSelectTransitions(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateMachineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateMachineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateMachineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QStateMachineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateMachineWrapper::endMicrostep(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "endMicrostep"));
    if (py_override.isNull()) {
        return this->QStateMachine::endMicrostep(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateMachineWrapper::endSelectTransitions(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "endSelectTransitions"));
    if (py_override.isNull()) {
        return this->QStateMachine::endSelectTransitions(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QStateMachineWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QStateMachine::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStateMachine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QStateMachineWrapper::eventFilter(QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QStateMachine::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(watched),
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QStateMachine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QStateMachineWrapper::onEntry(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "onEntry"));
    if (py_override.isNull()) {
        return this->QStateMachine::onEntry(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateMachineWrapper::onExit(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "onExit"));
    if (py_override.isNull()) {
        return this->QStateMachine::onExit(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QStateMachineWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QStateMachineWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QStateMachine::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QStateMachineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QStateMachine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QStateMachineWrapper::~QStateMachineWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQStateMachine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QStateMachine >()))
        return -1;

    QStateMachineWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QStateMachine", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QStateMachine(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QStateMachine(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QStateMachine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachine_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QStateMachine(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QStateMachine(QObject*)
            cptr = new QStateMachineWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QStateMachine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQStateMachine_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQStateMachine_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine", overloads);
        return -1;
}

static PyObject* SbkQStateMachineFunc_addDefaultAnimation(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addDefaultAnimation(QAbstractAnimation*)
    if (Shiboken::Converter<QAbstractAnimation * >::isConvertible(arg)) {
        overloadId = 0; // addDefaultAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_addDefaultAnimation_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractAnimation* cpp_arg0 = Shiboken::Converter<QAbstractAnimation* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addDefaultAnimation(QAbstractAnimation*)
            cppSelf->QStateMachine::addDefaultAnimation(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_addDefaultAnimation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractAnimation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.addDefaultAnimation", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_addState(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addState(QAbstractState*)
    if (Shiboken::Converter<QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // addState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_addState_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractState* cpp_arg0 = Shiboken::Converter<QAbstractState* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addState(QAbstractState*)
            cppSelf->QStateMachine::addState(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_addState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.addState", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_beginMicrostep(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginMicrostep(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // beginMicrostep(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_beginMicrostep_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // beginMicrostep(QEvent*)
            cppSelf->QStateMachine::beginMicrostep(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_beginMicrostep_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.beginMicrostep", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_beginSelectTransitions(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginSelectTransitions(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // beginSelectTransitions(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_beginSelectTransitions_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // beginSelectTransitions(QEvent*)
            cppSelf->QStateMachine::beginSelectTransitions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_beginSelectTransitions_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.beginSelectTransitions", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_cancelDelayedEvent(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cancelDelayedEvent(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // cancelDelayedEvent(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_cancelDelayedEvent_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // cancelDelayedEvent(int)
            bool cppResult = cppSelf->QStateMachine::cancelDelayedEvent(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQStateMachineFunc_cancelDelayedEvent_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.cancelDelayedEvent", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_clearError(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearError()
            cppSelf->QStateMachine::clearError();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQStateMachineFunc_configuration(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // configuration()
            // Begin code injection
            
            pyResult = PySet_New(0);
            foreach(QAbstractState* abs_state, cppSelf->configuration()) {
                    Shiboken::AutoDecRef obj(Shiboken::Converter<QAbstractState* >::toPython(abs_state));
                    Shiboken::setParent(self, obj);
                    PySet_Add(pyResult, obj);
            }
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateMachineFunc_defaultAnimations(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultAnimations()
            // Begin code injection
            
            pyResult = PyList_New(0);
            foreach(QAbstractAnimation* abs_anim, cppSelf->defaultAnimations()) {
                    Shiboken::AutoDecRef obj(Shiboken::Converter<QAbstractAnimation* >::toPython(abs_anim));
                    Shiboken::setParent(self, obj);
                    PyList_Append(pyResult, obj);
            }
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateMachineFunc_endMicrostep(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: endMicrostep(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // endMicrostep(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_endMicrostep_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // endMicrostep(QEvent*)
            cppSelf->QStateMachine::endMicrostep(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_endMicrostep_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.endMicrostep", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_endSelectTransitions(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: endSelectTransitions(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // endSelectTransitions(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_endSelectTransitions_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // endSelectTransitions(QEvent*)
            cppSelf->QStateMachine::endSelectTransitions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_endSelectTransitions_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.endSelectTransitions", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_error(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QStateMachine::Error cppResult = cppSelf->QStateMachine::error();
            pyResult = Shiboken::Converter<QStateMachine::Error >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateMachineFunc_errorString(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QStateMachine::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateMachineFunc_event(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QStateMachine::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQStateMachineFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.event", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_eventFilter(PyObject* self, PyObject* args)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: eventFilter(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_eventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = Shiboken::Converter<QEvent* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = cppSelf->QStateMachine::eventFilter(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQStateMachineFunc_eventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine.eventFilter", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_globalRestorePolicy(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // globalRestorePolicy()const
            QStateMachine::RestorePolicy cppResult = cppSelf->QStateMachine::globalRestorePolicy();
            pyResult = Shiboken::Converter<QStateMachine::RestorePolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateMachineFunc_isAnimated(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAnimated()const
            bool cppResult = cppSelf->QStateMachine::isAnimated();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateMachineFunc_isRunning(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRunning()const
            bool cppResult = cppSelf->QStateMachine::isRunning();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQStateMachineFunc_onEntry(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onEntry(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onEntry(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_onEntry_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // onEntry(QEvent*)
            cppSelf->QStateMachine::onEntry(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_onEntry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.onEntry", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_onExit(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onExit(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onExit(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_onExit_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // onExit(QEvent*)
            cppSelf->QStateMachine::onExit(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_onExit_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.onExit", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_postDelayedEvent(PyObject* self, PyObject* args)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "postDelayedEvent", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: postDelayedEvent(QEvent*,int)
    if (numArgs == 2 && Shiboken::Converter<QEvent * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // postDelayedEvent(QEvent*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_postDelayedEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // postDelayedEvent(QEvent*,int)
            int cppResult = cppSelf->QStateMachine::postDelayedEvent(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQStateMachineFunc_postDelayedEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine.postDelayedEvent", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_postEvent(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "priority" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QStateMachine.postEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QStateMachine.postEvent(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QStateMachine.postEvent(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:postEvent", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: postEvent(QEvent*,QStateMachine::EventPriority)
    if (Shiboken::Converter<QEvent * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // postEvent(QEvent*,QStateMachine::EventPriority)
        } else if (Shiboken::Converter<QStateMachine::EventPriority >::isConvertible(pyargs[1])) {
            overloadId = 0; // postEvent(QEvent*,QStateMachine::EventPriority)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_postEvent_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "priority");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "priority";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QStateMachine.postEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(pyargs[0]);
            QStateMachine::EventPriority cpp_arg1 = pyargs[1] ? Shiboken::Converter<QStateMachine::EventPriority >::toCpp(pyargs[1]) : QStateMachine::NormalPriority;

            if(!PyErr_Occurred()) {
            // postEvent(QEvent*,QStateMachine::EventPriority)
            cppSelf->QStateMachine::postEvent(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_postEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent, PySide.QtCore.QStateMachine.EventPriority = NormalPriority", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QStateMachine.postEvent", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_removeDefaultAnimation(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeDefaultAnimation(QAbstractAnimation*)
    if (Shiboken::Converter<QAbstractAnimation * >::isConvertible(arg)) {
        overloadId = 0; // removeDefaultAnimation(QAbstractAnimation*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_removeDefaultAnimation_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractAnimation* cpp_arg0 = Shiboken::Converter<QAbstractAnimation* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeDefaultAnimation(QAbstractAnimation*)
            cppSelf->QStateMachine::removeDefaultAnimation(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_removeDefaultAnimation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractAnimation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.removeDefaultAnimation", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_removeState(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeState(QAbstractState*)
    if (Shiboken::Converter<QAbstractState * >::isConvertible(arg)) {
        overloadId = 0; // removeState(QAbstractState*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_removeState_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractState* cpp_arg0 = Shiboken::Converter<QAbstractState* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeState(QAbstractState*)
            cppSelf->QStateMachine::removeState(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_removeState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.removeState", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_setAnimated(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnimated(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAnimated(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_setAnimated_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAnimated(bool)
            cppSelf->QStateMachine::setAnimated(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_setAnimated_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.setAnimated", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_setGlobalRestorePolicy(PyObject* self, PyObject* arg)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGlobalRestorePolicy(QStateMachine::RestorePolicy)
    if (Shiboken::Converter<QStateMachine::RestorePolicy >::isConvertible(arg)) {
        overloadId = 0; // setGlobalRestorePolicy(QStateMachine::RestorePolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStateMachineFunc_setGlobalRestorePolicy_TypeError;

    // Call function/method
    {
        {
            QStateMachine::RestorePolicy cpp_arg0 = Shiboken::Converter<QStateMachine::RestorePolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGlobalRestorePolicy(QStateMachine::RestorePolicy)
            cppSelf->QStateMachine::setGlobalRestorePolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStateMachineFunc_setGlobalRestorePolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.QStateMachine.RestorePolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QStateMachine.setGlobalRestorePolicy", overloads);
        return 0;
}

static PyObject* SbkQStateMachineFunc_start(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // start()
            cppSelf->QStateMachine::start();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQStateMachineFunc_stop(PyObject* self)
{
    QStateMachine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStateMachine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stop()
            cppSelf->QStateMachine::stop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQStateMachine_methods[] = {
    {"addDefaultAnimation", (PyCFunction)SbkQStateMachineFunc_addDefaultAnimation, METH_O},
    {"addState", (PyCFunction)SbkQStateMachineFunc_addState, METH_O},
    {"beginMicrostep", (PyCFunction)SbkQStateMachineFunc_beginMicrostep, METH_O},
    {"beginSelectTransitions", (PyCFunction)SbkQStateMachineFunc_beginSelectTransitions, METH_O},
    {"cancelDelayedEvent", (PyCFunction)SbkQStateMachineFunc_cancelDelayedEvent, METH_O},
    {"clearError", (PyCFunction)SbkQStateMachineFunc_clearError, METH_NOARGS},
    {"configuration", (PyCFunction)SbkQStateMachineFunc_configuration, METH_NOARGS},
    {"defaultAnimations", (PyCFunction)SbkQStateMachineFunc_defaultAnimations, METH_NOARGS},
    {"endMicrostep", (PyCFunction)SbkQStateMachineFunc_endMicrostep, METH_O},
    {"endSelectTransitions", (PyCFunction)SbkQStateMachineFunc_endSelectTransitions, METH_O},
    {"error", (PyCFunction)SbkQStateMachineFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQStateMachineFunc_errorString, METH_NOARGS},
    {"event", (PyCFunction)SbkQStateMachineFunc_event, METH_O},
    {"eventFilter", (PyCFunction)SbkQStateMachineFunc_eventFilter, METH_VARARGS},
    {"globalRestorePolicy", (PyCFunction)SbkQStateMachineFunc_globalRestorePolicy, METH_NOARGS},
    {"isAnimated", (PyCFunction)SbkQStateMachineFunc_isAnimated, METH_NOARGS},
    {"isRunning", (PyCFunction)SbkQStateMachineFunc_isRunning, METH_NOARGS},
    {"onEntry", (PyCFunction)SbkQStateMachineFunc_onEntry, METH_O},
    {"onExit", (PyCFunction)SbkQStateMachineFunc_onExit, METH_O},
    {"postDelayedEvent", (PyCFunction)SbkQStateMachineFunc_postDelayedEvent, METH_VARARGS},
    {"postEvent", (PyCFunction)SbkQStateMachineFunc_postEvent, METH_VARARGS|METH_KEYWORDS},
    {"removeDefaultAnimation", (PyCFunction)SbkQStateMachineFunc_removeDefaultAnimation, METH_O},
    {"removeState", (PyCFunction)SbkQStateMachineFunc_removeState, METH_O},
    {"setAnimated", (PyCFunction)SbkQStateMachineFunc_setAnimated, METH_O},
    {"setGlobalRestorePolicy", (PyCFunction)SbkQStateMachineFunc_setGlobalRestorePolicy, METH_O},
    {"start", (PyCFunction)SbkQStateMachineFunc_start, METH_NOARGS},
    {"stop", (PyCFunction)SbkQStateMachineFunc_stop, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQStateMachine_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QStateMachine",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQStateMachine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQStateMachine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QStateMachine >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QStateMachine*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQStateMachine_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QStateMachine*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQStateMachine_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtCore_QStateMachine_Error_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QStateMachine_Error_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QStateMachine_Error_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Error",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QStateMachine_Error_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QStateMachine_Error_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QStateMachine_Error_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QStateMachine_EventPriority_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QStateMachine_EventPriority_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QStateMachine_EventPriority_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "EventPriority",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QStateMachine_EventPriority_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QStateMachine_EventPriority_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QStateMachine_EventPriority_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QStateMachine_RestorePolicy_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QStateMachine_RestorePolicy_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QStateMachine_RestorePolicy_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RestorePolicy",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QStateMachine_RestorePolicy_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QStateMachine_RestorePolicy_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QStateMachine_RestorePolicy_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QStateMachine(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQStateMachine_Type);

    SbkQStateMachine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QSTATE_IDX];
    // Fill type discovery information
    SbkQStateMachine_Type.type_discovery = &SbkQStateMachine_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QSTATE_IDX]), &SbkQStateMachine_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQStateMachine_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQStateMachine_Type));
    PyModule_AddObject(module, "QStateMachine",
        ((PyObject*)&SbkQStateMachine_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Error
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_ERROR_IDX] = &SbkPySide_QtCore_QStateMachine_Error_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QStateMachine_Error_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QStateMachine_Error_Type);
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)&SbkPySide_QtCore_QStateMachine_Error_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_Error_Type,
        (long) QStateMachine::NoError, "NoError");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_Error_Type,
        (long) QStateMachine::NoInitialStateError, "NoInitialStateError");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "NoInitialStateError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error_Type.tp_dict,
        "NoInitialStateError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_Error_Type,
        (long) QStateMachine::NoDefaultStateInHistoryStateError, "NoDefaultStateInHistoryStateError");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "NoDefaultStateInHistoryStateError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error_Type.tp_dict,
        "NoDefaultStateInHistoryStateError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_Error_Type,
        (long) QStateMachine::NoCommonAncestorForTransitionError, "NoCommonAncestorForTransitionError");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "NoCommonAncestorForTransitionError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_Error_Type.tp_dict,
        "NoCommonAncestorForTransitionError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStateMachine::Error");

    // init enum class: EventPriority
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_EVENTPRIORITY_IDX] = &SbkPySide_QtCore_QStateMachine_EventPriority_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QStateMachine_EventPriority_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QStateMachine_EventPriority_Type);
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
            "EventPriority",((PyObject*)&SbkPySide_QtCore_QStateMachine_EventPriority_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_EventPriority_Type,
        (long) QStateMachine::NormalPriority, "NormalPriority");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "NormalPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_EventPriority_Type.tp_dict,
        "NormalPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_EventPriority_Type,
        (long) QStateMachine::HighPriority, "HighPriority");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "HighPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_EventPriority_Type.tp_dict,
        "HighPriority", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStateMachine::EventPriority");

    // init enum class: RestorePolicy
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_RESTOREPOLICY_IDX] = &SbkPySide_QtCore_QStateMachine_RestorePolicy_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QStateMachine_RestorePolicy_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QStateMachine_RestorePolicy_Type);
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
            "RestorePolicy",((PyObject*)&SbkPySide_QtCore_QStateMachine_RestorePolicy_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_RestorePolicy_Type,
        (long) QStateMachine::DontRestoreProperties, "DontRestoreProperties");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "DontRestoreProperties", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_RestorePolicy_Type.tp_dict,
        "DontRestoreProperties", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QStateMachine_RestorePolicy_Type,
        (long) QStateMachine::RestoreProperties, "RestoreProperties");
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict,
        "RestoreProperties", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QStateMachine_RestorePolicy_Type.tp_dict,
        "RestoreProperties", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStateMachine::RestorePolicy");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("stopped", "void", NULL);
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict, "stopped", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("started", "void", NULL);
    PyDict_SetItemString(SbkQStateMachine_Type.super.ht_type.tp_dict, "started", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QStateMachine >("QStateMachine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QStateMachine >(typeid(QStateMachine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QStateMachine >(typeid(QStateMachineWrapper).name());
    PySide::initQtMetaType<QStateMachine* >();
}

