/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtcore_python.h"

#include <qbytearray.h>
#include <qmath.h>
#include <qnumeric.h>
#include <qglobal.h>

    // Begin code injection
    
    #include <pyside.h>
    
    // End of code injection
    // Begin code injection
    
    // Define a global variable to handle qInstallMsgHandler callback
    static PyObject* qtmsghandler = 0;
    
    void
    msghandlercallback(QtMsgType type, const char* msg)
    {
        Shiboken::AutoDecRef arglist(Shiboken::makeTuple(type, msg));
        Shiboken::AutoDecRef ret(PyObject_CallObject(qtmsghandler, arglist));
    }
    void QtCoreModuleExit()
    {
        PySide::SignalManager::instance().clear();
    }
    
    // End of code injection
    // Begin code injection
    
    extern bool
    qRegisterResourceData(int,
                        const unsigned char *,
                        const unsigned char *,
                        const unsigned char *);
    
    extern bool
    qUnregisterResourceData(int,
                            const unsigned char *,
                            const unsigned char *,
                            const unsigned char *);
    
    // End of code injection

// Global functions ------------------------------------------------------------
static PyObject* SbkQtCoreModule_QT_TRANSLATE_NOOP(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QT_TRANSLATE_NOOP", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: QT_TRANSLATE_NOOP(const char*,const char*)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        overloadId = 0; // QT_TRANSLATE_NOOP(const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_QT_TRANSLATE_NOOP_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // QT_TRANSLATE_NOOP(const char*,const char*)
            // Begin code injection
            (void)cpp_arg0;(void)cpp_arg1;pyResult = pyargs[2-1];
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_QT_TRANSLATE_NOOP_TypeError:
        const char* overloads[] = {"str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QT_TRANSLATE_NOOP", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_QT_TRANSLATE_NOOP3(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QT_TRANSLATE_NOOP3", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: QT_TRANSLATE_NOOP3(const char*,const char*,const char*)
    if (numArgs == 3 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1]) && Shiboken::Converter<const char * >::isConvertible(pyargs[2])) {
        overloadId = 0; // QT_TRANSLATE_NOOP3(const char*,const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_QT_TRANSLATE_NOOP3_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            const char * cpp_arg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // QT_TRANSLATE_NOOP3(const char*,const char*,const char*)
            // Begin code injection
            (void)cpp_arg0;(void)cpp_arg1;(void)cpp_arg2;pyResult = pyargs[2-1];
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_QT_TRANSLATE_NOOP3_TypeError:
        const char* overloads[] = {"str, str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "QT_TRANSLATE_NOOP3", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_QT_TRANSLATE_NOOP_UTF8(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: QT_TRANSLATE_NOOP_UTF8(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // QT_TRANSLATE_NOOP_UTF8(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_QT_TRANSLATE_NOOP_UTF8_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // QT_TRANSLATE_NOOP_UTF8(const char*)
            // Begin code injection
            (void)cpp_arg0;pyResult = arg;
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_QT_TRANSLATE_NOOP_UTF8_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QT_TRANSLATE_NOOP_UTF8", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_QT_TR_NOOP(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: QT_TR_NOOP(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // QT_TR_NOOP(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_QT_TR_NOOP_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // QT_TR_NOOP(const char*)
            // Begin code injection
            (void)cpp_arg0;pyResult = arg;
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_QT_TR_NOOP_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QT_TR_NOOP", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_QT_TR_NOOP_UTF8(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: QT_TR_NOOP_UTF8(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // QT_TR_NOOP_UTF8(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_QT_TR_NOOP_UTF8_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // QT_TR_NOOP_UTF8(const char*)
            // Begin code injection
            (void)cpp_arg0;pyResult = arg;
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_QT_TR_NOOP_UTF8_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "QT_TR_NOOP_UTF8", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_SIGNAL(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: SIGNAL(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // SIGNAL(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_SIGNAL_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // SIGNAL(const char*)
            // Begin code injection
            
            pyResult = PyString_FromFormat("2%s", QMetaObject::normalizedSignature(cpp_arg0).constData());
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_SIGNAL_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "SIGNAL", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_SLOT(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: SLOT(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // SLOT(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_SLOT_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // SLOT(const char*)
            // Begin code injection
            
            pyResult = PyString_FromFormat("1%s", QMetaObject::normalizedSignature(cpp_arg0).constData());
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_SLOT_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "SLOT", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule___moduleShutdown(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // __moduleShutdown()
            // Begin code injection
            
            PySide::SignalManager::instance().clear();
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQtCoreModule_qAbs(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qAbs(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qAbs(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qAbs_TypeError;

    // Call function/method
    {
        {
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qAbs(double)
            // Begin code injection
            
            pyResult = Shiboken::Converter<double >::toPython(qAbs(cpp_arg0));
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qAbs_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qAbs", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qAcos(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qAcos(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qAcos(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qAcos_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qAcos(qreal)
            qreal cppResult = qAcos(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qAcos_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qAcos", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qAsin(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qAsin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qAsin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qAsin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qAsin(qreal)
            qreal cppResult = qAsin(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qAsin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qAsin", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qAtan(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qAtan(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qAtan(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qAtan_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qAtan(qreal)
            qreal cppResult = qAtan(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qAtan_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qAtan", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qAtan2(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qAtan2", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: qAtan2(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // qAtan2(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qAtan2_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // qAtan2(qreal,qreal)
            qreal cppResult = qAtan2(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qAtan2_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qAtan2", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qChecksum(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qChecksum", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: qChecksum(const char*,uint)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // qChecksum(const char*,uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qChecksum_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            uint cpp_arg1 = Shiboken::Converter<uint >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // qChecksum(const char*,uint)
            quint16 cppResult = qChecksum(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<unsigned short >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qChecksum_TypeError:
        const char* overloads[] = {"str, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qChecksum", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qCritical(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qCritical(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // qCritical(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qCritical_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qCritical(const char*)
            qCritical(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtCoreModule_qCritical_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qCritical", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qDebug(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qDebug(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // qDebug(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qDebug_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qDebug(const char*)
            qDebug(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtCoreModule_qDebug_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qDebug", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qExp(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qExp(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qExp(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qExp_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qExp(qreal)
            qreal cppResult = qExp(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qExp_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qExp", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qFabs(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qFabs(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qFabs(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qFabs_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qFabs(qreal)
            qreal cppResult = qFabs(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qFabs_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qFabs", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qFastCos(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qFastCos(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qFastCos(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qFastCos_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qFastCos(qreal)
            qreal cppResult = qFastCos(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qFastCos_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qFastCos", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qFastSin(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qFastSin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qFastSin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qFastSin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qFastSin(qreal)
            qreal cppResult = qFastSin(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qFastSin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qFastSin", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qFatal(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qFatal(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // qFatal(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qFatal_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qFatal(const char*)
            qFatal(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtCoreModule_qFatal_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qFatal", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qFuzzyCompare(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qFuzzyCompare", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: qFuzzyCompare(double,double)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // qFuzzyCompare(double,double)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qFuzzyCompare_TypeError;

    // Call function/method
    {
        {
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);
            double cpp_arg1 = Shiboken::Converter<double >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // qFuzzyCompare(double,double)
            bool cppResult = qFuzzyCompare(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qFuzzyCompare_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qFuzzyCompare", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qFuzzyIsNull(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qFuzzyIsNull(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qFuzzyIsNull(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qFuzzyIsNull_TypeError;

    // Call function/method
    {
        {
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qFuzzyIsNull(double)
            bool cppResult = qFuzzyIsNull(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qFuzzyIsNull_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qFuzzyIsNull", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qInstallMsgHandler(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qInstallMsgHandler(PyObject)
    if (PyObject_Check(arg)) {
        overloadId = 0; // qInstallMsgHandler(PyObject)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qInstallMsgHandler_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // qInstallMsgHandler(PyObject)
            // Begin code injection
            
            if (arg == Py_None) {
              qInstallMsgHandler(0);
              pyResult = qtmsghandler ? qtmsghandler : Py_None;
              qtmsghandler = 0;
            } else if (!PyCallable_Check(arg)) {
              PyErr_SetString(PyExc_TypeError, "parameter must be callable");
            } else {
              pyResult = qtmsghandler ? qtmsghandler : Py_None;
              Py_INCREF(arg);
              qtmsghandler = arg;
              qInstallMsgHandler(msghandlercallback);
            }
            
            if (pyResult == Py_None)
              Py_INCREF(pyResult);
            
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qInstallMsgHandler_TypeError:
        const char* overloads[] = {"PyObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qInstallMsgHandler", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qIsFinite(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qIsFinite(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qIsFinite(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qIsFinite_TypeError;

    // Call function/method
    {
        {
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qIsFinite(double)
            bool cppResult = qIsFinite(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qIsFinite_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qIsFinite", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qIsInf(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qIsInf(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qIsInf(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qIsInf_TypeError;

    // Call function/method
    {
        {
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qIsInf(double)
            bool cppResult = qIsInf(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qIsInf_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qIsInf", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qIsNaN(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qIsNaN(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qIsNaN(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qIsNaN_TypeError;

    // Call function/method
    {
        {
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qIsNaN(double)
            bool cppResult = qIsNaN(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qIsNaN_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qIsNaN", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qIsNull(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qIsNull(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qIsNull(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qIsNull_TypeError;

    // Call function/method
    {
        {
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qIsNull(double)
            bool cppResult = qIsNull(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qIsNull_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qIsNull", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qRegisterResourceData(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qRegisterResourceData", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: qRegisterResourceData(int,const char*,const char*,const char*)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1]) && Shiboken::Converter<const char * >::isConvertible(pyargs[2]) && Shiboken::Converter<const char * >::isConvertible(pyargs[3])) {
        overloadId = 0; // qRegisterResourceData(int,const char*,const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qRegisterResourceData_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            const char * cpp_arg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);
            const char * cpp_arg3 = Shiboken::Converter<const char * >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // qRegisterResourceData(int,const char*,const char*,const char*)
            // Begin code injection
            
            pyResult = Shiboken::Converter<bool >::toPython(qRegisterResourceData(cpp_arg0, (uchar*)cpp_arg1, (uchar*)cpp_arg2, (uchar*)cpp_arg3));
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qRegisterResourceData_TypeError:
        const char* overloads[] = {"int, str, str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qRegisterResourceData", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qRound(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qRound(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qRound(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qRound_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qRound(qreal)
            int cppResult = qRound(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qRound_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qRound", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qTan(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qTan(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qTan(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qTan_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qTan(qreal)
            qreal cppResult = qTan(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qTan_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qTan", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qUnregisterResourceData(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qUnregisterResourceData", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: qUnregisterResourceData(int,const char*,const char*,const char*)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1]) && Shiboken::Converter<const char * >::isConvertible(pyargs[2]) && Shiboken::Converter<const char * >::isConvertible(pyargs[3])) {
        overloadId = 0; // qUnregisterResourceData(int,const char*,const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qUnregisterResourceData_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            const char * cpp_arg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);
            const char * cpp_arg3 = Shiboken::Converter<const char * >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // qUnregisterResourceData(int,const char*,const char*,const char*)
            // Begin code injection
            
            pyResult = Shiboken::Converter<bool >::toPython(qUnregisterResourceData(cpp_arg0, (uchar*)cpp_arg1, (uchar*)cpp_arg2, (uchar*)cpp_arg3));
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qUnregisterResourceData_TypeError:
        const char* overloads[] = {"int, str, str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qUnregisterResourceData", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qVersion(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // qVersion()
            const char * cppResult = qVersion();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtCoreModule_qWarning(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qWarning(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // qWarning(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qWarning_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qWarning(const char*)
            qWarning(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtCoreModule_qWarning_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qWarning", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qrand(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // qrand()
            int cppResult = qrand();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQtCoreModule_qsrand(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qsrand(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qsrand(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qsrand_TypeError;

    // Call function/method
    {
        {
            uint cpp_arg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qsrand(uint)
            qsrand(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQtCoreModule_qsrand_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qsrand", overloads);
        return 0;
}

static PyObject* SbkQtCoreModule_qtTrId(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "n" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "qtTrId(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "qtTrId(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "qtTrId(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:qtTrId", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: qtTrId(const char*,int)
    if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // qtTrId(const char*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // qtTrId(const char*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtCoreModule_qtTrId_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "n");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "n";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "qtTrId(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // qtTrId(const char*,int)
            QString cppResult = qtTrId(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtCoreModule_qtTrId_TypeError:
        const char* overloads[] = {"str, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qtTrId", overloads);
        return 0;
}


static PyMethodDef QtCore_methods[] = {
    {"QT_TRANSLATE_NOOP", (PyCFunction)SbkQtCoreModule_QT_TRANSLATE_NOOP, METH_VARARGS},
    {"QT_TRANSLATE_NOOP3", (PyCFunction)SbkQtCoreModule_QT_TRANSLATE_NOOP3, METH_VARARGS},
    {"QT_TRANSLATE_NOOP_UTF8", (PyCFunction)SbkQtCoreModule_QT_TRANSLATE_NOOP_UTF8, METH_O},
    {"QT_TR_NOOP", (PyCFunction)SbkQtCoreModule_QT_TR_NOOP, METH_O},
    {"QT_TR_NOOP_UTF8", (PyCFunction)SbkQtCoreModule_QT_TR_NOOP_UTF8, METH_O},
    {"SIGNAL", (PyCFunction)SbkQtCoreModule_SIGNAL, METH_O},
    {"SLOT", (PyCFunction)SbkQtCoreModule_SLOT, METH_O},
    {"__moduleShutdown", (PyCFunction)SbkQtCoreModule___moduleShutdown, METH_NOARGS},
    {"qAbs", (PyCFunction)SbkQtCoreModule_qAbs, METH_O},
    {"qAcos", (PyCFunction)SbkQtCoreModule_qAcos, METH_O},
    {"qAsin", (PyCFunction)SbkQtCoreModule_qAsin, METH_O},
    {"qAtan", (PyCFunction)SbkQtCoreModule_qAtan, METH_O},
    {"qAtan2", (PyCFunction)SbkQtCoreModule_qAtan2, METH_VARARGS},
    {"qChecksum", (PyCFunction)SbkQtCoreModule_qChecksum, METH_VARARGS},
    {"qCritical", (PyCFunction)SbkQtCoreModule_qCritical, METH_O},
    {"qDebug", (PyCFunction)SbkQtCoreModule_qDebug, METH_O},
    {"qExp", (PyCFunction)SbkQtCoreModule_qExp, METH_O},
    {"qFabs", (PyCFunction)SbkQtCoreModule_qFabs, METH_O},
    {"qFastCos", (PyCFunction)SbkQtCoreModule_qFastCos, METH_O},
    {"qFastSin", (PyCFunction)SbkQtCoreModule_qFastSin, METH_O},
    {"qFatal", (PyCFunction)SbkQtCoreModule_qFatal, METH_O},
    {"qFuzzyCompare", (PyCFunction)SbkQtCoreModule_qFuzzyCompare, METH_VARARGS},
    {"qFuzzyIsNull", (PyCFunction)SbkQtCoreModule_qFuzzyIsNull, METH_O},
    {"qInstallMsgHandler", (PyCFunction)SbkQtCoreModule_qInstallMsgHandler, METH_O},
    {"qIsFinite", (PyCFunction)SbkQtCoreModule_qIsFinite, METH_O},
    {"qIsInf", (PyCFunction)SbkQtCoreModule_qIsInf, METH_O},
    {"qIsNaN", (PyCFunction)SbkQtCoreModule_qIsNaN, METH_O},
    {"qIsNull", (PyCFunction)SbkQtCoreModule_qIsNull, METH_O},
    {"qRegisterResourceData", (PyCFunction)SbkQtCoreModule_qRegisterResourceData, METH_VARARGS},
    {"qRound", (PyCFunction)SbkQtCoreModule_qRound, METH_O},
    {"qTan", (PyCFunction)SbkQtCoreModule_qTan, METH_O},
    {"qUnregisterResourceData", (PyCFunction)SbkQtCoreModule_qUnregisterResourceData, METH_VARARGS},
    {"qVersion", (PyCFunction)SbkQtCoreModule_qVersion, METH_NOARGS},
    {"qWarning", (PyCFunction)SbkQtCoreModule_qWarning, METH_O},
    {"qrand", (PyCFunction)SbkQtCoreModule_qrand, METH_NOARGS},
    {"qsrand", (PyCFunction)SbkQtCoreModule_qsrand, METH_O},
    {"qtTrId", (PyCFunction)SbkQtCoreModule_qtTrId, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QtConcurrent(PyObject* module);
void init_Qt(PyObject* module);
void init_QProcessEnvironment(PyObject* module);
void init_QTextStreamManipulator(PyObject* module);
void init_QAbstractFileEngineIterator(PyObject* module);
void init_QAbstractFileEngineHandler(PyObject* module);
void init_QAbstractFileEngine(PyObject* module);
void init_QFSFileEngine(PyObject* module);
void init_QDir(PyObject* module);
void init_QDirIterator(PyObject* module);
void init_QFileInfo(PyObject* module);
void init_QTextDecoder(PyObject* module);
void init_QTextEncoder(PyObject* module);
void init_QTextCodec(PyObject* module);
void init_QTextCodec_ConverterState(PyObject* module);
void init_QXmlStreamWriter(PyObject* module);
void init_QXmlStreamReader(PyObject* module);
void init_QXmlStreamEntityResolver(PyObject* module);
void init_QXmlStreamEntityDeclaration(PyObject* module);
void init_QXmlStreamNotationDeclaration(PyObject* module);
void init_QXmlStreamNamespaceDeclaration(PyObject* module);
void init_QXmlStreamAttributes(PyObject* module);
void init_QXmlStreamAttribute(PyObject* module);
void init_QTextBoundaryFinder(PyObject* module);
void init_QRectF(PyObject* module);
void init_QRect(PyObject* module);
void init_QSizeF(PyObject* module);
void init_QSize(PyObject* module);
void init_QMargins(PyObject* module);
void init_QLocale(PyObject* module);
void init_QResource(PyObject* module);
void init_QSystemLocale(PyObject* module);
void init_QLineF(PyObject* module);
void init_QLine(PyObject* module);
void init_QPointF(PyObject* module);
void init_QPoint(PyObject* module);
void init_QElapsedTimer(PyObject* module);
void init_QCryptographicHash(PyObject* module);
void init_QByteArrayMatcher(PyObject* module);
void init_QBitArray(PyObject* module);
void init_QUuid(PyObject* module);
void init_QFactoryInterface(PyObject* module);
void init_QRegExp(PyObject* module);
void init_QWaitCondition(PyObject* module);
void init_QSemaphore(PyObject* module);
void init_QWriteLocker(PyObject* module);
void init_QReadLocker(PyObject* module);
void init_QReadWriteLock(PyObject* module);
void init_QMutexLocker(PyObject* module);
void init_QMutex(PyObject* module);
void init_QLibraryInfo(PyObject* module);
void init_QDateTime(PyObject* module);
void init_QTime(PyObject* module);
void init_QDate(PyObject* module);
void init_QSystemSemaphore(PyObject* module);
void init_QMetaClassInfo(PyObject* module);
void init_QMetaProperty(PyObject* module);
void init_QMetaEnum(PyObject* module);
void init_QEvent(PyObject* module);
void init_QDynamicPropertyChangeEvent(PyObject* module);
void init_QChildEvent(PyObject* module);
void init_QTimerEvent(PyObject* module);
void init_QBasicTimer(PyObject* module);
void init_QPersistentModelIndex(PyObject* module);
void init_QModelIndex(PyObject* module);
void init_QDataStream(PyObject* module);
void init_QEasingCurve(PyObject* module);
void init_QObject(PyObject* module);
void init_QMimeData(PyObject* module);
void init_QEventLoop(PyObject* module);
void init_QThread(PyObject* module);
void init_QAbstractTransition(PyObject* module);
void init_QSignalTransition(PyObject* module);
void init_QEventTransition(PyObject* module);
void init_QAbstractState(PyObject* module);
void init_QHistoryState(PyObject* module);
void init_QFinalState(PyObject* module);
void init_QState(PyObject* module);
void init_QStateMachine(PyObject* module);
void init_QStateMachine_WrappedEvent(PyObject* module);
void init_QStateMachine_SignalEvent(PyObject* module);
void init_QCoreApplication(PyObject* module);
void init_QIODevice(PyObject* module);
void init_QTextStream(PyObject* module);
void init_QBuffer(PyObject* module);
void init_QFile(PyObject* module);
void init_QTemporaryFile(PyObject* module);
void init_QProcess(PyObject* module);
void init_QSettings(PyObject* module);
void init_QAbstractAnimation(PyObject* module);
void init_QVariantAnimation(PyObject* module);
void init_QPropertyAnimation(PyObject* module);
void init_QPauseAnimation(PyObject* module);
void init_QAnimationGroup(PyObject* module);
void init_QSequentialAnimationGroup(PyObject* module);
void init_QParallelAnimationGroup(PyObject* module);
void init_QTranslator(PyObject* module);
void init_QTimer(PyObject* module);
void init_QAbstractItemModel(PyObject* module);
void init_QAbstractListModel(PyObject* module);
void init_QAbstractTableModel(PyObject* module);
void init_QTimeLine(PyObject* module);
void init_QFileSystemWatcher(PyObject* module);
void init_QSocketNotifier(PyObject* module);
void init_QSignalMapper(PyObject* module);
void init_QAbstractEventDispatcher(PyObject* module);
void init_QByteArray(PyObject* module);
void init_QUrl(PyObject* module);
void init_QGenericArgument(PyObject* module);
void init_QMetaMethod(PyObject* module);
void init_QMetaObject(PyObject* module);
void init_QGenericReturnArgument(PyObject* module);
void init_QSysInfo(PyObject* module);

// Enum definitions ------------------------------------------------------------
static PyGetSetDef SbkPySide_QtCore_QtMsgType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QtMsgType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QtMsgType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QtMsgType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QtMsgType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QtMsgType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QtMsgType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtCore()
{

    Shiboken::initShiboken();
    PyObject* module = Py_InitModule("QtCore", QtCore_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtCore_IDX_COUNT];
    SbkPySide_QtCoreTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QtConcurrent(module);
    init_Qt(module);
    init_QProcessEnvironment(module);
    init_QTextStreamManipulator(module);
    init_QAbstractFileEngineIterator(module);
    init_QAbstractFileEngineHandler(module);
    init_QAbstractFileEngine(module);
    init_QFSFileEngine(module);
    init_QDir(module);
    init_QDirIterator(module);
    init_QFileInfo(module);
    init_QTextDecoder(module);
    init_QTextEncoder(module);
    init_QTextCodec(module);
    init_QTextCodec_ConverterState(SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_IDX]->tp_dict);
    init_QXmlStreamWriter(module);
    init_QXmlStreamReader(module);
    init_QXmlStreamEntityResolver(module);
    init_QXmlStreamEntityDeclaration(module);
    init_QXmlStreamNotationDeclaration(module);
    init_QXmlStreamNamespaceDeclaration(module);
    init_QXmlStreamAttributes(module);
    init_QXmlStreamAttribute(module);
    init_QTextBoundaryFinder(module);
    init_QRectF(module);
    init_QRect(module);
    init_QSizeF(module);
    init_QSize(module);
    init_QMargins(module);
    init_QLocale(module);
    init_QResource(module);
    init_QSystemLocale(module);
    init_QLineF(module);
    init_QLine(module);
    init_QPointF(module);
    init_QPoint(module);
    init_QElapsedTimer(module);
    init_QCryptographicHash(module);
    init_QByteArrayMatcher(module);
    init_QBitArray(module);
    init_QUuid(module);
    init_QFactoryInterface(module);
    init_QRegExp(module);
    init_QWaitCondition(module);
    init_QSemaphore(module);
    init_QWriteLocker(module);
    init_QReadLocker(module);
    init_QReadWriteLock(module);
    init_QMutexLocker(module);
    init_QMutex(module);
    init_QLibraryInfo(module);
    init_QDateTime(module);
    init_QTime(module);
    init_QDate(module);
    init_QSystemSemaphore(module);
    init_QMetaClassInfo(module);
    init_QMetaProperty(module);
    init_QMetaEnum(module);
    init_QEvent(module);
    init_QDynamicPropertyChangeEvent(module);
    init_QChildEvent(module);
    init_QTimerEvent(module);
    init_QBasicTimer(module);
    init_QPersistentModelIndex(module);
    init_QModelIndex(module);
    init_QDataStream(module);
    init_QEasingCurve(module);
    init_QObject(module);
    init_QMimeData(module);
    init_QEventLoop(module);
    init_QThread(module);
    init_QAbstractTransition(module);
    init_QSignalTransition(module);
    init_QEventTransition(module);
    init_QAbstractState(module);
    init_QHistoryState(module);
    init_QFinalState(module);
    init_QState(module);
    init_QStateMachine(module);
    init_QStateMachine_WrappedEvent(SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_IDX]->tp_dict);
    init_QStateMachine_SignalEvent(SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_IDX]->tp_dict);
    init_QCoreApplication(module);
    init_QIODevice(module);
    init_QTextStream(module);
    init_QBuffer(module);
    init_QFile(module);
    init_QTemporaryFile(module);
    init_QProcess(module);
    init_QSettings(module);
    init_QAbstractAnimation(module);
    init_QVariantAnimation(module);
    init_QPropertyAnimation(module);
    init_QPauseAnimation(module);
    init_QAnimationGroup(module);
    init_QSequentialAnimationGroup(module);
    init_QParallelAnimationGroup(module);
    init_QTranslator(module);
    init_QTimer(module);
    init_QAbstractItemModel(module);
    init_QAbstractListModel(module);
    init_QAbstractTableModel(module);
    init_QTimeLine(module);
    init_QFileSystemWatcher(module);
    init_QSocketNotifier(module);
    init_QSignalMapper(module);
    init_QAbstractEventDispatcher(module);
    init_QByteArray(module);
    init_QUrl(module);
    init_QGenericArgument(module);
    init_QMetaMethod(module);
    init_QMetaObject(module);
    init_QGenericReturnArgument(module);
    init_QSysInfo(module);

    // Initialize enums
    PyObject* enum_item;

    // init enum class: QtMsgType
    SbkPySide_QtCoreTypes[SBK_QTMSGTYPE_IDX] = &SbkPySide_QtCore_QtMsgType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QtMsgType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QtMsgType_Type);
    PyModule_AddObject(module,
            "QtMsgType",((PyObject*)&SbkPySide_QtCore_QtMsgType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QtMsgType_Type,
        (long) QtDebugMsg, "QtDebugMsg");
    PyModule_AddObject(module,
        "QtDebugMsg", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QtMsgType_Type.tp_dict,
        "QtDebugMsg", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QtMsgType_Type,
        (long) QtWarningMsg, "QtWarningMsg");
    PyModule_AddObject(module,
        "QtWarningMsg", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QtMsgType_Type.tp_dict,
        "QtWarningMsg", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QtMsgType_Type,
        (long) QtCriticalMsg, "QtCriticalMsg");
    PyModule_AddObject(module,
        "QtCriticalMsg", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QtMsgType_Type.tp_dict,
        "QtCriticalMsg", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QtMsgType_Type,
        (long) QtFatalMsg, "QtFatalMsg");
    PyModule_AddObject(module,
        "QtFatalMsg", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QtMsgType_Type.tp_dict,
        "QtFatalMsg", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QtMsgType_Type,
        (long) QtSystemMsg, "QtSystemMsg");
    PyModule_AddObject(module,
        "QtSystemMsg", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QtMsgType_Type.tp_dict,
        "QtSystemMsg", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QtMsgType");

    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver<int >("int");
    Shiboken::TypeResolver::createValueTypeResolver<QString >("QString");
    Shiboken::TypeResolver::createValueTypeResolver<ushort >("ushort");
    Shiboken::TypeResolver::createValueTypeResolver<signed int >("signed int");
    Shiboken::TypeResolver::createValueTypeResolver<float >("float");
    Shiboken::TypeResolver::createValueTypeResolver<qulonglong >("qulonglong");
    Shiboken::TypeResolver::createValueTypeResolver<unsigned long long >("unsigned long long");
    Shiboken::TypeResolver::createValueTypeResolver<signed short >("signed short");
    Shiboken::TypeResolver::createValueTypeResolver<unsigned long >("unsigned long");
    Shiboken::TypeResolver::createValueTypeResolver<quint64 >("quint64");
    Shiboken::TypeResolver::createValueTypeResolver<quint32 >("quint32");
    Shiboken::TypeResolver::createValueTypeResolver<quint16 >("quint16");
    Shiboken::TypeResolver::createValueTypeResolver<unsigned short >("unsigned short");
    Shiboken::TypeResolver::createValueTypeResolver<qreal >("qreal");
    Shiboken::TypeResolver::createValueTypeResolver<long >("long");
    Shiboken::TypeResolver::createValueTypeResolver<bool >("bool");
    Shiboken::TypeResolver::createValueTypeResolver<QVariant >("QVariant");
    Shiboken::TypeResolver::createValueTypeResolver<QBool >("QBool");
    Shiboken::TypeResolver::createValueTypeResolver<signed char >("signed char");
    Shiboken::TypeResolver::createValueTypeResolver<double >("double");
    Shiboken::TypeResolver::createValueTypeResolver<QVariant::Type >("QVariant::Type");
    Shiboken::TypeResolver::createValueTypeResolver<uchar >("uchar");
    Shiboken::TypeResolver::createValueTypeResolver<qlonglong >("qlonglong");
    Shiboken::TypeResolver::createValueTypeResolver<long long >("long long");
    Shiboken::TypeResolver::createValueTypeResolver<unsigned int >("unsigned int");
    Shiboken::TypeResolver::createValueTypeResolver<quint8 >("quint8");
    Shiboken::TypeResolver::createValueTypeResolver<QStringRef >("QStringRef");
    Shiboken::TypeResolver::createValueTypeResolver<unsigned char >("unsigned char");
    Shiboken::TypeResolver::createValueTypeResolver<char >("char");
    Shiboken::TypeResolver::createValueTypeResolver<QChar >("QChar");
    Shiboken::TypeResolver::createValueTypeResolver<uint >("uint");
    Shiboken::TypeResolver::createValueTypeResolver<qint8 >("qint8");
    Shiboken::TypeResolver::createValueTypeResolver<ulong >("ulong");
    Shiboken::TypeResolver::createValueTypeResolver<signed long >("signed long");
    Shiboken::TypeResolver::createValueTypeResolver<qint16 >("qint16");
    Shiboken::TypeResolver::createValueTypeResolver<qint32 >("qint32");
    Shiboken::TypeResolver::createValueTypeResolver<short >("short");
    Shiboken::TypeResolver::createValueTypeResolver<qint64 >("qint64");
    Shiboken::TypeResolver::createValueTypeResolver<Qt::HANDLE >("Qt::HANDLE");

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtCore");
    }
    // Begin code injection
    
    PyModule_AddIntConstant(module, "QT_VERSION", QT_VERSION);
    PyModule_AddStringConstant(module, "QT_VERSION_STR", QT_VERSION_STR);
    
    // End of code injection
    // Begin code injection
    
    Shiboken::TypeResolver::createValueTypeResolver<QString>("unicode");
    Shiboken::TypeResolver::createValueTypeResolver<QString>("str");
    PySide::init(module);
    Py_AtExit(QtCoreModuleExit);
    
    // End of code injection

}


