/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtextcodec_converterstate_wrapper.h"

// Extra includes
#include <QTextCodec>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextCodec_ConverterState_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextCodec::ConverterState >()))
        return -1;

    QTextCodec::ConverterState* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.ConverterState(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.ConverterState(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:ConverterState", &arg))
        return -1;

    // Overloaded function decisor
    // 0: ConverterState(QFlags<QTextCodec::ConversionFlag>)
    if (numArgs == 0) {
        overloadId = 0; // ConverterState(QFlags<QTextCodec::ConversionFlag>)
    } else if (Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::isConvertible(arg)) {
        overloadId = 0; // ConverterState(QFlags<QTextCodec::ConversionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCodec_ConverterState_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (arg)
                        errorArgName = "f";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.ConverterState(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QFlags<QTextCodec::ConversionFlag> cpp_arg0 = arg ? Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::toCpp(arg) : QTextCodec::DefaultConversion;

            if(!PyErr_Occurred()) {
            // ConverterState(QFlags<QTextCodec::ConversionFlag>)
            cptr = new QTextCodec::ConverterState(cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextCodec::ConverterState >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextCodec_ConverterState_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextCodec_ConverterState_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec.ConversionFlags = QTextCodec.DefaultConversion", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.ConverterState", overloads);
        return -1;
}

static PyMethodDef SbkQTextCodec_ConverterState_methods[] = {
    {0} // Sentinel
};

static PyObject* SbkQTextCodec_ConverterState_get_flags(PyObject* self, void*)
{
    return Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::toPython(Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(self)->flags);
}
static int SbkQTextCodec_ConverterState_set_flags(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'flags' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'flags', 'ConversionFlags' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(self)->flags = Shiboken::Converter<QFlags<QTextCodec::ConversionFlag> >::toCpp(value);

    return 0;
}

static PyObject* SbkQTextCodec_ConverterState_get_remainingChars(PyObject* self, void*)
{
    return Shiboken::Converter<int >::toPython(Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(self)->remainingChars);
}
static int SbkQTextCodec_ConverterState_set_remainingChars(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'remainingChars' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'remainingChars', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(self)->remainingChars = Shiboken::Converter<int >::toCpp(value);

    return 0;
}

static PyObject* SbkQTextCodec_ConverterState_get_invalidChars(PyObject* self, void*)
{
    return Shiboken::Converter<int >::toPython(Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(self)->invalidChars);
}
static int SbkQTextCodec_ConverterState_set_invalidChars(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'invalidChars' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'invalidChars', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QTextCodec::ConverterState* >::toCpp(self)->invalidChars = Shiboken::Converter<int >::toCpp(value);

    return 0;
}

// Getters and Setters for ConverterState
static PyGetSetDef SbkQTextCodec_ConverterState_getsetlist[] = {
    {const_cast<char*>("flags"), SbkQTextCodec_ConverterState_get_flags, SbkQTextCodec_ConverterState_set_flags},
    {const_cast<char*>("remainingChars"), SbkQTextCodec_ConverterState_get_remainingChars, SbkQTextCodec_ConverterState_set_remainingChars},
    {const_cast<char*>("invalidChars"), SbkQTextCodec_ConverterState_get_invalidChars, SbkQTextCodec_ConverterState_set_invalidChars},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextCodec_ConverterState_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.ConverterState",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextCodec_ConverterState_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQTextCodec_ConverterState_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextCodec_ConverterState_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextCodec::ConverterState >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextCodec::ConverterState*",
    /*user_data*/           0
};
} //extern


void init_QTextCodec_ConverterState(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTEXTCODEC_CONVERTERSTATE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextCodec_ConverterState_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextCodec_ConverterState_Type) < 0)
        return;

    PyDict_SetItemString(module,"ConverterState", (PyObject*)&SbkQTextCodec_ConverterState_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<QTextCodec::ConverterState >("QTextCodec::ConverterState*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextCodec::ConverterState >(typeid(QTextCodec::ConverterState).name());
    PySide::initQtMetaType<QTextCodec::ConverterState* >();
}

