/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtextstream_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>
#include <qlocale.h>
#include <qtextcodec.h>
#include <qtextstream.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QTextStreamWrapper::QTextStreamWrapper() : QTextStream() {
    // ... middle
}

QTextStreamWrapper::QTextStreamWrapper(QByteArray * array, QFlags<QIODevice::OpenModeFlag> openMode) : QTextStream(array, openMode) {
    // ... middle
}

QTextStreamWrapper::QTextStreamWrapper(QIODevice * device) : QTextStream(device) {
    // ... middle
}

QTextStreamWrapper::QTextStreamWrapper(QString * string, QFlags<QIODevice::OpenModeFlag> openMode) : QTextStream(string, openMode) {
    // ... middle
}

QTextStreamWrapper::~QTextStreamWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextStream_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextStream >()))
        return -1;

    QTextStreamWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "openMode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextStream(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QTextStream", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTextStream()
    // 1: QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
    // 2: QTextStream(QIODevice*)
    // 3: QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
    if (numArgs == 0) {
        overloadId = 0; // QTextStream()
    } else if (Shiboken::Converter<QString * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 3; // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
        }
    } else if (numArgs == 1 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextStream(QIODevice*)
    } else if (Shiboken::Converter<QByteArray * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 1; // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStream_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextStream()
            {

                if(!PyErr_Occurred()) {
                // QTextStream()
                cptr = new QTextStreamWrapper();
                }
                break;
            }
            case 1: // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "openMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "openMode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                QFlags<QIODevice::OpenModeFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // QTextStream(QByteArray*,QFlags<QIODevice::OpenModeFlag>)
                cptr = new QTextStreamWrapper(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QTextStream(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QTextStream(QIODevice*)
                cptr = new QTextStreamWrapper(cpp_arg0);
                }
                break;
            }
            case 3: // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "openMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "openMode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString * cpp_arg0 = Shiboken::Converter<QString * >::toCpp(pyargs[0]);
                QFlags<QIODevice::OpenModeFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // QTextStream(QString*,QFlags<QIODevice::OpenModeFlag>)
                cptr = new QTextStreamWrapper(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextStream >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextStream_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextStream_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", "PySide.QtCore.QIODevice", "QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTextStream", overloads);
        return -1;
}

static PyObject* SbkQTextStreamFunc_atEnd(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QTextStream::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_autoDetectUnicode(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoDetectUnicode()const
            bool cppResult = cppSelf->QTextStream::autoDetectUnicode();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_codec(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // codec()const
            QTextCodec * cppResult = cppSelf->QTextStream::codec();
            pyResult = Shiboken::Converter<QTextCodec * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_device(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QTextStream::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_fieldAlignment(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fieldAlignment()const
            QTextStream::FieldAlignment cppResult = cppSelf->QTextStream::fieldAlignment();
            pyResult = Shiboken::Converter<QTextStream::FieldAlignment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_fieldWidth(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fieldWidth()const
            int cppResult = cppSelf->QTextStream::fieldWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_flush(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // flush()
            threadStateSaver.save();
            cppSelf->QTextStream::flush();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextStreamFunc_generateByteOrderMark(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // generateByteOrderMark()const
            bool cppResult = cppSelf->QTextStream::generateByteOrderMark();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_integerBase(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // integerBase()const
            int cppResult = cppSelf->QTextStream::integerBase();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_locale(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // locale()const
            QLocale cppResult = cppSelf->QTextStream::locale();
            pyResult = Shiboken::Converter<QLocale >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_numberFlags(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numberFlags()const
            QFlags<QTextStream::NumberFlag> cppResult = cppSelf->QTextStream::numberFlags();
            pyResult = Shiboken::Converter<QFlags<QTextStream::NumberFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_padChar(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // padChar()const
            QChar cppResult = cppSelf->QTextStream::padChar();
            pyResult = Shiboken::Converter<QChar >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_pos(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            qint64 cppResult = cppSelf->QTextStream::pos();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_read(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_read_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // read(qint64)
            threadStateSaver.save();
            QString cppResult = cppSelf->QTextStream::read(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextStreamFunc_read_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.read", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_readAll(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // readAll()
            threadStateSaver.save();
            QString cppResult = cppSelf->QTextStream::readAll();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_readLine(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "maxlen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream.readLine(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTextStream.readLine(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:readLine", &arg))
        return 0;


    // Overloaded function decisor
    // 0: readLine(qint64)
    if (numArgs == 0) {
        overloadId = 0; // readLine(qint64)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // readLine(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_readLine_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "maxlen");
                if (value) {
                    if (arg)
                        errorArgName = "maxlen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTextStream.readLine(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qint64 cpp_arg0 = arg ? Shiboken::Converter<qint64 >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // readLine(qint64)
            threadStateSaver.save();
            QString cppResult = cppSelf->QTextStream::readLine(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextStreamFunc_readLine_TypeError:
        const char* overloads[] = {"long long = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.readLine", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_realNumberNotation(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // realNumberNotation()const
            QTextStream::RealNumberNotation cppResult = cppSelf->QTextStream::realNumberNotation();
            pyResult = Shiboken::Converter<QTextStream::RealNumberNotation >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_realNumberPrecision(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // realNumberPrecision()const
            int cppResult = cppSelf->QTextStream::realNumberPrecision();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_reset(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QTextStream::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextStreamFunc_resetStatus(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetStatus()
            cppSelf->QTextStream::resetStatus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextStreamFunc_seek(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_seek_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // seek(qint64)
            bool cppResult = cppSelf->QTextStream::seek(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextStreamFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.seek", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setAutoDetectUnicode(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoDetectUnicode(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoDetectUnicode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setAutoDetectUnicode_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoDetectUnicode(bool)
            cppSelf->QTextStream::setAutoDetectUnicode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setAutoDetectUnicode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setAutoDetectUnicode", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setCodec(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodec(QTextCodec*)
    // 1: setCodec(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 1; // setCodec(const char*)
    } else if (Shiboken::Converter<QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodec(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setCodec_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setCodec(QTextCodec*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setCodec(QTextCodec*)
                cppSelf->QTextStream::setCodec(cpp_arg0);
                }
                break;
            }
            case 1: // setCodec(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setCodec(const char*)
                cppSelf->QTextStream::setCodec(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setCodec", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setDevice(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QTextStream::setDevice(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setDevice", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setFieldAlignment(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFieldAlignment(QTextStream::FieldAlignment)
    if (Shiboken::Converter<QTextStream::FieldAlignment >::isConvertible(arg)) {
        overloadId = 0; // setFieldAlignment(QTextStream::FieldAlignment)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setFieldAlignment_TypeError;

    // Call function/method
    {
        {
            QTextStream::FieldAlignment cpp_arg0 = Shiboken::Converter<QTextStream::FieldAlignment >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFieldAlignment(QTextStream::FieldAlignment)
            cppSelf->QTextStream::setFieldAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setFieldAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.FieldAlignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setFieldAlignment", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setFieldWidth(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFieldWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFieldWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setFieldWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFieldWidth(int)
            cppSelf->QTextStream::setFieldWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setFieldWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setFieldWidth", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setGenerateByteOrderMark(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGenerateByteOrderMark(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGenerateByteOrderMark(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setGenerateByteOrderMark_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGenerateByteOrderMark(bool)
            cppSelf->QTextStream::setGenerateByteOrderMark(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setGenerateByteOrderMark_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setGenerateByteOrderMark", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setIntegerBase(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIntegerBase(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIntegerBase(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setIntegerBase_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIntegerBase(int)
            cppSelf->QTextStream::setIntegerBase(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setIntegerBase_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setIntegerBase", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setLocale(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocale(QLocale)
    if (Shiboken::Converter<const QLocale & >::isConvertible(arg)) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setLocale_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QLocale > cpp_arg0_auto_ptr;
            QLocale* cpp_arg0 = Shiboken::Converter<QLocale* >::toCpp(arg);
            if (!Shiboken::Converter<QLocale >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QLocale >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setLocale(QLocale)
            cppSelf->QTextStream::setLocale(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setLocale_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setLocale", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setNumberFlags(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumberFlags(QFlags<QTextStream::NumberFlag>)
    if (Shiboken::Converter<QFlags<QTextStream::NumberFlag> >::isConvertible(arg)) {
        overloadId = 0; // setNumberFlags(QFlags<QTextStream::NumberFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setNumberFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QTextStream::NumberFlag> cpp_arg0 = Shiboken::Converter<QFlags<QTextStream::NumberFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNumberFlags(QFlags<QTextStream::NumberFlag>)
            cppSelf->QTextStream::setNumberFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setNumberFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.NumberFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setNumberFlags", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setPadChar(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPadChar(QChar)
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // setPadChar(QChar)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setPadChar_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPadChar(QChar)
            cppSelf->QTextStream::setPadChar(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setPadChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setPadChar", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setRealNumberNotation(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRealNumberNotation(QTextStream::RealNumberNotation)
    if (Shiboken::Converter<QTextStream::RealNumberNotation >::isConvertible(arg)) {
        overloadId = 0; // setRealNumberNotation(QTextStream::RealNumberNotation)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setRealNumberNotation_TypeError;

    // Call function/method
    {
        {
            QTextStream::RealNumberNotation cpp_arg0 = Shiboken::Converter<QTextStream::RealNumberNotation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRealNumberNotation(QTextStream::RealNumberNotation)
            cppSelf->QTextStream::setRealNumberNotation(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setRealNumberNotation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.RealNumberNotation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setRealNumberNotation", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setRealNumberPrecision(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRealNumberPrecision(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRealNumberPrecision(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setRealNumberPrecision_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRealNumberPrecision(int)
            cppSelf->QTextStream::setRealNumberPrecision(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setRealNumberPrecision_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setRealNumberPrecision", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_setStatus(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatus(QTextStream::Status)
    if (Shiboken::Converter<QTextStream::Status >::isConvertible(arg)) {
        overloadId = 0; // setStatus(QTextStream::Status)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc_setStatus_TypeError;

    // Call function/method
    {
        {
            QTextStream::Status cpp_arg0 = Shiboken::Converter<QTextStream::Status >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStatus(QTextStream::Status)
            cppSelf->QTextStream::setStatus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextStreamFunc_setStatus_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream.Status", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.setStatus", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc_skipWhiteSpace(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // skipWhiteSpace()
            cppSelf->QTextStream::skipWhiteSpace();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextStreamFunc_status(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // status()const
            QTextStream::Status cppResult = cppSelf->QTextStream::status();
            pyResult = Shiboken::Converter<QTextStream::Status >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextStreamFunc_string(PyObject* self)
{
    QTextStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // string()const
            QString * cppResult = cppSelf->QTextStream::string();
            pyResult = Shiboken::Converter<QString * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextStream_methods[] = {
    {"atEnd", (PyCFunction)SbkQTextStreamFunc_atEnd, METH_NOARGS},
    {"autoDetectUnicode", (PyCFunction)SbkQTextStreamFunc_autoDetectUnicode, METH_NOARGS},
    {"codec", (PyCFunction)SbkQTextStreamFunc_codec, METH_NOARGS},
    {"device", (PyCFunction)SbkQTextStreamFunc_device, METH_NOARGS},
    {"fieldAlignment", (PyCFunction)SbkQTextStreamFunc_fieldAlignment, METH_NOARGS},
    {"fieldWidth", (PyCFunction)SbkQTextStreamFunc_fieldWidth, METH_NOARGS},
    {"flush", (PyCFunction)SbkQTextStreamFunc_flush, METH_NOARGS},
    {"generateByteOrderMark", (PyCFunction)SbkQTextStreamFunc_generateByteOrderMark, METH_NOARGS},
    {"integerBase", (PyCFunction)SbkQTextStreamFunc_integerBase, METH_NOARGS},
    {"locale", (PyCFunction)SbkQTextStreamFunc_locale, METH_NOARGS},
    {"numberFlags", (PyCFunction)SbkQTextStreamFunc_numberFlags, METH_NOARGS},
    {"padChar", (PyCFunction)SbkQTextStreamFunc_padChar, METH_NOARGS},
    {"pos", (PyCFunction)SbkQTextStreamFunc_pos, METH_NOARGS},
    {"read", (PyCFunction)SbkQTextStreamFunc_read, METH_O},
    {"readAll", (PyCFunction)SbkQTextStreamFunc_readAll, METH_NOARGS},
    {"readLine", (PyCFunction)SbkQTextStreamFunc_readLine, METH_VARARGS|METH_KEYWORDS},
    {"realNumberNotation", (PyCFunction)SbkQTextStreamFunc_realNumberNotation, METH_NOARGS},
    {"realNumberPrecision", (PyCFunction)SbkQTextStreamFunc_realNumberPrecision, METH_NOARGS},
    {"reset", (PyCFunction)SbkQTextStreamFunc_reset, METH_NOARGS},
    {"resetStatus", (PyCFunction)SbkQTextStreamFunc_resetStatus, METH_NOARGS},
    {"seek", (PyCFunction)SbkQTextStreamFunc_seek, METH_O},
    {"setAutoDetectUnicode", (PyCFunction)SbkQTextStreamFunc_setAutoDetectUnicode, METH_O},
    {"setCodec", (PyCFunction)SbkQTextStreamFunc_setCodec, METH_O},
    {"setDevice", (PyCFunction)SbkQTextStreamFunc_setDevice, METH_O},
    {"setFieldAlignment", (PyCFunction)SbkQTextStreamFunc_setFieldAlignment, METH_O},
    {"setFieldWidth", (PyCFunction)SbkQTextStreamFunc_setFieldWidth, METH_O},
    {"setGenerateByteOrderMark", (PyCFunction)SbkQTextStreamFunc_setGenerateByteOrderMark, METH_O},
    {"setIntegerBase", (PyCFunction)SbkQTextStreamFunc_setIntegerBase, METH_O},
    {"setLocale", (PyCFunction)SbkQTextStreamFunc_setLocale, METH_O},
    {"setNumberFlags", (PyCFunction)SbkQTextStreamFunc_setNumberFlags, METH_O},
    {"setPadChar", (PyCFunction)SbkQTextStreamFunc_setPadChar, METH_O},
    {"setRealNumberNotation", (PyCFunction)SbkQTextStreamFunc_setRealNumberNotation, METH_O},
    {"setRealNumberPrecision", (PyCFunction)SbkQTextStreamFunc_setRealNumberPrecision, METH_O},
    {"setStatus", (PyCFunction)SbkQTextStreamFunc_setStatus, METH_O},
    {"skipWhiteSpace", (PyCFunction)SbkQTextStreamFunc_skipWhiteSpace, METH_NOARGS},
    {"status", (PyCFunction)SbkQTextStreamFunc_status, METH_NOARGS},
    {"string", (PyCFunction)SbkQTextStreamFunc_string, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQTextStreamFunc___lshift__(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTextStream* >::checkType(arg) && !Shiboken::Converter<QTextStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QChar)
    // 1: operator<<(QTextStream&,QTextStreamManipulator)
    // 2: operator<<(char)
    // 3: operator<<(QByteArray)
    // 4: operator<<(QString)
    // 5: operator<<(const char*)
    // 6: operator<<(double)
    // 7: operator<<(signed long)
    // 8: operator<<(ulong)
    if (!isReverse && PyLong_Check(arg)) {
        overloadId = 8; // operator<<(ulong)
    } else if (!isReverse && PyLong_Check(arg)) {
        overloadId = 7; // operator<<(signed long)
    } else if (!isReverse && PyFloat_Check(arg)) {
        overloadId = 6; // operator<<(double)
    } else if (!isReverse && Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 5; // operator<<(const char*)
    } else if (!isReverse && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 4; // operator<<(QString)
    } else if (!isReverse && Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 3; // operator<<(QByteArray)
    } else if (!isReverse && Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 2; // operator<<(char)
    } else if (!isReverse && Shiboken::Converter<QTextStreamManipulator >::isConvertible(arg)) {
        overloadId = 1; // operator<<(QTextStream&,QTextStreamManipulator)
    } else if (!isReverse && Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QChar)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc___lshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator<<(QChar)
            {
                QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QChar)
                QTextStream & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator<<(QTextStream&,QTextStreamManipulator)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextStreamManipulator* cpp_arg0 = Shiboken::Converter<QTextStreamManipulator* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QTextStream&,QTextStreamManipulator)
                QTextStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator<<(char)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(char)
                QTextStream & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator<<(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator<<(QByteArray)
                QTextStream & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator<<(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QString)
                QTextStream & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator<<(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(const char*)
                QTextStream & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 6: // operator<<(double)
            {
                double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(double)
                QTextStream & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 7: // operator<<(signed long)
            {
                signed long cpp_arg0 = Shiboken::Converter<signed long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(signed long)
                QTextStream & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 8: // operator<<(ulong)
            {
                unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(ulong)
                QTextStream & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextStreamFunc___lshift___TypeError:
        const char* overloads[] = {"QChar", "PySide.QtCore.QTextStreamManipulator", "char", "PySide.QtCore.QByteArray", "QString", "str", "float", "long", "unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQTextStreamFunc___rshift__(PyObject* self, PyObject* arg)
{
    QTextStream* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QTextStream* >::checkType(arg) && !Shiboken::Converter<QTextStream* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextStream* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QByteArray&)
    // 1: operator>>(char&)
    // 2: operator>>(char*)
    // 3: operator>>(double&)
    // 4: operator>>(signed long&)
    // 5: operator>>(ulong&)
    if (!isReverse && PyLong_Check(arg)) {
        overloadId = 5; // operator>>(ulong&)
    } else if (!isReverse && PyLong_Check(arg)) {
        overloadId = 4; // operator>>(signed long&)
    } else if (!isReverse && PyFloat_Check(arg)) {
        overloadId = 3; // operator>>(double&)
    } else if (!isReverse && Shiboken::Converter<char * >::isConvertible(arg)) {
        overloadId = 2; // operator>>(char*)
    } else if (!isReverse && Shiboken::Converter<char & >::isConvertible(arg)) {
        overloadId = 1; // operator>>(char&)
    } else if (!isReverse && Shiboken::Converter<QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextStreamFunc___rshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator>>(QByteArray&)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator>>(QByteArray&)
                QTextStream & cppResult = (*cppSelf) >> (*cpp_arg0);
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // operator>>(char&)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(char&)
                QTextStream & cppResult = (*cppSelf) >> cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 2: // operator>>(char*)
            {
                char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(char*)
                QTextStream & cppResult = (*cppSelf) >> cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 3: // operator>>(double&)
            {
                double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(double&)
                QTextStream & cppResult = (*cppSelf) >> cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 4: // operator>>(signed long&)
            {
                signed long cpp_arg0 = Shiboken::Converter<signed long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(signed long&)
                QTextStream & cppResult = (*cppSelf) >> cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 5: // operator>>(ulong&)
            {
                unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator>>(ulong&)
                QTextStream & cppResult = (*cppSelf) >> cpp_arg0;
                pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextStreamFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "str", "str", "double", "signed long", "unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStream.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQTextStream_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQTextStreamFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQTextStreamFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextStream_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTextStream",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQTextStream_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextStream_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextStream_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextStream >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextStream*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QTextStream_RealNumberNotation_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTextStream_RealNumberNotation_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTextStream_RealNumberNotation_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RealNumberNotation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTextStream_RealNumberNotation_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTextStream_RealNumberNotation_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTextStream_RealNumberNotation_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextStream::NumberFlags >::checkType(self) && Shiboken::Converter<QTextStream::NumberFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        Shiboken::Converter<QTextStream::NumberFlags>::toCpp(self)
        & Shiboken::Converter< QTextStream::NumberFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextStream::NumberFlags >::checkType(self) && Shiboken::Converter<QTextStream::NumberFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        Shiboken::Converter<QTextStream::NumberFlags>::toCpp(self)
        | Shiboken::Converter< QTextStream::NumberFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextStream::NumberFlags >::checkType(self) && Shiboken::Converter<QTextStream::NumberFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        Shiboken::Converter<QTextStream::NumberFlags>::toCpp(self)
        ^ Shiboken::Converter< QTextStream::NumberFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QTextStream_NumberFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextStream::NumberFlags >::toPython(
        ~Shiboken::Converter<QTextStream::NumberFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QTextStream_NumberFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QTextStream_NumberFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtCore_QTextStream_NumberFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTextStream_NumberFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTextStream_NumberFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "NumberFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtCore_QTextStream_NumberFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTextStream_NumberFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTextStream_NumberFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTextStream_NumberFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QTextStream_NumberFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "NumberFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtCore_QTextStream_NumberFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtCore_QTextStream_FieldAlignment_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTextStream_FieldAlignment_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTextStream_FieldAlignment_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FieldAlignment",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTextStream_FieldAlignment_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTextStream_FieldAlignment_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTextStream_FieldAlignment_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QTextStream_Status_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTextStream_Status_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTextStream_Status_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Status",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTextStream_Status_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTextStream_Status_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTextStream_Status_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextStream(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextStream_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQTextStream_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextStream_Type));
    PyModule_AddObject(module, "QTextStream",
        ((PyObject*)&SbkQTextStream_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: RealNumberNotation
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_REALNUMBERNOTATION_IDX] = &SbkPySide_QtCore_QTextStream_RealNumberNotation_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextStream_RealNumberNotation_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTextStream_RealNumberNotation_Type);
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
            "RealNumberNotation",((PyObject*)&SbkPySide_QtCore_QTextStream_RealNumberNotation_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_RealNumberNotation_Type,
        (long) QTextStream::SmartNotation, "SmartNotation");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "SmartNotation", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_RealNumberNotation_Type.tp_dict,
        "SmartNotation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_RealNumberNotation_Type,
        (long) QTextStream::FixedNotation, "FixedNotation");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "FixedNotation", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_RealNumberNotation_Type.tp_dict,
        "FixedNotation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_RealNumberNotation_Type,
        (long) QTextStream::ScientificNotation, "ScientificNotation");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "ScientificNotation", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_RealNumberNotation_Type.tp_dict,
        "ScientificNotation", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::RealNumberNotation");

    // init enum class: NumberFlag
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_NUMBERFLAG_IDX] = &SbkPySide_QtCore_QTextStream_NumberFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextStream_NumberFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTextStream_NumberFlag_Type);
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
            "NumberFlag",((PyObject*)&SbkPySide_QtCore_QTextStream_NumberFlag_Type));

    // init flags class: QFlags<QTextStream::NumberFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QTEXTSTREAM_NUMBERFLAG__IDX] = &SbkPySide_QtCore_QTextStream_NumberFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextStream_NumberFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTextStream_NumberFlags_Type);
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
            "NumberFlags",((PyObject*)&SbkPySide_QtCore_QTextStream_NumberFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_NumberFlag_Type,
        (long) QTextStream::ShowBase, "ShowBase");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "ShowBase", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag_Type.tp_dict,
        "ShowBase", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_NumberFlag_Type,
        (long) QTextStream::ForcePoint, "ForcePoint");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "ForcePoint", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag_Type.tp_dict,
        "ForcePoint", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_NumberFlag_Type,
        (long) QTextStream::ForceSign, "ForceSign");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "ForceSign", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag_Type.tp_dict,
        "ForceSign", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_NumberFlag_Type,
        (long) QTextStream::UppercaseBase, "UppercaseBase");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "UppercaseBase", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag_Type.tp_dict,
        "UppercaseBase", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_NumberFlag_Type,
        (long) QTextStream::UppercaseDigits, "UppercaseDigits");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "UppercaseDigits", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_NumberFlag_Type.tp_dict,
        "UppercaseDigits", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::NumberFlag");

    // init enum class: FieldAlignment
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_FIELDALIGNMENT_IDX] = &SbkPySide_QtCore_QTextStream_FieldAlignment_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextStream_FieldAlignment_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTextStream_FieldAlignment_Type);
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
            "FieldAlignment",((PyObject*)&SbkPySide_QtCore_QTextStream_FieldAlignment_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_FieldAlignment_Type,
        (long) QTextStream::AlignLeft, "AlignLeft");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "AlignLeft", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment_Type.tp_dict,
        "AlignLeft", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_FieldAlignment_Type,
        (long) QTextStream::AlignRight, "AlignRight");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "AlignRight", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment_Type.tp_dict,
        "AlignRight", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_FieldAlignment_Type,
        (long) QTextStream::AlignCenter, "AlignCenter");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "AlignCenter", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment_Type.tp_dict,
        "AlignCenter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_FieldAlignment_Type,
        (long) QTextStream::AlignAccountingStyle, "AlignAccountingStyle");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "AlignAccountingStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_FieldAlignment_Type.tp_dict,
        "AlignAccountingStyle", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::FieldAlignment");

    // init enum class: Status
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAM_STATUS_IDX] = &SbkPySide_QtCore_QTextStream_Status_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTextStream_Status_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTextStream_Status_Type);
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
            "Status",((PyObject*)&SbkPySide_QtCore_QTextStream_Status_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_Status_Type,
        (long) QTextStream::Ok, "Ok");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "Ok", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_Status_Type.tp_dict,
        "Ok", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_Status_Type,
        (long) QTextStream::ReadPastEnd, "ReadPastEnd");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "ReadPastEnd", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_Status_Type.tp_dict,
        "ReadPastEnd", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTextStream_Status_Type,
        (long) QTextStream::ReadCorruptData, "ReadCorruptData");
    PyDict_SetItemString(SbkQTextStream_Type.super.ht_type.tp_dict,
        "ReadCorruptData", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTextStream_Status_Type.tp_dict,
        "ReadCorruptData", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextStream::Status");


    Shiboken::TypeResolver::createObjectTypeResolver<QTextStream >("QTextStream*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextStream >(typeid(QTextStream).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTextStream >(typeid(QTextStreamWrapper).name());
    PySide::initQtMetaType<QTextStream* >();
}

