/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qthread_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QThreadWrapper::QThreadWrapper(QObject * parent) : QThread(parent), m_metaObject(0) {
    // ... middle
}

void QThreadWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QThreadWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QThreadWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QThreadWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QThreadWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QThread.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QThreadWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QThread.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QThreadWrapper::run()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "run"));
    if (py_override.isNull()) {
        return this->QThread::run();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QThreadWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QThreadWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QThread::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QThreadWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QThread::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QThreadWrapper::~QThreadWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQThread_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QThread >()))
        return -1;

    QThreadWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QThread", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QThread(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QThread(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QThread(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThread_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QThread(QObject*)
            cptr = new QThreadWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QThread >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQThread_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQThread_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QThread", overloads);
        return -1;
}

static PyObject* SbkQThreadFunc_currentThread(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentThread()
            QThread * cppResult = QThread::currentThread();
            pyResult = Shiboken::Converter<QThread * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_currentThreadId(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentThreadId()
            Qt::HANDLE cppResult = QThread::currentThreadId();
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_exec_(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // exec()
            threadStateSaver.save();
            int cppResult = cppSelf->QThread::exec();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_exit(PyObject* self, PyObject* args, PyObject* kwds)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "retcode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.exit(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.exit(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:exit", &arg))
        return 0;


    // Overloaded function decisor
    // 0: exit(int)
    if (numArgs == 0) {
        overloadId = 0; // exit(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // exit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_exit_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "retcode");
                if (value) {
                    if (arg)
                        errorArgName = "retcode";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.exit(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // exit(int)
            threadStateSaver.save();
            cppSelf->QThread::exit(cpp_arg0);
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_exit_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.exit", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_idealThreadCount(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // idealThreadCount()
            int cppResult = QThread::idealThreadCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_isFinished(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isFinished()const
            bool cppResult = cppSelf->QThread::isFinished();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_isRunning(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRunning()const
            bool cppResult = cppSelf->QThread::isRunning();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_msleep(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: msleep(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // msleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_msleep_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // msleep(ulong)
            threadStateSaver.save();
            QThread::msleep(cpp_arg0);
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_msleep_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.msleep", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_priority(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // priority()const
            QThread::Priority cppResult = cppSelf->QThread::priority();
            pyResult = Shiboken::Converter<QThread::Priority >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_quit(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // quit()
            cppSelf->QThread::quit();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQThreadFunc_run(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // run()
            cppSelf->QThread::run();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQThreadFunc_setPriority(PyObject* self, PyObject* arg)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPriority(QThread::Priority)
    if (Shiboken::Converter<QThread::Priority >::isConvertible(arg)) {
        overloadId = 0; // setPriority(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_setPriority_TypeError;

    // Call function/method
    {
        {
            QThread::Priority cpp_arg0 = Shiboken::Converter<QThread::Priority >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPriority(QThread::Priority)
            cppSelf->QThread::setPriority(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_setPriority_TypeError:
        const char* overloads[] = {"PySide.QtCore.QThread.Priority", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.setPriority", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_setStackSize(PyObject* self, PyObject* arg)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStackSize(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStackSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_setStackSize_TypeError;

    // Call function/method
    {
        {
            uint cpp_arg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStackSize(uint)
            cppSelf->QThread::setStackSize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_setStackSize_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.setStackSize", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_setTerminationEnabled(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "enabled" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.setTerminationEnabled(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.setTerminationEnabled(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setTerminationEnabled", &arg))
        return 0;


    // Overloaded function decisor
    // 0: setTerminationEnabled(bool)
    if (numArgs == 0) {
        overloadId = 0; // setTerminationEnabled(bool)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTerminationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_setTerminationEnabled_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enabled");
                if (value) {
                    if (arg)
                        errorArgName = "enabled";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.setTerminationEnabled(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cpp_arg0 = arg ? Shiboken::Converter<bool >::toCpp(arg) : true;

            if(!PyErr_Occurred()) {
            // setTerminationEnabled(bool)
            QThread::setTerminationEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_setTerminationEnabled_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.setTerminationEnabled", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_sleep(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sleep(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_sleep_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // sleep(ulong)
            threadStateSaver.save();
            QThread::sleep(cpp_arg0);
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_sleep_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.sleep", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_stackSize(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stackSize()const
            uint cppResult = cppSelf->QThread::stackSize();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQThreadFunc_start(PyObject* self, PyObject* args, PyObject* kwds)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "priority" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.start(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.start(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:start", &arg))
        return 0;


    // Overloaded function decisor
    // 0: start(QThread::Priority)
    if (numArgs == 0) {
        overloadId = 0; // start(QThread::Priority)
    } else if (Shiboken::Converter<QThread::Priority >::isConvertible(arg)) {
        overloadId = 0; // start(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_start_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "priority");
                if (value) {
                    if (arg)
                        errorArgName = "priority";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.start(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QThread::Priority cpp_arg0 = arg ? Shiboken::Converter<QThread::Priority >::toCpp(arg) : QThread::InheritPriority;

            if(!PyErr_Occurred()) {
            // start(QThread::Priority)
            threadStateSaver.save();
            cppSelf->QThread::start(cpp_arg0);
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_start_TypeError:
        const char* overloads[] = {"PySide.QtCore.QThread.Priority = InheritPriority", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.start", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_terminate(PyObject* self)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // terminate()
            cppSelf->QThread::terminate();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQThreadFunc_usleep(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: usleep(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // usleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_usleep_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // usleep(ulong)
            threadStateSaver.save();
            QThread::usleep(cpp_arg0);
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQThreadFunc_usleep_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.usleep", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_wait(PyObject* self, PyObject* args, PyObject* kwds)
{
    QThread* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QThread* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "time" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.wait(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.wait(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:wait", &arg))
        return 0;


    // Overloaded function decisor
    // 0: wait(ulong)
    if (numArgs == 0) {
        overloadId = 0; // wait(ulong)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // wait(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQThreadFunc_wait_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "time");
                if (value) {
                    if (arg)
                        errorArgName = "time";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.wait(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            unsigned long cpp_arg0 = arg ? Shiboken::Converter<unsigned long >::toCpp(arg) : 4294967295UL;

            if(!PyErr_Occurred()) {
            // wait(ulong)
            threadStateSaver.save();
            bool cppResult = cppSelf->QThread::wait(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQThreadFunc_wait_TypeError:
        const char* overloads[] = {"unsigned long = 4294967295UL", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.wait", overloads);
        return 0;
}

static PyObject* SbkQThreadFunc_yieldCurrentThread(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // yieldCurrentThread()
            QThread::yieldCurrentThread();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQThread_methods[] = {
    {"currentThread", (PyCFunction)SbkQThreadFunc_currentThread, METH_NOARGS|METH_STATIC},
    {"currentThreadId", (PyCFunction)SbkQThreadFunc_currentThreadId, METH_NOARGS|METH_STATIC},
    {"exec_", (PyCFunction)SbkQThreadFunc_exec_, METH_NOARGS},
    {"exit", (PyCFunction)SbkQThreadFunc_exit, METH_VARARGS|METH_KEYWORDS},
    {"idealThreadCount", (PyCFunction)SbkQThreadFunc_idealThreadCount, METH_NOARGS|METH_STATIC},
    {"isFinished", (PyCFunction)SbkQThreadFunc_isFinished, METH_NOARGS},
    {"isRunning", (PyCFunction)SbkQThreadFunc_isRunning, METH_NOARGS},
    {"msleep", (PyCFunction)SbkQThreadFunc_msleep, METH_O|METH_STATIC},
    {"priority", (PyCFunction)SbkQThreadFunc_priority, METH_NOARGS},
    {"quit", (PyCFunction)SbkQThreadFunc_quit, METH_NOARGS},
    {"run", (PyCFunction)SbkQThreadFunc_run, METH_NOARGS},
    {"setPriority", (PyCFunction)SbkQThreadFunc_setPriority, METH_O},
    {"setStackSize", (PyCFunction)SbkQThreadFunc_setStackSize, METH_O},
    {"setTerminationEnabled", (PyCFunction)SbkQThreadFunc_setTerminationEnabled, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"sleep", (PyCFunction)SbkQThreadFunc_sleep, METH_O|METH_STATIC},
    {"stackSize", (PyCFunction)SbkQThreadFunc_stackSize, METH_NOARGS},
    {"start", (PyCFunction)SbkQThreadFunc_start, METH_VARARGS|METH_KEYWORDS},
    {"terminate", (PyCFunction)SbkQThreadFunc_terminate, METH_NOARGS},
    {"usleep", (PyCFunction)SbkQThreadFunc_usleep, METH_O|METH_STATIC},
    {"wait", (PyCFunction)SbkQThreadFunc_wait, METH_VARARGS|METH_KEYWORDS},
    {"yieldCurrentThread", (PyCFunction)SbkQThreadFunc_yieldCurrentThread, METH_NOARGS|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQThread_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QThread",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQThread_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQThread_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QThread >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QThread*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQThread_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QThread*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQThread_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtCore_QThread_Priority_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QThread_Priority_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QThread_Priority_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Priority",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QThread_Priority_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QThread_Priority_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QThread_Priority_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QThread(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTHREAD_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQThread_Type);

    SbkQThread_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQThread_Type.type_discovery = &SbkQThread_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQThread_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQThread_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQThread_Type));
    PyModule_AddObject(module, "QThread",
        ((PyObject*)&SbkQThread_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Priority
    SbkPySide_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX] = &SbkPySide_QtCore_QThread_Priority_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QThread_Priority_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QThread_Priority_Type);
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
            "Priority",((PyObject*)&SbkPySide_QtCore_QThread_Priority_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::IdlePriority, "IdlePriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "IdlePriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "IdlePriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::LowestPriority, "LowestPriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "LowestPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "LowestPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::LowPriority, "LowPriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "LowPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "LowPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::NormalPriority, "NormalPriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "NormalPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "NormalPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::HighPriority, "HighPriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "HighPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "HighPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::HighestPriority, "HighestPriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "HighestPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "HighestPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::TimeCriticalPriority, "TimeCriticalPriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "TimeCriticalPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "TimeCriticalPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QThread_Priority_Type,
        (long) QThread::InheritPriority, "InheritPriority");
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict,
        "InheritPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority_Type.tp_dict,
        "InheritPriority", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QThread::Priority");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("terminated", "void", NULL);
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict, "terminated", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("started", "void", NULL);
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict, "started", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("finished", "void", NULL);
    PyDict_SetItemString(SbkQThread_Type.super.ht_type.tp_dict, "finished", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QThread >("QThread*");
    Shiboken::TypeResolver::createObjectTypeResolver<QThread >(typeid(QThread).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QThread >(typeid(QThreadWrapper).name());
    PySide::initQtMetaType<QThread* >();
}

