/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtime_wrapper.h"

// Extra includes
#include <qdatetime.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTime_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTime >()))
        return -1;

    QTime* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "ms", "s" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTime(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QTime", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QTime(QTime)
    // 1: QTime()
    // 2: QTime(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 1; // QTime()
    } else if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QTime(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QTime(int,int,int,int)
            } else if (SbkNumber_Check(pyargs[3])) {
                overloadId = 2; // QTime(int,int,int,int)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QTime & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QTime(QTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTime_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTime(QTime)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTime* cpp_arg0 = Shiboken::Converter<QTime* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QTime(QTime)
                cptr = new QTime(*cpp_arg0);
                }
                break;
            }
            case 1: // QTime()
            {

                if(!PyErr_Occurred()) {
                // QTime()
                cptr = new QTime();
                }
                break;
            }
            case 2: // QTime(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "s");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "s";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "ms");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "ms";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // QTime(int,int,int,int)
                cptr = new QTime(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTime >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTime_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTime_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTime", "", "int, int, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTime", overloads);
        return -1;
}

static PyObject* SbkQTimeFunc_addMSecs(PyObject* self, PyObject* arg)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addMSecs(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addMSecs(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_addMSecs_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addMSecs(int)const
            QTime cppResult = cppSelf->QTime::addMSecs(cpp_arg0);
            pyResult = Shiboken::Converter<QTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_addMSecs_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTime.addMSecs", overloads);
        return 0;
}

static PyObject* SbkQTimeFunc_addSecs(PyObject* self, PyObject* arg)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addSecs(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addSecs(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_addSecs_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addSecs(int)const
            QTime cppResult = cppSelf->QTime::addSecs(cpp_arg0);
            pyResult = Shiboken::Converter<QTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_addSecs_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTime.addSecs", overloads);
        return 0;
}

static PyObject* SbkQTimeFunc_currentTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentTime()
            QTime cppResult = QTime::currentTime();
            pyResult = Shiboken::Converter<QTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_elapsed(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // elapsed()const
            int cppResult = cppSelf->QTime::elapsed();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_fromString(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.fromString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTime.fromString(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTime.fromString(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromString", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromString(QString,Qt::DateFormat)
    // 1: fromString(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // fromString(QString,QString)
        } else if (Shiboken::Converter<Qt::DateFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_fromString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromString(QString,Qt::DateFormat)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "f";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.fromString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                Qt::DateFormat cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::DateFormat >::toCpp(pyargs[1]) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                // fromString(QString,Qt::DateFormat)
                QTime cppResult = QTime::fromString(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QTime >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromString(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fromString(QString,QString)
                QTime cppResult = QTime::fromString(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QTime >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_fromString_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTime.fromString", overloads);
        return 0;
}

static PyObject* SbkQTimeFunc_hour(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hour()const
            int cppResult = cppSelf->QTime::hour();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_isNull(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QTime::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_isValid(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTime* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTime* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "ms" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.isValid(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTime.isValid(): too many arguments");
        return 0;
    } else if (numArgs == 1 || numArgs == 2)
        goto SbkQTimeFunc_isValid_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:isValid", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: isValid()const
    // 1: isValid(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // isValid()const
    } else if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 1; // isValid(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 1; // isValid(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_isValid_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // isValid()const
            {

                if(!PyErr_Occurred()) {
                // isValid()const
                bool cppResult = cppSelf->QTime::isValid();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // isValid(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "ms");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "ms";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.isValid(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // isValid(int,int,int,int)
                bool cppResult = QTime::isValid(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_isValid_TypeError:
        const char* overloads[] = {"", "int, int, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTime.isValid", overloads);
        return 0;
}

static PyObject* SbkQTimeFunc_minute(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minute()const
            int cppResult = cppSelf->QTime::minute();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_msec(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // msec()const
            int cppResult = cppSelf->QTime::msec();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_msecsTo(PyObject* self, PyObject* arg)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: msecsTo(QTime)const
    if (Shiboken::Converter<const QTime & >::isConvertible(arg)) {
        overloadId = 0; // msecsTo(QTime)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_msecsTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTime* cpp_arg0 = Shiboken::Converter<QTime* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // msecsTo(QTime)const
            int cppResult = cppSelf->QTime::msecsTo(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_msecsTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTime.msecsTo", overloads);
        return 0;
}

static PyObject* SbkQTimeFunc_restart(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // restart()
            int cppResult = cppSelf->QTime::restart();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_second(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // second()const
            int cppResult = cppSelf->QTime::second();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeFunc_secsTo(PyObject* self, PyObject* arg)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: secsTo(QTime)const
    if (Shiboken::Converter<const QTime & >::isConvertible(arg)) {
        overloadId = 0; // secsTo(QTime)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_secsTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTime* cpp_arg0 = Shiboken::Converter<QTime* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // secsTo(QTime)const
            int cppResult = cppSelf->QTime::secsTo(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_secsTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTime", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTime.secsTo", overloads);
        return 0;
}

static PyObject* SbkQTimeFunc_setHMS(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "ms" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.setHMS(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTime.setHMS(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTime.setHMS(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHMS", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHMS(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHMS(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHMS(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_setHMS_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "ms");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "ms";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.setHMS(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
            // setHMS(int,int,int,int)
            bool cppResult = cppSelf->QTime::setHMS(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_setHMS_TypeError:
        const char* overloads[] = {"int, int, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTime.setHMS", overloads);
        return 0;
}

static PyObject* SbkQTimeFunc_start(PyObject* self)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // start()
            cppSelf->QTime::start();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTimeFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTime* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTime* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.toString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QTime.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toString(Qt::DateFormat)const
    // 1: toString(QString)const
    if (numArgs == 0) {
        overloadId = 0; // toString(Qt::DateFormat)const
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // toString(QString)const
    } else if (Shiboken::Converter<Qt::DateFormat >::isConvertible(arg)) {
        overloadId = 0; // toString(Qt::DateFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeFunc_toString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toString(Qt::DateFormat)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (arg)
                            errorArgName = "f";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTime.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                Qt::DateFormat cpp_arg0 = arg ? Shiboken::Converter<Qt::DateFormat >::toCpp(arg) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                // toString(Qt::DateFormat)const
                QString cppResult = cppSelf->QTime::toString(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // toString(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // toString(QString)const
                QString cppResult = cppSelf->QTime::toString(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTime.toString", overloads);
        return 0;
}

static PyMethodDef SbkQTimeMethod_isValid = {
    "isValid", (PyCFunction)SbkQTimeFunc_isValid, METH_VARARGS|METH_KEYWORDS|METH_STATIC
};

static PyMethodDef SbkQTime_methods[] = {
    {"addMSecs", (PyCFunction)SbkQTimeFunc_addMSecs, METH_O},
    {"addSecs", (PyCFunction)SbkQTimeFunc_addSecs, METH_O},
    {"currentTime", (PyCFunction)SbkQTimeFunc_currentTime, METH_NOARGS|METH_STATIC},
    {"elapsed", (PyCFunction)SbkQTimeFunc_elapsed, METH_NOARGS},
    {"fromString", (PyCFunction)SbkQTimeFunc_fromString, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"hour", (PyCFunction)SbkQTimeFunc_hour, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQTimeFunc_isNull, METH_NOARGS},
    SbkQTimeMethod_isValid,
    {"minute", (PyCFunction)SbkQTimeFunc_minute, METH_NOARGS},
    {"msec", (PyCFunction)SbkQTimeFunc_msec, METH_NOARGS},
    {"msecsTo", (PyCFunction)SbkQTimeFunc_msecsTo, METH_O},
    {"restart", (PyCFunction)SbkQTimeFunc_restart, METH_NOARGS},
    {"second", (PyCFunction)SbkQTimeFunc_second, METH_NOARGS},
    {"secsTo", (PyCFunction)SbkQTimeFunc_secsTo, METH_O},
    {"setHMS", (PyCFunction)SbkQTimeFunc_setHMS, METH_VARARGS|METH_KEYWORDS},
    {"start", (PyCFunction)SbkQTimeFunc_start, METH_NOARGS},
    {"toString", (PyCFunction)SbkQTimeFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

static PyObject* SbkQTime_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (SbkBaseWrapper_instanceDict(self)) {
            PyObject* meth = PyDict_GetItem(SbkBaseWrapper_instanceDict(self), name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "isValid") == 0)
            return PyCFunction_NewEx(&SbkQTimeMethod_isValid, self, 0);
    }
    PyObject* attr = PyObject_GenericGetAttr(self, name);
    if (attr && PySide::isQPropertyType(attr)) {
        PyObject *value = PySide::qproperty_get(attr, self);
        Py_DECREF(attr);
        Py_INCREF(value);
        attr = value;
    }
    return attr;
}

// Rich comparison
static PyObject* SbkQTime_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QTime& cpp_self = *Shiboken::Converter<QTime* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QTime & >::isConvertible(other)) {
                // operator!=(const QTime & other) const
                QTime* cpp_other = Shiboken::Converter<QTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTime  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQTime_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QTime & >::isConvertible(other)) {
                // operator<(const QTime & other) const
                QTime* cpp_other = Shiboken::Converter<QTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTime  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else goto SbkQTime_RichComparison_TypeError;

            break;
        case Py_LE:
            if (Shiboken::Converter<const QTime & >::isConvertible(other)) {
                // operator<=(const QTime & other) const
                QTime* cpp_other = Shiboken::Converter<QTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTime  >::toCpp(other) : (cpp_self <= (*cpp_other));
            } else goto SbkQTime_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QTime & >::isConvertible(other)) {
                // operator==(const QTime & other) const
                QTime* cpp_other = Shiboken::Converter<QTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTime  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQTime_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter<const QTime & >::isConvertible(other)) {
                // operator>(const QTime & other) const
                QTime* cpp_other = Shiboken::Converter<QTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTime  >::toCpp(other) : (cpp_self > (*cpp_other));
            } else goto SbkQTime_RichComparison_TypeError;

            break;
        case Py_GE:
            if (Shiboken::Converter<const QTime & >::isConvertible(other)) {
                // operator>=(const QTime & other) const
                QTime* cpp_other = Shiboken::Converter<QTime* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTime  >::toCpp(other) : (cpp_self >= (*cpp_other));
            } else goto SbkQTime_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQTime_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQTime_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter<QTime >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTime_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTime",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQTime_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         SbkQTime_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQTime_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTime_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTime_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTime >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTime",
    /*user_data*/           0
};
} //extern


void init_QTime(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTIME_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTime_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTime_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTime_Type));
    PyModule_AddObject(module, "QTime",
        ((PyObject*)&SbkQTime_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTime >("QTime");
    Shiboken::TypeResolver::createObjectTypeResolver<QTime >("QTime*");
    Shiboken::TypeResolver::createValueTypeResolver<QTime >(typeid(QTime).name());
    PySide::initQtMetaType<QTime >();
}

