/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtcore_python.h"

#include "qtimeline_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qeasingcurve.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qtimeline.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QTimeLineWrapper::QTimeLineWrapper(int duration, QObject * parent) : QTimeLine(duration, parent), m_metaObject(0) {
    // ... middle
}

void QTimeLineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTimeLineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTimeLineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTimeLineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QTimeLineWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTimeLine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QTimeLineWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTimeLine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QTimeLineWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QTimeLine::timerEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

qreal QTimeLineWrapper::valueForTime(int msec) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "valueForTime"));
    if (py_override.isNull()) {
        return this->QTimeLine::valueForTime(msec);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msec
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qreal(0);
    }
    // Check return type
    bool typeIsValid = PyFloat_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTimeLine.valueForTime", "qreal", pyResult->ob_type->tp_name);
        return qreal(0);
    }
    qreal cppResult(Shiboken::Converter<double >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QTimeLineWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QTimeLine::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QTimeLineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTimeLine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTimeLineWrapper::~QTimeLineWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTimeLine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTimeLine >()))
        return -1;

    QTimeLineWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "duration", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QTimeLine", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTimeLine(int,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QTimeLine(int,QObject*)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QTimeLine(int,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QTimeLine(int,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLine_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "duration");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "duration";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QTimeLine(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cpp_arg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 1000;
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return -1;
            QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // QTimeLine(int,QObject*)
            cptr = new QTimeLineWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[1], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTimeLine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTimeLine_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQTimeLine_Init_TypeError:
        const char* overloads[] = {"int = 1000, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTimeLine", overloads);
        return -1;
}

static PyObject* SbkQTimeLineFunc_currentFrame(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentFrame()const
            int cppResult = cppSelf->QTimeLine::currentFrame();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_currentTime(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentTime()const
            int cppResult = cppSelf->QTimeLine::currentTime();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_currentValue(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentValue()const
            qreal cppResult = cppSelf->QTimeLine::currentValue();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_curveShape(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // curveShape()const
            QTimeLine::CurveShape cppResult = cppSelf->QTimeLine::curveShape();
            pyResult = Shiboken::Converter<QTimeLine::CurveShape >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_direction(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // direction()const
            QTimeLine::Direction cppResult = cppSelf->QTimeLine::direction();
            pyResult = Shiboken::Converter<QTimeLine::Direction >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_duration(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // duration()const
            int cppResult = cppSelf->QTimeLine::duration();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_easingCurve(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // easingCurve()const
            QEasingCurve cppResult = cppSelf->QTimeLine::easingCurve();
            pyResult = Shiboken::Converter<QEasingCurve >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_endFrame(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endFrame()const
            int cppResult = cppSelf->QTimeLine::endFrame();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_frameForTime(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: frameForTime(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // frameForTime(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_frameForTime_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // frameForTime(int)const
            int cppResult = cppSelf->QTimeLine::frameForTime(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeLineFunc_frameForTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.frameForTime", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_loopCount(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // loopCount()const
            int cppResult = cppSelf->QTimeLine::loopCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_resume(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resume()
            cppSelf->QTimeLine::resume();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTimeLineFunc_setCurrentTime(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentTime(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentTime(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setCurrentTime_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentTime(int)
            cppSelf->QTimeLine::setCurrentTime(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setCurrentTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setCurrentTime", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setCurveShape(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurveShape(QTimeLine::CurveShape)
    if (Shiboken::Converter<QTimeLine::CurveShape >::isConvertible(arg)) {
        overloadId = 0; // setCurveShape(QTimeLine::CurveShape)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setCurveShape_TypeError;

    // Call function/method
    {
        {
            QTimeLine::CurveShape cpp_arg0 = Shiboken::Converter<QTimeLine::CurveShape >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurveShape(QTimeLine::CurveShape)
            cppSelf->QTimeLine::setCurveShape(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setCurveShape_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimeLine.CurveShape", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setCurveShape", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setDirection(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDirection(QTimeLine::Direction)
    if (Shiboken::Converter<QTimeLine::Direction >::isConvertible(arg)) {
        overloadId = 0; // setDirection(QTimeLine::Direction)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setDirection_TypeError;

    // Call function/method
    {
        {
            QTimeLine::Direction cpp_arg0 = Shiboken::Converter<QTimeLine::Direction >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDirection(QTimeLine::Direction)
            cppSelf->QTimeLine::setDirection(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimeLine.Direction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setDirection", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setDuration(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDuration(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDuration(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setDuration_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDuration(int)
            cppSelf->QTimeLine::setDuration(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setDuration_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setDuration", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setEasingCurve(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEasingCurve(QEasingCurve)
    if (Shiboken::Converter<const QEasingCurve & >::isConvertible(arg)) {
        overloadId = 0; // setEasingCurve(QEasingCurve)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setEasingCurve_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QEasingCurve > cpp_arg0_auto_ptr;
            QEasingCurve* cpp_arg0 = Shiboken::Converter<QEasingCurve* >::toCpp(arg);
            if (!Shiboken::Converter<QEasingCurve >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QEasingCurve >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setEasingCurve(QEasingCurve)
            cppSelf->QTimeLine::setEasingCurve(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setEasingCurve_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEasingCurve", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setEasingCurve", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setEndFrame(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEndFrame(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEndFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setEndFrame_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEndFrame(int)
            cppSelf->QTimeLine::setEndFrame(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setEndFrame_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setEndFrame", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setFrameRange(PyObject* self, PyObject* args)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFrameRange", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFrameRange(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFrameRange(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setFrameRange_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setFrameRange(int,int)
            cppSelf->QTimeLine::setFrameRange(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setFrameRange_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QTimeLine.setFrameRange", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setLoopCount(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLoopCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLoopCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setLoopCount_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLoopCount(int)
            cppSelf->QTimeLine::setLoopCount(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setLoopCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setLoopCount", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setPaused(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPaused(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPaused(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setPaused_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPaused(bool)
            cppSelf->QTimeLine::setPaused(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setPaused_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setPaused", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setStartFrame(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartFrame(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setStartFrame_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStartFrame(int)
            cppSelf->QTimeLine::setStartFrame(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setStartFrame_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setStartFrame", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_setUpdateInterval(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUpdateInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUpdateInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_setUpdateInterval_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUpdateInterval(int)
            cppSelf->QTimeLine::setUpdateInterval(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_setUpdateInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.setUpdateInterval", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_start(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // start()
            cppSelf->QTimeLine::start();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTimeLineFunc_startFrame(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startFrame()const
            int cppResult = cppSelf->QTimeLine::startFrame();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_state(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QTimeLine::State cppResult = cppSelf->QTimeLine::state();
            pyResult = Shiboken::Converter<QTimeLine::State >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_stop(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stop()
            cppSelf->QTimeLine::stop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTimeLineFunc_timerEvent(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: timerEvent(QTimerEvent*)
    if (Shiboken::Converter<QTimerEvent * >::isConvertible(arg)) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_timerEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTimerEvent* cpp_arg0 = Shiboken::Converter<QTimerEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // timerEvent(QTimerEvent*)
            cppSelf->QTimeLine::timerEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTimeLineFunc_timerEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimerEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.timerEvent", overloads);
        return 0;
}

static PyObject* SbkQTimeLineFunc_toggleDirection(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toggleDirection()
            cppSelf->QTimeLine::toggleDirection();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTimeLineFunc_updateInterval(PyObject* self)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateInterval()const
            int cppResult = cppSelf->QTimeLine::updateInterval();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTimeLineFunc_valueForTime(PyObject* self, PyObject* arg)
{
    QTimeLine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTimeLine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: valueForTime(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // valueForTime(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTimeLineFunc_valueForTime_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // valueForTime(int)const
            qreal cppResult = cppSelf->QTimeLine::valueForTime(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTimeLineFunc_valueForTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTimeLine.valueForTime", overloads);
        return 0;
}

static PyMethodDef SbkQTimeLine_methods[] = {
    {"currentFrame", (PyCFunction)SbkQTimeLineFunc_currentFrame, METH_NOARGS},
    {"currentTime", (PyCFunction)SbkQTimeLineFunc_currentTime, METH_NOARGS},
    {"currentValue", (PyCFunction)SbkQTimeLineFunc_currentValue, METH_NOARGS},
    {"curveShape", (PyCFunction)SbkQTimeLineFunc_curveShape, METH_NOARGS},
    {"direction", (PyCFunction)SbkQTimeLineFunc_direction, METH_NOARGS},
    {"duration", (PyCFunction)SbkQTimeLineFunc_duration, METH_NOARGS},
    {"easingCurve", (PyCFunction)SbkQTimeLineFunc_easingCurve, METH_NOARGS},
    {"endFrame", (PyCFunction)SbkQTimeLineFunc_endFrame, METH_NOARGS},
    {"frameForTime", (PyCFunction)SbkQTimeLineFunc_frameForTime, METH_O},
    {"loopCount", (PyCFunction)SbkQTimeLineFunc_loopCount, METH_NOARGS},
    {"resume", (PyCFunction)SbkQTimeLineFunc_resume, METH_NOARGS},
    {"setCurrentTime", (PyCFunction)SbkQTimeLineFunc_setCurrentTime, METH_O},
    {"setCurveShape", (PyCFunction)SbkQTimeLineFunc_setCurveShape, METH_O},
    {"setDirection", (PyCFunction)SbkQTimeLineFunc_setDirection, METH_O},
    {"setDuration", (PyCFunction)SbkQTimeLineFunc_setDuration, METH_O},
    {"setEasingCurve", (PyCFunction)SbkQTimeLineFunc_setEasingCurve, METH_O},
    {"setEndFrame", (PyCFunction)SbkQTimeLineFunc_setEndFrame, METH_O},
    {"setFrameRange", (PyCFunction)SbkQTimeLineFunc_setFrameRange, METH_VARARGS},
    {"setLoopCount", (PyCFunction)SbkQTimeLineFunc_setLoopCount, METH_O},
    {"setPaused", (PyCFunction)SbkQTimeLineFunc_setPaused, METH_O},
    {"setStartFrame", (PyCFunction)SbkQTimeLineFunc_setStartFrame, METH_O},
    {"setUpdateInterval", (PyCFunction)SbkQTimeLineFunc_setUpdateInterval, METH_O},
    {"start", (PyCFunction)SbkQTimeLineFunc_start, METH_NOARGS},
    {"startFrame", (PyCFunction)SbkQTimeLineFunc_startFrame, METH_NOARGS},
    {"state", (PyCFunction)SbkQTimeLineFunc_state, METH_NOARGS},
    {"stop", (PyCFunction)SbkQTimeLineFunc_stop, METH_NOARGS},
    {"timerEvent", (PyCFunction)SbkQTimeLineFunc_timerEvent, METH_O},
    {"toggleDirection", (PyCFunction)SbkQTimeLineFunc_toggleDirection, METH_NOARGS},
    {"updateInterval", (PyCFunction)SbkQTimeLineFunc_updateInterval, METH_NOARGS},
    {"valueForTime", (PyCFunction)SbkQTimeLineFunc_valueForTime, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTimeLine_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTimeLine",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTimeLine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTimeLine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTimeLine >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTimeLine*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQTimeLine_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTimeLine*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQTimeLine_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtCore_QTimeLine_Direction_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTimeLine_Direction_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTimeLine_Direction_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Direction",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTimeLine_Direction_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTimeLine_Direction_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTimeLine_Direction_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QTimeLine_CurveShape_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTimeLine_CurveShape_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTimeLine_CurveShape_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CurveShape",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTimeLine_CurveShape_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTimeLine_CurveShape_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTimeLine_CurveShape_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QTimeLine_State_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QTimeLine_State_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QTimeLine_State_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "State",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QTimeLine_State_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QTimeLine_State_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QTimeLine_State_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTimeLine(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTimeLine_Type);

    SbkQTimeLine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQTimeLine_Type.type_discovery = &SbkQTimeLine_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQTimeLine_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTimeLine_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTimeLine_Type));
    PyModule_AddObject(module, "QTimeLine",
        ((PyObject*)&SbkQTimeLine_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Direction
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_DIRECTION_IDX] = &SbkPySide_QtCore_QTimeLine_Direction_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTimeLine_Direction_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTimeLine_Direction_Type);
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
            "Direction",((PyObject*)&SbkPySide_QtCore_QTimeLine_Direction_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_Direction_Type,
        (long) QTimeLine::Forward, "Forward");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "Forward", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_Direction_Type.tp_dict,
        "Forward", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_Direction_Type,
        (long) QTimeLine::Backward, "Backward");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "Backward", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_Direction_Type.tp_dict,
        "Backward", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTimeLine::Direction");

    // init enum class: CurveShape
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_CURVESHAPE_IDX] = &SbkPySide_QtCore_QTimeLine_CurveShape_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTimeLine_CurveShape_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTimeLine_CurveShape_Type);
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
            "CurveShape",((PyObject*)&SbkPySide_QtCore_QTimeLine_CurveShape_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_CurveShape_Type,
        (long) QTimeLine::EaseInCurve, "EaseInCurve");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "EaseInCurve", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape_Type.tp_dict,
        "EaseInCurve", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_CurveShape_Type,
        (long) QTimeLine::EaseOutCurve, "EaseOutCurve");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "EaseOutCurve", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape_Type.tp_dict,
        "EaseOutCurve", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_CurveShape_Type,
        (long) QTimeLine::EaseInOutCurve, "EaseInOutCurve");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "EaseInOutCurve", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape_Type.tp_dict,
        "EaseInOutCurve", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_CurveShape_Type,
        (long) QTimeLine::LinearCurve, "LinearCurve");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "LinearCurve", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape_Type.tp_dict,
        "LinearCurve", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_CurveShape_Type,
        (long) QTimeLine::SineCurve, "SineCurve");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "SineCurve", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape_Type.tp_dict,
        "SineCurve", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_CurveShape_Type,
        (long) QTimeLine::CosineCurve, "CosineCurve");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "CosineCurve", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_CurveShape_Type.tp_dict,
        "CosineCurve", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTimeLine::CurveShape");

    // init enum class: State
    SbkPySide_QtCoreTypes[SBK_QTIMELINE_STATE_IDX] = &SbkPySide_QtCore_QTimeLine_State_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QTimeLine_State_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QTimeLine_State_Type);
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
            "State",((PyObject*)&SbkPySide_QtCore_QTimeLine_State_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_State_Type,
        (long) QTimeLine::NotRunning, "NotRunning");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "NotRunning", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_State_Type.tp_dict,
        "NotRunning", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_State_Type,
        (long) QTimeLine::Paused, "Paused");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "Paused", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_State_Type.tp_dict,
        "Paused", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QTimeLine_State_Type,
        (long) QTimeLine::Running, "Running");
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict,
        "Running", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QTimeLine_State_Type.tp_dict,
        "Running", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTimeLine::State");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("finished", "void", NULL);
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict, "finished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("frameChanged", "int", NULL);
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict, "frameChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("valueChanged", "qreal", NULL);
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict, "valueChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "QTimeLine::State", NULL);
    PyDict_SetItemString(SbkQTimeLine_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTimeLine >("QTimeLine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTimeLine >(typeid(QTimeLine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTimeLine >(typeid(QTimeLineWrapper).name());
    PySide::initQtMetaType<QTimeLine* >();
}

