/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qurl_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <QStringList>
#include <qbytearray.h>
#include <qurl.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQUrl_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QUrl >()))
        return -1;

    QUrl* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QUrl", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QUrl()
    // 1: QUrl(QString)
    // 2: QUrl(QString,QUrl::ParsingMode)
    // 3: QUrl(QUrl)
    if (numArgs == 0) {
        overloadId = 0; // QUrl()
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QUrl(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 2; // QUrl(QString,QUrl::ParsingMode)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrl_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QUrl()
            {

                if(!PyErr_Occurred()) {
                // QUrl()
                cptr = new QUrl();
                }
                break;
            }
            case 1: // QUrl(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QUrl(QString)
                cptr = new QUrl(cpp_arg0);
                }
                break;
            }
            case 2: // QUrl(QString,QUrl::ParsingMode)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QUrl::ParsingMode cpp_arg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QUrl(QString,QUrl::ParsingMode)
                cptr = new QUrl(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QUrl(QUrl)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QUrl >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QUrl(QUrl)
                cptr = new QUrl(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QUrl >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQUrl_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQUrl_Init_TypeError:
        const char* overloads[] = {"", "QString", "QString, PySide.QtCore.QUrl.ParsingMode", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl", overloads);
        return -1;
}

static PyObject* SbkQUrlFunc_addEncodedQueryItem(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addEncodedQueryItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addEncodedQueryItem(QByteArray,QByteArray)
    if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
        overloadId = 0; // addEncodedQueryItem(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_addEncodedQueryItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
            QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // addEncodedQueryItem(QByteArray,QByteArray)
            cppSelf->QUrl::addEncodedQueryItem(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_addEncodedQueryItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.addEncodedQueryItem", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_addQueryItem(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addQueryItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addQueryItem(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // addQueryItem(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_addQueryItem_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // addQueryItem(QString,QString)
            cppSelf->QUrl::addQueryItem(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_addQueryItem_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.addQueryItem", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_allEncodedQueryItemValues(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: allEncodedQueryItemValues(QByteArray)const
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // allEncodedQueryItemValues(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_allEncodedQueryItemValues_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // allEncodedQueryItemValues(QByteArray)const
            QList<QByteArray > cppResult = cppSelf->QUrl::allEncodedQueryItemValues(*cpp_arg0);
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_allEncodedQueryItemValues_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.allEncodedQueryItemValues", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_allQueryItemValues(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: allQueryItemValues(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // allQueryItemValues(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_allQueryItemValues_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // allQueryItemValues(QString)const
            QStringList cppResult = cppSelf->QUrl::allQueryItemValues(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_allQueryItemValues_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.allQueryItemValues", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_authority(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // authority()const
            QString cppResult = cppSelf->QUrl::authority();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_clear(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QUrl::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQUrlFunc_encodedFragment(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encodedFragment()const
            QByteArray cppResult = cppSelf->QUrl::encodedFragment();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_encodedHost(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encodedHost()const
            QByteArray cppResult = cppSelf->QUrl::encodedHost();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_encodedPassword(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encodedPassword()const
            QByteArray cppResult = cppSelf->QUrl::encodedPassword();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_encodedPath(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encodedPath()const
            QByteArray cppResult = cppSelf->QUrl::encodedPath();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_encodedQuery(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encodedQuery()const
            QByteArray cppResult = cppSelf->QUrl::encodedQuery();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_encodedQueryItemValue(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: encodedQueryItemValue(QByteArray)const
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // encodedQueryItemValue(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_encodedQueryItemValue_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // encodedQueryItemValue(QByteArray)const
            QByteArray cppResult = cppSelf->QUrl::encodedQueryItemValue(*cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_encodedQueryItemValue_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.encodedQueryItemValue", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_encodedQueryItems(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encodedQueryItems()const
            QList<QPair<QByteArray, QByteArray > > cppResult = cppSelf->QUrl::encodedQueryItems();
            pyResult = Shiboken::Converter<QList<QPair<QByteArray, QByteArray > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_encodedUserName(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encodedUserName()const
            QByteArray cppResult = cppSelf->QUrl::encodedUserName();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_errorString(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QUrl::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_fragment(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fragment()const
            QString cppResult = cppSelf->QUrl::fragment();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_fromAce(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromAce(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // fromAce(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_fromAce_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // fromAce(QByteArray)
            QString cppResult = QUrl::fromAce(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_fromAce_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromAce", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_fromEncoded(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromEncoded", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromEncoded(QByteArray)
    // 1: fromEncoded(QByteArray,QUrl::ParsingMode)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromEncoded(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter<QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // fromEncoded(QByteArray,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_fromEncoded_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromEncoded(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // fromEncoded(QByteArray)
                QUrl cppResult = QUrl::fromEncoded(*cpp_arg0);
                pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromEncoded(QByteArray,QUrl::ParsingMode)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                QUrl::ParsingMode cpp_arg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fromEncoded(QByteArray,QUrl::ParsingMode)
                QUrl cppResult = QUrl::fromEncoded(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_fromEncoded_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "PySide.QtCore.QByteArray, PySide.QtCore.QUrl.ParsingMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.fromEncoded", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_fromLocalFile(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromLocalFile(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // fromLocalFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_fromLocalFile_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromLocalFile(QString)
            QUrl cppResult = QUrl::fromLocalFile(cpp_arg0);
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_fromLocalFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromLocalFile", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_fromPercentEncoding(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromPercentEncoding(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // fromPercentEncoding(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_fromPercentEncoding_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // fromPercentEncoding(QByteArray)
            QString cppResult = QUrl::fromPercentEncoding(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_fromPercentEncoding_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromPercentEncoding", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_fromPunycode(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromPunycode(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // fromPunycode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_fromPunycode_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // fromPunycode(QByteArray)
            QString cppResult = QUrl::fromPunycode(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_fromPunycode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromPunycode", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_fromUserInput(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromUserInput(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // fromUserInput(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_fromUserInput_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromUserInput(QString)
            QUrl cppResult = QUrl::fromUserInput(cpp_arg0);
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_fromUserInput_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromUserInput", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_hasEncodedQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasEncodedQueryItem(QByteArray)const
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // hasEncodedQueryItem(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_hasEncodedQueryItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // hasEncodedQueryItem(QByteArray)const
            bool cppResult = cppSelf->QUrl::hasEncodedQueryItem(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_hasEncodedQueryItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.hasEncodedQueryItem", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_hasFragment(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasFragment()const
            bool cppResult = cppSelf->QUrl::hasFragment();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_hasQuery(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasQuery()const
            bool cppResult = cppSelf->QUrl::hasQuery();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_hasQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasQueryItem(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasQueryItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_hasQueryItem_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasQueryItem(QString)const
            bool cppResult = cppSelf->QUrl::hasQueryItem(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_hasQueryItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.hasQueryItem", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_host(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // host()const
            QString cppResult = cppSelf->QUrl::host();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_idnWhitelist(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // idnWhitelist()
            QStringList cppResult = QUrl::idnWhitelist();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_isEmpty(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QUrl::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_isParentOf(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isParentOf(QUrl)const
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // isParentOf(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_isParentOf_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // isParentOf(QUrl)const
            bool cppResult = cppSelf->QUrl::isParentOf(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_isParentOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.isParentOf", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_isRelative(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRelative()const
            bool cppResult = cppSelf->QUrl::isRelative();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_isValid(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QUrl::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_password(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // password()const
            QString cppResult = cppSelf->QUrl::password();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_path(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // path()const
            QString cppResult = cppSelf->QUrl::path();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_port(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: port()const
    // 1: port(int)const
    if (numArgs == 0) {
        overloadId = 0; // port()const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 1; // port(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_port_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // port()const
            {

                if(!PyErr_Occurred()) {
                // port()const
                int cppResult = cppSelf->QUrl::port();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // port(int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // port(int)const
                int cppResult = cppSelf->QUrl::port(cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_port_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.port", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_queryItemValue(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: queryItemValue(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // queryItemValue(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_queryItemValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // queryItemValue(QString)const
            QString cppResult = cppSelf->QUrl::queryItemValue(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_queryItemValue_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.queryItemValue", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_queryItems(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // queryItems()const
            QList<QPair<QString, QString > > cppResult = cppSelf->QUrl::queryItems();
            pyResult = Shiboken::Converter<QList<QPair<QString, QString > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_queryPairDelimiter(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // queryPairDelimiter()const
            char cppResult = cppSelf->QUrl::queryPairDelimiter();
            pyResult = Shiboken::Converter<char >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_queryValueDelimiter(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // queryValueDelimiter()const
            char cppResult = cppSelf->QUrl::queryValueDelimiter();
            pyResult = Shiboken::Converter<char >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_removeAllEncodedQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAllEncodedQueryItems(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // removeAllEncodedQueryItems(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_removeAllEncodedQueryItems_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // removeAllEncodedQueryItems(QByteArray)
            cppSelf->QUrl::removeAllEncodedQueryItems(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_removeAllEncodedQueryItems_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeAllEncodedQueryItems", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_removeAllQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAllQueryItems(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeAllQueryItems(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_removeAllQueryItems_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAllQueryItems(QString)
            cppSelf->QUrl::removeAllQueryItems(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_removeAllQueryItems_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeAllQueryItems", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_removeEncodedQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeEncodedQueryItem(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // removeEncodedQueryItem(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_removeEncodedQueryItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // removeEncodedQueryItem(QByteArray)
            cppSelf->QUrl::removeEncodedQueryItem(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_removeEncodedQueryItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeEncodedQueryItem", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_removeQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeQueryItem(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeQueryItem(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_removeQueryItem_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeQueryItem(QString)
            cppSelf->QUrl::removeQueryItem(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_removeQueryItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeQueryItem", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_resolved(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: resolved(QUrl)const
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // resolved(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_resolved_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // resolved(QUrl)const
            QUrl cppResult = cppSelf->QUrl::resolved(*cpp_arg0);
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_resolved_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.resolved", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_scheme(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scheme()const
            QString cppResult = cppSelf->QUrl::scheme();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_setAuthority(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAuthority(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setAuthority(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setAuthority_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAuthority(QString)
            cppSelf->QUrl::setAuthority(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setAuthority_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setAuthority", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedFragment(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedFragment(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setEncodedFragment(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedFragment_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setEncodedFragment(QByteArray)
            cppSelf->QUrl::setEncodedFragment(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedFragment_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedFragment", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedHost(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedHost(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setEncodedHost(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedHost_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setEncodedHost(QByteArray)
            cppSelf->QUrl::setEncodedHost(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedHost_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedHost", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedPassword(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedPassword(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setEncodedPassword(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedPassword_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setEncodedPassword(QByteArray)
            cppSelf->QUrl::setEncodedPassword(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedPassword_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedPassword", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedPath(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedPath(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setEncodedPath(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedPath_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setEncodedPath(QByteArray)
            cppSelf->QUrl::setEncodedPath(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedPath_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedPath", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedQuery(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedQuery(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setEncodedQuery(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedQuery_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setEncodedQuery(QByteArray)
            cppSelf->QUrl::setEncodedQuery(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedQuery", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedQueryItems(QList<QPair<QByteArray,QByteArray> >)
    if (Shiboken::Converter< QList<QPair<QByteArray, QByteArray > >  >::isConvertible(arg)) {
        overloadId = 0; // setEncodedQueryItems(QList<QPair<QByteArray,QByteArray> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedQueryItems_TypeError;

    // Call function/method
    {
        {
            QList<QPair<QByteArray, QByteArray > > cpp_arg0 = Shiboken::Converter<QList<QPair<QByteArray, QByteArray > > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEncodedQueryItems(QList<QPair<QByteArray,QByteArray> >)
            cppSelf->QUrl::setEncodedQueryItems(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedQueryItems_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedQueryItems", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedUrl(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setEncodedUrl", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setEncodedUrl(QByteArray)
    // 1: setEncodedUrl(QByteArray,QUrl::ParsingMode)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setEncodedUrl(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter<QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // setEncodedUrl(QByteArray,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedUrl_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setEncodedUrl(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setEncodedUrl(QByteArray)
                cppSelf->QUrl::setEncodedUrl(*cpp_arg0);
                }
                break;
            }
            case 1: // setEncodedUrl(QByteArray,QUrl::ParsingMode)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                QUrl::ParsingMode cpp_arg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setEncodedUrl(QByteArray,QUrl::ParsingMode)
                cppSelf->QUrl::setEncodedUrl(*cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "PySide.QtCore.QByteArray, PySide.QtCore.QUrl.ParsingMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.setEncodedUrl", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setEncodedUserName(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedUserName(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setEncodedUserName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setEncodedUserName_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setEncodedUserName(QByteArray)
            cppSelf->QUrl::setEncodedUserName(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setEncodedUserName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedUserName", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setFragment(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFragment(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFragment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setFragment_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFragment(QString)
            cppSelf->QUrl::setFragment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setFragment_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setFragment", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setHost(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHost(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setHost(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setHost_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHost(QString)
            cppSelf->QUrl::setHost(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setHost_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setHost", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setIdnWhitelist(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIdnWhitelist(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setIdnWhitelist(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setIdnWhitelist_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIdnWhitelist(QStringList)
            QUrl::setIdnWhitelist(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setIdnWhitelist_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setIdnWhitelist", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setPassword(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPassword(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setPassword_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPassword(QString)
            cppSelf->QUrl::setPassword(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setPassword_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setPassword", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setPath(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setPath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPath(QString)
            cppSelf->QUrl::setPath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setPath", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setPort(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPort(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPort(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setPort_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPort(int)
            cppSelf->QUrl::setPort(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setPort_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setPort", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setQueryDelimiters(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setQueryDelimiters", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setQueryDelimiters(char,char)
    if (numArgs == 2 && Shiboken::Converter<char >::isConvertible(pyargs[0]) && Shiboken::Converter<char >::isConvertible(pyargs[1])) {
        overloadId = 0; // setQueryDelimiters(char,char)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setQueryDelimiters_TypeError;

    // Call function/method
    {
        {
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
            char cpp_arg1 = Shiboken::Converter<char >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setQueryDelimiters(char,char)
            cppSelf->QUrl::setQueryDelimiters(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setQueryDelimiters_TypeError:
        const char* overloads[] = {"char, char", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.setQueryDelimiters", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQueryItems(QList<QPair<QString,QString> >)
    if (Shiboken::Converter< QList<QPair<QString, QString > >  >::isConvertible(arg)) {
        overloadId = 0; // setQueryItems(QList<QPair<QString,QString> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setQueryItems_TypeError;

    // Call function/method
    {
        {
            QList<QPair<QString, QString > > cpp_arg0 = Shiboken::Converter<QList<QPair<QString, QString > > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setQueryItems(QList<QPair<QString,QString> >)
            cppSelf->QUrl::setQueryItems(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setQueryItems_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setQueryItems", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setScheme(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScheme(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setScheme(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setScheme_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScheme(QString)
            cppSelf->QUrl::setScheme(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setScheme_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setScheme", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setUrl(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUrl", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUrl(QString)
    // 1: setUrl(QString,QUrl::ParsingMode)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setUrl(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // setUrl(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setUrl_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setUrl(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setUrl(QString)
                cppSelf->QUrl::setUrl(cpp_arg0);
                }
                break;
            }
            case 1: // setUrl(QString,QUrl::ParsingMode)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QUrl::ParsingMode cpp_arg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUrl(QString,QUrl::ParsingMode)
                cppSelf->QUrl::setUrl(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setUrl_TypeError:
        const char* overloads[] = {"QString", "QString, PySide.QtCore.QUrl.ParsingMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.setUrl", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setUserInfo(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserInfo(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setUserInfo(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setUserInfo_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUserInfo(QString)
            cppSelf->QUrl::setUserInfo(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setUserInfo_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setUserInfo", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_setUserName(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setUserName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_setUserName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUserName(QString)
            cppSelf->QUrl::setUserName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQUrlFunc_setUserName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setUserName", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_toAce(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toAce(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // toAce(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_toAce_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toAce(QString)
            QByteArray cppResult = QUrl::toAce(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_toAce_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.toAce", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_toEncoded(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "options" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toEncoded(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toEncoded(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toEncoded", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toEncoded(QFlags<QUrl::FormattingOption>)const
    if (numArgs == 0) {
        overloadId = 0; // toEncoded(QFlags<QUrl::FormattingOption>)const
    } else if (Shiboken::Converter<QFlags<QUrl::FormattingOption> >::isConvertible(arg)) {
        overloadId = 0; // toEncoded(QFlags<QUrl::FormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_toEncoded_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (arg)
                        errorArgName = "options";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toEncoded(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QUrl::FormattingOption> cpp_arg0 = arg ? Shiboken::Converter<QFlags<QUrl::FormattingOption> >::toCpp(arg) : QUrl::None;

            if(!PyErr_Occurred()) {
            // toEncoded(QFlags<QUrl::FormattingOption>)const
            QByteArray cppResult = cppSelf->QUrl::toEncoded(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_toEncoded_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl.FormattingOptions = QUrl.None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.toEncoded", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_toLocalFile(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toLocalFile()const
            QString cppResult = cppSelf->QUrl::toLocalFile();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_toPercentEncoding(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "exclude", "include" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toPercentEncoding(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toPercentEncoding(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toPercentEncoding(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:toPercentEncoding", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: toPercentEncoding(QString,QByteArray,QByteArray)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
            } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[2])) {
                overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_toPercentEncoding_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "exclude");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "exclude";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "include");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "include";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toPercentEncoding(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
            QByteArray cpp_arg1_tmp = QByteArray();
            QByteArray* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg2_auto_ptr;
            QByteArray cpp_arg2_tmp = QByteArray();
            QByteArray* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            if (pyargs[2] && !Shiboken::Converter<QByteArray >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg2);

            if(!PyErr_Occurred()) {
            // toPercentEncoding(QString,QByteArray,QByteArray)
            QByteArray cppResult = QUrl::toPercentEncoding(cpp_arg0, *cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_toPercentEncoding_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QByteArray = QByteArray(), PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.toPercentEncoding", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_toPunycode(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toPunycode(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // toPunycode(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_toPunycode_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toPunycode(QString)
            QByteArray cppResult = QUrl::toPunycode(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_toPunycode_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.toPunycode", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "options" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toString(QFlags<QUrl::FormattingOption>)const
    if (numArgs == 0) {
        overloadId = 0; // toString(QFlags<QUrl::FormattingOption>)const
    } else if (Shiboken::Converter<QFlags<QUrl::FormattingOption> >::isConvertible(arg)) {
        overloadId = 0; // toString(QFlags<QUrl::FormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQUrlFunc_toString_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (arg)
                        errorArgName = "options";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toString(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QUrl::FormattingOption> cpp_arg0 = arg ? Shiboken::Converter<QFlags<QUrl::FormattingOption> >::toCpp(arg) : QUrl::None;

            if(!PyErr_Occurred()) {
            // toString(QFlags<QUrl::FormattingOption>)const
            QString cppResult = cppSelf->QUrl::toString(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQUrlFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl.FormattingOptions = QUrl.None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.toString", overloads);
        return 0;
}

static PyObject* SbkQUrlFunc_userInfo(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userInfo()const
            QString cppResult = cppSelf->QUrl::userInfo();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQUrlFunc_userName(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userName()const
            QString cppResult = cppSelf->QUrl::userName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQUrl_methods[] = {
    {"addEncodedQueryItem", (PyCFunction)SbkQUrlFunc_addEncodedQueryItem, METH_VARARGS},
    {"addQueryItem", (PyCFunction)SbkQUrlFunc_addQueryItem, METH_VARARGS},
    {"allEncodedQueryItemValues", (PyCFunction)SbkQUrlFunc_allEncodedQueryItemValues, METH_O},
    {"allQueryItemValues", (PyCFunction)SbkQUrlFunc_allQueryItemValues, METH_O},
    {"authority", (PyCFunction)SbkQUrlFunc_authority, METH_NOARGS},
    {"clear", (PyCFunction)SbkQUrlFunc_clear, METH_NOARGS},
    {"encodedFragment", (PyCFunction)SbkQUrlFunc_encodedFragment, METH_NOARGS},
    {"encodedHost", (PyCFunction)SbkQUrlFunc_encodedHost, METH_NOARGS},
    {"encodedPassword", (PyCFunction)SbkQUrlFunc_encodedPassword, METH_NOARGS},
    {"encodedPath", (PyCFunction)SbkQUrlFunc_encodedPath, METH_NOARGS},
    {"encodedQuery", (PyCFunction)SbkQUrlFunc_encodedQuery, METH_NOARGS},
    {"encodedQueryItemValue", (PyCFunction)SbkQUrlFunc_encodedQueryItemValue, METH_O},
    {"encodedQueryItems", (PyCFunction)SbkQUrlFunc_encodedQueryItems, METH_NOARGS},
    {"encodedUserName", (PyCFunction)SbkQUrlFunc_encodedUserName, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQUrlFunc_errorString, METH_NOARGS},
    {"fragment", (PyCFunction)SbkQUrlFunc_fragment, METH_NOARGS},
    {"fromAce", (PyCFunction)SbkQUrlFunc_fromAce, METH_O|METH_STATIC},
    {"fromEncoded", (PyCFunction)SbkQUrlFunc_fromEncoded, METH_VARARGS|METH_STATIC},
    {"fromLocalFile", (PyCFunction)SbkQUrlFunc_fromLocalFile, METH_O|METH_STATIC},
    {"fromPercentEncoding", (PyCFunction)SbkQUrlFunc_fromPercentEncoding, METH_O|METH_STATIC},
    {"fromPunycode", (PyCFunction)SbkQUrlFunc_fromPunycode, METH_O|METH_STATIC},
    {"fromUserInput", (PyCFunction)SbkQUrlFunc_fromUserInput, METH_O|METH_STATIC},
    {"hasEncodedQueryItem", (PyCFunction)SbkQUrlFunc_hasEncodedQueryItem, METH_O},
    {"hasFragment", (PyCFunction)SbkQUrlFunc_hasFragment, METH_NOARGS},
    {"hasQuery", (PyCFunction)SbkQUrlFunc_hasQuery, METH_NOARGS},
    {"hasQueryItem", (PyCFunction)SbkQUrlFunc_hasQueryItem, METH_O},
    {"host", (PyCFunction)SbkQUrlFunc_host, METH_NOARGS},
    {"idnWhitelist", (PyCFunction)SbkQUrlFunc_idnWhitelist, METH_NOARGS|METH_STATIC},
    {"isEmpty", (PyCFunction)SbkQUrlFunc_isEmpty, METH_NOARGS},
    {"isParentOf", (PyCFunction)SbkQUrlFunc_isParentOf, METH_O},
    {"isRelative", (PyCFunction)SbkQUrlFunc_isRelative, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQUrlFunc_isValid, METH_NOARGS},
    {"password", (PyCFunction)SbkQUrlFunc_password, METH_NOARGS},
    {"path", (PyCFunction)SbkQUrlFunc_path, METH_NOARGS},
    {"port", (PyCFunction)SbkQUrlFunc_port, METH_NOARGS|METH_O},
    {"queryItemValue", (PyCFunction)SbkQUrlFunc_queryItemValue, METH_O},
    {"queryItems", (PyCFunction)SbkQUrlFunc_queryItems, METH_NOARGS},
    {"queryPairDelimiter", (PyCFunction)SbkQUrlFunc_queryPairDelimiter, METH_NOARGS},
    {"queryValueDelimiter", (PyCFunction)SbkQUrlFunc_queryValueDelimiter, METH_NOARGS},
    {"removeAllEncodedQueryItems", (PyCFunction)SbkQUrlFunc_removeAllEncodedQueryItems, METH_O},
    {"removeAllQueryItems", (PyCFunction)SbkQUrlFunc_removeAllQueryItems, METH_O},
    {"removeEncodedQueryItem", (PyCFunction)SbkQUrlFunc_removeEncodedQueryItem, METH_O},
    {"removeQueryItem", (PyCFunction)SbkQUrlFunc_removeQueryItem, METH_O},
    {"resolved", (PyCFunction)SbkQUrlFunc_resolved, METH_O},
    {"scheme", (PyCFunction)SbkQUrlFunc_scheme, METH_NOARGS},
    {"setAuthority", (PyCFunction)SbkQUrlFunc_setAuthority, METH_O},
    {"setEncodedFragment", (PyCFunction)SbkQUrlFunc_setEncodedFragment, METH_O},
    {"setEncodedHost", (PyCFunction)SbkQUrlFunc_setEncodedHost, METH_O},
    {"setEncodedPassword", (PyCFunction)SbkQUrlFunc_setEncodedPassword, METH_O},
    {"setEncodedPath", (PyCFunction)SbkQUrlFunc_setEncodedPath, METH_O},
    {"setEncodedQuery", (PyCFunction)SbkQUrlFunc_setEncodedQuery, METH_O},
    {"setEncodedQueryItems", (PyCFunction)SbkQUrlFunc_setEncodedQueryItems, METH_O},
    {"setEncodedUrl", (PyCFunction)SbkQUrlFunc_setEncodedUrl, METH_VARARGS},
    {"setEncodedUserName", (PyCFunction)SbkQUrlFunc_setEncodedUserName, METH_O},
    {"setFragment", (PyCFunction)SbkQUrlFunc_setFragment, METH_O},
    {"setHost", (PyCFunction)SbkQUrlFunc_setHost, METH_O},
    {"setIdnWhitelist", (PyCFunction)SbkQUrlFunc_setIdnWhitelist, METH_O|METH_STATIC},
    {"setPassword", (PyCFunction)SbkQUrlFunc_setPassword, METH_O},
    {"setPath", (PyCFunction)SbkQUrlFunc_setPath, METH_O},
    {"setPort", (PyCFunction)SbkQUrlFunc_setPort, METH_O},
    {"setQueryDelimiters", (PyCFunction)SbkQUrlFunc_setQueryDelimiters, METH_VARARGS},
    {"setQueryItems", (PyCFunction)SbkQUrlFunc_setQueryItems, METH_O},
    {"setScheme", (PyCFunction)SbkQUrlFunc_setScheme, METH_O},
    {"setUrl", (PyCFunction)SbkQUrlFunc_setUrl, METH_VARARGS},
    {"setUserInfo", (PyCFunction)SbkQUrlFunc_setUserInfo, METH_O},
    {"setUserName", (PyCFunction)SbkQUrlFunc_setUserName, METH_O},
    {"toAce", (PyCFunction)SbkQUrlFunc_toAce, METH_O|METH_STATIC},
    {"toEncoded", (PyCFunction)SbkQUrlFunc_toEncoded, METH_VARARGS|METH_KEYWORDS},
    {"toLocalFile", (PyCFunction)SbkQUrlFunc_toLocalFile, METH_NOARGS},
    {"toPercentEncoding", (PyCFunction)SbkQUrlFunc_toPercentEncoding, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"toPunycode", (PyCFunction)SbkQUrlFunc_toPunycode, METH_O|METH_STATIC},
    {"toString", (PyCFunction)SbkQUrlFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {"userInfo", (PyCFunction)SbkQUrlFunc_userInfo, METH_NOARGS},
    {"userName", (PyCFunction)SbkQUrlFunc_userName, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQUrl_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QUrl& cpp_self = *Shiboken::Converter<QUrl* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QUrl & >::isConvertible(other)) {
                // operator!=(const QUrl & url) const
                QUrl* cpp_other = Shiboken::Converter<QUrl* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QUrl  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QUrl >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QUrl > cpp_other_auto_ptr;
                QUrl* cpp_other = Shiboken::Converter<QUrl* >::toCpp(other);
                if (!Shiboken::Converter<QUrl >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QUrl >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQUrl_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QUrl & >::isConvertible(other)) {
                // operator<(const QUrl & url) const
                QUrl* cpp_other = Shiboken::Converter<QUrl* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QUrl  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else if (Shiboken::Converter<QUrl >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QUrl > cpp_other_auto_ptr;
                QUrl* cpp_other = Shiboken::Converter<QUrl* >::toCpp(other);
                if (!Shiboken::Converter<QUrl >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QUrl >(cpp_other);
                result = (cpp_self < (*cpp_other));
            } else goto SbkQUrl_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QUrl & >::isConvertible(other)) {
                // operator==(const QUrl & url) const
                QUrl* cpp_other = Shiboken::Converter<QUrl* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QUrl  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QUrl >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QUrl > cpp_other_auto_ptr;
                QUrl* cpp_other = Shiboken::Converter<QUrl* >::toCpp(other);
                if (!Shiboken::Converter<QUrl >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QUrl >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQUrl_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQUrl_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQUrl_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter<QUrl >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQUrl_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QUrl",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQUrl_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQUrl_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQUrl_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQUrl_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QUrl >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QUrl",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QUrl_ParsingMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QUrl_ParsingMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QUrl_ParsingMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ParsingMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QUrl_ParsingMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QUrl_ParsingMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QUrl_ParsingMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QUrl::FormattingOptions >::checkType(self) && Shiboken::Converter<QUrl::FormattingOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        Shiboken::Converter<QUrl::FormattingOptions>::toCpp(self)
        & Shiboken::Converter< QUrl::FormattingOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QUrl::FormattingOptions >::checkType(self) && Shiboken::Converter<QUrl::FormattingOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        Shiboken::Converter<QUrl::FormattingOptions>::toCpp(self)
        | Shiboken::Converter< QUrl::FormattingOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QUrl::FormattingOptions >::checkType(self) && Shiboken::Converter<QUrl::FormattingOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        Shiboken::Converter<QUrl::FormattingOptions>::toCpp(self)
        ^ Shiboken::Converter< QUrl::FormattingOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        ~Shiboken::Converter<QUrl::FormattingOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QUrl_FormattingOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtCore_QUrl_FormattingOption_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QUrl_FormattingOption_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QUrl_FormattingOption_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FormattingOption",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtCore_QUrl_FormattingOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QUrl_FormattingOption_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QUrl_FormattingOption_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QUrl_FormattingOption_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QUrl_FormattingOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FormattingOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QUrl(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QURL_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQUrl_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQUrl_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQUrl_Type));
    PyModule_AddObject(module, "QUrl",
        ((PyObject*)&SbkQUrl_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ParsingMode
    SbkPySide_QtCoreTypes[SBK_QURL_PARSINGMODE_IDX] = &SbkPySide_QtCore_QUrl_ParsingMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QUrl_ParsingMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QUrl_ParsingMode_Type);
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
            "ParsingMode",((PyObject*)&SbkPySide_QtCore_QUrl_ParsingMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_ParsingMode_Type,
        (long) QUrl::TolerantMode, "TolerantMode");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "TolerantMode", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_ParsingMode_Type.tp_dict,
        "TolerantMode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_ParsingMode_Type,
        (long) QUrl::StrictMode, "StrictMode");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "StrictMode", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_ParsingMode_Type.tp_dict,
        "StrictMode", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QUrl::ParsingMode");

    // init enum class: FormattingOption
    SbkPySide_QtCoreTypes[SBK_QURL_FORMATTINGOPTION_IDX] = &SbkPySide_QtCore_QUrl_FormattingOption_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QUrl_FormattingOption_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QUrl_FormattingOption_Type);
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
            "FormattingOption",((PyObject*)&SbkPySide_QtCore_QUrl_FormattingOption_Type));

    // init flags class: QFlags<QUrl::FormattingOption>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QURL_FORMATTINGOPTION__IDX] = &SbkPySide_QtCore_QUrl_FormattingOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QUrl_FormattingOptions_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QUrl_FormattingOptions_Type);
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
            "FormattingOptions",((PyObject*)&SbkPySide_QtCore_QUrl_FormattingOptions_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::None, "None");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "None", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "None", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemoveScheme, "RemoveScheme");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemoveScheme", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemoveScheme", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemovePassword, "RemovePassword");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemovePassword", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemovePassword", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemoveUserInfo, "RemoveUserInfo");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemoveUserInfo", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemoveUserInfo", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemovePort, "RemovePort");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemovePort", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemovePort", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemoveAuthority, "RemoveAuthority");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemoveAuthority", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemoveAuthority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemovePath, "RemovePath");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemovePath", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemovePath", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemoveQuery, "RemoveQuery");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemoveQuery", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemoveQuery", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::RemoveFragment, "RemoveFragment");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "RemoveFragment", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "RemoveFragment", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QUrl_FormattingOption_Type,
        (long) QUrl::StripTrailingSlash, "StripTrailingSlash");
    PyDict_SetItemString(SbkQUrl_Type.super.ht_type.tp_dict,
        "StripTrailingSlash", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption_Type.tp_dict,
        "StripTrailingSlash", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QUrl::FormattingOption");


    Shiboken::TypeResolver::createValueTypeResolver<QUrl >("QUrl");
    Shiboken::TypeResolver::createObjectTypeResolver<QUrl >("QUrl*");
    Shiboken::TypeResolver::createValueTypeResolver<QUrl >(typeid(QUrl).name());
    PySide::initQtMetaType<QUrl >();
}

