/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamattribute_wrapper.h"

// Extra includes
#include <qxmlstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlStreamAttribute_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamAttribute >()))
        return -1;

    QXmlStreamAttribute* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamAttribute", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamAttribute()
    // 1: QXmlStreamAttribute(QString,QString,QString)
    // 2: QXmlStreamAttribute(QString,QString)
    // 3: QXmlStreamAttribute(QXmlStreamAttribute)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamAttribute()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QXmlStreamAttribute(QXmlStreamAttribute)
    } else if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QXmlStreamAttribute(QString,QString)
        } else if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 1; // QXmlStreamAttribute(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttribute_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamAttribute()
            {

                if(!PyErr_Occurred()) {
                // QXmlStreamAttribute()
                cptr = new QXmlStreamAttribute();
                }
                break;
            }
            case 1: // QXmlStreamAttribute(QString,QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // QXmlStreamAttribute(QString,QString,QString)
                cptr = new QXmlStreamAttribute(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // QXmlStreamAttribute(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QXmlStreamAttribute(QString,QString)
                cptr = new QXmlStreamAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QXmlStreamAttribute(QXmlStreamAttribute)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QXmlStreamAttribute(QXmlStreamAttribute)
                cptr = new QXmlStreamAttribute(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamAttribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlStreamAttribute_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlStreamAttribute_Init_TypeError:
        const char* overloads[] = {"", "QString, QString, QString", "QString, QString", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttribute", overloads);
        return -1;
}

static PyObject* SbkQXmlStreamAttributeFunc_isDefault(PyObject* self)
{
    QXmlStreamAttribute* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDefault()const
            bool cppResult = cppSelf->QXmlStreamAttribute::isDefault();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributeFunc_name(PyObject* self)
{
    QXmlStreamAttribute* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QStringRef cppResult = cppSelf->QXmlStreamAttribute::name();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributeFunc_namespaceUri(PyObject* self)
{
    QXmlStreamAttribute* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namespaceUri()const
            QStringRef cppResult = cppSelf->QXmlStreamAttribute::namespaceUri();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributeFunc_prefix(PyObject* self)
{
    QXmlStreamAttribute* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prefix()const
            QStringRef cppResult = cppSelf->QXmlStreamAttribute::prefix();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributeFunc_qualifiedName(PyObject* self)
{
    QXmlStreamAttribute* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // qualifiedName()const
            QStringRef cppResult = cppSelf->QXmlStreamAttribute::qualifiedName();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributeFunc_value(PyObject* self)
{
    QXmlStreamAttribute* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // value()const
            QStringRef cppResult = cppSelf->QXmlStreamAttribute::value();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQXmlStreamAttribute_methods[] = {
    {"isDefault", (PyCFunction)SbkQXmlStreamAttributeFunc_isDefault, METH_NOARGS},
    {"name", (PyCFunction)SbkQXmlStreamAttributeFunc_name, METH_NOARGS},
    {"namespaceUri", (PyCFunction)SbkQXmlStreamAttributeFunc_namespaceUri, METH_NOARGS},
    {"prefix", (PyCFunction)SbkQXmlStreamAttributeFunc_prefix, METH_NOARGS},
    {"qualifiedName", (PyCFunction)SbkQXmlStreamAttributeFunc_qualifiedName, METH_NOARGS},
    {"value", (PyCFunction)SbkQXmlStreamAttributeFunc_value, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQXmlStreamAttribute_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QXmlStreamAttribute& cpp_self = *Shiboken::Converter<QXmlStreamAttribute* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(other)) {
                // operator!=(const QXmlStreamAttribute & other) const
                QXmlStreamAttribute* cpp_other = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlStreamAttribute  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQXmlStreamAttribute_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(other)) {
                // operator==(const QXmlStreamAttribute & other) const
                QXmlStreamAttribute* cpp_other = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlStreamAttribute  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQXmlStreamAttribute_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQXmlStreamAttribute_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlStreamAttribute_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamAttribute",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQXmlStreamAttribute_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlStreamAttribute_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlStreamAttribute_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlStreamAttribute >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlStreamAttribute",
    /*user_data*/           0
};
} //extern


void init_QXmlStreamAttribute(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMATTRIBUTE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlStreamAttribute_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlStreamAttribute_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlStreamAttribute_Type));
    PyModule_AddObject(module, "QXmlStreamAttribute",
        ((PyObject*)&SbkQXmlStreamAttribute_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamAttribute >("QXmlStreamAttribute");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamAttribute >("QXmlStreamAttribute*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamAttribute >(typeid(QXmlStreamAttribute).name());
    PySide::initQtMetaType<QXmlStreamAttribute >();
}

