/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamattributes_wrapper.h"

// Extra includes
#include <QVector>
#include <qxmlstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlStreamAttributes_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamAttributes >()))
        return -1;

    QXmlStreamAttributes* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamAttributes", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamAttributes()
    // 1: QXmlStreamAttributes(QXmlStreamAttributes)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamAttributes()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlStreamAttributes & >::isConvertible(arg)) {
        overloadId = 1; // QXmlStreamAttributes(QXmlStreamAttributes)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributes_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamAttributes()
            {

                if(!PyErr_Occurred()) {
                // QXmlStreamAttributes()
                cptr = new QXmlStreamAttributes();
                }
                break;
            }
            case 1: // QXmlStreamAttributes(QXmlStreamAttributes)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QXmlStreamAttributes* cpp_arg0 = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlStreamAttributes(QXmlStreamAttributes)
                cptr = new QXmlStreamAttributes(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamAttributes >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlStreamAttributes_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlStreamAttributes_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QXmlStreamAttributes", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes", overloads);
        return -1;
}

static PyObject* SbkQXmlStreamAttributesFunc_append(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "append", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: append(QString,QString,QString)
    // 1: append(QString,QString)
    // 2: append(QXmlStreamAttribute)
    if (numArgs == 1 && Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(pyargs[0])) {
        overloadId = 2; // append(QXmlStreamAttribute)
    } else if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // append(QString,QString)
        } else if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // append(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_append_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // append(QString,QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // append(QString,QString,QString)
                cppSelf->QXmlStreamAttributes::append(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // append(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // append(QString,QString)
                cppSelf->QXmlStreamAttributes::append(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // append(QXmlStreamAttribute)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // append(QXmlStreamAttribute)
                cppSelf->QXmlStreamAttributes::append(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamAttributesFunc_append_TypeError:
        const char* overloads[] = {"QString, QString, QString", "QString, QString", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.append", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_capacity(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // capacity()const
            int cppResult = cppSelf->QXmlStreamAttributes::capacity();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributesFunc_clear(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QXmlStreamAttributes::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlStreamAttributesFunc_count(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: count()const
    // 1: count(QXmlStreamAttribute)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(arg)) {
        overloadId = 1; // count(QXmlStreamAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                // count()const
                int cppResult = cppSelf->QXmlStreamAttributes::count();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(QXmlStreamAttribute)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // count(QXmlStreamAttribute)const
                int cppResult = cppSelf->QXmlStreamAttributes::count(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_count_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.count", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_empty(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // empty()const
            bool cppResult = cppSelf->QXmlStreamAttributes::empty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributesFunc_endsWith(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(QXmlStreamAttribute)const
    if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(arg)) {
        overloadId = 0; // endsWith(QXmlStreamAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_endsWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // endsWith(QXmlStreamAttribute)const
            bool cppResult = cppSelf->QXmlStreamAttributes::endsWith(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_endsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.endsWith", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_hasAttribute(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hasAttribute", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hasAttribute(QString,QString)const
    // 1: hasAttribute(QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // hasAttribute(QString)const
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // hasAttribute(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_hasAttribute_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // hasAttribute(QString,QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // hasAttribute(QString,QString)const
                bool cppResult = cppSelf->QXmlStreamAttributes::hasAttribute(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // hasAttribute(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // hasAttribute(QString)const
                bool cppResult = cppSelf->QXmlStreamAttributes::hasAttribute(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_hasAttribute_TypeError:
        const char* overloads[] = {"QString, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.hasAttribute", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.indexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QXmlStreamAttribute,int)const
    if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QXmlStreamAttribute,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(QXmlStreamAttribute,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // indexOf(QXmlStreamAttribute,int)const
            int cppResult = cppSelf->QXmlStreamAttributes::indexOf(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.indexOf", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_isEmpty(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QXmlStreamAttributes::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributesFunc_isSharedWith(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSharedWith(QVector<QXmlStreamAttribute>)const
    if (Shiboken::Converter< QVector<QXmlStreamAttribute >  >::isConvertible(arg)) {
        overloadId = 0; // isSharedWith(QVector<QXmlStreamAttribute>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_isSharedWith_TypeError;

    // Call function/method
    {
        {
            QVector<QXmlStreamAttribute > cpp_arg0 = Shiboken::Converter<QVector<QXmlStreamAttribute > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isSharedWith(QVector<QXmlStreamAttribute>)const
            bool cppResult = cppSelf->QXmlStreamAttributes::isSharedWith(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_isSharedWith_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.isSharedWith", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QXmlStreamAttribute,int)const
    if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QXmlStreamAttribute,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(QXmlStreamAttribute,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // lastIndexOf(QXmlStreamAttribute,int)const
            int cppResult = cppSelf->QXmlStreamAttributes::lastIndexOf(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.lastIndexOf", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_prepend(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(QXmlStreamAttribute)
    if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(arg)) {
        overloadId = 0; // prepend(QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_prepend_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // prepend(QXmlStreamAttribute)
            cppSelf->QXmlStreamAttributes::prepend(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamAttributesFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.prepend", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_remove(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "remove", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: remove(int)
    // 1: remove(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // remove(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // remove(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_remove_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // remove(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // remove(int)
                cppSelf->QXmlStreamAttributes::remove(cpp_arg0);
                }
                break;
            }
            case 1: // remove(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // remove(int,int)
                cppSelf->QXmlStreamAttributes::remove(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamAttributesFunc_remove_TypeError:
        const char* overloads[] = {"int", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.remove", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_replace(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QXmlStreamAttribute)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(int,QXmlStreamAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_replace_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QXmlStreamAttribute* cpp_arg1 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // replace(int,QXmlStreamAttribute)
            cppSelf->QXmlStreamAttributes::replace(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamAttributesFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.replace", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_reserve(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reserve(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // reserve(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_reserve_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // reserve(int)
            cppSelf->QXmlStreamAttributes::reserve(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamAttributesFunc_reserve_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.reserve", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_resize(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_resize_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resize(int)
            cppSelf->QXmlStreamAttributes::resize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamAttributesFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.resize", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_setSharable(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSharable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSharable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_setSharable_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSharable(bool)
            cppSelf->QXmlStreamAttributes::setSharable(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamAttributesFunc_setSharable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.setSharable", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_size(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            int cppResult = cppSelf->QXmlStreamAttributes::size();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamAttributesFunc_squeeze(PyObject* self)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // squeeze()
            cppSelf->QXmlStreamAttributes::squeeze();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlStreamAttributesFunc_startsWith(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(QXmlStreamAttribute)const
    if (Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(arg)) {
        overloadId = 0; // startsWith(QXmlStreamAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_startsWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // startsWith(QXmlStreamAttribute)const
            bool cppResult = cppSelf->QXmlStreamAttributes::startsWith(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_startsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.startsWith", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc_value(PyObject* self, PyObject* args)
{
    QXmlStreamAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(QString,QString)const
    // 1: value(QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // value(QString)const
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // value(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(QString,QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // value(QString,QString)const
                QStringRef cppResult = cppSelf->QXmlStreamAttributes::value(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // value(QString)const
                QStringRef cppResult = cppSelf->QXmlStreamAttributes::value(cpp_arg0);
                pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc_value_TypeError:
        const char* overloads[] = {"QString, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamAttributes.value", overloads);
        return 0;
}

static PyMethodDef SbkQXmlStreamAttributes_methods[] = {
    {"append", (PyCFunction)SbkQXmlStreamAttributesFunc_append, METH_VARARGS},
    {"capacity", (PyCFunction)SbkQXmlStreamAttributesFunc_capacity, METH_NOARGS},
    {"clear", (PyCFunction)SbkQXmlStreamAttributesFunc_clear, METH_NOARGS},
    {"count", (PyCFunction)SbkQXmlStreamAttributesFunc_count, METH_NOARGS|METH_O},
    {"empty", (PyCFunction)SbkQXmlStreamAttributesFunc_empty, METH_NOARGS},
    {"endsWith", (PyCFunction)SbkQXmlStreamAttributesFunc_endsWith, METH_O},
    {"hasAttribute", (PyCFunction)SbkQXmlStreamAttributesFunc_hasAttribute, METH_VARARGS},
    {"indexOf", (PyCFunction)SbkQXmlStreamAttributesFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"isEmpty", (PyCFunction)SbkQXmlStreamAttributesFunc_isEmpty, METH_NOARGS},
    {"isSharedWith", (PyCFunction)SbkQXmlStreamAttributesFunc_isSharedWith, METH_O},
    {"lastIndexOf", (PyCFunction)SbkQXmlStreamAttributesFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"prepend", (PyCFunction)SbkQXmlStreamAttributesFunc_prepend, METH_O},
    {"remove", (PyCFunction)SbkQXmlStreamAttributesFunc_remove, METH_VARARGS},
    {"replace", (PyCFunction)SbkQXmlStreamAttributesFunc_replace, METH_VARARGS},
    {"reserve", (PyCFunction)SbkQXmlStreamAttributesFunc_reserve, METH_O},
    {"resize", (PyCFunction)SbkQXmlStreamAttributesFunc_resize, METH_O},
    {"setSharable", (PyCFunction)SbkQXmlStreamAttributesFunc_setSharable, METH_O},
    {"size", (PyCFunction)SbkQXmlStreamAttributesFunc_size, METH_NOARGS},
    {"squeeze", (PyCFunction)SbkQXmlStreamAttributesFunc_squeeze, METH_NOARGS},
    {"startsWith", (PyCFunction)SbkQXmlStreamAttributesFunc_startsWith, METH_O},
    {"value", (PyCFunction)SbkQXmlStreamAttributesFunc_value, METH_VARARGS},
    {0} // Sentinel
};

static PyObject* SbkQXmlStreamAttributesFunc___add__(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QXmlStreamAttributes >::checkType(arg) && !Shiboken::Converter<QXmlStreamAttributes >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QVector<QXmlStreamAttribute>)const
    if (!isReverse && Shiboken::Converter< QVector<QXmlStreamAttribute >  >::isConvertible(arg)) {
        overloadId = 0; // operator+(QVector<QXmlStreamAttribute>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc___add___TypeError;

    // Call function/method
    {
        {
            QVector<QXmlStreamAttribute > cpp_arg0 = Shiboken::Converter<QVector<QXmlStreamAttribute > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+(QVector<QXmlStreamAttribute>)const
            QVector<QXmlStreamAttribute > cppResult = (*cppSelf) + cpp_arg0;
            pyResult = Shiboken::Converter<QVector<QXmlStreamAttribute > >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc___add___TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.__add__", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamAttributesFunc___lshift__(PyObject* self, PyObject* arg)
{
    QXmlStreamAttributes* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QXmlStreamAttributes >::checkType(arg) && !Shiboken::Converter<QXmlStreamAttributes >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QVector<QXmlStreamAttribute>)
    // 1: operator<<(QXmlStreamAttribute)
    if (!isReverse && Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(arg)) {
        overloadId = 1; // operator<<(QXmlStreamAttribute)
    } else if (!isReverse && Shiboken::Converter< QVector<QXmlStreamAttribute >  >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QVector<QXmlStreamAttribute>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamAttributesFunc___lshift___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator<<(QVector<QXmlStreamAttribute>)
            {
                QVector<QXmlStreamAttribute > cpp_arg0 = Shiboken::Converter<QVector<QXmlStreamAttribute > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QVector<QXmlStreamAttribute>)
                QVector<QXmlStreamAttribute > & cppResult = (*cppSelf) << cpp_arg0;
                pyResult = Shiboken::Converter<QVector<QXmlStreamAttribute >  >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator<<(QXmlStreamAttribute)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator<<(QXmlStreamAttribute)
                QVector<QXmlStreamAttribute > & cppResult = (*cppSelf) << (*cpp_arg0);
                pyResult = Shiboken::Converter<QVector<QXmlStreamAttribute >  >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamAttributesFunc___lshift___TypeError:
        const char* overloads[] = {"list", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamAttributes.__lshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQXmlStreamAttributes_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQXmlStreamAttributesFunc___add__,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQXmlStreamAttributesFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQXmlStreamAttributes_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QXmlStreamAttributes& cpp_self = *Shiboken::Converter<QXmlStreamAttributes* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< QVector<QXmlStreamAttribute >  >::isConvertible(other)) {
                // operator!=(const QVector<QXmlStreamAttribute > & v) const
                const QVector<QXmlStreamAttribute > & cpp_other = Shiboken::Converter< QVector<QXmlStreamAttribute >  >::toCpp(other);
                result = (cpp_self != cpp_other);
            } else goto SbkQXmlStreamAttributes_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< QVector<QXmlStreamAttribute >  >::isConvertible(other)) {
                // operator==(const QVector<QXmlStreamAttribute > & v) const
                const QVector<QXmlStreamAttribute > & cpp_other = Shiboken::Converter< QVector<QXmlStreamAttribute >  >::toCpp(other);
                result = (cpp_self == cpp_other);
            } else goto SbkQXmlStreamAttributes_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQXmlStreamAttributes_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlStreamAttributes_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamAttributes",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQXmlStreamAttributes_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQXmlStreamAttributes_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlStreamAttributes_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlStreamAttributes_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlStreamAttributes >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlStreamAttributes",
    /*user_data*/           0
};
} //extern


void init_QXmlStreamAttributes(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMATTRIBUTES_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlStreamAttributes_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlStreamAttributes_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlStreamAttributes_Type));
    PyModule_AddObject(module, "QXmlStreamAttributes",
        ((PyObject*)&SbkQXmlStreamAttributes_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamAttributes >("QXmlStreamAttributes");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamAttributes >("QXmlStreamAttributes*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamAttributes >(typeid(QXmlStreamAttributes).name());
    PySide::initQtMetaType<QXmlStreamAttributes >();
}

