/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamnamespacedeclaration_wrapper.h"

// Extra includes
#include <qxmlstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlStreamNamespaceDeclaration_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamNamespaceDeclaration >()))
        return -1;

    QXmlStreamNamespaceDeclaration* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamNamespaceDeclaration", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamNamespaceDeclaration()
    // 1: QXmlStreamNamespaceDeclaration(QString,QString)
    // 2: QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamNamespaceDeclaration()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlStreamNamespaceDeclaration & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // QXmlStreamNamespaceDeclaration(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamNamespaceDeclaration_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamNamespaceDeclaration()
            {

                if(!PyErr_Occurred()) {
                // QXmlStreamNamespaceDeclaration()
                cptr = new QXmlStreamNamespaceDeclaration();
                }
                break;
            }
            case 1: // QXmlStreamNamespaceDeclaration(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QXmlStreamNamespaceDeclaration(QString,QString)
                cptr = new QXmlStreamNamespaceDeclaration(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QXmlStreamNamespaceDeclaration* cpp_arg0 = Shiboken::Converter<QXmlStreamNamespaceDeclaration* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QXmlStreamNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
                cptr = new QXmlStreamNamespaceDeclaration(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamNamespaceDeclaration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlStreamNamespaceDeclaration_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlStreamNamespaceDeclaration_Init_TypeError:
        const char* overloads[] = {"", "QString, QString", "PySide.QtCore.QXmlStreamNamespaceDeclaration", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamNamespaceDeclaration", overloads);
        return -1;
}

static PyObject* SbkQXmlStreamNamespaceDeclarationFunc_namespaceUri(PyObject* self)
{
    QXmlStreamNamespaceDeclaration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamNamespaceDeclaration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namespaceUri()const
            QStringRef cppResult = cppSelf->QXmlStreamNamespaceDeclaration::namespaceUri();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamNamespaceDeclarationFunc_prefix(PyObject* self)
{
    QXmlStreamNamespaceDeclaration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamNamespaceDeclaration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prefix()const
            QStringRef cppResult = cppSelf->QXmlStreamNamespaceDeclaration::prefix();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQXmlStreamNamespaceDeclaration_methods[] = {
    {"namespaceUri", (PyCFunction)SbkQXmlStreamNamespaceDeclarationFunc_namespaceUri, METH_NOARGS},
    {"prefix", (PyCFunction)SbkQXmlStreamNamespaceDeclarationFunc_prefix, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQXmlStreamNamespaceDeclaration_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QXmlStreamNamespaceDeclaration& cpp_self = *Shiboken::Converter<QXmlStreamNamespaceDeclaration* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QXmlStreamNamespaceDeclaration & >::isConvertible(other)) {
                // operator!=(const QXmlStreamNamespaceDeclaration & other) const
                QXmlStreamNamespaceDeclaration* cpp_other = Shiboken::Converter<QXmlStreamNamespaceDeclaration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlStreamNamespaceDeclaration  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQXmlStreamNamespaceDeclaration_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QXmlStreamNamespaceDeclaration & >::isConvertible(other)) {
                // operator==(const QXmlStreamNamespaceDeclaration & other) const
                QXmlStreamNamespaceDeclaration* cpp_other = Shiboken::Converter<QXmlStreamNamespaceDeclaration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlStreamNamespaceDeclaration  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQXmlStreamNamespaceDeclaration_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQXmlStreamNamespaceDeclaration_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlStreamNamespaceDeclaration_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamNamespaceDeclaration",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQXmlStreamNamespaceDeclaration_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlStreamNamespaceDeclaration_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlStreamNamespaceDeclaration_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlStreamNamespaceDeclaration >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlStreamNamespaceDeclaration",
    /*user_data*/           0
};
} //extern


void init_QXmlStreamNamespaceDeclaration(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMNAMESPACEDECLARATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlStreamNamespaceDeclaration_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlStreamNamespaceDeclaration_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlStreamNamespaceDeclaration_Type));
    PyModule_AddObject(module, "QXmlStreamNamespaceDeclaration",
        ((PyObject*)&SbkQXmlStreamNamespaceDeclaration_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamNamespaceDeclaration >("QXmlStreamNamespaceDeclaration");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamNamespaceDeclaration >("QXmlStreamNamespaceDeclaration*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamNamespaceDeclaration >(typeid(QXmlStreamNamespaceDeclaration).name());
    PySide::initQtMetaType<QXmlStreamNamespaceDeclaration >();
}

