/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamnotationdeclaration_wrapper.h"

// Extra includes
#include <qxmlstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlStreamNotationDeclaration_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamNotationDeclaration >()))
        return -1;

    QXmlStreamNotationDeclaration* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamNotationDeclaration", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamNotationDeclaration()
    // 1: QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamNotationDeclaration()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlStreamNotationDeclaration & >::isConvertible(arg)) {
        overloadId = 1; // QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamNotationDeclaration_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamNotationDeclaration()
            {

                if(!PyErr_Occurred()) {
                // QXmlStreamNotationDeclaration()
                cptr = new QXmlStreamNotationDeclaration();
                }
                break;
            }
            case 1: // QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QXmlStreamNotationDeclaration* cpp_arg0 = Shiboken::Converter<QXmlStreamNotationDeclaration* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlStreamNotationDeclaration(QXmlStreamNotationDeclaration)
                cptr = new QXmlStreamNotationDeclaration(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamNotationDeclaration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlStreamNotationDeclaration_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlStreamNotationDeclaration_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QXmlStreamNotationDeclaration", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamNotationDeclaration", overloads);
        return -1;
}

static PyObject* SbkQXmlStreamNotationDeclarationFunc_name(PyObject* self)
{
    QXmlStreamNotationDeclaration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamNotationDeclaration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QStringRef cppResult = cppSelf->QXmlStreamNotationDeclaration::name();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamNotationDeclarationFunc_publicId(PyObject* self)
{
    QXmlStreamNotationDeclaration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamNotationDeclaration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // publicId()const
            QStringRef cppResult = cppSelf->QXmlStreamNotationDeclaration::publicId();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamNotationDeclarationFunc_systemId(PyObject* self)
{
    QXmlStreamNotationDeclaration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamNotationDeclaration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // systemId()const
            QStringRef cppResult = cppSelf->QXmlStreamNotationDeclaration::systemId();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQXmlStreamNotationDeclaration_methods[] = {
    {"name", (PyCFunction)SbkQXmlStreamNotationDeclarationFunc_name, METH_NOARGS},
    {"publicId", (PyCFunction)SbkQXmlStreamNotationDeclarationFunc_publicId, METH_NOARGS},
    {"systemId", (PyCFunction)SbkQXmlStreamNotationDeclarationFunc_systemId, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQXmlStreamNotationDeclaration_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QXmlStreamNotationDeclaration& cpp_self = *Shiboken::Converter<QXmlStreamNotationDeclaration* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QXmlStreamNotationDeclaration & >::isConvertible(other)) {
                // operator!=(const QXmlStreamNotationDeclaration & other) const
                QXmlStreamNotationDeclaration* cpp_other = Shiboken::Converter<QXmlStreamNotationDeclaration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlStreamNotationDeclaration  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQXmlStreamNotationDeclaration_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QXmlStreamNotationDeclaration & >::isConvertible(other)) {
                // operator==(const QXmlStreamNotationDeclaration & other) const
                QXmlStreamNotationDeclaration* cpp_other = Shiboken::Converter<QXmlStreamNotationDeclaration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlStreamNotationDeclaration  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQXmlStreamNotationDeclaration_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQXmlStreamNotationDeclaration_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlStreamNotationDeclaration_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamNotationDeclaration",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQXmlStreamNotationDeclaration_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlStreamNotationDeclaration_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlStreamNotationDeclaration_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlStreamNotationDeclaration >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlStreamNotationDeclaration",
    /*user_data*/           0
};
} //extern


void init_QXmlStreamNotationDeclaration(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMNOTATIONDECLARATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlStreamNotationDeclaration_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlStreamNotationDeclaration_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlStreamNotationDeclaration_Type));
    PyModule_AddObject(module, "QXmlStreamNotationDeclaration",
        ((PyObject*)&SbkQXmlStreamNotationDeclaration_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamNotationDeclaration >("QXmlStreamNotationDeclaration");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamNotationDeclaration >("QXmlStreamNotationDeclaration*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlStreamNotationDeclaration >(typeid(QXmlStreamNotationDeclaration).name());
    PySide::initQtMetaType<QXmlStreamNotationDeclaration >();
}

