/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamreader_wrapper.h"

// Extra includes
#include <QVector>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qxmlstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlStreamReader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamReader >()))
        return -1;

    QXmlStreamReader* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamReader", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamReader()
    // 1: QXmlStreamReader(QIODevice*)
    // 2: QXmlStreamReader(QByteArray)
    // 3: QXmlStreamReader(QString)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamReader()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 3; // QXmlStreamReader(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 2; // QXmlStreamReader(QByteArray)
    } else if (numArgs == 1 && Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 1; // QXmlStreamReader(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamReader()
            {

                if(!PyErr_Occurred()) {
                // QXmlStreamReader()
                cptr = new QXmlStreamReader();
                }
                break;
            }
            case 1: // QXmlStreamReader(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlStreamReader(QIODevice*)
                cptr = new QXmlStreamReader(cpp_arg0);
                }
                break;
            }
            case 2: // QXmlStreamReader(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QXmlStreamReader(QByteArray)
                cptr = new QXmlStreamReader(*cpp_arg0);
                }
                break;
            }
            case 3: // QXmlStreamReader(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlStreamReader(QString)
                cptr = new QXmlStreamReader(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlStreamReader_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlStreamReader_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice", "PySide.QtCore.QByteArray", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamReader", overloads);
        return -1;
}

static PyObject* SbkQXmlStreamReaderFunc_addData(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addData(QByteArray)
    // 1: addData(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // addData(QString)
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // addData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_addData_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addData(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // addData(QByteArray)
                cppSelf->QXmlStreamReader::addData(*cpp_arg0);
                }
                break;
            }
            case 1: // addData(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // addData(QString)
                cppSelf->QXmlStreamReader::addData(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamReaderFunc_addData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.addData", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_addExtraNamespaceDeclaration(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    if (Shiboken::Converter<const QXmlStreamNamespaceDeclaration & >::isConvertible(arg)) {
        overloadId = 0; // addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_addExtraNamespaceDeclaration_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlStreamNamespaceDeclaration* cpp_arg0 = Shiboken::Converter<QXmlStreamNamespaceDeclaration* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
            cppSelf->QXmlStreamReader::addExtraNamespaceDeclaration(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamReaderFunc_addExtraNamespaceDeclaration_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamNamespaceDeclaration", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.addExtraNamespaceDeclaration", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_addExtraNamespaceDeclarations(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addExtraNamespaceDeclarations(QVector<QXmlStreamNamespaceDeclaration>)
    if (Shiboken::Converter< QVector<QXmlStreamNamespaceDeclaration >  >::isConvertible(arg)) {
        overloadId = 0; // addExtraNamespaceDeclarations(QVector<QXmlStreamNamespaceDeclaration>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_addExtraNamespaceDeclarations_TypeError;

    // Call function/method
    {
        {
            QVector<QXmlStreamNamespaceDeclaration > cpp_arg0 = Shiboken::Converter<QVector<QXmlStreamNamespaceDeclaration > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addExtraNamespaceDeclarations(QVector<QXmlStreamNamespaceDeclaration>)
            cppSelf->QXmlStreamReader::addExtraNamespaceDeclarations(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamReaderFunc_addExtraNamespaceDeclarations_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.addExtraNamespaceDeclarations", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_atEnd(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QXmlStreamReader::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_attributes(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // attributes()const
            QXmlStreamAttributes cppResult = cppSelf->QXmlStreamReader::attributes();
            pyResult = Shiboken::Converter<QXmlStreamAttributes >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_characterOffset(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // characterOffset()const
            qint64 cppResult = cppSelf->QXmlStreamReader::characterOffset();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_clear(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QXmlStreamReader::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlStreamReaderFunc_columnNumber(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columnNumber()const
            qint64 cppResult = cppSelf->QXmlStreamReader::columnNumber();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_device(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QXmlStreamReader::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_documentEncoding(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentEncoding()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::documentEncoding();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_documentVersion(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentVersion()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::documentVersion();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_dtdName(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dtdName()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::dtdName();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_dtdPublicId(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dtdPublicId()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::dtdPublicId();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_dtdSystemId(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dtdSystemId()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::dtdSystemId();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_entityDeclarations(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // entityDeclarations()const
            QVector<QXmlStreamEntityDeclaration > cppResult = cppSelf->QXmlStreamReader::entityDeclarations();
            pyResult = Shiboken::Converter<QVector<QXmlStreamEntityDeclaration > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_entityResolver(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // entityResolver()const
            QXmlStreamEntityResolver * cppResult = cppSelf->QXmlStreamReader::entityResolver();
            pyResult = Shiboken::Converter<QXmlStreamEntityResolver * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_error(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QXmlStreamReader::Error cppResult = cppSelf->QXmlStreamReader::error();
            pyResult = Shiboken::Converter<QXmlStreamReader::Error >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_errorString(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QXmlStreamReader::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_hasError(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasError()const
            bool cppResult = cppSelf->QXmlStreamReader::hasError();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isCDATA(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCDATA()const
            bool cppResult = cppSelf->QXmlStreamReader::isCDATA();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isCharacters(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCharacters()const
            bool cppResult = cppSelf->QXmlStreamReader::isCharacters();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isComment(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isComment()const
            bool cppResult = cppSelf->QXmlStreamReader::isComment();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isDTD(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDTD()const
            bool cppResult = cppSelf->QXmlStreamReader::isDTD();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isEndDocument(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEndDocument()const
            bool cppResult = cppSelf->QXmlStreamReader::isEndDocument();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isEndElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEndElement()const
            bool cppResult = cppSelf->QXmlStreamReader::isEndElement();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isEntityReference(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEntityReference()const
            bool cppResult = cppSelf->QXmlStreamReader::isEntityReference();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isProcessingInstruction(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isProcessingInstruction()const
            bool cppResult = cppSelf->QXmlStreamReader::isProcessingInstruction();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isStandaloneDocument(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isStandaloneDocument()const
            bool cppResult = cppSelf->QXmlStreamReader::isStandaloneDocument();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isStartDocument(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isStartDocument()const
            bool cppResult = cppSelf->QXmlStreamReader::isStartDocument();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isStartElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isStartElement()const
            bool cppResult = cppSelf->QXmlStreamReader::isStartElement();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_isWhitespace(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWhitespace()const
            bool cppResult = cppSelf->QXmlStreamReader::isWhitespace();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_lineNumber(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineNumber()const
            qint64 cppResult = cppSelf->QXmlStreamReader::lineNumber();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_name(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::name();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_namespaceDeclarations(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namespaceDeclarations()const
            QVector<QXmlStreamNamespaceDeclaration > cppResult = cppSelf->QXmlStreamReader::namespaceDeclarations();
            pyResult = Shiboken::Converter<QVector<QXmlStreamNamespaceDeclaration > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_namespaceProcessing(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namespaceProcessing()const
            bool cppResult = cppSelf->QXmlStreamReader::namespaceProcessing();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_namespaceUri(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namespaceUri()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::namespaceUri();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_notationDeclarations(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // notationDeclarations()const
            QVector<QXmlStreamNotationDeclaration > cppResult = cppSelf->QXmlStreamReader::notationDeclarations();
            pyResult = Shiboken::Converter<QVector<QXmlStreamNotationDeclaration > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_prefix(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prefix()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::prefix();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_processingInstructionData(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // processingInstructionData()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::processingInstructionData();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_processingInstructionTarget(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // processingInstructionTarget()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::processingInstructionTarget();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_qualifiedName(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // qualifiedName()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::qualifiedName();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_raiseError(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "message" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamReader.raiseError(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamReader.raiseError(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:raiseError", &arg))
        return 0;


    // Overloaded function decisor
    // 0: raiseError(QString)
    if (numArgs == 0) {
        overloadId = 0; // raiseError(QString)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // raiseError(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_raiseError_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "message");
                if (value) {
                    if (arg)
                        errorArgName = "message";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamReader.raiseError(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // raiseError(QString)
            cppSelf->QXmlStreamReader::raiseError(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamReaderFunc_raiseError_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.raiseError", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_readElementText(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: readElementText()
    // 1: readElementText(QXmlStreamReader::ReadElementTextBehaviour)
    if (numArgs == 0) {
        overloadId = 0; // readElementText()
    } else if (Shiboken::Converter<QXmlStreamReader::ReadElementTextBehaviour >::isConvertible(arg)) {
        overloadId = 1; // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_readElementText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // readElementText()
            {

                if(!PyErr_Occurred()) {
                // readElementText()
                QString cppResult = cppSelf->QXmlStreamReader::readElementText();
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
            {
                QXmlStreamReader::ReadElementTextBehaviour cpp_arg0 = Shiboken::Converter<QXmlStreamReader::ReadElementTextBehaviour >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
                QString cppResult = cppSelf->QXmlStreamReader::readElementText(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlStreamReaderFunc_readElementText_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QXmlStreamReader.ReadElementTextBehaviour", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.readElementText", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_readNext(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readNext()
            QXmlStreamReader::TokenType cppResult = cppSelf->QXmlStreamReader::readNext();
            pyResult = Shiboken::Converter<QXmlStreamReader::TokenType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_readNextStartElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readNextStartElement()
            bool cppResult = cppSelf->QXmlStreamReader::readNextStartElement();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_setDevice(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QXmlStreamReader::setDevice(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamReaderFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.setDevice", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_setEntityResolver(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEntityResolver(QXmlStreamEntityResolver*)
    if (Shiboken::Converter<QXmlStreamEntityResolver * >::isConvertible(arg)) {
        overloadId = 0; // setEntityResolver(QXmlStreamEntityResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_setEntityResolver_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlStreamEntityResolver* cpp_arg0 = Shiboken::Converter<QXmlStreamEntityResolver* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEntityResolver(QXmlStreamEntityResolver*)
            cppSelf->QXmlStreamReader::setEntityResolver(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamReaderFunc_setEntityResolver_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamEntityResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.setEntityResolver", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_setNamespaceProcessing(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNamespaceProcessing(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNamespaceProcessing(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamReaderFunc_setNamespaceProcessing_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNamespaceProcessing(bool)
            cppSelf->QXmlStreamReader::setNamespaceProcessing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamReaderFunc_setNamespaceProcessing_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.setNamespaceProcessing", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamReaderFunc_skipCurrentElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // skipCurrentElement()
            cppSelf->QXmlStreamReader::skipCurrentElement();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlStreamReaderFunc_text(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QStringRef cppResult = cppSelf->QXmlStreamReader::text();
            pyResult = Shiboken::Converter<QStringRef >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_tokenString(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tokenString()const
            QString cppResult = cppSelf->QXmlStreamReader::tokenString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamReaderFunc_tokenType(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tokenType()const
            QXmlStreamReader::TokenType cppResult = cppSelf->QXmlStreamReader::tokenType();
            pyResult = Shiboken::Converter<QXmlStreamReader::TokenType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQXmlStreamReader_methods[] = {
    {"addData", (PyCFunction)SbkQXmlStreamReaderFunc_addData, METH_O},
    {"addExtraNamespaceDeclaration", (PyCFunction)SbkQXmlStreamReaderFunc_addExtraNamespaceDeclaration, METH_O},
    {"addExtraNamespaceDeclarations", (PyCFunction)SbkQXmlStreamReaderFunc_addExtraNamespaceDeclarations, METH_O},
    {"atEnd", (PyCFunction)SbkQXmlStreamReaderFunc_atEnd, METH_NOARGS},
    {"attributes", (PyCFunction)SbkQXmlStreamReaderFunc_attributes, METH_NOARGS},
    {"characterOffset", (PyCFunction)SbkQXmlStreamReaderFunc_characterOffset, METH_NOARGS},
    {"clear", (PyCFunction)SbkQXmlStreamReaderFunc_clear, METH_NOARGS},
    {"columnNumber", (PyCFunction)SbkQXmlStreamReaderFunc_columnNumber, METH_NOARGS},
    {"device", (PyCFunction)SbkQXmlStreamReaderFunc_device, METH_NOARGS},
    {"documentEncoding", (PyCFunction)SbkQXmlStreamReaderFunc_documentEncoding, METH_NOARGS},
    {"documentVersion", (PyCFunction)SbkQXmlStreamReaderFunc_documentVersion, METH_NOARGS},
    {"dtdName", (PyCFunction)SbkQXmlStreamReaderFunc_dtdName, METH_NOARGS},
    {"dtdPublicId", (PyCFunction)SbkQXmlStreamReaderFunc_dtdPublicId, METH_NOARGS},
    {"dtdSystemId", (PyCFunction)SbkQXmlStreamReaderFunc_dtdSystemId, METH_NOARGS},
    {"entityDeclarations", (PyCFunction)SbkQXmlStreamReaderFunc_entityDeclarations, METH_NOARGS},
    {"entityResolver", (PyCFunction)SbkQXmlStreamReaderFunc_entityResolver, METH_NOARGS},
    {"error", (PyCFunction)SbkQXmlStreamReaderFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQXmlStreamReaderFunc_errorString, METH_NOARGS},
    {"hasError", (PyCFunction)SbkQXmlStreamReaderFunc_hasError, METH_NOARGS},
    {"isCDATA", (PyCFunction)SbkQXmlStreamReaderFunc_isCDATA, METH_NOARGS},
    {"isCharacters", (PyCFunction)SbkQXmlStreamReaderFunc_isCharacters, METH_NOARGS},
    {"isComment", (PyCFunction)SbkQXmlStreamReaderFunc_isComment, METH_NOARGS},
    {"isDTD", (PyCFunction)SbkQXmlStreamReaderFunc_isDTD, METH_NOARGS},
    {"isEndDocument", (PyCFunction)SbkQXmlStreamReaderFunc_isEndDocument, METH_NOARGS},
    {"isEndElement", (PyCFunction)SbkQXmlStreamReaderFunc_isEndElement, METH_NOARGS},
    {"isEntityReference", (PyCFunction)SbkQXmlStreamReaderFunc_isEntityReference, METH_NOARGS},
    {"isProcessingInstruction", (PyCFunction)SbkQXmlStreamReaderFunc_isProcessingInstruction, METH_NOARGS},
    {"isStandaloneDocument", (PyCFunction)SbkQXmlStreamReaderFunc_isStandaloneDocument, METH_NOARGS},
    {"isStartDocument", (PyCFunction)SbkQXmlStreamReaderFunc_isStartDocument, METH_NOARGS},
    {"isStartElement", (PyCFunction)SbkQXmlStreamReaderFunc_isStartElement, METH_NOARGS},
    {"isWhitespace", (PyCFunction)SbkQXmlStreamReaderFunc_isWhitespace, METH_NOARGS},
    {"lineNumber", (PyCFunction)SbkQXmlStreamReaderFunc_lineNumber, METH_NOARGS},
    {"name", (PyCFunction)SbkQXmlStreamReaderFunc_name, METH_NOARGS},
    {"namespaceDeclarations", (PyCFunction)SbkQXmlStreamReaderFunc_namespaceDeclarations, METH_NOARGS},
    {"namespaceProcessing", (PyCFunction)SbkQXmlStreamReaderFunc_namespaceProcessing, METH_NOARGS},
    {"namespaceUri", (PyCFunction)SbkQXmlStreamReaderFunc_namespaceUri, METH_NOARGS},
    {"notationDeclarations", (PyCFunction)SbkQXmlStreamReaderFunc_notationDeclarations, METH_NOARGS},
    {"prefix", (PyCFunction)SbkQXmlStreamReaderFunc_prefix, METH_NOARGS},
    {"processingInstructionData", (PyCFunction)SbkQXmlStreamReaderFunc_processingInstructionData, METH_NOARGS},
    {"processingInstructionTarget", (PyCFunction)SbkQXmlStreamReaderFunc_processingInstructionTarget, METH_NOARGS},
    {"qualifiedName", (PyCFunction)SbkQXmlStreamReaderFunc_qualifiedName, METH_NOARGS},
    {"raiseError", (PyCFunction)SbkQXmlStreamReaderFunc_raiseError, METH_VARARGS|METH_KEYWORDS},
    {"readElementText", (PyCFunction)SbkQXmlStreamReaderFunc_readElementText, METH_NOARGS|METH_O},
    {"readNext", (PyCFunction)SbkQXmlStreamReaderFunc_readNext, METH_NOARGS},
    {"readNextStartElement", (PyCFunction)SbkQXmlStreamReaderFunc_readNextStartElement, METH_NOARGS},
    {"setDevice", (PyCFunction)SbkQXmlStreamReaderFunc_setDevice, METH_O},
    {"setEntityResolver", (PyCFunction)SbkQXmlStreamReaderFunc_setEntityResolver, METH_O},
    {"setNamespaceProcessing", (PyCFunction)SbkQXmlStreamReaderFunc_setNamespaceProcessing, METH_O},
    {"skipCurrentElement", (PyCFunction)SbkQXmlStreamReaderFunc_skipCurrentElement, METH_NOARGS},
    {"text", (PyCFunction)SbkQXmlStreamReaderFunc_text, METH_NOARGS},
    {"tokenString", (PyCFunction)SbkQXmlStreamReaderFunc_tokenString, METH_NOARGS},
    {"tokenType", (PyCFunction)SbkQXmlStreamReaderFunc_tokenType, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlStreamReader_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamReader",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlStreamReader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlStreamReader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlStreamReader >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlStreamReader*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtCore_QXmlStreamReader_Error_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QXmlStreamReader_Error_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QXmlStreamReader_Error_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Error",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QXmlStreamReader_Error_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QXmlStreamReader_Error_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QXmlStreamReader_Error_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QXmlStreamReader_TokenType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QXmlStreamReader_TokenType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QXmlStreamReader_TokenType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "TokenType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QXmlStreamReader_TokenType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QXmlStreamReader_TokenType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QXmlStreamReader_TokenType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ReadElementTextBehaviour",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QXmlStreamReader(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlStreamReader_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlStreamReader_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlStreamReader_Type));
    PyModule_AddObject(module, "QXmlStreamReader",
        ((PyObject*)&SbkQXmlStreamReader_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Error
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_ERROR_IDX] = &SbkPySide_QtCore_QXmlStreamReader_Error_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QXmlStreamReader_Error_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QXmlStreamReader_Error_Type);
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)&SbkPySide_QtCore_QXmlStreamReader_Error_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_Error_Type,
        (long) QXmlStreamReader::NoError, "NoError");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_Error_Type,
        (long) QXmlStreamReader::UnexpectedElementError, "UnexpectedElementError");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "UnexpectedElementError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error_Type.tp_dict,
        "UnexpectedElementError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_Error_Type,
        (long) QXmlStreamReader::CustomError, "CustomError");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "CustomError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error_Type.tp_dict,
        "CustomError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_Error_Type,
        (long) QXmlStreamReader::NotWellFormedError, "NotWellFormedError");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "NotWellFormedError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error_Type.tp_dict,
        "NotWellFormedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_Error_Type,
        (long) QXmlStreamReader::PrematureEndOfDocumentError, "PrematureEndOfDocumentError");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "PrematureEndOfDocumentError", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error_Type.tp_dict,
        "PrematureEndOfDocumentError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlStreamReader::Error");

    // init enum class: TokenType
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_TOKENTYPE_IDX] = &SbkPySide_QtCore_QXmlStreamReader_TokenType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type);
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
            "TokenType",((PyObject*)&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::NoToken, "NoToken");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "NoToken", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "NoToken", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::Invalid, "Invalid");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "Invalid", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "Invalid", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::StartDocument, "StartDocument");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "StartDocument", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "StartDocument", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::EndDocument, "EndDocument");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "EndDocument", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "EndDocument", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::StartElement, "StartElement");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "StartElement", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "StartElement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::EndElement, "EndElement");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "EndElement", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "EndElement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::Characters, "Characters");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "Characters", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "Characters", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::Comment, "Comment");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "Comment", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "Comment", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::DTD, "DTD");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "DTD", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "DTD", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::EntityReference, "EntityReference");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "EntityReference", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "EntityReference", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_TokenType_Type,
        (long) QXmlStreamReader::ProcessingInstruction, "ProcessingInstruction");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "ProcessingInstruction", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType_Type.tp_dict,
        "ProcessingInstruction", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlStreamReader::TokenType");

    // init enum class: ReadElementTextBehaviour
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_READELEMENTTEXTBEHAVIOUR_IDX] = &SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type);
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
            "ReadElementTextBehaviour",((PyObject*)&SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type,
        (long) QXmlStreamReader::ErrorOnUnexpectedElement, "ErrorOnUnexpectedElement");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "ErrorOnUnexpectedElement", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type.tp_dict,
        "ErrorOnUnexpectedElement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type,
        (long) QXmlStreamReader::IncludeChildElements, "IncludeChildElements");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "IncludeChildElements", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type.tp_dict,
        "IncludeChildElements", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type,
        (long) QXmlStreamReader::SkipChildElements, "SkipChildElements");
    PyDict_SetItemString(SbkQXmlStreamReader_Type.super.ht_type.tp_dict,
        "SkipChildElements", enum_item);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour_Type.tp_dict,
        "SkipChildElements", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlStreamReader::ReadElementTextBehaviour");


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamReader >("QXmlStreamReader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamReader >(typeid(QXmlStreamReader).name());
    PySide::initQtMetaType<QXmlStreamReader* >();
}

