/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamwriter_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>
#include <qtextcodec.h>
#include <qxmlstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlStreamWriter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamWriter >()))
        return -1;

    QXmlStreamWriter* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamWriter", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamWriter()
    // 1: QXmlStreamWriter(QByteArray*)
    // 2: QXmlStreamWriter(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamWriter()
    } else if (numArgs == 1 && Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 2; // QXmlStreamWriter(QIODevice*)
    } else if (numArgs == 1 && Shiboken::Converter<QByteArray * >::isConvertible(arg)) {
        overloadId = 1; // QXmlStreamWriter(QByteArray*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamWriter()
            {

                if(!PyErr_Occurred()) {
                // QXmlStreamWriter()
                cptr = new QXmlStreamWriter();
                }
                break;
            }
            case 1: // QXmlStreamWriter(QByteArray*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QXmlStreamWriter(QByteArray*)
                cptr = new QXmlStreamWriter(cpp_arg0);
                }
                break;
            }
            case 2: // QXmlStreamWriter(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlStreamWriter(QIODevice*)
                cptr = new QXmlStreamWriter(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlStreamWriter_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlStreamWriter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", "PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter", overloads);
        return -1;
}

static PyObject* SbkQXmlStreamWriterFunc_autoFormatting(PyObject* self)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoFormatting()const
            bool cppResult = cppSelf->QXmlStreamWriter::autoFormatting();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamWriterFunc_autoFormattingIndent(PyObject* self)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoFormattingIndent()const
            int cppResult = cppSelf->QXmlStreamWriter::autoFormattingIndent();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamWriterFunc_device(PyObject* self)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QXmlStreamWriter::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlStreamWriterFunc_setAutoFormatting(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFormatting(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoFormatting(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_setAutoFormatting_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoFormatting(bool)
            cppSelf->QXmlStreamWriter::setAutoFormatting(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_setAutoFormatting_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.setAutoFormatting", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_setAutoFormattingIndent(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFormattingIndent(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoFormattingIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_setAutoFormattingIndent_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoFormattingIndent(int)
            cppSelf->QXmlStreamWriter::setAutoFormattingIndent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_setAutoFormattingIndent_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.setAutoFormattingIndent", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_setCodec(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCodec(QTextCodec*)
    // 1: setCodec(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 1; // setCodec(const char*)
    } else if (Shiboken::Converter<QTextCodec * >::isConvertible(arg)) {
        overloadId = 0; // setCodec(QTextCodec*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_setCodec_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setCodec(QTextCodec*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextCodec* cpp_arg0 = Shiboken::Converter<QTextCodec* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setCodec(QTextCodec*)
                cppSelf->QXmlStreamWriter::setCodec(cpp_arg0);
                }
                break;
            }
            case 1: // setCodec(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setCodec(const char*)
                cppSelf->QXmlStreamWriter::setCodec(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_setCodec_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextCodec", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.setCodec", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_setDevice(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QXmlStreamWriter::setDevice(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.setDevice", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeAttribute(PyObject* self, PyObject* args)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeAttribute", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: writeAttribute(QString,QString,QString)
    // 1: writeAttribute(QString,QString)
    // 2: writeAttribute(QXmlStreamAttribute)
    if (numArgs == 1 && Shiboken::Converter<const QXmlStreamAttribute & >::isConvertible(pyargs[0])) {
        overloadId = 2; // writeAttribute(QXmlStreamAttribute)
    } else if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // writeAttribute(QString,QString)
        } else if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // writeAttribute(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeAttribute_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // writeAttribute(QString,QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // writeAttribute(QString,QString,QString)
                cppSelf->QXmlStreamWriter::writeAttribute(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // writeAttribute(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // writeAttribute(QString,QString)
                cppSelf->QXmlStreamWriter::writeAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // writeAttribute(QXmlStreamAttribute)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlStreamAttribute* cpp_arg0 = Shiboken::Converter<QXmlStreamAttribute* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // writeAttribute(QXmlStreamAttribute)
                cppSelf->QXmlStreamWriter::writeAttribute(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeAttribute_TypeError:
        const char* overloads[] = {"QString, QString, QString", "QString, QString", "PySide.QtCore.QXmlStreamAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeAttribute", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeAttributes(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeAttributes(QXmlStreamAttributes)
    if (Shiboken::Converter<const QXmlStreamAttributes & >::isConvertible(arg)) {
        overloadId = 0; // writeAttributes(QXmlStreamAttributes)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeAttributes_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlStreamAttributes* cpp_arg0 = Shiboken::Converter<QXmlStreamAttributes* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeAttributes(QXmlStreamAttributes)
            cppSelf->QXmlStreamWriter::writeAttributes(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeAttributes_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamAttributes", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeAttributes", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeCDATA(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeCDATA(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeCDATA(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeCDATA_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeCDATA(QString)
            cppSelf->QXmlStreamWriter::writeCDATA(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeCDATA_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeCDATA", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeCharacters(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeCharacters(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeCharacters(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeCharacters_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeCharacters(QString)
            cppSelf->QXmlStreamWriter::writeCharacters(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeCharacters_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeCharacters", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeComment(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeComment(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeComment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeComment_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeComment(QString)
            cppSelf->QXmlStreamWriter::writeComment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeComment_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeComment", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeCurrentToken(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeCurrentToken(QXmlStreamReader)
    if (Shiboken::Converter< QXmlStreamReader & >::isConvertible(arg)) {
        overloadId = 0; // writeCurrentToken(QXmlStreamReader)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeCurrentToken_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlStreamReader* cpp_arg0 = Shiboken::Converter<QXmlStreamReader* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeCurrentToken(QXmlStreamReader)
            cppSelf->QXmlStreamWriter::writeCurrentToken(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeCurrentToken_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamReader", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeCurrentToken", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeDTD(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeDTD(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeDTD(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeDTD_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeDTD(QString)
            cppSelf->QXmlStreamWriter::writeDTD(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeDTD_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeDTD", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeDefaultNamespace(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeDefaultNamespace(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeDefaultNamespace(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeDefaultNamespace_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeDefaultNamespace(QString)
            cppSelf->QXmlStreamWriter::writeDefaultNamespace(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeDefaultNamespace_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeDefaultNamespace", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeEmptyElement(PyObject* self, PyObject* args)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeEmptyElement", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeEmptyElement(QString,QString)
    // 1: writeEmptyElement(QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // writeEmptyElement(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // writeEmptyElement(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeEmptyElement_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // writeEmptyElement(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // writeEmptyElement(QString,QString)
                cppSelf->QXmlStreamWriter::writeEmptyElement(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // writeEmptyElement(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // writeEmptyElement(QString)
                cppSelf->QXmlStreamWriter::writeEmptyElement(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeEmptyElement_TypeError:
        const char* overloads[] = {"QString, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeEmptyElement", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeEndDocument(PyObject* self)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // writeEndDocument()
            cppSelf->QXmlStreamWriter::writeEndDocument();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlStreamWriterFunc_writeEndElement(PyObject* self)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // writeEndElement()
            cppSelf->QXmlStreamWriter::writeEndElement();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlStreamWriterFunc_writeEntityReference(PyObject* self, PyObject* arg)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeEntityReference(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // writeEntityReference(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeEntityReference_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writeEntityReference(QString)
            cppSelf->QXmlStreamWriter::writeEntityReference(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeEntityReference_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamWriter.writeEntityReference", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeNamespace(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "prefix" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeNamespace(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeNamespace(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeNamespace(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:writeNamespace", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeNamespace(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // writeNamespace(QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // writeNamespace(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeNamespace_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "prefix");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "prefix";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeNamespace(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // writeNamespace(QString,QString)
            cppSelf->QXmlStreamWriter::writeNamespace(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeNamespace_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeNamespace", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeProcessingInstruction(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "data" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:writeProcessingInstruction", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeProcessingInstruction(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // writeProcessingInstruction(QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // writeProcessingInstruction(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeProcessingInstruction_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "data");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "data";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // writeProcessingInstruction(QString,QString)
            cppSelf->QXmlStreamWriter::writeProcessingInstruction(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeProcessingInstruction_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeProcessingInstruction", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeStartDocument(PyObject* self, PyObject* args)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeStartDocument", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeStartDocument()
    // 1: writeStartDocument(QString)
    // 2: writeStartDocument(QString,bool)
    if (numArgs == 0) {
        overloadId = 0; // writeStartDocument()
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartDocument(QString)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // writeStartDocument(QString,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeStartDocument_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // writeStartDocument()
            {

                if(!PyErr_Occurred()) {
                // writeStartDocument()
                cppSelf->QXmlStreamWriter::writeStartDocument();
                }
                break;
            }
            case 1: // writeStartDocument(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // writeStartDocument(QString)
                cppSelf->QXmlStreamWriter::writeStartDocument(cpp_arg0);
                }
                break;
            }
            case 2: // writeStartDocument(QString,bool)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // writeStartDocument(QString,bool)
                cppSelf->QXmlStreamWriter::writeStartDocument(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeStartDocument_TypeError:
        const char* overloads[] = {"", "QString", "QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeStartDocument", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeStartElement(PyObject* self, PyObject* args)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeStartElement", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeStartElement(QString,QString)
    // 1: writeStartElement(QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // writeStartElement(QString)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // writeStartElement(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeStartElement_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // writeStartElement(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // writeStartElement(QString,QString)
                cppSelf->QXmlStreamWriter::writeStartElement(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // writeStartElement(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // writeStartElement(QString)
                cppSelf->QXmlStreamWriter::writeStartElement(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeStartElement_TypeError:
        const char* overloads[] = {"QString, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeStartElement", overloads);
        return 0;
}

static PyObject* SbkQXmlStreamWriterFunc_writeTextElement(PyObject* self, PyObject* args)
{
    QXmlStreamWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlStreamWriter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeTextElement", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: writeTextElement(QString,QString,QString)
    // 1: writeTextElement(QString,QString)
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // writeTextElement(QString,QString)
        } else if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // writeTextElement(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlStreamWriterFunc_writeTextElement_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // writeTextElement(QString,QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // writeTextElement(QString,QString,QString)
                cppSelf->QXmlStreamWriter::writeTextElement(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // writeTextElement(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // writeTextElement(QString,QString)
                cppSelf->QXmlStreamWriter::writeTextElement(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlStreamWriterFunc_writeTextElement_TypeError:
        const char* overloads[] = {"QString, QString, QString", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamWriter.writeTextElement", overloads);
        return 0;
}

static PyMethodDef SbkQXmlStreamWriter_methods[] = {
    {"autoFormatting", (PyCFunction)SbkQXmlStreamWriterFunc_autoFormatting, METH_NOARGS},
    {"autoFormattingIndent", (PyCFunction)SbkQXmlStreamWriterFunc_autoFormattingIndent, METH_NOARGS},
    {"device", (PyCFunction)SbkQXmlStreamWriterFunc_device, METH_NOARGS},
    {"setAutoFormatting", (PyCFunction)SbkQXmlStreamWriterFunc_setAutoFormatting, METH_O},
    {"setAutoFormattingIndent", (PyCFunction)SbkQXmlStreamWriterFunc_setAutoFormattingIndent, METH_O},
    {"setCodec", (PyCFunction)SbkQXmlStreamWriterFunc_setCodec, METH_O},
    {"setDevice", (PyCFunction)SbkQXmlStreamWriterFunc_setDevice, METH_O},
    {"writeAttribute", (PyCFunction)SbkQXmlStreamWriterFunc_writeAttribute, METH_VARARGS},
    {"writeAttributes", (PyCFunction)SbkQXmlStreamWriterFunc_writeAttributes, METH_O},
    {"writeCDATA", (PyCFunction)SbkQXmlStreamWriterFunc_writeCDATA, METH_O},
    {"writeCharacters", (PyCFunction)SbkQXmlStreamWriterFunc_writeCharacters, METH_O},
    {"writeComment", (PyCFunction)SbkQXmlStreamWriterFunc_writeComment, METH_O},
    {"writeCurrentToken", (PyCFunction)SbkQXmlStreamWriterFunc_writeCurrentToken, METH_O},
    {"writeDTD", (PyCFunction)SbkQXmlStreamWriterFunc_writeDTD, METH_O},
    {"writeDefaultNamespace", (PyCFunction)SbkQXmlStreamWriterFunc_writeDefaultNamespace, METH_O},
    {"writeEmptyElement", (PyCFunction)SbkQXmlStreamWriterFunc_writeEmptyElement, METH_VARARGS},
    {"writeEndDocument", (PyCFunction)SbkQXmlStreamWriterFunc_writeEndDocument, METH_NOARGS},
    {"writeEndElement", (PyCFunction)SbkQXmlStreamWriterFunc_writeEndElement, METH_NOARGS},
    {"writeEntityReference", (PyCFunction)SbkQXmlStreamWriterFunc_writeEntityReference, METH_O},
    {"writeNamespace", (PyCFunction)SbkQXmlStreamWriterFunc_writeNamespace, METH_VARARGS|METH_KEYWORDS},
    {"writeProcessingInstruction", (PyCFunction)SbkQXmlStreamWriterFunc_writeProcessingInstruction, METH_VARARGS|METH_KEYWORDS},
    {"writeStartDocument", (PyCFunction)SbkQXmlStreamWriterFunc_writeStartDocument, METH_VARARGS},
    {"writeStartElement", (PyCFunction)SbkQXmlStreamWriterFunc_writeStartElement, METH_VARARGS},
    {"writeTextElement", (PyCFunction)SbkQXmlStreamWriterFunc_writeTextElement, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlStreamWriter_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamWriter",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlStreamWriter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlStreamWriter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlStreamWriter >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlStreamWriter*",
    /*user_data*/           0
};
} //extern


void init_QXmlStreamWriter(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMWRITER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlStreamWriter_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlStreamWriter_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlStreamWriter_Type));
    PyModule_AddObject(module, "QXmlStreamWriter",
        ((PyObject*)&SbkQXmlStreamWriter_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamWriter >("QXmlStreamWriter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamWriter >(typeid(QXmlStreamWriter).name());
    PySide::initQtMetaType<QXmlStreamWriter* >();
}

