/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativecomponent_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeclarativecomponent.h>
#include <qdeclarativecontext.h>
#include <qdeclarativeengine.h>
#include <qdeclarativeerror.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDeclarativeComponentWrapper::QDeclarativeComponentWrapper(QDeclarativeEngine * arg__1, QObject * parent) : QDeclarativeComponent(arg__1, parent), m_metaObject(0) {
    // ... middle
}

QDeclarativeComponentWrapper::QDeclarativeComponentWrapper(QDeclarativeEngine * arg__1, const QString & fileName, QObject * parent) : QDeclarativeComponent(arg__1, fileName, parent), m_metaObject(0) {
    // ... middle
}

QDeclarativeComponentWrapper::QDeclarativeComponentWrapper(QDeclarativeEngine * arg__1, const QUrl & url, QObject * parent) : QDeclarativeComponent(arg__1, url, parent), m_metaObject(0) {
    // ... middle
}

QDeclarativeComponentWrapper::QDeclarativeComponentWrapper(QObject * parent) : QDeclarativeComponent(parent), m_metaObject(0) {
    // ... middle
}

QObject * QDeclarativeComponentWrapper::beginCreate(QDeclarativeContext * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "beginCreate"));
    if (py_override.isNull()) {
        return this->QDeclarativeComponent::beginCreate(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDeclarativeContext * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.beginCreate", SbkType<QObject * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter<QObject * >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeComponentWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeComponentWrapper::completeCreate()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "completeCreate"));
    if (py_override.isNull()) {
        return this->QDeclarativeComponent::completeCreate();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeComponentWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QObject * QDeclarativeComponentWrapper::create(QDeclarativeContext * context)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "create"));
    if (py_override.isNull()) {
        return this->QDeclarativeComponent::create(context);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDeclarativeContext * >::toPython(context)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.create", SbkType<QObject * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter<QObject * >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeComponentWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeComponentWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QDeclarativeComponentWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QDeclarativeComponentWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeComponent.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QDeclarativeComponentWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QDeclarativeComponentWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QDeclarativeComponent::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QDeclarativeComponentWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDeclarativeComponent::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDeclarativeComponentWrapper::~QDeclarativeComponentWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeComponent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeComponent >()))
        return -1;

    QDeclarativeComponentWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOO:QDeclarativeComponent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeComponent(QDeclarativeEngine*,QObject*)
    // 1: QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
    // 2: QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
    // 3: QDeclarativeComponent(QObject*)
    if (numArgs == 0) {
        overloadId = 3; // QDeclarativeComponent(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 3; // QDeclarativeComponent(QObject*)
    } else if (Shiboken::Converter<QDeclarativeEngine * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 1; // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
            }
        } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 2; // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
            }
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeComponent_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDeclarativeEngine* cpp_arg0 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QDeclarativeComponent(QDeclarativeEngine*,QObject*)
                cptr = new QDeclarativeComponentWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDeclarativeEngine* cpp_arg0 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QDeclarativeComponent(QDeclarativeEngine*,QString,QObject*)
                cptr = new QDeclarativeComponentWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
            case 2: // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDeclarativeEngine* cpp_arg0 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
                QUrl* cpp_arg1 = Shiboken::Converter<QUrl* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QDeclarativeComponent(QDeclarativeEngine*,QUrl,QObject*)
                cptr = new QDeclarativeComponentWrapper(cpp_arg0, *cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
            case 3: // QDeclarativeComponent(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QDeclarativeComponent(QObject*)
                cptr = new QDeclarativeComponentWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeComponent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDeclarativeComponent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQDeclarativeComponent_Init_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeEngine, PySide.QtCore.QObject = None", "PySide.QtDeclarative.QDeclarativeEngine, QString, PySide.QtCore.QObject = None", "PySide.QtDeclarative.QDeclarativeEngine, PySide.QtCore.QUrl, PySide.QtCore.QObject = None", "PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeComponent", overloads);
        return -1;
}

static PyObject* SbkQDeclarativeComponentFunc_beginCreate(PyObject* self, PyObject* arg)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginCreate(QDeclarativeContext*)
    if (Shiboken::Converter<QDeclarativeContext * >::isConvertible(arg)) {
        overloadId = 0; // beginCreate(QDeclarativeContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeComponentFunc_beginCreate_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDeclarativeContext* cpp_arg0 = Shiboken::Converter<QDeclarativeContext* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // beginCreate(QDeclarativeContext*)
            QObject * cppResult = cppSelf->QDeclarativeComponent::beginCreate(cpp_arg0);
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeComponentFunc_beginCreate_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeComponent.beginCreate", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeComponentFunc_completeCreate(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completeCreate()
            cppSelf->QDeclarativeComponent::completeCreate();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDeclarativeComponentFunc_create(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "context" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent.create(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent.create(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:create", &arg))
        return 0;


    // Overloaded function decisor
    // 0: create(QDeclarativeContext*)
    if (numArgs == 0) {
        overloadId = 0; // create(QDeclarativeContext*)
    } else if (Shiboken::Converter<QDeclarativeContext * >::isConvertible(arg)) {
        overloadId = 0; // create(QDeclarativeContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeComponentFunc_create_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "context");
                if (value) {
                    if (arg)
                        errorArgName = "context";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeComponent.create(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDeclarativeContext* cpp_arg0 = arg ? Shiboken::Converter<QDeclarativeContext* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // create(QDeclarativeContext*)
            QObject * cppResult = cppSelf->QDeclarativeComponent::create(cpp_arg0);
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeComponentFunc_create_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeComponent.create", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeComponentFunc_creationContext(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // creationContext()const
            QDeclarativeContext * cppResult = cppSelf->QDeclarativeComponent::creationContext();
            pyResult = Shiboken::Converter<QDeclarativeContext * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_errorString(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QDeclarativeComponent::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_errors(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errors()const
            QList<QDeclarativeError > cppResult = cppSelf->QDeclarativeComponent::errors();
            pyResult = Shiboken::Converter<QList<QDeclarativeError > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_isError(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isError()const
            bool cppResult = cppSelf->QDeclarativeComponent::isError();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_isLoading(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isLoading()const
            bool cppResult = cppSelf->QDeclarativeComponent::isLoading();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_isNull(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QDeclarativeComponent::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_isReady(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isReady()const
            bool cppResult = cppSelf->QDeclarativeComponent::isReady();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_loadUrl(PyObject* self, PyObject* arg)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: loadUrl(QUrl)
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // loadUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeComponentFunc_loadUrl_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // loadUrl(QUrl)
            cppSelf->QDeclarativeComponent::loadUrl(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeComponentFunc_loadUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeComponent.loadUrl", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeComponentFunc_progress(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // progress()const
            qreal cppResult = cppSelf->QDeclarativeComponent::progress();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_setData(PyObject* self, PyObject* args)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setData(QByteArray,QUrl)
    if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setData(QByteArray,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeComponentFunc_setData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
            QUrl* cpp_arg1 = Shiboken::Converter<QUrl* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setData(QByteArray,QUrl)
            cppSelf->QDeclarativeComponent::setData(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeComponentFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeComponent.setData", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeComponentFunc_status(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // status()const
            QDeclarativeComponent::Status cppResult = cppSelf->QDeclarativeComponent::status();
            pyResult = Shiboken::Converter<QDeclarativeComponent::Status >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeComponentFunc_url(PyObject* self)
{
    QDeclarativeComponent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeComponent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = cppSelf->QDeclarativeComponent::url();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDeclarativeComponent_methods[] = {
    {"beginCreate", (PyCFunction)SbkQDeclarativeComponentFunc_beginCreate, METH_O},
    {"completeCreate", (PyCFunction)SbkQDeclarativeComponentFunc_completeCreate, METH_NOARGS},
    {"create", (PyCFunction)SbkQDeclarativeComponentFunc_create, METH_VARARGS|METH_KEYWORDS},
    {"creationContext", (PyCFunction)SbkQDeclarativeComponentFunc_creationContext, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQDeclarativeComponentFunc_errorString, METH_NOARGS},
    {"errors", (PyCFunction)SbkQDeclarativeComponentFunc_errors, METH_NOARGS},
    {"isError", (PyCFunction)SbkQDeclarativeComponentFunc_isError, METH_NOARGS},
    {"isLoading", (PyCFunction)SbkQDeclarativeComponentFunc_isLoading, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQDeclarativeComponentFunc_isNull, METH_NOARGS},
    {"isReady", (PyCFunction)SbkQDeclarativeComponentFunc_isReady, METH_NOARGS},
    {"loadUrl", (PyCFunction)SbkQDeclarativeComponentFunc_loadUrl, METH_O},
    {"progress", (PyCFunction)SbkQDeclarativeComponentFunc_progress, METH_NOARGS},
    {"setData", (PyCFunction)SbkQDeclarativeComponentFunc_setData, METH_VARARGS},
    {"status", (PyCFunction)SbkQDeclarativeComponentFunc_status, METH_NOARGS},
    {"url", (PyCFunction)SbkQDeclarativeComponentFunc_url, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeComponent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeComponent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeComponent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeComponent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeComponent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeComponent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQDeclarativeComponent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDeclarativeComponent*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQDeclarativeComponent_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtDeclarative_QDeclarativeComponent_Status_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtDeclarative_QDeclarativeComponent_Status_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Status",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtDeclarative_QDeclarativeComponent_Status_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtDeclarative_QDeclarativeComponent_Status_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtDeclarative_QDeclarativeComponent_Status_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDeclarativeComponent(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVECOMPONENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeComponent_Type);

    SbkQDeclarativeComponent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQDeclarativeComponent_Type.type_discovery = &SbkQDeclarativeComponent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQDeclarativeComponent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeComponent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeComponent_Type));
    PyModule_AddObject(module, "QDeclarativeComponent",
        ((PyObject*)&SbkQDeclarativeComponent_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Status
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVECOMPONENT_STATUS_IDX] = &SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type);
    PyDict_SetItemString(SbkQDeclarativeComponent_Type.super.ht_type.tp_dict,
            "Status",((PyObject*)&SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type,
        (long) QDeclarativeComponent::Null, "Null");
    PyDict_SetItemString(SbkQDeclarativeComponent_Type.super.ht_type.tp_dict,
        "Null", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type.tp_dict,
        "Null", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type,
        (long) QDeclarativeComponent::Ready, "Ready");
    PyDict_SetItemString(SbkQDeclarativeComponent_Type.super.ht_type.tp_dict,
        "Ready", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type.tp_dict,
        "Ready", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type,
        (long) QDeclarativeComponent::Loading, "Loading");
    PyDict_SetItemString(SbkQDeclarativeComponent_Type.super.ht_type.tp_dict,
        "Loading", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type.tp_dict,
        "Loading", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type,
        (long) QDeclarativeComponent::Error, "Error");
    PyDict_SetItemString(SbkQDeclarativeComponent_Type.super.ht_type.tp_dict,
        "Error", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeComponent_Status_Type.tp_dict,
        "Error", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeComponent::Status");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("progressChanged", "qreal", NULL);
    PyDict_SetItemString(SbkQDeclarativeComponent_Type.super.ht_type.tp_dict, "progressChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("statusChanged", "QDeclarativeComponent::Status", NULL);
    PyDict_SetItemString(SbkQDeclarativeComponent_Type.super.ht_type.tp_dict, "statusChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeComponent >("QDeclarativeComponent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeComponent >(typeid(QDeclarativeComponent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeComponent >(typeid(QDeclarativeComponentWrapper).name());
    PySide::initQtMetaType<QDeclarativeComponent* >();
}

