/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeengine_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeclarativecontext.h>
#include <qdeclarativeengine.h>
#include <qdeclarativeerror.h>
#include <qdeclarativeimageprovider.h>
#include <qdeclarativenetworkaccessmanagerfactory.h>
#include <qnetworkaccessmanager.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDeclarativeEngineWrapper::QDeclarativeEngineWrapper(QObject * p) : QDeclarativeEngine(p), m_metaObject(0) {
    // ... middle
}

void QDeclarativeEngineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeEngineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeEngineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeEngineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QDeclarativeEngineWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeEngine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QDeclarativeEngineWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeEngine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QDeclarativeEngineWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QDeclarativeEngineWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QDeclarativeEngine::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QDeclarativeEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDeclarativeEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDeclarativeEngineWrapper::~QDeclarativeEngineWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeEngine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeEngine >()))
        return -1;

    QDeclarativeEngineWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "p" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QDeclarativeEngine", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeEngine(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeEngine(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QDeclarativeEngine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngine_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "p");
                if (value) {
                    if (arg)
                        errorArgName = "p";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeEngine(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QDeclarativeEngine(QObject*)
            cptr = new QDeclarativeEngineWrapper(cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDeclarativeEngine_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQDeclarativeEngine_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine", overloads);
        return -1;
}

static PyObject* SbkQDeclarativeEngineFunc_addImageProvider(PyObject* self, PyObject* args)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addImageProvider", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addImageProvider(QString,QDeclarativeImageProvider*)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QDeclarativeImageProvider * >::isConvertible(pyargs[1])) {
        overloadId = 0; // addImageProvider(QString,QDeclarativeImageProvider*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_addImageProvider_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDeclarativeImageProvider* cpp_arg1 = Shiboken::Converter<QDeclarativeImageProvider* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // addImageProvider(QString,QDeclarativeImageProvider*)
            cppSelf->QDeclarativeEngine::addImageProvider(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_addImageProvider_TypeError:
        const char* overloads[] = {"QString, PySide.QtDeclarative.QDeclarativeImageProvider", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.addImageProvider", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_addImportPath(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addImportPath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // addImportPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_addImportPath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addImportPath(QString)
            cppSelf->QDeclarativeEngine::addImportPath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_addImportPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.addImportPath", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_addPluginPath(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPluginPath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // addPluginPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_addPluginPath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addPluginPath(QString)
            cppSelf->QDeclarativeEngine::addPluginPath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_addPluginPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.addPluginPath", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_baseUrl(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // baseUrl()const
            QUrl cppResult = cppSelf->QDeclarativeEngine::baseUrl();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_clearComponentCache(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearComponentCache()
            cppSelf->QDeclarativeEngine::clearComponentCache();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDeclarativeEngineFunc_contextForObject(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextForObject(const QObject*)
    if (Shiboken::Converter<const QObject * >::isConvertible(arg)) {
        overloadId = 0; // contextForObject(const QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_contextForObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contextForObject(const QObject*)
            QDeclarativeContext * cppResult = QDeclarativeEngine::contextForObject(cpp_arg0);
            pyResult = Shiboken::Converter<QDeclarativeContext * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeEngineFunc_contextForObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.contextForObject", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_imageProvider(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: imageProvider(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // imageProvider(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_imageProvider_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // imageProvider(QString)const
            QDeclarativeImageProvider * cppResult = cppSelf->QDeclarativeEngine::imageProvider(cpp_arg0);
            pyResult = Shiboken::Converter<QDeclarativeImageProvider * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeEngineFunc_imageProvider_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.imageProvider", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_importPathList(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // importPathList()const
            QStringList cppResult = cppSelf->QDeclarativeEngine::importPathList();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_importPlugin(PyObject* self, PyObject* args)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "importPlugin", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: importPlugin(QString,QString,QString*)
    if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString * >::isConvertible(pyargs[2])) {
        overloadId = 0; // importPlugin(QString,QString,QString*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_importPlugin_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString * cpp_arg2 = Shiboken::Converter<QString * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // importPlugin(QString,QString,QString*)
            bool cppResult = cppSelf->QDeclarativeEngine::importPlugin(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeEngineFunc_importPlugin_TypeError:
        const char* overloads[] = {"QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.importPlugin", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_networkAccessManager(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // networkAccessManager()const
            QNetworkAccessManager * cppResult = cppSelf->QDeclarativeEngine::networkAccessManager();
            pyResult = Shiboken::Converter<QNetworkAccessManager * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_networkAccessManagerFactory(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // networkAccessManagerFactory()const
            QDeclarativeNetworkAccessManagerFactory * cppResult = cppSelf->QDeclarativeEngine::networkAccessManagerFactory();
            pyResult = Shiboken::Converter<QDeclarativeNetworkAccessManagerFactory * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_objectOwnership(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectOwnership(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // objectOwnership(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_objectOwnership_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // objectOwnership(QObject*)
            QDeclarativeEngine::ObjectOwnership cppResult = QDeclarativeEngine::objectOwnership(cpp_arg0);
            pyResult = Shiboken::Converter<QDeclarativeEngine::ObjectOwnership >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeEngineFunc_objectOwnership_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.objectOwnership", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_offlineStoragePath(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // offlineStoragePath()const
            QString cppResult = cppSelf->QDeclarativeEngine::offlineStoragePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_outputWarningsToStandardError(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // outputWarningsToStandardError()const
            bool cppResult = cppSelf->QDeclarativeEngine::outputWarningsToStandardError();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_pluginPathList(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pluginPathList()const
            QStringList cppResult = cppSelf->QDeclarativeEngine::pluginPathList();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_removeImageProvider(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeImageProvider(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeImageProvider(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_removeImageProvider_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeImageProvider(QString)
            cppSelf->QDeclarativeEngine::removeImageProvider(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_removeImageProvider_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.removeImageProvider", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_rootContext(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rootContext()const
            QDeclarativeContext * cppResult = cppSelf->QDeclarativeEngine::rootContext();
            pyResult = Shiboken::Converter<QDeclarativeContext * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeEngineFunc_setBaseUrl(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBaseUrl(QUrl)
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // setBaseUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setBaseUrl_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBaseUrl(QUrl)
            cppSelf->QDeclarativeEngine::setBaseUrl(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setBaseUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setBaseUrl", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_setContextForObject(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setContextForObject", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setContextForObject(QObject*,QDeclarativeContext*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QDeclarativeContext * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setContextForObject(QObject*,QDeclarativeContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setContextForObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDeclarativeContext* cpp_arg1 = Shiboken::Converter<QDeclarativeContext* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setContextForObject(QObject*,QDeclarativeContext*)
            QDeclarativeEngine::setContextForObject(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setContextForObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeContext", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.setContextForObject", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_setImportPathList(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setImportPathList(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setImportPathList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setImportPathList_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setImportPathList(QStringList)
            cppSelf->QDeclarativeEngine::setImportPathList(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setImportPathList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setImportPathList", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_setNetworkAccessManagerFactory(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNetworkAccessManagerFactory(QDeclarativeNetworkAccessManagerFactory*)
    if (Shiboken::Converter<QDeclarativeNetworkAccessManagerFactory * >::isConvertible(arg)) {
        overloadId = 0; // setNetworkAccessManagerFactory(QDeclarativeNetworkAccessManagerFactory*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setNetworkAccessManagerFactory_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDeclarativeNetworkAccessManagerFactory* cpp_arg0 = Shiboken::Converter<QDeclarativeNetworkAccessManagerFactory* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNetworkAccessManagerFactory(QDeclarativeNetworkAccessManagerFactory*)
            cppSelf->QDeclarativeEngine::setNetworkAccessManagerFactory(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setNetworkAccessManagerFactory_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeNetworkAccessManagerFactory", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setNetworkAccessManagerFactory", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_setObjectOwnership(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setObjectOwnership", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setObjectOwnership(QObject*,QDeclarativeEngine::ObjectOwnership)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QDeclarativeEngine::ObjectOwnership >::isConvertible(pyargs[1])) {
        overloadId = 0; // setObjectOwnership(QObject*,QDeclarativeEngine::ObjectOwnership)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setObjectOwnership_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            QDeclarativeEngine::ObjectOwnership cpp_arg1 = Shiboken::Converter<QDeclarativeEngine::ObjectOwnership >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setObjectOwnership(QObject*,QDeclarativeEngine::ObjectOwnership)
            QDeclarativeEngine::setObjectOwnership(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setObjectOwnership_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeEngine.ObjectOwnership", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.setObjectOwnership", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_setOfflineStoragePath(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineStoragePath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setOfflineStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setOfflineStoragePath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOfflineStoragePath(QString)
            cppSelf->QDeclarativeEngine::setOfflineStoragePath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setOfflineStoragePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setOfflineStoragePath", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_setOutputWarningsToStandardError(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOutputWarningsToStandardError(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOutputWarningsToStandardError(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setOutputWarningsToStandardError_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOutputWarningsToStandardError(bool)
            cppSelf->QDeclarativeEngine::setOutputWarningsToStandardError(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setOutputWarningsToStandardError_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setOutputWarningsToStandardError", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeEngineFunc_setPluginPathList(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPluginPathList(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setPluginPathList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeEngineFunc_setPluginPathList_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPluginPathList(QStringList)
            cppSelf->QDeclarativeEngine::setPluginPathList(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeEngineFunc_setPluginPathList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setPluginPathList", overloads);
        return 0;
}

static PyMethodDef SbkQDeclarativeEngine_methods[] = {
    {"addImageProvider", (PyCFunction)SbkQDeclarativeEngineFunc_addImageProvider, METH_VARARGS},
    {"addImportPath", (PyCFunction)SbkQDeclarativeEngineFunc_addImportPath, METH_O},
    {"addPluginPath", (PyCFunction)SbkQDeclarativeEngineFunc_addPluginPath, METH_O},
    {"baseUrl", (PyCFunction)SbkQDeclarativeEngineFunc_baseUrl, METH_NOARGS},
    {"clearComponentCache", (PyCFunction)SbkQDeclarativeEngineFunc_clearComponentCache, METH_NOARGS},
    {"contextForObject", (PyCFunction)SbkQDeclarativeEngineFunc_contextForObject, METH_O|METH_STATIC},
    {"imageProvider", (PyCFunction)SbkQDeclarativeEngineFunc_imageProvider, METH_O},
    {"importPathList", (PyCFunction)SbkQDeclarativeEngineFunc_importPathList, METH_NOARGS},
    {"importPlugin", (PyCFunction)SbkQDeclarativeEngineFunc_importPlugin, METH_VARARGS},
    {"networkAccessManager", (PyCFunction)SbkQDeclarativeEngineFunc_networkAccessManager, METH_NOARGS},
    {"networkAccessManagerFactory", (PyCFunction)SbkQDeclarativeEngineFunc_networkAccessManagerFactory, METH_NOARGS},
    {"objectOwnership", (PyCFunction)SbkQDeclarativeEngineFunc_objectOwnership, METH_O|METH_STATIC},
    {"offlineStoragePath", (PyCFunction)SbkQDeclarativeEngineFunc_offlineStoragePath, METH_NOARGS},
    {"outputWarningsToStandardError", (PyCFunction)SbkQDeclarativeEngineFunc_outputWarningsToStandardError, METH_NOARGS},
    {"pluginPathList", (PyCFunction)SbkQDeclarativeEngineFunc_pluginPathList, METH_NOARGS},
    {"removeImageProvider", (PyCFunction)SbkQDeclarativeEngineFunc_removeImageProvider, METH_O},
    {"rootContext", (PyCFunction)SbkQDeclarativeEngineFunc_rootContext, METH_NOARGS},
    {"setBaseUrl", (PyCFunction)SbkQDeclarativeEngineFunc_setBaseUrl, METH_O},
    {"setContextForObject", (PyCFunction)SbkQDeclarativeEngineFunc_setContextForObject, METH_VARARGS|METH_STATIC},
    {"setImportPathList", (PyCFunction)SbkQDeclarativeEngineFunc_setImportPathList, METH_O},
    {"setNetworkAccessManagerFactory", (PyCFunction)SbkQDeclarativeEngineFunc_setNetworkAccessManagerFactory, METH_O},
    {"setObjectOwnership", (PyCFunction)SbkQDeclarativeEngineFunc_setObjectOwnership, METH_VARARGS|METH_STATIC},
    {"setOfflineStoragePath", (PyCFunction)SbkQDeclarativeEngineFunc_setOfflineStoragePath, METH_O},
    {"setOutputWarningsToStandardError", (PyCFunction)SbkQDeclarativeEngineFunc_setOutputWarningsToStandardError, METH_O},
    {"setPluginPathList", (PyCFunction)SbkQDeclarativeEngineFunc_setPluginPathList, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeEngine_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeEngine",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeEngine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeEngine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeEngine >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeEngine*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQDeclarativeEngine_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDeclarativeEngine*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQDeclarativeEngine_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ObjectOwnership",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDeclarativeEngine(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEENGINE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeEngine_Type);

    SbkQDeclarativeEngine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQDeclarativeEngine_Type.type_discovery = &SbkQDeclarativeEngine_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQDeclarativeEngine_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeEngine_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeEngine_Type));
    PyModule_AddObject(module, "QDeclarativeEngine",
        ((PyObject*)&SbkQDeclarativeEngine_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ObjectOwnership
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEENGINE_OBJECTOWNERSHIP_IDX] = &SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type);
    PyDict_SetItemString(SbkQDeclarativeEngine_Type.super.ht_type.tp_dict,
            "ObjectOwnership",((PyObject*)&SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type,
        (long) QDeclarativeEngine::CppOwnership, "CppOwnership");
    PyDict_SetItemString(SbkQDeclarativeEngine_Type.super.ht_type.tp_dict,
        "CppOwnership", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type.tp_dict,
        "CppOwnership", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type,
        (long) QDeclarativeEngine::JavaScriptOwnership, "JavaScriptOwnership");
    PyDict_SetItemString(SbkQDeclarativeEngine_Type.super.ht_type.tp_dict,
        "JavaScriptOwnership", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership_Type.tp_dict,
        "JavaScriptOwnership", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeEngine::ObjectOwnership");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("warnings", "const QList<QDeclarativeError>&", NULL);
    PyDict_SetItemString(SbkQDeclarativeEngine_Type.super.ht_type.tp_dict, "warnings", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("quit", "void", NULL);
    PyDict_SetItemString(SbkQDeclarativeEngine_Type.super.ht_type.tp_dict, "quit", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeEngine >("QDeclarativeEngine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeEngine >(typeid(QDeclarativeEngine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeEngine >(typeid(QDeclarativeEngineWrapper).name());
    PySide::initQtMetaType<QDeclarativeEngine* >();
}

