/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeerror_wrapper.h"

// Extra includes
#include <qdeclarativeerror.h>
#include <qurl.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeError_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeError >()))
        return -1;

    QDeclarativeError* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDeclarativeError", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeError()
    // 1: QDeclarativeError(QDeclarativeError)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeError()
    } else if (numArgs == 1 && Shiboken::Converter<const QDeclarativeError & >::isConvertible(arg)) {
        overloadId = 1; // QDeclarativeError(QDeclarativeError)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeError_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeError()
            {

                if(!PyErr_Occurred()) {
                // QDeclarativeError()
                cptr = new QDeclarativeError();
                }
                break;
            }
            case 1: // QDeclarativeError(QDeclarativeError)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDeclarativeError* cpp_arg0 = Shiboken::Converter<QDeclarativeError* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDeclarativeError(QDeclarativeError)
                cptr = new QDeclarativeError(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDeclarativeError_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDeclarativeError_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtDeclarative.QDeclarativeError", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeError", overloads);
        return -1;
}

static PyObject* SbkQDeclarativeErrorFunc_column(PyObject* self)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // column()const
            int cppResult = cppSelf->QDeclarativeError::column();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeErrorFunc_description(PyObject* self)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // description()const
            QString cppResult = cppSelf->QDeclarativeError::description();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeErrorFunc_isValid(PyObject* self)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QDeclarativeError::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeErrorFunc_line(PyObject* self)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // line()const
            int cppResult = cppSelf->QDeclarativeError::line();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeErrorFunc_setColumn(PyObject* self, PyObject* arg)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeErrorFunc_setColumn_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setColumn(int)
            cppSelf->QDeclarativeError::setColumn(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeErrorFunc_setColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeError.setColumn", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeErrorFunc_setDescription(PyObject* self, PyObject* arg)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDescription(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeErrorFunc_setDescription_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDescription(QString)
            cppSelf->QDeclarativeError::setDescription(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeErrorFunc_setDescription_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeError.setDescription", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeErrorFunc_setLine(PyObject* self, PyObject* arg)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLine(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLine(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeErrorFunc_setLine_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLine(int)
            cppSelf->QDeclarativeError::setLine(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeErrorFunc_setLine_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeError.setLine", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeErrorFunc_setUrl(PyObject* self, PyObject* arg)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUrl(QUrl)
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeErrorFunc_setUrl_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setUrl(QUrl)
            cppSelf->QDeclarativeError::setUrl(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeErrorFunc_setUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeError.setUrl", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeErrorFunc_toString(PyObject* self)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toString()const
            QString cppResult = cppSelf->QDeclarativeError::toString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeErrorFunc_url(PyObject* self)
{
    QDeclarativeError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = cppSelf->QDeclarativeError::url();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDeclarativeError_methods[] = {
    {"column", (PyCFunction)SbkQDeclarativeErrorFunc_column, METH_NOARGS},
    {"description", (PyCFunction)SbkQDeclarativeErrorFunc_description, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQDeclarativeErrorFunc_isValid, METH_NOARGS},
    {"line", (PyCFunction)SbkQDeclarativeErrorFunc_line, METH_NOARGS},
    {"setColumn", (PyCFunction)SbkQDeclarativeErrorFunc_setColumn, METH_O},
    {"setDescription", (PyCFunction)SbkQDeclarativeErrorFunc_setDescription, METH_O},
    {"setLine", (PyCFunction)SbkQDeclarativeErrorFunc_setLine, METH_O},
    {"setUrl", (PyCFunction)SbkQDeclarativeErrorFunc_setUrl, METH_O},
    {"toString", (PyCFunction)SbkQDeclarativeErrorFunc_toString, METH_NOARGS},
    {"url", (PyCFunction)SbkQDeclarativeErrorFunc_url, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeError_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeError",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeError_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeError_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeError >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeError",
    /*user_data*/           0
};
} //extern


void init_QDeclarativeError(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEERROR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeError_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeError_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeError_Type));
    PyModule_AddObject(module, "QDeclarativeError",
        ((PyObject*)&SbkQDeclarativeError_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeError >("QDeclarativeError");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeError >("QDeclarativeError*");
    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeError >(typeid(QDeclarativeError).name());
    PySide::initQtMetaType<QDeclarativeError >();
}

