/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeextensioninterface_wrapper.h"

// Extra includes
#include <qdeclarativeengine.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDeclarativeExtensionInterfaceWrapper::QDeclarativeExtensionInterfaceWrapper() : QDeclarativeExtensionInterface() {
    // ... middle
}

void QDeclarativeExtensionInterfaceWrapper::initializeEngine(QDeclarativeEngine * engine, const char * uri)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "initializeEngine"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeExtensionInterface.initializeEngine()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QDeclarativeEngine * >::toPython(engine),
        Shiboken::Converter<const char * >::toPython(uri)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeExtensionInterfaceWrapper::registerTypes(const char * uri)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "registerTypes"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeExtensionInterface.registerTypes()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(uri)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QDeclarativeExtensionInterfaceWrapper::~QDeclarativeExtensionInterfaceWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeExtensionInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeExtensionInterface >()))
        return -1;

    QDeclarativeExtensionInterfaceWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QDeclarativeExtensionInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QDeclarativeExtensionInterface()
            cptr = new QDeclarativeExtensionInterfaceWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeExtensionInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQDeclarativeExtensionInterfaceFunc_initializeEngine(PyObject* self, PyObject* args)
{
    QDeclarativeExtensionInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeExtensionInterface* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "initializeEngine", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: initializeEngine(QDeclarativeEngine*,const char*)
    if (numArgs == 2 && Shiboken::Converter<QDeclarativeEngine * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        overloadId = 0; // initializeEngine(QDeclarativeEngine*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeExtensionInterfaceFunc_initializeEngine_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QDeclarativeEngine* cpp_arg0 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // initializeEngine(QDeclarativeEngine*,const char*)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeExtensionInterface.initializeEngine()' not implemented.");
                return 0;
            }
            cppSelf->initializeEngine(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeExtensionInterfaceFunc_initializeEngine_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeEngine, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeExtensionInterface.initializeEngine", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeExtensionInterfaceFunc_registerTypes(PyObject* self, PyObject* arg)
{
    QDeclarativeExtensionInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeExtensionInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: registerTypes(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // registerTypes(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeExtensionInterfaceFunc_registerTypes_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // registerTypes(const char*)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativeExtensionInterface.registerTypes()' not implemented.");
                return 0;
            }
            cppSelf->registerTypes(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeExtensionInterfaceFunc_registerTypes_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeExtensionInterface.registerTypes", overloads);
        return 0;
}

static PyMethodDef SbkQDeclarativeExtensionInterface_methods[] = {
    {"initializeEngine", (PyCFunction)SbkQDeclarativeExtensionInterfaceFunc_initializeEngine, METH_VARARGS},
    {"registerTypes", (PyCFunction)SbkQDeclarativeExtensionInterfaceFunc_registerTypes, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeExtensionInterface_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeExtensionInterface",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeExtensionInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeExtensionInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeExtensionInterface >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeExtensionInterface*",
    /*user_data*/           0
};
} //extern


void init_QDeclarativeExtensionInterface(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEEXTENSIONINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeExtensionInterface_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeExtensionInterface_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeExtensionInterface_Type));
    PyModule_AddObject(module, "QDeclarativeExtensionInterface",
        ((PyObject*)&SbkQDeclarativeExtensionInterface_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeExtensionInterface >("QDeclarativeExtensionInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeExtensionInterface >(typeid(QDeclarativeExtensionInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeExtensionInterface >(typeid(QDeclarativeExtensionInterfaceWrapper).name());
    PySide::initQtMetaType<QDeclarativeExtensionInterface* >();
}

