/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeitem_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qdeclarativeitem.h>
#include <qevent.h>
#include <qgraphicseffect.h>
#include <qgraphicsitem.h>
#include <qgraphicsscene.h>
#include <qgraphicssceneevent.h>
#include <qgraphicstransform.h>
#include <qgraphicswidget.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qstyleoption.h>
#include <qthread.h>
#include <qtransform.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDeclarativeItemWrapper::QDeclarativeItemWrapper(QDeclarativeItem * parent) : QDeclarativeItem(parent), m_metaObject(0) {
    // ... middle
}

void QDeclarativeItemWrapper::advance(int phase)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "advance"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::advance(phase);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        phase
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QRectF QDeclarativeItemWrapper::boundingRect() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "boundingRect"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::boundingRect();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRectF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRectF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.boundingRect", SbkType<QRectF >()->tp_name, pyResult->ob_type->tp_name);
        return QRectF();
    }
    QRectF cppResult(Shiboken::Converter<QRectF >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::classBegin()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "classBegin"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::classBegin();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QDeclarativeItemWrapper::collidesWithItem(const QGraphicsItem * other, Qt::ItemSelectionMode mode) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "collidesWithItem"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::collidesWithItem(other, mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QGraphicsItem * >::toPython(other),
        Shiboken::Converter<Qt::ItemSelectionMode >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.collidesWithItem", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QDeclarativeItemWrapper::collidesWithPath(const QPainterPath & path, Qt::ItemSelectionMode mode) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "collidesWithPath"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::collidesWithPath(path, mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QPainterPath & >::toPython(path),
        Shiboken::Converter<Qt::ItemSelectionMode >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.collidesWithPath", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::componentComplete()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "componentComplete"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::componentComplete();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QDeclarativeItemWrapper::contains(const QPointF & point) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contains"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::contains(point);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QPointF & >::toPython(point)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.contains", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::contextMenuEvent(QGraphicsSceneContextMenuEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneContextMenuEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::dragEnterEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::dragLeaveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::dragMoveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::dropEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QDeclarativeItemWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QDeclarativeItemWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QVariant QDeclarativeItemWrapper::extension(const QVariant & variant) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "extension"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::extension(variant);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QVariant >::toPython(variant)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.extension", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::geometryChanged(const QRectF & newGeometry, const QRectF & oldGeometry)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "geometryChanged"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::geometryChanged(newGeometry, oldGeometry);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QRectF & >::toPython(newGeometry),
        Shiboken::Converter<const QRectF & >::toPython(oldGeometry)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::hoverEnterEvent(QGraphicsSceneHoverEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hoverEnterEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::hoverEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneHoverEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::hoverLeaveEvent(QGraphicsSceneHoverEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hoverLeaveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::hoverLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneHoverEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::hoverMoveEvent(QGraphicsSceneHoverEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hoverMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::hoverMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneHoverEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QVariant QDeclarativeItemWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

bool QDeclarativeItemWrapper::isObscuredBy(const QGraphicsItem * item) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isObscuredBy"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::isObscuredBy(item);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QGraphicsItem * >::toPython(item)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.isObscuredBy", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QVariant QDeclarativeItemWrapper::itemChange(QGraphicsItem::GraphicsItemChange arg__1, const QVariant & arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "itemChange"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::itemChange(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QGraphicsItem::GraphicsItemChange >::toPython(arg__1),
        Shiboken::Converter<QVariant >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.itemChange", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::mouseMoveEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::mousePressEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDeclarativeItemWrapper::mouseReleaseEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QPainterPath QDeclarativeItemWrapper::opaqueArea() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "opaqueArea"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::opaqueArea();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPainterPath();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPainterPath >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.opaqueArea", SbkType<QPainterPath >()->tp_name, pyResult->ob_type->tp_name);
        return QPainterPath();
    }
    QPainterPath cppResult(Shiboken::Converter<QPainterPath >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::paint(QPainter * arg__1, const QStyleOptionGraphicsItem * arg__2, QWidget * arg__3)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paint"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::paint(arg__1, arg__2, arg__3);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter<QPainter * >::toPython(arg__1),
        Shiboken::Converter<const QStyleOptionGraphicsItem * >::toPython(arg__2),
        Shiboken::Converter<QWidget * >::toPython(arg__3)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QDeclarativeItemWrapper::sceneEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sceneEvent"));
    if (py_override.isNull()) {
        return this->QDeclarativeItem::sceneEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.sceneEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QDeclarativeItemWrapper::sceneEventFilter(QGraphicsItem * watched, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sceneEventFilter"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::sceneEventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QGraphicsItem * >::toPython(watched),
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.sceneEventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QPainterPath QDeclarativeItemWrapper::shape() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "shape"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::shape();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPainterPath();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPainterPath >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.shape", SbkType<QPainterPath >()->tp_name, pyResult->ob_type->tp_name);
        return QPainterPath();
    }
    QPainterPath cppResult(Shiboken::Converter<QPainterPath >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QDeclarativeItemWrapper::type() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "type"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::type();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeItem.type", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QDeclarativeItemWrapper::wheelEvent(QGraphicsSceneWheelEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsItem::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneWheelEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

const QMetaObject* QDeclarativeItemWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QDeclarativeItem::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QDeclarativeItemWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDeclarativeItem::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDeclarativeItemWrapper::~QDeclarativeItemWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeItem >()))
        return -1;

    QDeclarativeItemWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEITEM_IDX]);
    if (type != myType) {
        type->mi_init = myType->mi_init;
        type->mi_offsets = myType->mi_offsets;
        type->mi_specialcast = myType->mi_specialcast;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QDeclarativeItem", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeItem(QDeclarativeItem*)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeItem(QDeclarativeItem*)
    } else if (Shiboken::Converter<QDeclarativeItem * >::isConvertible(arg)) {
        overloadId = 0; // QDeclarativeItem(QDeclarativeItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItem_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QDeclarativeItem* cpp_arg0 = arg ? Shiboken::Converter<QDeclarativeItem* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QDeclarativeItem(QDeclarativeItem*)
            cptr = new QDeclarativeItemWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDeclarativeItem_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQDeclarativeItem_Init_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeItem = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeItem", overloads);
        return -1;
}

static PyObject* SbkQDeclarativeItemFunc_baselineOffset(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // baselineOffset()const
            qreal cppResult = cppSelf->QDeclarativeItem::baselineOffset();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_boundingRect(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect()const
            QRectF cppResult = cppSelf->QDeclarativeItem::boundingRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_childAt(PyObject* self, PyObject* args)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "childAt", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: childAt(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // childAt(qreal,qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_childAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // childAt(qreal,qreal)const
            QDeclarativeItem * cppResult = cppSelf->QDeclarativeItem::childAt(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDeclarativeItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeItemFunc_childAt_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeItem.childAt", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_childrenRect(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childrenRect()
            QRectF cppResult = cppSelf->QDeclarativeItem::childrenRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_classBegin(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // classBegin()
            cppSelf->QDeclarativeItem::classBegin();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDeclarativeItemFunc_clip(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clip()const
            bool cppResult = cppSelf->QDeclarativeItem::clip();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_componentComplete(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // componentComplete()
            cppSelf->QDeclarativeItem::componentComplete();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDeclarativeItemFunc_event(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QDeclarativeItem::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeItemFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.event", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_forceActiveFocus(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // forceActiveFocus()
            cppSelf->QDeclarativeItem::forceActiveFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDeclarativeItemFunc_geometryChanged(PyObject* self, PyObject* args)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "geometryChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: geometryChanged(QRectF,QRectF)
    if (numArgs == 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // geometryChanged(QRectF,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_geometryChanged_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // geometryChanged(QRectF,QRectF)
            cppSelf->QDeclarativeItem::geometryChanged(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_geometryChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeItem.geometryChanged", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_hasActiveFocus(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasActiveFocus()const
            bool cppResult = cppSelf->QDeclarativeItem::hasActiveFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_hasFocus(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasFocus()const
            bool cppResult = cppSelf->QDeclarativeItem::hasFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_height(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            qreal cppResult = cppSelf->QDeclarativeItem::height();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_heightValid(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // heightValid()const
            bool cppResult = cppSelf->QDeclarativeItem::heightValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_implicitHeight(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // implicitHeight()const
            qreal cppResult = cppSelf->QDeclarativeItem::implicitHeight();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_implicitWidth(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // implicitWidth()const
            qreal cppResult = cppSelf->QDeclarativeItem::implicitWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            cppSelf->QDeclarativeItem::inputMethodEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.inputMethodEvent", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_inputMethodPreHandler(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodPreHandler(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodPreHandler(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_inputMethodPreHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodPreHandler(QInputMethodEvent*)
            cppSelf->QDeclarativeItem::inputMethodPreHandler(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_inputMethodPreHandler_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.inputMethodPreHandler", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter<Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cpp_arg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = cppSelf->QDeclarativeItem::inputMethodQuery(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeItemFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.inputMethodQuery", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_isComponentComplete(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isComponentComplete()const
            bool cppResult = cppSelf->QDeclarativeItem::isComponentComplete();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_itemChange(PyObject* self, PyObject* args)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemChange", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QGraphicsItem::GraphicsItemChange >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_itemChange_TypeError;

    // Call function/method
    {
        {
            QGraphicsItem::GraphicsItemChange cpp_arg0 = Shiboken::Converter<QGraphicsItem::GraphicsItemChange >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // itemChange(QGraphicsItem::GraphicsItemChange,QVariant)
            QVariant cppResult = cppSelf->QDeclarativeItem::itemChange(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeItemFunc_itemChange_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem.GraphicsItemChange, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeItem.itemChange", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_keepMouseGrab(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keepMouseGrab()const
            bool cppResult = cppSelf->QDeclarativeItem::keepMouseGrab();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QDeclarativeItem::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_keyPressPreHandler(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressPreHandler(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressPreHandler(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_keyPressPreHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressPreHandler(QKeyEvent*)
            cppSelf->QDeclarativeItem::keyPressPreHandler(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_keyPressPreHandler_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.keyPressPreHandler", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyReleaseEvent(QKeyEvent*)
            cppSelf->QDeclarativeItem::keyReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_keyReleasePreHandler(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleasePreHandler(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleasePreHandler(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_keyReleasePreHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyReleasePreHandler(QKeyEvent*)
            cppSelf->QDeclarativeItem::keyReleasePreHandler(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_keyReleasePreHandler_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.keyReleasePreHandler", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_paint(PyObject* self, PyObject* args)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "paint", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
    if (numArgs == 3 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QStyleOptionGraphicsItem * >::isConvertible(pyargs[1]) && Shiboken::Converter<QWidget * >::isConvertible(pyargs[2])) {
        overloadId = 0; // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_paint_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QStyleOptionGraphicsItem* cpp_arg1 = Shiboken::Converter<QStyleOptionGraphicsItem* >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QWidget* cpp_arg2 = Shiboken::Converter<QWidget* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // paint(QPainter*,const QStyleOptionGraphicsItem*,QWidget*)
            cppSelf->QDeclarativeItem::paint(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_paint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtGui.QStyleOptionGraphicsItem, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeItem.paint", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_parentItem(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentItem()const
            QDeclarativeItem * cppResult = cppSelf->QDeclarativeItem::parentItem();
            pyResult = Shiboken::Converter<QDeclarativeItem * >::toPython(cppResult);
            Shiboken::setParent(pyResult, self);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_resetHeight(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetHeight()
            cppSelf->QDeclarativeItem::resetHeight();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDeclarativeItemFunc_resetWidth(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetWidth()
            cppSelf->QDeclarativeItem::resetWidth();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDeclarativeItemFunc_sceneEvent(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sceneEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // sceneEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_sceneEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // sceneEvent(QEvent*)
            bool cppResult = cppSelf->QDeclarativeItem::sceneEvent(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeItemFunc_sceneEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.sceneEvent", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setBaselineOffset(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBaselineOffset(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBaselineOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setBaselineOffset_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBaselineOffset(qreal)
            cppSelf->QDeclarativeItem::setBaselineOffset(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setBaselineOffset_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setBaselineOffset", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setClip(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setClip(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setClip(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setClip_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setClip(bool)
            cppSelf->QDeclarativeItem::setClip(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setClip_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setClip", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setFocus(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocus(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFocus(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setFocus_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFocus(bool)
            cppSelf->QDeclarativeItem::setFocus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setFocus_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setFocus", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setHeight(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setHeight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHeight(qreal)
            cppSelf->QDeclarativeItem::setHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setHeight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setHeight", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setImplicitHeight(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setImplicitHeight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setImplicitHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setImplicitHeight_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setImplicitHeight(qreal)
            cppSelf->QDeclarativeItem::setImplicitHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setImplicitHeight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setImplicitHeight", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setImplicitWidth(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setImplicitWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setImplicitWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setImplicitWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setImplicitWidth(qreal)
            cppSelf->QDeclarativeItem::setImplicitWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setImplicitWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setImplicitWidth", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setKeepMouseGrab(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKeepMouseGrab(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setKeepMouseGrab(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setKeepMouseGrab_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setKeepMouseGrab(bool)
            cppSelf->QDeclarativeItem::setKeepMouseGrab(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setKeepMouseGrab_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setKeepMouseGrab", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setParentItem(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setParentItem(QDeclarativeItem*)
    if (Shiboken::Converter<QDeclarativeItem * >::isConvertible(arg)) {
        overloadId = 0; // setParentItem(QDeclarativeItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setParentItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDeclarativeItem* cpp_arg0 = Shiboken::Converter<QDeclarativeItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setParentItem(QDeclarativeItem*)
            cppSelf->QDeclarativeItem::setParentItem(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setParentItem_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setParentItem", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setSize(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSize(QSizeF)
    if (Shiboken::Converter<const QSizeF & >::isConvertible(arg)) {
        overloadId = 0; // setSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
            QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(arg);
            if (!Shiboken::Converter<QSizeF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setSize(QSizeF)
            cppSelf->QDeclarativeItem::setSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setSize", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setSmooth(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSmooth(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSmooth(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setSmooth_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSmooth(bool)
            cppSelf->QDeclarativeItem::setSmooth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setSmooth_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setSmooth", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setTransformOrigin(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransformOrigin(QDeclarativeItem::TransformOrigin)
    if (Shiboken::Converter<QDeclarativeItem::TransformOrigin >::isConvertible(arg)) {
        overloadId = 0; // setTransformOrigin(QDeclarativeItem::TransformOrigin)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setTransformOrigin_TypeError;

    // Call function/method
    {
        {
            QDeclarativeItem::TransformOrigin cpp_arg0 = Shiboken::Converter<QDeclarativeItem::TransformOrigin >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTransformOrigin(QDeclarativeItem::TransformOrigin)
            cppSelf->QDeclarativeItem::setTransformOrigin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setTransformOrigin_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeItem.TransformOrigin", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setTransformOrigin", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_setWidth(PyObject* self, PyObject* arg)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeItemFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidth(qreal)
            cppSelf->QDeclarativeItem::setWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeItemFunc_setWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeItem.setWidth", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeItemFunc_smooth(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // smooth()const
            bool cppResult = cppSelf->QDeclarativeItem::smooth();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_transformOrigin(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transformOrigin()const
            QDeclarativeItem::TransformOrigin cppResult = cppSelf->QDeclarativeItem::transformOrigin();
            pyResult = Shiboken::Converter<QDeclarativeItem::TransformOrigin >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_width(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            qreal cppResult = cppSelf->QDeclarativeItem::width();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeItemFunc_widthValid(PyObject* self)
{
    QDeclarativeItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // widthValid()const
            bool cppResult = cppSelf->QDeclarativeItem::widthValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDeclarativeItem_methods[] = {
    {"baselineOffset", (PyCFunction)SbkQDeclarativeItemFunc_baselineOffset, METH_NOARGS},
    {"boundingRect", (PyCFunction)SbkQDeclarativeItemFunc_boundingRect, METH_NOARGS},
    {"childAt", (PyCFunction)SbkQDeclarativeItemFunc_childAt, METH_VARARGS},
    {"childrenRect", (PyCFunction)SbkQDeclarativeItemFunc_childrenRect, METH_NOARGS},
    {"classBegin", (PyCFunction)SbkQDeclarativeItemFunc_classBegin, METH_NOARGS},
    {"clip", (PyCFunction)SbkQDeclarativeItemFunc_clip, METH_NOARGS},
    {"componentComplete", (PyCFunction)SbkQDeclarativeItemFunc_componentComplete, METH_NOARGS},
    {"event", (PyCFunction)SbkQDeclarativeItemFunc_event, METH_O},
    {"forceActiveFocus", (PyCFunction)SbkQDeclarativeItemFunc_forceActiveFocus, METH_NOARGS},
    {"geometryChanged", (PyCFunction)SbkQDeclarativeItemFunc_geometryChanged, METH_VARARGS},
    {"hasActiveFocus", (PyCFunction)SbkQDeclarativeItemFunc_hasActiveFocus, METH_NOARGS},
    {"hasFocus", (PyCFunction)SbkQDeclarativeItemFunc_hasFocus, METH_NOARGS},
    {"height", (PyCFunction)SbkQDeclarativeItemFunc_height, METH_NOARGS},
    {"heightValid", (PyCFunction)SbkQDeclarativeItemFunc_heightValid, METH_NOARGS},
    {"implicitHeight", (PyCFunction)SbkQDeclarativeItemFunc_implicitHeight, METH_NOARGS},
    {"implicitWidth", (PyCFunction)SbkQDeclarativeItemFunc_implicitWidth, METH_NOARGS},
    {"inputMethodEvent", (PyCFunction)SbkQDeclarativeItemFunc_inputMethodEvent, METH_O},
    {"inputMethodPreHandler", (PyCFunction)SbkQDeclarativeItemFunc_inputMethodPreHandler, METH_O},
    {"inputMethodQuery", (PyCFunction)SbkQDeclarativeItemFunc_inputMethodQuery, METH_O},
    {"isComponentComplete", (PyCFunction)SbkQDeclarativeItemFunc_isComponentComplete, METH_NOARGS},
    {"itemChange", (PyCFunction)SbkQDeclarativeItemFunc_itemChange, METH_VARARGS},
    {"keepMouseGrab", (PyCFunction)SbkQDeclarativeItemFunc_keepMouseGrab, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)SbkQDeclarativeItemFunc_keyPressEvent, METH_O},
    {"keyPressPreHandler", (PyCFunction)SbkQDeclarativeItemFunc_keyPressPreHandler, METH_O},
    {"keyReleaseEvent", (PyCFunction)SbkQDeclarativeItemFunc_keyReleaseEvent, METH_O},
    {"keyReleasePreHandler", (PyCFunction)SbkQDeclarativeItemFunc_keyReleasePreHandler, METH_O},
    {"paint", (PyCFunction)SbkQDeclarativeItemFunc_paint, METH_VARARGS},
    {"parentItem", (PyCFunction)SbkQDeclarativeItemFunc_parentItem, METH_NOARGS},
    {"resetHeight", (PyCFunction)SbkQDeclarativeItemFunc_resetHeight, METH_NOARGS},
    {"resetWidth", (PyCFunction)SbkQDeclarativeItemFunc_resetWidth, METH_NOARGS},
    {"sceneEvent", (PyCFunction)SbkQDeclarativeItemFunc_sceneEvent, METH_O},
    {"setBaselineOffset", (PyCFunction)SbkQDeclarativeItemFunc_setBaselineOffset, METH_O},
    {"setClip", (PyCFunction)SbkQDeclarativeItemFunc_setClip, METH_O},
    {"setFocus", (PyCFunction)SbkQDeclarativeItemFunc_setFocus, METH_O},
    {"setHeight", (PyCFunction)SbkQDeclarativeItemFunc_setHeight, METH_O},
    {"setImplicitHeight", (PyCFunction)SbkQDeclarativeItemFunc_setImplicitHeight, METH_O},
    {"setImplicitWidth", (PyCFunction)SbkQDeclarativeItemFunc_setImplicitWidth, METH_O},
    {"setKeepMouseGrab", (PyCFunction)SbkQDeclarativeItemFunc_setKeepMouseGrab, METH_O},
    {"setParentItem", (PyCFunction)SbkQDeclarativeItemFunc_setParentItem, METH_O},
    {"setSize", (PyCFunction)SbkQDeclarativeItemFunc_setSize, METH_O},
    {"setSmooth", (PyCFunction)SbkQDeclarativeItemFunc_setSmooth, METH_O},
    {"setTransformOrigin", (PyCFunction)SbkQDeclarativeItemFunc_setTransformOrigin, METH_O},
    {"setWidth", (PyCFunction)SbkQDeclarativeItemFunc_setWidth, METH_O},
    {"smooth", (PyCFunction)SbkQDeclarativeItemFunc_smooth, METH_NOARGS},
    {"transformOrigin", (PyCFunction)SbkQDeclarativeItemFunc_transformOrigin, METH_NOARGS},
    {"width", (PyCFunction)SbkQDeclarativeItemFunc_width, METH_NOARGS},
    {"widthValid", (PyCFunction)SbkQDeclarativeItemFunc_widthValid, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1, -1, -1, -1, -1, -1, -1 };
int*
SbkQDeclarativeItem_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QDeclarativeItem* class_ptr = reinterpret_cast<const QDeclarativeItem*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QGraphicsObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QGraphicsObject*>((QDeclarativeItem*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QDeclarativeParserStatus*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QDeclarativeParserStatus*>((QDeclarativeItem*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((QGraphicsObject*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QGraphicsItem*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QGraphicsItem*>((QGraphicsObject*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* SbkQDeclarativeItemSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QDeclarativeItem* me = reinterpret_cast<QDeclarativeItem*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSOBJECT_IDX]))
        return static_cast<QGraphicsObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEM_IDX]))
        return static_cast<QGraphicsItem*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPARSERSTATUS_IDX]))
        return static_cast<QDeclarativeParserStatus*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeItem_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeItem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             SbkQDeclarativeItem_mi_init,
    /*mi_specialcast*/      &SbkQDeclarativeItemSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeItem >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeItem*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQDeclarativeItem_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDeclarativeItem*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQDeclarativeItem_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QGraphicsItem >()) && dynamic_cast<QDeclarativeItem*>(reinterpret_cast<QGraphicsItem*>(cptr)))
        return &SbkQDeclarativeItem_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QDeclarativeParserStatus >()) && dynamic_cast<QDeclarativeItem*>(reinterpret_cast<QDeclarativeParserStatus*>(cptr)))
        return &SbkQDeclarativeItem_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "TransformOrigin",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDeclarativeItem(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEITEM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeItem_Type);

    SbkQDeclarativeItem_Type.super.ht_type.tp_base = SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPARSERSTATUS_IDX];
    SbkQDeclarativeItem_Type.super.ht_type.tp_bases = PyTuple_Pack(2,
        (PyTypeObject*)SbkPySide_QtGuiTypes[SBK_QGRAPHICSOBJECT_IDX], (PyTypeObject*)SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPARSERSTATUS_IDX]);

    // Fill type discovery information
    SbkQDeclarativeItem_Type.type_discovery = &SbkQDeclarativeItem_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSOBJECT_IDX]), &SbkQDeclarativeItem_Type);
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPARSERSTATUS_IDX]), &SbkQDeclarativeItem_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeItem_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeItem_Type));
    PyModule_AddObject(module, "QDeclarativeItem",
        ((PyObject*)&SbkQDeclarativeItem_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: TransformOrigin
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEITEM_TRANSFORMORIGIN_IDX] = &SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
            "TransformOrigin",((PyObject*)&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::TopLeft, "TopLeft");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "TopLeft", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "TopLeft", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::Top, "Top");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "Top", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "Top", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::TopRight, "TopRight");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "TopRight", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "TopRight", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::Left, "Left");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "Left", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "Left", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::Center, "Center");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "Center", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "Center", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::Right, "Right");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "Right", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "Right", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::BottomLeft, "BottomLeft");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "BottomLeft", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "BottomLeft", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::Bottom, "Bottom");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "Bottom", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "Bottom", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type,
        (long) QDeclarativeItem::BottomRight, "BottomRight");
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict,
        "BottomRight", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeItem_TransformOrigin_Type.tp_dict,
        "BottomRight", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeItem::TransformOrigin");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("baselineOffsetChanged", "qreal", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "baselineOffsetChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("focusChanged", "bool", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "focusChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("childrenRectChanged", "const QRectF&", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "childrenRectChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("clipChanged", "bool", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "clipChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("parentChanged", "QDeclarativeItem*", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "parentChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("smoothChanged", "bool", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "smoothChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("activeFocusChanged", "bool", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "activeFocusChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("transformOriginChanged", "QDeclarativeItem::TransformOrigin", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "transformOriginChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "const QString&", NULL);
    PyDict_SetItemString(SbkQDeclarativeItem_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeItem >("QDeclarativeItem*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeItem >(typeid(QDeclarativeItem).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeItem >(typeid(QDeclarativeItemWrapper).name());
    PySide::initQtMetaType<QDeclarativeItem* >();
}

