/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativelistreference_wrapper.h"

// Extra includes
#include <qdeclarativeengine.h>
#include <qdeclarativelist.h>
#include <qobject.h>
#include <qobjectdefs.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeListReference_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeListReference >()))
        return -1;

    QDeclarativeListReference* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "arg__3" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeListReference(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeListReference(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QDeclarativeListReference", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeListReference()
    // 1: QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
    // 2: QDeclarativeListReference(QDeclarativeListReference)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeListReference()
    } else if (numArgs == 1 && Shiboken::Converter<const QDeclarativeListReference & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QDeclarativeListReference(QDeclarativeListReference)
    } else if (numArgs >= 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
        } else if (Shiboken::Converter<QDeclarativeEngine * >::isConvertible(pyargs[2])) {
            overloadId = 1; // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeListReference_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeListReference()
            {

                if(!PyErr_Occurred()) {
                // QDeclarativeListReference()
                cptr = new QDeclarativeListReference();
                }
                break;
            }
            case 1: // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "arg__3");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "arg__3";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeListReference(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QDeclarativeEngine* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QDeclarativeListReference(QObject*,const char*,QDeclarativeEngine*)
                cptr = new QDeclarativeListReference(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // QDeclarativeListReference(QDeclarativeListReference)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QDeclarativeListReference* cpp_arg0 = Shiboken::Converter<QDeclarativeListReference* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QDeclarativeListReference(QDeclarativeListReference)
                cptr = new QDeclarativeListReference(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeListReference >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDeclarativeListReference_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDeclarativeListReference_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, str, PySide.QtDeclarative.QDeclarativeEngine = None", "PySide.QtDeclarative.QDeclarativeListReference", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeListReference", overloads);
        return -1;
}

static PyObject* SbkQDeclarativeListReferenceFunc_append(PyObject* self, PyObject* arg)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QObject*)const
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // append(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeListReferenceFunc_append_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // append(QObject*)const
            bool cppResult = cppSelf->QDeclarativeListReference::append(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeListReferenceFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeListReference.append", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeListReferenceFunc_at(PyObject* self, PyObject* arg)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeListReferenceFunc_at_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // at(int)const
            QObject * cppResult = cppSelf->QDeclarativeListReference::at(cpp_arg0);
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativeListReferenceFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeListReference.at", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeListReferenceFunc_canAppend(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canAppend()const
            bool cppResult = cppSelf->QDeclarativeListReference::canAppend();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_canAt(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canAt()const
            bool cppResult = cppSelf->QDeclarativeListReference::canAt();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_canClear(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canClear()const
            bool cppResult = cppSelf->QDeclarativeListReference::canClear();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_canCount(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canCount()const
            bool cppResult = cppSelf->QDeclarativeListReference::canCount();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_clear(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()const
            bool cppResult = cppSelf->QDeclarativeListReference::clear();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_count(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // count()const
            int cppResult = cppSelf->QDeclarativeListReference::count();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_isValid(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QDeclarativeListReference::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_listElementType(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // listElementType()const
            const QMetaObject * cppResult = cppSelf->QDeclarativeListReference::listElementType();
            pyResult = Shiboken::Converter< QMetaObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeListReferenceFunc_object(PyObject* self)
{
    QDeclarativeListReference* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeListReference* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // object()const
            QObject * cppResult = cppSelf->QDeclarativeListReference::object();
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDeclarativeListReference_methods[] = {
    {"append", (PyCFunction)SbkQDeclarativeListReferenceFunc_append, METH_O},
    {"at", (PyCFunction)SbkQDeclarativeListReferenceFunc_at, METH_O},
    {"canAppend", (PyCFunction)SbkQDeclarativeListReferenceFunc_canAppend, METH_NOARGS},
    {"canAt", (PyCFunction)SbkQDeclarativeListReferenceFunc_canAt, METH_NOARGS},
    {"canClear", (PyCFunction)SbkQDeclarativeListReferenceFunc_canClear, METH_NOARGS},
    {"canCount", (PyCFunction)SbkQDeclarativeListReferenceFunc_canCount, METH_NOARGS},
    {"clear", (PyCFunction)SbkQDeclarativeListReferenceFunc_clear, METH_NOARGS},
    {"count", (PyCFunction)SbkQDeclarativeListReferenceFunc_count, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQDeclarativeListReferenceFunc_isValid, METH_NOARGS},
    {"listElementType", (PyCFunction)SbkQDeclarativeListReferenceFunc_listElementType, METH_NOARGS},
    {"object", (PyCFunction)SbkQDeclarativeListReferenceFunc_object, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeListReference_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeListReference",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeListReference_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeListReference_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeListReference >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeListReference",
    /*user_data*/           0
};
} //extern


void init_QDeclarativeListReference(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVELISTREFERENCE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeListReference_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeListReference_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeListReference_Type));
    PyModule_AddObject(module, "QDeclarativeListReference",
        ((PyObject*)&SbkQDeclarativeListReference_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeListReference >("QDeclarativeListReference");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeListReference >("QDeclarativeListReference*");
    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeListReference >(typeid(QDeclarativeListReference).name());
    PySide::initQtMetaType<QDeclarativeListReference >();
}

