/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeproperty_wrapper.h"

// Extra includes
#include <qdeclarativecontext.h>
#include <qdeclarativeengine.h>
#include <qdeclarativeproperty.h>
#include <qmetaobject.h>
#include <qobject.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeProperty_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeProperty >()))
        return -1;

    QDeclarativeProperty* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDeclarativeProperty", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeProperty()
    // 1: QDeclarativeProperty(QObject*)
    // 2: QDeclarativeProperty(QObject*,QDeclarativeContext*)
    // 3: QDeclarativeProperty(QObject*,QDeclarativeEngine*)
    // 4: QDeclarativeProperty(QObject*,QString)
    // 5: QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
    // 6: QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
    // 7: QDeclarativeProperty(QDeclarativeProperty)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeProperty()
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QDeclarativeProperty(QObject*)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // QDeclarativeProperty(QObject*,QString)
            } else if (numArgs == 3 && Shiboken::Converter<QDeclarativeEngine * >::isConvertible(pyargs[2])) {
                overloadId = 6; // QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
            } else if (numArgs == 3 && Shiboken::Converter<QDeclarativeContext * >::isConvertible(pyargs[2])) {
                overloadId = 5; // QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
            }
        } else if (numArgs == 2 && Shiboken::Converter<QDeclarativeEngine * >::isConvertible(pyargs[1])) {
            overloadId = 3; // QDeclarativeProperty(QObject*,QDeclarativeEngine*)
        } else if (numArgs == 2 && Shiboken::Converter<QDeclarativeContext * >::isConvertible(pyargs[1])) {
            overloadId = 2; // QDeclarativeProperty(QObject*,QDeclarativeContext*)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QDeclarativeProperty & >::isConvertible(pyargs[0])) {
        overloadId = 7; // QDeclarativeProperty(QDeclarativeProperty)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeProperty_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeProperty()
            {

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty()
                cptr = new QDeclarativeProperty();
                }
                break;
            }
            case 1: // QDeclarativeProperty(QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty(QObject*)
                cptr = new QDeclarativeProperty(cpp_arg0);
                }
                break;
            }
            case 2: // QDeclarativeProperty(QObject*,QDeclarativeContext*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QDeclarativeContext* cpp_arg1 = Shiboken::Converter<QDeclarativeContext* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty(QObject*,QDeclarativeContext*)
                cptr = new QDeclarativeProperty(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QDeclarativeProperty(QObject*,QDeclarativeEngine*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QDeclarativeEngine* cpp_arg1 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty(QObject*,QDeclarativeEngine*)
                cptr = new QDeclarativeProperty(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 4: // QDeclarativeProperty(QObject*,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty(QObject*,QString)
                cptr = new QDeclarativeProperty(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 5: // QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QDeclarativeContext* cpp_arg2 = Shiboken::Converter<QDeclarativeContext* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
                cptr = new QDeclarativeProperty(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 6: // QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QDeclarativeEngine* cpp_arg2 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
                cptr = new QDeclarativeProperty(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 7: // QDeclarativeProperty(QDeclarativeProperty)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QDeclarativeProperty > cpp_arg0_auto_ptr;
                QDeclarativeProperty* cpp_arg0 = Shiboken::Converter<QDeclarativeProperty* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QDeclarativeProperty >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QDeclarativeProperty >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QDeclarativeProperty(QDeclarativeProperty)
                cptr = new QDeclarativeProperty(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeProperty >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDeclarativeProperty_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDeclarativeProperty_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject", "PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeEngine", "PySide.QtCore.QObject, QString", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeEngine", "PySide.QtDeclarative.QDeclarativeProperty", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty", overloads);
        return -1;
}

static PyObject* SbkQDeclarativePropertyFunc_connectNotifySignal(PyObject* self, PyObject* args)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "connectNotifySignal", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: connectNotifySignal(QObject*,const char*)const
    // 1: connectNotifySignal(QObject*,int)const
    if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // connectNotifySignal(QObject*,int)const
        } else if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // connectNotifySignal(QObject*,const char*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativePropertyFunc_connectNotifySignal_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // connectNotifySignal(QObject*,const char*)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // connectNotifySignal(QObject*,const char*)const
                bool cppResult = cppSelf->QDeclarativeProperty::connectNotifySignal(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // connectNotifySignal(QObject*,int)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // connectNotifySignal(QObject*,int)const
                bool cppResult = cppSelf->QDeclarativeProperty::connectNotifySignal(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativePropertyFunc_connectNotifySignal_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str", "PySide.QtCore.QObject, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty.connectNotifySignal", overloads);
        return 0;
}

static PyObject* SbkQDeclarativePropertyFunc_hasNotifySignal(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasNotifySignal()const
            bool cppResult = cppSelf->QDeclarativeProperty::hasNotifySignal();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_index(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // index()const
            int cppResult = cppSelf->QDeclarativeProperty::index();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_isDesignable(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDesignable()const
            bool cppResult = cppSelf->QDeclarativeProperty::isDesignable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_isProperty(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isProperty()const
            bool cppResult = cppSelf->QDeclarativeProperty::isProperty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_isResettable(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isResettable()const
            bool cppResult = cppSelf->QDeclarativeProperty::isResettable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_isSignalProperty(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSignalProperty()const
            bool cppResult = cppSelf->QDeclarativeProperty::isSignalProperty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_isValid(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QDeclarativeProperty::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_isWritable(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWritable()const
            bool cppResult = cppSelf->QDeclarativeProperty::isWritable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_method(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // method()const
            QMetaMethod cppResult = cppSelf->QDeclarativeProperty::method();
            pyResult = Shiboken::Converter<QMetaMethod >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_name(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QDeclarativeProperty::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_needsNotifySignal(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // needsNotifySignal()const
            bool cppResult = cppSelf->QDeclarativeProperty::needsNotifySignal();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_object(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // object()const
            QObject * cppResult = cppSelf->QDeclarativeProperty::object();
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_property(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // property()const
            QMetaProperty cppResult = cppSelf->QDeclarativeProperty::property();
            pyResult = Shiboken::Converter<QMetaProperty >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_propertyType(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // propertyType()const
            int cppResult = cppSelf->QDeclarativeProperty::propertyType();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_propertyTypeCategory(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // propertyTypeCategory()const
            QDeclarativeProperty::PropertyTypeCategory cppResult = cppSelf->QDeclarativeProperty::propertyTypeCategory();
            pyResult = Shiboken::Converter<QDeclarativeProperty::PropertyTypeCategory >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_propertyTypeName(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // propertyTypeName()const
            const char * cppResult = cppSelf->QDeclarativeProperty::propertyTypeName();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_read(PyObject* self, PyObject* args)
{
    QDeclarativeProperty* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto SbkQDeclarativePropertyFunc_read_TypeError;

    if (!PyArg_UnpackTuple(args, "read", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: read()const
    // 1: read(QObject*,QString)
    // 2: read(QObject*,QString,QDeclarativeContext*)
    // 3: read(QObject*,QString,QDeclarativeEngine*)
    if (numArgs == 0) {
        overloadId = 0; // read()const
    } else if (numArgs >= 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // read(QObject*,QString)
        } else if (numArgs == 3 && Shiboken::Converter<QDeclarativeEngine * >::isConvertible(pyargs[2])) {
            overloadId = 3; // read(QObject*,QString,QDeclarativeEngine*)
        } else if (numArgs == 3 && Shiboken::Converter<QDeclarativeContext * >::isConvertible(pyargs[2])) {
            overloadId = 2; // read(QObject*,QString,QDeclarativeContext*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativePropertyFunc_read_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // read()const
            {

                if(!PyErr_Occurred()) {
                // read()const
                QVariant cppResult = cppSelf->QDeclarativeProperty::read();
                pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
                }
                break;
            }
            case 1: // read(QObject*,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // read(QObject*,QString)
                QVariant cppResult = QDeclarativeProperty::read(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
                }
                break;
            }
            case 2: // read(QObject*,QString,QDeclarativeContext*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QDeclarativeContext* cpp_arg2 = Shiboken::Converter<QDeclarativeContext* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // read(QObject*,QString,QDeclarativeContext*)
                QVariant cppResult = QDeclarativeProperty::read(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
                }
                break;
            }
            case 3: // read(QObject*,QString,QDeclarativeEngine*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QDeclarativeEngine* cpp_arg2 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // read(QObject*,QString,QDeclarativeEngine*)
                QVariant cppResult = QDeclarativeProperty::read(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativePropertyFunc_read_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, QString", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeEngine", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty.read", overloads);
        return 0;
}

static PyObject* SbkQDeclarativePropertyFunc_reset(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()const
            bool cppResult = cppSelf->QDeclarativeProperty::reset();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_type(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            QDeclarativeProperty::Type cppResult = cppSelf->QDeclarativeProperty::type();
            pyResult = Shiboken::Converter<QDeclarativeProperty::Type >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativePropertyFunc_write(PyObject* self, PyObject* args)
{
    QDeclarativeProperty* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQDeclarativePropertyFunc_write_TypeError;

    if (!PyArg_UnpackTuple(args, "write", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: write(QObject*,QString,QVariant)
    // 1: write(QObject*,QString,QVariant,QDeclarativeContext*)
    // 2: write(QObject*,QString,QVariant,QDeclarativeEngine*)
    // 3: write(QVariant)const
    if (numArgs == 1 && Shiboken::Converter<QVariant >::isConvertible(pyargs[0])) {
        overloadId = 3; // write(QVariant)const
    } else if (numArgs >= 3 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // write(QObject*,QString,QVariant)
        } else if (numArgs == 4 && Shiboken::Converter<QDeclarativeEngine * >::isConvertible(pyargs[3])) {
            overloadId = 2; // write(QObject*,QString,QVariant,QDeclarativeEngine*)
        } else if (numArgs == 4 && Shiboken::Converter<QDeclarativeContext * >::isConvertible(pyargs[3])) {
            overloadId = 1; // write(QObject*,QString,QVariant,QDeclarativeContext*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativePropertyFunc_write_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // write(QObject*,QString,QVariant)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // write(QObject*,QString,QVariant)
                bool cppResult = QDeclarativeProperty::write(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // write(QObject*,QString,QVariant,QDeclarativeContext*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QDeclarativeContext* cpp_arg3 = Shiboken::Converter<QDeclarativeContext* >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // write(QObject*,QString,QVariant,QDeclarativeContext*)
                bool cppResult = QDeclarativeProperty::write(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // write(QObject*,QString,QVariant,QDeclarativeEngine*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QDeclarativeEngine* cpp_arg3 = Shiboken::Converter<QDeclarativeEngine* >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // write(QObject*,QString,QVariant,QDeclarativeEngine*)
                bool cppResult = QDeclarativeProperty::write(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // write(QVariant)const
            {
                QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // write(QVariant)const
                bool cppResult = cppSelf->QDeclarativeProperty::write(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDeclarativePropertyFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, QString, QVariant", "PySide.QtCore.QObject, QString, QVariant, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, QString, QVariant, PySide.QtDeclarative.QDeclarativeEngine", "QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty.write", overloads);
        return 0;
}

static PyMethodDef SbkQDeclarativePropertyMethod_read = {
    "read", (PyCFunction)SbkQDeclarativePropertyFunc_read, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQDeclarativePropertyMethod_write = {
    "write", (PyCFunction)SbkQDeclarativePropertyFunc_write, METH_VARARGS|METH_STATIC
};

static PyMethodDef SbkQDeclarativeProperty_methods[] = {
    {"connectNotifySignal", (PyCFunction)SbkQDeclarativePropertyFunc_connectNotifySignal, METH_VARARGS},
    {"hasNotifySignal", (PyCFunction)SbkQDeclarativePropertyFunc_hasNotifySignal, METH_NOARGS},
    {"index", (PyCFunction)SbkQDeclarativePropertyFunc_index, METH_NOARGS},
    {"isDesignable", (PyCFunction)SbkQDeclarativePropertyFunc_isDesignable, METH_NOARGS},
    {"isProperty", (PyCFunction)SbkQDeclarativePropertyFunc_isProperty, METH_NOARGS},
    {"isResettable", (PyCFunction)SbkQDeclarativePropertyFunc_isResettable, METH_NOARGS},
    {"isSignalProperty", (PyCFunction)SbkQDeclarativePropertyFunc_isSignalProperty, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQDeclarativePropertyFunc_isValid, METH_NOARGS},
    {"isWritable", (PyCFunction)SbkQDeclarativePropertyFunc_isWritable, METH_NOARGS},
    {"method", (PyCFunction)SbkQDeclarativePropertyFunc_method, METH_NOARGS},
    {"name", (PyCFunction)SbkQDeclarativePropertyFunc_name, METH_NOARGS},
    {"needsNotifySignal", (PyCFunction)SbkQDeclarativePropertyFunc_needsNotifySignal, METH_NOARGS},
    {"object", (PyCFunction)SbkQDeclarativePropertyFunc_object, METH_NOARGS},
    {"property", (PyCFunction)SbkQDeclarativePropertyFunc_property, METH_NOARGS},
    {"propertyType", (PyCFunction)SbkQDeclarativePropertyFunc_propertyType, METH_NOARGS},
    {"propertyTypeCategory", (PyCFunction)SbkQDeclarativePropertyFunc_propertyTypeCategory, METH_NOARGS},
    {"propertyTypeName", (PyCFunction)SbkQDeclarativePropertyFunc_propertyTypeName, METH_NOARGS},
    SbkQDeclarativePropertyMethod_read,
    {"reset", (PyCFunction)SbkQDeclarativePropertyFunc_reset, METH_NOARGS},
    {"type", (PyCFunction)SbkQDeclarativePropertyFunc_type, METH_NOARGS},
    SbkQDeclarativePropertyMethod_write,
    {0} // Sentinel
};

static PyObject* SbkQDeclarativeProperty_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (SbkBaseWrapper_instanceDict(self)) {
            PyObject* meth = PyDict_GetItem(SbkBaseWrapper_instanceDict(self), name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "read") == 0)
            return PyCFunction_NewEx(&SbkQDeclarativePropertyMethod_read, self, 0);
        if (strcmp(cname, "write") == 0)
            return PyCFunction_NewEx(&SbkQDeclarativePropertyMethod_write, self, 0);
    }
    PyObject* attr = PyObject_GenericGetAttr(self, name);
    if (attr && PySide::isQPropertyType(attr)) {
        PyObject *value = PySide::qproperty_get(attr, self);
        Py_DECREF(attr);
        Py_INCREF(value);
        attr = value;
    }
    return attr;
}

// Rich comparison
static PyObject* SbkQDeclarativeProperty_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QDeclarativeProperty& cpp_self = *Shiboken::Converter<QDeclarativeProperty* >::toCpp(self);

    switch (op) {
        case Py_EQ:
            if (Shiboken::Converter<const QDeclarativeProperty & >::isConvertible(other)) {
                // operator==(const QDeclarativeProperty & arg__1) const
                QDeclarativeProperty* cpp_other = Shiboken::Converter<QDeclarativeProperty* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDeclarativeProperty  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QDeclarativeProperty >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QDeclarativeProperty > cpp_other_auto_ptr;
                QDeclarativeProperty* cpp_other = Shiboken::Converter<QDeclarativeProperty* >::toCpp(other);
                if (!Shiboken::Converter<QDeclarativeProperty >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QDeclarativeProperty >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQDeclarativeProperty_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQDeclarativeProperty_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeProperty_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeProperty",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         SbkQDeclarativeProperty_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQDeclarativeProperty_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeProperty_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeProperty_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeProperty >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeProperty",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtDeclarative_QDeclarativeProperty_Type_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtDeclarative_QDeclarativeProperty_Type_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Type",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtDeclarative_QDeclarativeProperty_Type_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtDeclarative_QDeclarativeProperty_Type_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtDeclarative_QDeclarativeProperty_Type_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PropertyTypeCategory",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDeclarativeProperty(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeProperty_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeProperty_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeProperty_Type));
    PyModule_AddObject(module, "QDeclarativeProperty",
        ((PyObject*)&SbkQDeclarativeProperty_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Type
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTY_TYPE_IDX] = &SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type);
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)&SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type,
        (long) QDeclarativeProperty::Invalid, "Invalid");
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
        "Invalid", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type.tp_dict,
        "Invalid", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type,
        (long) QDeclarativeProperty::Property, "Property");
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
        "Property", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type.tp_dict,
        "Property", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type,
        (long) QDeclarativeProperty::SignalProperty, "SignalProperty");
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
        "SignalProperty", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_Type_Type.tp_dict,
        "SignalProperty", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeProperty::Type");

    // init enum class: PropertyTypeCategory
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTY_PROPERTYTYPECATEGORY_IDX] = &SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type);
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
            "PropertyTypeCategory",((PyObject*)&SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type,
        (long) QDeclarativeProperty::InvalidCategory, "InvalidCategory");
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
        "InvalidCategory", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type.tp_dict,
        "InvalidCategory", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type,
        (long) QDeclarativeProperty::List, "List");
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
        "List", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type.tp_dict,
        "List", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type,
        (long) QDeclarativeProperty::Object, "Object");
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
        "Object", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type.tp_dict,
        "Object", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type,
        (long) QDeclarativeProperty::Normal, "Normal");
    PyDict_SetItemString(SbkQDeclarativeProperty_Type.super.ht_type.tp_dict,
        "Normal", enum_item);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory_Type.tp_dict,
        "Normal", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeProperty::PropertyTypeCategory");


    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeProperty >("QDeclarativeProperty");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeProperty >("QDeclarativeProperty*");
    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeProperty >(typeid(QDeclarativeProperty).name());
    PySide::initQtMetaType<QDeclarativeProperty >();
}

