/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativescriptstring_wrapper.h"

// Extra includes
#include <qdeclarativecontext.h>
#include <qdeclarativescriptstring.h>
#include <qobject.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDeclarativeScriptString_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeScriptString >()))
        return -1;

    QDeclarativeScriptString* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDeclarativeScriptString", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeScriptString()
    // 1: QDeclarativeScriptString(QDeclarativeScriptString)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeScriptString()
    } else if (numArgs == 1 && Shiboken::Converter<const QDeclarativeScriptString & >::isConvertible(arg)) {
        overloadId = 1; // QDeclarativeScriptString(QDeclarativeScriptString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeScriptString_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeScriptString()
            {

                if(!PyErr_Occurred()) {
                // QDeclarativeScriptString()
                cptr = new QDeclarativeScriptString();
                }
                break;
            }
            case 1: // QDeclarativeScriptString(QDeclarativeScriptString)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDeclarativeScriptString* cpp_arg0 = Shiboken::Converter<QDeclarativeScriptString* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDeclarativeScriptString(QDeclarativeScriptString)
                cptr = new QDeclarativeScriptString(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeScriptString >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDeclarativeScriptString_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDeclarativeScriptString_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtDeclarative.QDeclarativeScriptString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeScriptString", overloads);
        return -1;
}

static PyObject* SbkQDeclarativeScriptStringFunc_context(PyObject* self)
{
    QDeclarativeScriptString* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeScriptString* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // context()const
            QDeclarativeContext * cppResult = cppSelf->QDeclarativeScriptString::context();
            pyResult = Shiboken::Converter<QDeclarativeContext * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeScriptStringFunc_scopeObject(PyObject* self)
{
    QDeclarativeScriptString* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeScriptString* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scopeObject()const
            QObject * cppResult = cppSelf->QDeclarativeScriptString::scopeObject();
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeScriptStringFunc_script(PyObject* self)
{
    QDeclarativeScriptString* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeScriptString* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // script()const
            QString cppResult = cppSelf->QDeclarativeScriptString::script();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDeclarativeScriptStringFunc_setContext(PyObject* self, PyObject* arg)
{
    QDeclarativeScriptString* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeScriptString* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContext(QDeclarativeContext*)
    if (Shiboken::Converter<QDeclarativeContext * >::isConvertible(arg)) {
        overloadId = 0; // setContext(QDeclarativeContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeScriptStringFunc_setContext_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDeclarativeContext* cpp_arg0 = Shiboken::Converter<QDeclarativeContext* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setContext(QDeclarativeContext*)
            cppSelf->QDeclarativeScriptString::setContext(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeScriptStringFunc_setContext_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeScriptString.setContext", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeScriptStringFunc_setScopeObject(PyObject* self, PyObject* arg)
{
    QDeclarativeScriptString* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeScriptString* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScopeObject(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // setScopeObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeScriptStringFunc_setScopeObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScopeObject(QObject*)
            cppSelf->QDeclarativeScriptString::setScopeObject(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeScriptStringFunc_setScopeObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeScriptString.setScopeObject", overloads);
        return 0;
}

static PyObject* SbkQDeclarativeScriptStringFunc_setScript(PyObject* self, PyObject* arg)
{
    QDeclarativeScriptString* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDeclarativeScriptString* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScript(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setScript(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDeclarativeScriptStringFunc_setScript_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScript(QString)
            cppSelf->QDeclarativeScriptString::setScript(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDeclarativeScriptStringFunc_setScript_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeScriptString.setScript", overloads);
        return 0;
}

static PyMethodDef SbkQDeclarativeScriptString_methods[] = {
    {"context", (PyCFunction)SbkQDeclarativeScriptStringFunc_context, METH_NOARGS},
    {"scopeObject", (PyCFunction)SbkQDeclarativeScriptStringFunc_scopeObject, METH_NOARGS},
    {"script", (PyCFunction)SbkQDeclarativeScriptStringFunc_script, METH_NOARGS},
    {"setContext", (PyCFunction)SbkQDeclarativeScriptStringFunc_setContext, METH_O},
    {"setScopeObject", (PyCFunction)SbkQDeclarativeScriptStringFunc_setScopeObject, METH_O},
    {"setScript", (PyCFunction)SbkQDeclarativeScriptStringFunc_setScript, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDeclarativeScriptString_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeScriptString",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDeclarativeScriptString_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDeclarativeScriptString_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDeclarativeScriptString >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDeclarativeScriptString",
    /*user_data*/           0
};
} //extern


void init_QDeclarativeScriptString(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVESCRIPTSTRING_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDeclarativeScriptString_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDeclarativeScriptString_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDeclarativeScriptString_Type));
    PyModule_AddObject(module, "QDeclarativeScriptString",
        ((PyObject*)&SbkQDeclarativeScriptString_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeScriptString >("QDeclarativeScriptString");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeScriptString >("QDeclarativeScriptString*");
    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeScriptString >(typeid(QDeclarativeScriptString).name());
    PySide::initQtMetaType<QDeclarativeScriptString >();
}

