/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtdeclarative_python.h"


// Global functions ------------------------------------------------------------

static PyMethodDef QtDeclarative_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QDeclarativeScriptString(PyObject* module);
void init_QDeclarativeProperty(PyObject* module);
void init_QDeclarativeNetworkAccessManagerFactory(PyObject* module);
void init_QDeclarativeImageProvider(PyObject* module);
void init_QDeclarativeExtensionInterface(PyObject* module);
void init_QDeclarativeError(PyObject* module);
void init_QDeclarativeListReference(PyObject* module);
void init_QDeclarativePropertyValueSource(PyObject* module);
void init_QDeclarativeParserStatus(PyObject* module);
void init_QDeclarativeView(PyObject* module);
void init_QDeclarativeItem(PyObject* module);
void init_QDeclarativeExtensionPlugin(PyObject* module);
void init_QDeclarativeExpression(PyObject* module);
void init_QDeclarativeEngine(PyObject* module);
void init_QDeclarativeContext(PyObject* module);
void init_QDeclarativeComponent(PyObject* module);
void init_QDeclarativePropertyMap(PyObject* module);

PyTypeObject** SbkPySide_QtDeclarativeTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

PyTypeObject** SbkPySide_QtNetworkTypes;

PyTypeObject** SbkPySide_QtGuiTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtDeclarative()
{
    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    if (!Shiboken::importModule("PySide.QtNetwork", &SbkPySide_QtNetworkTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtNetwork");
        return;
    }

    if (!Shiboken::importModule("PySide.QtGui", &SbkPySide_QtGuiTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtGui");
        return;
    }

    Shiboken::initShiboken();
    PyObject* module = Py_InitModule("QtDeclarative", QtDeclarative_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtDeclarative_IDX_COUNT];
    SbkPySide_QtDeclarativeTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QDeclarativeScriptString(module);
    init_QDeclarativeProperty(module);
    init_QDeclarativeNetworkAccessManagerFactory(module);
    init_QDeclarativeImageProvider(module);
    init_QDeclarativeExtensionInterface(module);
    init_QDeclarativeError(module);
    init_QDeclarativeListReference(module);
    init_QDeclarativePropertyValueSource(module);
    init_QDeclarativeParserStatus(module);
    init_QDeclarativeView(module);
    init_QDeclarativeItem(module);
    init_QDeclarativeExtensionPlugin(module);
    init_QDeclarativeExpression(module);
    init_QDeclarativeEngine(module);
    init_QDeclarativeContext(module);
    init_QDeclarativeComponent(module);
    init_QDeclarativePropertyMap(module);

    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver<QList<QDeclarativeError> >("QList<QDeclarativeError>");

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtDeclarative");
    }
}

