/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qabstracttextdocumentlayout_wrapper.h"
#include "qabstracttextdocumentlayout_selection_wrapper.h"
#include "qabstracttextdocumentlayout_paintcontext_wrapper.h"

// Extra includes
#include <QAbstractTextDocumentLayout>
#include <QList>
#include <qabstracttextdocumentlayout.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpainter.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qtextdocument.h>
#include <qtextformat.h>
#include <qtextlayout.h>
#include <qtextobject.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QAbstractTextDocumentLayoutWrapper::QAbstractTextDocumentLayoutWrapper(QTextDocument * doc) : QAbstractTextDocumentLayout(doc), m_metaObject(0) {
    // ... middle
}

QRectF QAbstractTextDocumentLayoutWrapper::blockBoundingRect(const QTextBlock & block) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "blockBoundingRect"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.blockBoundingRect()' not implemented.");
        return QRectF();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QTextBlock & >::toPython(block)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRectF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRectF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTextDocumentLayout.blockBoundingRect", SbkType<QRectF >()->tp_name, pyResult->ob_type->tp_name);
        return QRectF();
    }
    QRectF cppResult(Shiboken::Converter<QRectF >::toCpp(pyResult));
    return cppResult;
}

void QAbstractTextDocumentLayoutWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractTextDocumentLayoutWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractTextDocumentLayoutWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractTextDocumentLayoutWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractTextDocumentLayoutWrapper::documentChanged(int from, int charsRemoved, int charsAdded)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "documentChanged"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.documentChanged()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iii)",
        from,
        charsRemoved,
        charsAdded
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QSizeF QAbstractTextDocumentLayoutWrapper::documentSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "documentSize"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.documentSize()' not implemented.");
        return QSizeF();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSizeF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSizeF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTextDocumentLayout.documentSize", SbkType<QSizeF >()->tp_name, pyResult->ob_type->tp_name);
        return QSizeF();
    }
    QSizeF cppResult(Shiboken::Converter<QSizeF >::toCpp(pyResult));
    return cppResult;
}

void QAbstractTextDocumentLayoutWrapper::draw(QPainter * painter, const QAbstractTextDocumentLayout::PaintContext & context)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "draw"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.draw()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        Shiboken::Converter<const QAbstractTextDocumentLayout::PaintContext & >::toPython(context)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractTextDocumentLayoutWrapper::drawInlineObject(QPainter * painter, const QRectF & rect, QTextInlineObject object, int posInDocument, const QTextFormat & format)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "drawInlineObject"));
    if (py_override.isNull()) {
        return this->QAbstractTextDocumentLayout::drawInlineObject(painter, rect, object, posInDocument, format);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNiN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        Shiboken::Converter<const QRectF & >::toPython(rect),
        Shiboken::Converter<QTextInlineObject >::toPython(object),
        posInDocument,
        Shiboken::Converter<const QTextFormat & >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QAbstractTextDocumentLayoutWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTextDocumentLayout.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QAbstractTextDocumentLayoutWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTextDocumentLayout.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QRectF QAbstractTextDocumentLayoutWrapper::frameBoundingRect(QTextFrame * frame) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "frameBoundingRect"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.frameBoundingRect()' not implemented.");
        return QRectF();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTextFrame * >::toPython(frame)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRectF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRectF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTextDocumentLayout.frameBoundingRect", SbkType<QRectF >()->tp_name, pyResult->ob_type->tp_name);
        return QRectF();
    }
    QRectF cppResult(Shiboken::Converter<QRectF >::toCpp(pyResult));
    return cppResult;
}

int QAbstractTextDocumentLayoutWrapper::hitTest(const QPointF & point, Qt::HitTestAccuracy accuracy) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hitTest"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.hitTest()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QPointF & >::toPython(point),
        Shiboken::Converter<Qt::HitTestAccuracy >::toPython(accuracy)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTextDocumentLayout.hitTest", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QAbstractTextDocumentLayoutWrapper::pageCount() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pageCount"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.pageCount()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractTextDocumentLayout.pageCount", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QAbstractTextDocumentLayoutWrapper::positionInlineObject(QTextInlineObject item, int posInDocument, const QTextFormat & format)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "positionInlineObject"));
    if (py_override.isNull()) {
        return this->QAbstractTextDocumentLayout::positionInlineObject(item, posInDocument, format);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter<QTextInlineObject >::toPython(item),
        posInDocument,
        Shiboken::Converter<const QTextFormat & >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractTextDocumentLayoutWrapper::resizeInlineObject(QTextInlineObject item, int posInDocument, const QTextFormat & format)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeInlineObject"));
    if (py_override.isNull()) {
        return this->QAbstractTextDocumentLayout::resizeInlineObject(item, posInDocument, format);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter<QTextInlineObject >::toPython(item),
        posInDocument,
        Shiboken::Converter<const QTextFormat & >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractTextDocumentLayoutWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QAbstractTextDocumentLayoutWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QAbstractTextDocumentLayout::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QAbstractTextDocumentLayoutWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAbstractTextDocumentLayout::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QAbstractTextDocumentLayoutWrapper::~QAbstractTextDocumentLayoutWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAbstractTextDocumentLayout_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractTextDocumentLayout >()))
        return -1;

    QAbstractTextDocumentLayoutWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAbstractTextDocumentLayout' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QAbstractTextDocumentLayout", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QAbstractTextDocumentLayout(QTextDocument*)
    if (numArgs == 1 && Shiboken::Converter<QTextDocument * >::isConvertible(arg)) {
        overloadId = 0; // QAbstractTextDocumentLayout(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayout_Init_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QTextDocument* cpp_arg0 = Shiboken::Converter<QTextDocument* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // QAbstractTextDocumentLayout(QTextDocument*)
            cptr = new QAbstractTextDocumentLayoutWrapper(cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractTextDocumentLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAbstractTextDocumentLayout_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQAbstractTextDocumentLayout_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout", overloads);
        return -1;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_anchorAt(PyObject* self, PyObject* arg)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: anchorAt(QPointF)const
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // anchorAt(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_anchorAt_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // anchorAt(QPointF)const
            QString cppResult = cppSelf->QAbstractTextDocumentLayout::anchorAt(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTextDocumentLayoutFunc_anchorAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractTextDocumentLayout.anchorAt", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_blockBoundingRect(PyObject* self, PyObject* arg)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: blockBoundingRect(QTextBlock)const
    if (Shiboken::Converter<const QTextBlock & >::isConvertible(arg)) {
        overloadId = 0; // blockBoundingRect(QTextBlock)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_blockBoundingRect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextBlock* cpp_arg0 = Shiboken::Converter<QTextBlock* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // blockBoundingRect(QTextBlock)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.blockBoundingRect()' not implemented.");
                return 0;
            }
            QRectF cppResult = cppSelf->blockBoundingRect(*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTextDocumentLayoutFunc_blockBoundingRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlock", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractTextDocumentLayout.blockBoundingRect", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_document(PyObject* self)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // document()const
            QTextDocument * cppResult = cppSelf->QAbstractTextDocumentLayout::document();
            pyResult = Shiboken::Converter<QTextDocument * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_documentChanged(PyObject* self, PyObject* args)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "documentChanged", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: documentChanged(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // documentChanged(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_documentChanged_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // documentChanged(int,int,int)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.documentChanged()' not implemented.");
                return 0;
            }
            cppSelf->documentChanged(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTextDocumentLayoutFunc_documentChanged_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout.documentChanged", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_documentSize(PyObject* self)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentSize()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.documentSize()' not implemented.");
                return 0;
            }
            QSizeF cppResult = cppSelf->documentSize();
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_draw(PyObject* self, PyObject* args)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "draw", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: draw(QPainter*,QAbstractTextDocumentLayout::PaintContext)
    if (numArgs == 2 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QAbstractTextDocumentLayout::PaintContext & >::isConvertible(pyargs[1])) {
        overloadId = 0; // draw(QPainter*,QAbstractTextDocumentLayout::PaintContext)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_draw_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QAbstractTextDocumentLayout::PaintContext* cpp_arg1 = Shiboken::Converter<QAbstractTextDocumentLayout::PaintContext* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // draw(QPainter*,QAbstractTextDocumentLayout::PaintContext)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.draw()' not implemented.");
                return 0;
            }
            cppSelf->draw(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTextDocumentLayoutFunc_draw_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtGui.QAbstractTextDocumentLayout::PaintContext", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout.draw", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_drawInlineObject(PyObject* self, PyObject* args)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawInlineObject", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: drawInlineObject(QPainter*,QRectF,QTextInlineObject,int,QTextFormat)
    if (numArgs == 5 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1]) && Shiboken::Converter<QTextInlineObject >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter<const QTextFormat & >::isConvertible(pyargs[4])) {
        overloadId = 0; // drawInlineObject(QPainter*,QRectF,QTextInlineObject,int,QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_drawInlineObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QTextInlineObject* cpp_arg2 = Shiboken::Converter<QTextInlineObject* >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                return 0;
            QTextFormat* cpp_arg4 = Shiboken::Converter<QTextFormat* >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
            // drawInlineObject(QPainter*,QRectF,QTextInlineObject,int,QTextFormat)
            cppSelf->QAbstractTextDocumentLayout::drawInlineObject(cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3, *cpp_arg4);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTextDocumentLayoutFunc_drawInlineObject_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF, PySide.QtGui.QTextInlineObject, int, PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout.drawInlineObject", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_format(PyObject* self, PyObject* arg)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: format(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // format(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_format_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // format(int)
            QTextCharFormat cppResult = cppSelf->QAbstractTextDocumentLayout::format(cpp_arg0);
            pyResult = Shiboken::Converter<QTextCharFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTextDocumentLayoutFunc_format_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractTextDocumentLayout.format", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_formatIndex(PyObject* self, PyObject* arg)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: formatIndex(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // formatIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_formatIndex_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // formatIndex(int)
            int cppResult = cppSelf->QAbstractTextDocumentLayout::formatIndex(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTextDocumentLayoutFunc_formatIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractTextDocumentLayout.formatIndex", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_frameBoundingRect(PyObject* self, PyObject* arg)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: frameBoundingRect(QTextFrame*)const
    if (Shiboken::Converter<QTextFrame * >::isConvertible(arg)) {
        overloadId = 0; // frameBoundingRect(QTextFrame*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_frameBoundingRect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextFrame* cpp_arg0 = Shiboken::Converter<QTextFrame* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // frameBoundingRect(QTextFrame*)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.frameBoundingRect()' not implemented.");
                return 0;
            }
            QRectF cppResult = cppSelf->frameBoundingRect(cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTextDocumentLayoutFunc_frameBoundingRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrame", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractTextDocumentLayout.frameBoundingRect", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_handlerForObject(PyObject* self, PyObject* arg)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: handlerForObject(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // handlerForObject(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_handlerForObject_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // handlerForObject(int)const
            QTextObjectInterface * cppResult = cppSelf->QAbstractTextDocumentLayout::handlerForObject(cpp_arg0);
            pyResult = Shiboken::Converter<QTextObjectInterface * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTextDocumentLayoutFunc_handlerForObject_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractTextDocumentLayout.handlerForObject", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_hitTest(PyObject* self, PyObject* args)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hitTest", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hitTest(QPointF,Qt::HitTestAccuracy)const
    if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::HitTestAccuracy >::isConvertible(pyargs[1])) {
        overloadId = 0; // hitTest(QPointF,Qt::HitTestAccuracy)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_hitTest_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
            Qt::HitTestAccuracy cpp_arg1 = Shiboken::Converter<Qt::HitTestAccuracy >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // hitTest(QPointF,Qt::HitTestAccuracy)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.hitTest()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->hitTest(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractTextDocumentLayoutFunc_hitTest_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.Qt.HitTestAccuracy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout.hitTest", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_pageCount(PyObject* self)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pageCount()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractTextDocumentLayout.pageCount()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->pageCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_paintDevice(PyObject* self)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // paintDevice()const
            QPaintDevice * cppResult = cppSelf->QAbstractTextDocumentLayout::paintDevice();
            pyResult = Shiboken::Converter<QPaintDevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_positionInlineObject(PyObject* self, PyObject* args)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "positionInlineObject", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: positionInlineObject(QTextInlineObject,int,QTextFormat)
    if (numArgs == 3 && Shiboken::Converter<QTextInlineObject >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QTextFormat & >::isConvertible(pyargs[2])) {
        overloadId = 0; // positionInlineObject(QTextInlineObject,int,QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_positionInlineObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QTextInlineObject* cpp_arg0 = Shiboken::Converter<QTextInlineObject* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QTextFormat* cpp_arg2 = Shiboken::Converter<QTextFormat* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // positionInlineObject(QTextInlineObject,int,QTextFormat)
            cppSelf->QAbstractTextDocumentLayout::positionInlineObject(*cpp_arg0, cpp_arg1, *cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTextDocumentLayoutFunc_positionInlineObject_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextInlineObject, int, PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout.positionInlineObject", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_registerHandler(PyObject* self, PyObject* args)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "registerHandler", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: registerHandler(int,QObject*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        overloadId = 0; // registerHandler(int,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_registerHandler_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // registerHandler(int,QObject*)
            cppSelf->QAbstractTextDocumentLayout::registerHandler(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTextDocumentLayoutFunc_registerHandler_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout.registerHandler", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_resizeInlineObject(PyObject* self, PyObject* args)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resizeInlineObject", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: resizeInlineObject(QTextInlineObject,int,QTextFormat)
    if (numArgs == 3 && Shiboken::Converter<QTextInlineObject >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QTextFormat & >::isConvertible(pyargs[2])) {
        overloadId = 0; // resizeInlineObject(QTextInlineObject,int,QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_resizeInlineObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QTextInlineObject* cpp_arg0 = Shiboken::Converter<QTextInlineObject* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QTextFormat* cpp_arg2 = Shiboken::Converter<QTextFormat* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // resizeInlineObject(QTextInlineObject,int,QTextFormat)
            cppSelf->QAbstractTextDocumentLayout::resizeInlineObject(*cpp_arg0, cpp_arg1, *cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTextDocumentLayoutFunc_resizeInlineObject_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextInlineObject, int, PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractTextDocumentLayout.resizeInlineObject", overloads);
        return 0;
}

static PyObject* SbkQAbstractTextDocumentLayoutFunc_setPaintDevice(PyObject* self, PyObject* arg)
{
    QAbstractTextDocumentLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPaintDevice(QPaintDevice*)
    if (Shiboken::Converter<QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // setPaintDevice(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractTextDocumentLayoutFunc_setPaintDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPaintDevice(QPaintDevice*)
            cppSelf->QAbstractTextDocumentLayout::setPaintDevice(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractTextDocumentLayoutFunc_setPaintDevice_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractTextDocumentLayout.setPaintDevice", overloads);
        return 0;
}

static PyMethodDef SbkQAbstractTextDocumentLayout_methods[] = {
    {"anchorAt", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_anchorAt, METH_O},
    {"blockBoundingRect", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_blockBoundingRect, METH_O},
    {"document", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_document, METH_NOARGS},
    {"documentChanged", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_documentChanged, METH_VARARGS},
    {"documentSize", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_documentSize, METH_NOARGS},
    {"draw", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_draw, METH_VARARGS},
    {"drawInlineObject", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_drawInlineObject, METH_VARARGS},
    {"format", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_format, METH_O},
    {"formatIndex", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_formatIndex, METH_O},
    {"frameBoundingRect", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_frameBoundingRect, METH_O},
    {"handlerForObject", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_handlerForObject, METH_O},
    {"hitTest", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_hitTest, METH_VARARGS},
    {"pageCount", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_pageCount, METH_NOARGS},
    {"paintDevice", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_paintDevice, METH_NOARGS},
    {"positionInlineObject", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_positionInlineObject, METH_VARARGS},
    {"registerHandler", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_registerHandler, METH_VARARGS},
    {"resizeInlineObject", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_resizeInlineObject, METH_VARARGS},
    {"setPaintDevice", (PyCFunction)SbkQAbstractTextDocumentLayoutFunc_setPaintDevice, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAbstractTextDocumentLayout_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QAbstractTextDocumentLayout",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAbstractTextDocumentLayout_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAbstractTextDocumentLayout_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAbstractTextDocumentLayout >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAbstractTextDocumentLayout*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQAbstractTextDocumentLayout_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAbstractTextDocumentLayout*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQAbstractTextDocumentLayout_Type;
    return 0;
}


void init_QAbstractTextDocumentLayout(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAbstractTextDocumentLayout_Type);

    SbkQAbstractTextDocumentLayout_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQAbstractTextDocumentLayout_Type.type_discovery = &SbkQAbstractTextDocumentLayout_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQAbstractTextDocumentLayout_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAbstractTextDocumentLayout_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAbstractTextDocumentLayout_Type));
    PyModule_AddObject(module, "QAbstractTextDocumentLayout",
        ((PyObject*)&SbkQAbstractTextDocumentLayout_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("documentSizeChanged", "const QSizeF&", NULL);
    PyDict_SetItemString(SbkQAbstractTextDocumentLayout_Type.super.ht_type.tp_dict, "documentSizeChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("pageCountChanged", "int", NULL);
    PyDict_SetItemString(SbkQAbstractTextDocumentLayout_Type.super.ht_type.tp_dict, "pageCountChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("updateBlock", "const QTextBlock&", NULL);
    PyDict_SetItemString(SbkQAbstractTextDocumentLayout_Type.super.ht_type.tp_dict, "updateBlock", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("update", "const QRectF&", NULL);
    PyDict_SetItemString(SbkQAbstractTextDocumentLayout_Type.super.ht_type.tp_dict, "update", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractTextDocumentLayout >("QAbstractTextDocumentLayout*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractTextDocumentLayout >(typeid(QAbstractTextDocumentLayout).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractTextDocumentLayout >(typeid(QAbstractTextDocumentLayoutWrapper).name());
    PySide::initQtMetaType<QAbstractTextDocumentLayout* >();
}

