/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qaction_wrapper.h"

// Extra includes
#include <QList>
#include <qaction.h>
#include <qactiongroup.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qfont.h>
#include <qgraphicswidget.h>
#include <qicon.h>
#include <qkeysequence.h>
#include <qmenu.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QActionWrapper::QActionWrapper(QObject * parent) : QAction(parent), m_metaObject(0) {
    // ... middle
}

QActionWrapper::QActionWrapper(const QIcon & icon, const QString & text, QObject * parent) : QAction(icon, text, parent), m_metaObject(0) {
    // ... middle
}

QActionWrapper::QActionWrapper(const QString & text, QObject * parent) : QAction(text, parent), m_metaObject(0) {
    // ... middle
}

void QActionWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QActionWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QActionWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QActionWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QActionWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QAction::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAction.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QActionWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAction.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QActionWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QActionWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QAction::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QActionWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAction::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QActionWrapper::~QActionWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAction_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAction >()))
        return -1;

    QActionWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QAction", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QAction(QObject*)
    // 1: QAction(QIcon,QString,QObject*)
    // 2: QAction(QString,QObject*)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        overloadId = 2; // QAction(QString,QObject*)
    } else if (numArgs == 3 && Shiboken::Converter<const QIcon & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
        overloadId = 1; // QAction(QIcon,QString,QObject*)
    } else if (numArgs == 1 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QAction(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAction_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QAction(QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QAction(QObject*)
                cptr = new QActionWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QAction(QIcon,QString,QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QIcon > cpp_arg0_auto_ptr;
                QIcon* cpp_arg0 = Shiboken::Converter<QIcon* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QIcon >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QIcon >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = Shiboken::Converter<QObject* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // QAction(QIcon,QString,QObject*)
                cptr = new QActionWrapper(*cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
            case 2: // QAction(QString,QObject*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QAction(QString,QObject*)
                cptr = new QActionWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAction >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAction_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQAction_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", "PySide.QtGui.QIcon, QString, PySide.QtCore.QObject", "QString, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAction", overloads);
        return -1;
}

static PyObject* SbkQActionFunc_actionGroup(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // actionGroup()const
            QActionGroup * cppResult = cppSelf->QAction::actionGroup();
            pyResult = Shiboken::Converter<QActionGroup * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_activate(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: activate(QAction::ActionEvent)
    if (Shiboken::Converter<QAction::ActionEvent >::isConvertible(arg)) {
        overloadId = 0; // activate(QAction::ActionEvent)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_activate_TypeError;

    // Call function/method
    {
        {
            QAction::ActionEvent cpp_arg0 = Shiboken::Converter<QAction::ActionEvent >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // activate(QAction::ActionEvent)
            cppSelf->QAction::activate(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_activate_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction.ActionEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.activate", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_associatedGraphicsWidgets(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // associatedGraphicsWidgets()const
            QList<QGraphicsWidget * > cppResult = cppSelf->QAction::associatedGraphicsWidgets();
            pyResult = Shiboken::Converter<QList<QGraphicsWidget * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_associatedWidgets(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // associatedWidgets()const
            QList<QWidget * > cppResult = cppSelf->QAction::associatedWidgets();
            pyResult = Shiboken::Converter<QList<QWidget * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_autoRepeat(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoRepeat()const
            bool cppResult = cppSelf->QAction::autoRepeat();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_data(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // data()const
            QVariant cppResult = cppSelf->QAction::data();
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_event(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QAction::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQActionFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.event", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_font(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // font()const
            QFont cppResult = cppSelf->QAction::font();
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_hover(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hover()
            cppSelf->QAction::hover();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQActionFunc_icon(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // icon()const
            QIcon cppResult = cppSelf->QAction::icon();
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_iconText(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // iconText()const
            QString cppResult = cppSelf->QAction::iconText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_isCheckable(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCheckable()const
            bool cppResult = cppSelf->QAction::isCheckable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_isChecked(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isChecked()const
            bool cppResult = cppSelf->QAction::isChecked();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_isEnabled(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEnabled()const
            bool cppResult = cppSelf->QAction::isEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_isIconVisibleInMenu(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isIconVisibleInMenu()const
            bool cppResult = cppSelf->QAction::isIconVisibleInMenu();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_isSeparator(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSeparator()const
            bool cppResult = cppSelf->QAction::isSeparator();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_isVisible(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isVisible()const
            bool cppResult = cppSelf->QAction::isVisible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_menu(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // menu()const
            QMenu * cppResult = cppSelf->QAction::menu();
            pyResult = Shiboken::Converter<QMenu * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_menuRole(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // menuRole()const
            QAction::MenuRole cppResult = cppSelf->QAction::menuRole();
            pyResult = Shiboken::Converter<QAction::MenuRole >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_parentWidget(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentWidget()const
            QWidget * cppResult = cppSelf->QAction::parentWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_priority(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // priority()const
            QAction::Priority cppResult = cppSelf->QAction::priority();
            pyResult = Shiboken::Converter<QAction::Priority >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_setActionGroup(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActionGroup(QActionGroup*)
    if (Shiboken::Converter<QActionGroup * >::isConvertible(arg)) {
        overloadId = 0; // setActionGroup(QActionGroup*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setActionGroup_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QActionGroup* cpp_arg0 = Shiboken::Converter<QActionGroup* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setActionGroup(QActionGroup*)
            cppSelf->QAction::setActionGroup(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setActionGroup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QActionGroup", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setActionGroup", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setAutoRepeat(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoRepeat(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoRepeat(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setAutoRepeat_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoRepeat(bool)
            cppSelf->QAction::setAutoRepeat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setAutoRepeat_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setAutoRepeat", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setCheckable(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCheckable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCheckable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setCheckable_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCheckable(bool)
            cppSelf->QAction::setCheckable(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setCheckable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setCheckable", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setChecked(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChecked(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setChecked(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setChecked_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setChecked(bool)
            cppSelf->QAction::setChecked(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setChecked_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setChecked", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setData(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setData(QVariant)
    if (Shiboken::Converter<QVariant >::isConvertible(arg)) {
        overloadId = 0; // setData(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setData_TypeError;

    // Call function/method
    {
        {
            QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setData(QVariant)
            cppSelf->QAction::setData(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setData_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setData", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setDisabled(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDisabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDisabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setDisabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDisabled(bool)
            cppSelf->QAction::setDisabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setDisabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setDisabled", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEnabled(bool)
            cppSelf->QAction::setEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setEnabled", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setFont(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFont(QFont)
            cppSelf->QAction::setFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setFont", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setIcon(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIcon(QIcon)
    if (Shiboken::Converter<const QIcon & >::isConvertible(arg)) {
        overloadId = 0; // setIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setIcon_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QIcon > cpp_arg0_auto_ptr;
            QIcon* cpp_arg0 = Shiboken::Converter<QIcon* >::toCpp(arg);
            if (!Shiboken::Converter<QIcon >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QIcon >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setIcon(QIcon)
            cppSelf->QAction::setIcon(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setIcon", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setIconText(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setIconText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setIconText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIconText(QString)
            cppSelf->QAction::setIconText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setIconText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setIconText", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setIconVisibleInMenu(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconVisibleInMenu(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIconVisibleInMenu(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setIconVisibleInMenu_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIconVisibleInMenu(bool)
            cppSelf->QAction::setIconVisibleInMenu(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setIconVisibleInMenu_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setIconVisibleInMenu", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setMenu(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMenu(QMenu*)
    if (Shiboken::Converter<QMenu * >::isConvertible(arg)) {
        overloadId = 0; // setMenu(QMenu*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setMenu_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMenu* cpp_arg0 = Shiboken::Converter<QMenu* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMenu(QMenu*)
            cppSelf->QAction::setMenu(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setMenu_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMenu", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setMenu", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setMenuRole(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMenuRole(QAction::MenuRole)
    if (Shiboken::Converter<QAction::MenuRole >::isConvertible(arg)) {
        overloadId = 0; // setMenuRole(QAction::MenuRole)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setMenuRole_TypeError;

    // Call function/method
    {
        {
            QAction::MenuRole cpp_arg0 = Shiboken::Converter<QAction::MenuRole >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMenuRole(QAction::MenuRole)
            cppSelf->QAction::setMenuRole(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setMenuRole_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction.MenuRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setMenuRole", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setPriority(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPriority(QAction::Priority)
    if (Shiboken::Converter<QAction::Priority >::isConvertible(arg)) {
        overloadId = 0; // setPriority(QAction::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setPriority_TypeError;

    // Call function/method
    {
        {
            QAction::Priority cpp_arg0 = Shiboken::Converter<QAction::Priority >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPriority(QAction::Priority)
            cppSelf->QAction::setPriority(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setPriority_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction.Priority", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setPriority", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setSeparator(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSeparator(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSeparator(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setSeparator_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSeparator(bool)
            cppSelf->QAction::setSeparator(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setSeparator_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setSeparator", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setShortcut(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setShortcut(QKeySequence)
    if (Shiboken::Converter<const QKeySequence & >::isConvertible(arg)) {
        overloadId = 0; // setShortcut(QKeySequence)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setShortcut_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QKeySequence > cpp_arg0_auto_ptr;
            QKeySequence* cpp_arg0 = Shiboken::Converter<QKeySequence* >::toCpp(arg);
            if (!Shiboken::Converter<QKeySequence >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QKeySequence >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setShortcut(QKeySequence)
            cppSelf->QAction::setShortcut(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setShortcut_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setShortcut", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setShortcutContext(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setShortcutContext(Qt::ShortcutContext)
    if (Shiboken::Converter<Qt::ShortcutContext >::isConvertible(arg)) {
        overloadId = 0; // setShortcutContext(Qt::ShortcutContext)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setShortcutContext_TypeError;

    // Call function/method
    {
        {
            Qt::ShortcutContext cpp_arg0 = Shiboken::Converter<Qt::ShortcutContext >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setShortcutContext(Qt::ShortcutContext)
            cppSelf->QAction::setShortcutContext(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setShortcutContext_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ShortcutContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setShortcutContext", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setShortcuts(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setShortcuts(QKeySequence::StandardKey)
    // 1: setShortcuts(QList<QKeySequence>)
    if (Shiboken::Converter< QList<QKeySequence >  >::isConvertible(arg)) {
        overloadId = 1; // setShortcuts(QList<QKeySequence>)
    } else if (Shiboken::Converter<QKeySequence::StandardKey >::isConvertible(arg)) {
        overloadId = 0; // setShortcuts(QKeySequence::StandardKey)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setShortcuts_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setShortcuts(QKeySequence::StandardKey)
            {
                QKeySequence::StandardKey cpp_arg0 = Shiboken::Converter<QKeySequence::StandardKey >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setShortcuts(QKeySequence::StandardKey)
                cppSelf->QAction::setShortcuts(cpp_arg0);
                }
                break;
            }
            case 1: // setShortcuts(QList<QKeySequence>)
            {
                QList<QKeySequence > cpp_arg0 = Shiboken::Converter<QList<QKeySequence > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setShortcuts(QList<QKeySequence>)
                cppSelf->QAction::setShortcuts(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setShortcuts_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence.StandardKey", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setShortcuts", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setSoftKeyRole(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSoftKeyRole(QAction::SoftKeyRole)
    if (Shiboken::Converter<QAction::SoftKeyRole >::isConvertible(arg)) {
        overloadId = 0; // setSoftKeyRole(QAction::SoftKeyRole)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setSoftKeyRole_TypeError;

    // Call function/method
    {
        {
            QAction::SoftKeyRole cpp_arg0 = Shiboken::Converter<QAction::SoftKeyRole >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSoftKeyRole(QAction::SoftKeyRole)
            cppSelf->QAction::setSoftKeyRole(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setSoftKeyRole_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction.SoftKeyRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setSoftKeyRole", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setStatusTip(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatusTip(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setStatusTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setStatusTip_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStatusTip(QString)
            cppSelf->QAction::setStatusTip(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setStatusTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setStatusTip", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setText(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setText(QString)
            cppSelf->QAction::setText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setText", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setToolTip(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setToolTip(QString)
            cppSelf->QAction::setToolTip(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setToolTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setToolTip", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setVisible(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisible(bool)
            cppSelf->QAction::setVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setVisible", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_setWhatsThis(PyObject* self, PyObject* arg)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWhatsThis(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWhatsThis(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWhatsThis(QString)
            cppSelf->QAction::setWhatsThis(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.setWhatsThis", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_shortcut(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shortcut()const
            QKeySequence cppResult = cppSelf->QAction::shortcut();
            pyResult = Shiboken::Converter<QKeySequence >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_shortcutContext(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shortcutContext()const
            Qt::ShortcutContext cppResult = cppSelf->QAction::shortcutContext();
            pyResult = Shiboken::Converter<Qt::ShortcutContext >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_shortcuts(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shortcuts()const
            QList<QKeySequence > cppResult = cppSelf->QAction::shortcuts();
            pyResult = Shiboken::Converter<QList<QKeySequence > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_showStatusText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "widget" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QAction.showStatusText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QAction.showStatusText(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:showStatusText", &arg))
        return 0;


    // Overloaded function decisor
    // 0: showStatusText(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // showStatusText(QWidget*)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // showStatusText(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionFunc_showStatusText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (arg)
                        errorArgName = "widget";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QAction.showStatusText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = arg ? Shiboken::Converter<QWidget* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // showStatusText(QWidget*)
            bool cppResult = cppSelf->QAction::showStatusText(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQActionFunc_showStatusText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAction.showStatusText", overloads);
        return 0;
}

static PyObject* SbkQActionFunc_softKeyRole(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // softKeyRole()const
            QAction::SoftKeyRole cppResult = cppSelf->QAction::softKeyRole();
            pyResult = Shiboken::Converter<QAction::SoftKeyRole >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_statusTip(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // statusTip()const
            QString cppResult = cppSelf->QAction::statusTip();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_text(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QString cppResult = cppSelf->QAction::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_toggle(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toggle()
            cppSelf->QAction::toggle();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQActionFunc_toolTip(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toolTip()const
            QString cppResult = cppSelf->QAction::toolTip();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionFunc_trigger(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // trigger()
            cppSelf->QAction::trigger();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQActionFunc_whatsThis(PyObject* self)
{
    QAction* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAction* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // whatsThis()const
            QString cppResult = cppSelf->QAction::whatsThis();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQAction_methods[] = {
    {"actionGroup", (PyCFunction)SbkQActionFunc_actionGroup, METH_NOARGS},
    {"activate", (PyCFunction)SbkQActionFunc_activate, METH_O},
    {"associatedGraphicsWidgets", (PyCFunction)SbkQActionFunc_associatedGraphicsWidgets, METH_NOARGS},
    {"associatedWidgets", (PyCFunction)SbkQActionFunc_associatedWidgets, METH_NOARGS},
    {"autoRepeat", (PyCFunction)SbkQActionFunc_autoRepeat, METH_NOARGS},
    {"data", (PyCFunction)SbkQActionFunc_data, METH_NOARGS},
    {"event", (PyCFunction)SbkQActionFunc_event, METH_O},
    {"font", (PyCFunction)SbkQActionFunc_font, METH_NOARGS},
    {"hover", (PyCFunction)SbkQActionFunc_hover, METH_NOARGS},
    {"icon", (PyCFunction)SbkQActionFunc_icon, METH_NOARGS},
    {"iconText", (PyCFunction)SbkQActionFunc_iconText, METH_NOARGS},
    {"isCheckable", (PyCFunction)SbkQActionFunc_isCheckable, METH_NOARGS},
    {"isChecked", (PyCFunction)SbkQActionFunc_isChecked, METH_NOARGS},
    {"isEnabled", (PyCFunction)SbkQActionFunc_isEnabled, METH_NOARGS},
    {"isIconVisibleInMenu", (PyCFunction)SbkQActionFunc_isIconVisibleInMenu, METH_NOARGS},
    {"isSeparator", (PyCFunction)SbkQActionFunc_isSeparator, METH_NOARGS},
    {"isVisible", (PyCFunction)SbkQActionFunc_isVisible, METH_NOARGS},
    {"menu", (PyCFunction)SbkQActionFunc_menu, METH_NOARGS},
    {"menuRole", (PyCFunction)SbkQActionFunc_menuRole, METH_NOARGS},
    {"parentWidget", (PyCFunction)SbkQActionFunc_parentWidget, METH_NOARGS},
    {"priority", (PyCFunction)SbkQActionFunc_priority, METH_NOARGS},
    {"setActionGroup", (PyCFunction)SbkQActionFunc_setActionGroup, METH_O},
    {"setAutoRepeat", (PyCFunction)SbkQActionFunc_setAutoRepeat, METH_O},
    {"setCheckable", (PyCFunction)SbkQActionFunc_setCheckable, METH_O},
    {"setChecked", (PyCFunction)SbkQActionFunc_setChecked, METH_O},
    {"setData", (PyCFunction)SbkQActionFunc_setData, METH_O},
    {"setDisabled", (PyCFunction)SbkQActionFunc_setDisabled, METH_O},
    {"setEnabled", (PyCFunction)SbkQActionFunc_setEnabled, METH_O},
    {"setFont", (PyCFunction)SbkQActionFunc_setFont, METH_O},
    {"setIcon", (PyCFunction)SbkQActionFunc_setIcon, METH_O},
    {"setIconText", (PyCFunction)SbkQActionFunc_setIconText, METH_O},
    {"setIconVisibleInMenu", (PyCFunction)SbkQActionFunc_setIconVisibleInMenu, METH_O},
    {"setMenu", (PyCFunction)SbkQActionFunc_setMenu, METH_O},
    {"setMenuRole", (PyCFunction)SbkQActionFunc_setMenuRole, METH_O},
    {"setPriority", (PyCFunction)SbkQActionFunc_setPriority, METH_O},
    {"setSeparator", (PyCFunction)SbkQActionFunc_setSeparator, METH_O},
    {"setShortcut", (PyCFunction)SbkQActionFunc_setShortcut, METH_O},
    {"setShortcutContext", (PyCFunction)SbkQActionFunc_setShortcutContext, METH_O},
    {"setShortcuts", (PyCFunction)SbkQActionFunc_setShortcuts, METH_O},
    {"setSoftKeyRole", (PyCFunction)SbkQActionFunc_setSoftKeyRole, METH_O},
    {"setStatusTip", (PyCFunction)SbkQActionFunc_setStatusTip, METH_O},
    {"setText", (PyCFunction)SbkQActionFunc_setText, METH_O},
    {"setToolTip", (PyCFunction)SbkQActionFunc_setToolTip, METH_O},
    {"setVisible", (PyCFunction)SbkQActionFunc_setVisible, METH_O},
    {"setWhatsThis", (PyCFunction)SbkQActionFunc_setWhatsThis, METH_O},
    {"shortcut", (PyCFunction)SbkQActionFunc_shortcut, METH_NOARGS},
    {"shortcutContext", (PyCFunction)SbkQActionFunc_shortcutContext, METH_NOARGS},
    {"shortcuts", (PyCFunction)SbkQActionFunc_shortcuts, METH_NOARGS},
    {"showStatusText", (PyCFunction)SbkQActionFunc_showStatusText, METH_VARARGS|METH_KEYWORDS},
    {"softKeyRole", (PyCFunction)SbkQActionFunc_softKeyRole, METH_NOARGS},
    {"statusTip", (PyCFunction)SbkQActionFunc_statusTip, METH_NOARGS},
    {"text", (PyCFunction)SbkQActionFunc_text, METH_NOARGS},
    {"toggle", (PyCFunction)SbkQActionFunc_toggle, METH_NOARGS},
    {"toolTip", (PyCFunction)SbkQActionFunc_toolTip, METH_NOARGS},
    {"trigger", (PyCFunction)SbkQActionFunc_trigger, METH_NOARGS},
    {"whatsThis", (PyCFunction)SbkQActionFunc_whatsThis, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAction_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QAction",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAction_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAction_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAction >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAction*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQAction_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAction*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQAction_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QAction_Priority_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAction_Priority_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAction_Priority_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Priority",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAction_Priority_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAction_Priority_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAction_Priority_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAction_ActionEvent_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAction_ActionEvent_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAction_ActionEvent_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ActionEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAction_ActionEvent_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAction_ActionEvent_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAction_ActionEvent_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAction_SoftKeyRole_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAction_SoftKeyRole_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAction_SoftKeyRole_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SoftKeyRole",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAction_SoftKeyRole_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAction_SoftKeyRole_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAction_SoftKeyRole_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAction_MenuRole_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAction_MenuRole_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAction_MenuRole_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MenuRole",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAction_MenuRole_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAction_MenuRole_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAction_MenuRole_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QAction(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QACTION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAction_Type);

    SbkQAction_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQAction_Type.type_discovery = &SbkQAction_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQAction_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAction_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAction_Type));
    PyModule_AddObject(module, "QAction",
        ((PyObject*)&SbkQAction_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Priority
    SbkPySide_QtGuiTypes[SBK_QACTION_PRIORITY_IDX] = &SbkPySide_QtGui_QAction_Priority_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAction_Priority_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAction_Priority_Type);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
            "Priority",((PyObject*)&SbkPySide_QtGui_QAction_Priority_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_Priority_Type,
        (long) QAction::LowPriority, "LowPriority");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "LowPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_Priority_Type.tp_dict,
        "LowPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_Priority_Type,
        (long) QAction::NormalPriority, "NormalPriority");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "NormalPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_Priority_Type.tp_dict,
        "NormalPriority", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_Priority_Type,
        (long) QAction::HighPriority, "HighPriority");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "HighPriority", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_Priority_Type.tp_dict,
        "HighPriority", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAction::Priority");

    // init enum class: ActionEvent
    SbkPySide_QtGuiTypes[SBK_QACTION_ACTIONEVENT_IDX] = &SbkPySide_QtGui_QAction_ActionEvent_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAction_ActionEvent_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAction_ActionEvent_Type);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
            "ActionEvent",((PyObject*)&SbkPySide_QtGui_QAction_ActionEvent_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_ActionEvent_Type,
        (long) QAction::Trigger, "Trigger");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "Trigger", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_ActionEvent_Type.tp_dict,
        "Trigger", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_ActionEvent_Type,
        (long) QAction::Hover, "Hover");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "Hover", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_ActionEvent_Type.tp_dict,
        "Hover", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAction::ActionEvent");

    // init enum class: SoftKeyRole
    SbkPySide_QtGuiTypes[SBK_QACTION_SOFTKEYROLE_IDX] = &SbkPySide_QtGui_QAction_SoftKeyRole_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAction_SoftKeyRole_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAction_SoftKeyRole_Type);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
            "SoftKeyRole",((PyObject*)&SbkPySide_QtGui_QAction_SoftKeyRole_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_SoftKeyRole_Type,
        (long) QAction::NoSoftKey, "NoSoftKey");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "NoSoftKey", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_SoftKeyRole_Type.tp_dict,
        "NoSoftKey", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_SoftKeyRole_Type,
        (long) QAction::PositiveSoftKey, "PositiveSoftKey");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "PositiveSoftKey", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_SoftKeyRole_Type.tp_dict,
        "PositiveSoftKey", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_SoftKeyRole_Type,
        (long) QAction::NegativeSoftKey, "NegativeSoftKey");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "NegativeSoftKey", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_SoftKeyRole_Type.tp_dict,
        "NegativeSoftKey", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_SoftKeyRole_Type,
        (long) QAction::SelectSoftKey, "SelectSoftKey");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "SelectSoftKey", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_SoftKeyRole_Type.tp_dict,
        "SelectSoftKey", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAction::SoftKeyRole");

    // init enum class: MenuRole
    SbkPySide_QtGuiTypes[SBK_QACTION_MENUROLE_IDX] = &SbkPySide_QtGui_QAction_MenuRole_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAction_MenuRole_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAction_MenuRole_Type);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
            "MenuRole",((PyObject*)&SbkPySide_QtGui_QAction_MenuRole_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_MenuRole_Type,
        (long) QAction::NoRole, "NoRole");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "NoRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_MenuRole_Type.tp_dict,
        "NoRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_MenuRole_Type,
        (long) QAction::TextHeuristicRole, "TextHeuristicRole");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "TextHeuristicRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_MenuRole_Type.tp_dict,
        "TextHeuristicRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_MenuRole_Type,
        (long) QAction::ApplicationSpecificRole, "ApplicationSpecificRole");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "ApplicationSpecificRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_MenuRole_Type.tp_dict,
        "ApplicationSpecificRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_MenuRole_Type,
        (long) QAction::AboutQtRole, "AboutQtRole");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "AboutQtRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_MenuRole_Type.tp_dict,
        "AboutQtRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_MenuRole_Type,
        (long) QAction::AboutRole, "AboutRole");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "AboutRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_MenuRole_Type.tp_dict,
        "AboutRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_MenuRole_Type,
        (long) QAction::PreferencesRole, "PreferencesRole");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "PreferencesRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_MenuRole_Type.tp_dict,
        "PreferencesRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAction_MenuRole_Type,
        (long) QAction::QuitRole, "QuitRole");
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict,
        "QuitRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAction_MenuRole_Type.tp_dict,
        "QuitRole", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAction::MenuRole");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("triggered", "bool", NULL);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict, "triggered", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("toggled", "bool", NULL);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict, "toggled", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("changed", "void", NULL);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict, "changed", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("hovered", "void", NULL);
    PyDict_SetItemString(SbkQAction_Type.super.ht_type.tp_dict, "hovered", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QAction >("QAction*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAction >(typeid(QAction).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAction >(typeid(QActionWrapper).name());
    PySide::initQtMetaType<QAction* >();
}

