/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qactiongroup_wrapper.h"

// Extra includes
#include <QList>
#include <qaction.h>
#include <qactiongroup.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qicon.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QActionGroupWrapper::QActionGroupWrapper(QObject * parent) : QActionGroup(parent), m_metaObject(0) {
    // ... middle
}

void QActionGroupWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QActionGroupWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QActionGroupWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QActionGroupWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QActionGroupWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QActionGroup.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QActionGroupWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QActionGroup.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QActionGroupWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QActionGroupWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QActionGroup::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QActionGroupWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QActionGroup::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QActionGroupWrapper::~QActionGroupWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQActionGroup_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QActionGroup >()))
        return -1;

    QActionGroupWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QActionGroup", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QActionGroup(QObject*)
    if (numArgs == 1 && Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QActionGroup(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionGroup_Init_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // QActionGroup(QObject*)
            cptr = new QActionGroupWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QActionGroup >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQActionGroup_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQActionGroup_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QActionGroup", overloads);
        return -1;
}

static PyObject* SbkQActionGroupFunc_actions(PyObject* self)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // actions()const
            QList<QAction * > cppResult = cppSelf->QActionGroup::actions();
            pyResult = Shiboken::Converter<QList<QAction * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionGroupFunc_addAction(PyObject* self, PyObject* args)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addAction", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addAction(QAction*)
    // 1: addAction(QIcon,QString)
    // 2: addAction(QString)
    if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 2; // addAction(QString)
    } else if (numArgs == 2 && Shiboken::Converter<const QIcon & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // addAction(QIcon,QString)
    } else if (numArgs == 1 && Shiboken::Converter<QAction * >::isConvertible(pyargs[0])) {
        overloadId = 0; // addAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionGroupFunc_addAction_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addAction(QAction*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QAction* cpp_arg0 = Shiboken::Converter<QAction* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addAction(QAction*)
                QAction * cppResult = cppSelf->QActionGroup::addAction(cpp_arg0);
                pyResult = Shiboken::Converter<QAction * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // addAction(QIcon,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QIcon > cpp_arg0_auto_ptr;
                QIcon* cpp_arg0 = Shiboken::Converter<QIcon* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QIcon >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QIcon >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addAction(QIcon,QString)
                QAction * cppResult = cppSelf->QActionGroup::addAction(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QAction * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 2: // addAction(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addAction(QString)
                QAction * cppResult = cppSelf->QActionGroup::addAction(cpp_arg0);
                pyResult = Shiboken::Converter<QAction * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQActionGroupFunc_addAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction", "PySide.QtGui.QIcon, QString", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QActionGroup.addAction", overloads);
        return 0;
}

static PyObject* SbkQActionGroupFunc_checkedAction(PyObject* self)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // checkedAction()const
            QAction * cppResult = cppSelf->QActionGroup::checkedAction();
            pyResult = Shiboken::Converter<QAction * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionGroupFunc_isEnabled(PyObject* self)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEnabled()const
            bool cppResult = cppSelf->QActionGroup::isEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionGroupFunc_isExclusive(PyObject* self)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isExclusive()const
            bool cppResult = cppSelf->QActionGroup::isExclusive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionGroupFunc_isVisible(PyObject* self)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isVisible()const
            bool cppResult = cppSelf->QActionGroup::isVisible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQActionGroupFunc_removeAction(PyObject* self, PyObject* arg)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAction(QAction*)
    if (Shiboken::Converter<QAction * >::isConvertible(arg)) {
        overloadId = 0; // removeAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionGroupFunc_removeAction_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAction* cpp_arg0 = Shiboken::Converter<QAction* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAction(QAction*)
            cppSelf->QActionGroup::removeAction(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionGroupFunc_removeAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QActionGroup.removeAction", overloads);
        return 0;
}

static PyObject* SbkQActionGroupFunc_setDisabled(PyObject* self, PyObject* arg)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDisabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDisabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionGroupFunc_setDisabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDisabled(bool)
            cppSelf->QActionGroup::setDisabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionGroupFunc_setDisabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QActionGroup.setDisabled", overloads);
        return 0;
}

static PyObject* SbkQActionGroupFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionGroupFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEnabled(bool)
            cppSelf->QActionGroup::setEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionGroupFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QActionGroup.setEnabled", overloads);
        return 0;
}

static PyObject* SbkQActionGroupFunc_setExclusive(PyObject* self, PyObject* arg)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setExclusive(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setExclusive(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionGroupFunc_setExclusive_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setExclusive(bool)
            cppSelf->QActionGroup::setExclusive(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionGroupFunc_setExclusive_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QActionGroup.setExclusive", overloads);
        return 0;
}

static PyObject* SbkQActionGroupFunc_setVisible(PyObject* self, PyObject* arg)
{
    QActionGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QActionGroup* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQActionGroupFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisible(bool)
            cppSelf->QActionGroup::setVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQActionGroupFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QActionGroup.setVisible", overloads);
        return 0;
}

static PyMethodDef SbkQActionGroup_methods[] = {
    {"actions", (PyCFunction)SbkQActionGroupFunc_actions, METH_NOARGS},
    {"addAction", (PyCFunction)SbkQActionGroupFunc_addAction, METH_VARARGS},
    {"checkedAction", (PyCFunction)SbkQActionGroupFunc_checkedAction, METH_NOARGS},
    {"isEnabled", (PyCFunction)SbkQActionGroupFunc_isEnabled, METH_NOARGS},
    {"isExclusive", (PyCFunction)SbkQActionGroupFunc_isExclusive, METH_NOARGS},
    {"isVisible", (PyCFunction)SbkQActionGroupFunc_isVisible, METH_NOARGS},
    {"removeAction", (PyCFunction)SbkQActionGroupFunc_removeAction, METH_O},
    {"setDisabled", (PyCFunction)SbkQActionGroupFunc_setDisabled, METH_O},
    {"setEnabled", (PyCFunction)SbkQActionGroupFunc_setEnabled, METH_O},
    {"setExclusive", (PyCFunction)SbkQActionGroupFunc_setExclusive, METH_O},
    {"setVisible", (PyCFunction)SbkQActionGroupFunc_setVisible, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQActionGroup_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QActionGroup",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQActionGroup_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQActionGroup_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QActionGroup >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QActionGroup*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQActionGroup_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QActionGroup*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQActionGroup_Type;
    return 0;
}


void init_QActionGroup(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QACTIONGROUP_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQActionGroup_Type);

    SbkQActionGroup_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQActionGroup_Type.type_discovery = &SbkQActionGroup_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQActionGroup_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQActionGroup_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQActionGroup_Type));
    PyModule_AddObject(module, "QActionGroup",
        ((PyObject*)&SbkQActionGroup_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("triggered", "QAction*", NULL);
    PyDict_SetItemString(SbkQActionGroup_Type.super.ht_type.tp_dict, "triggered", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("hovered", "QAction*", NULL);
    PyDict_SetItemString(SbkQActionGroup_Type.super.ht_type.tp_dict, "hovered", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QActionGroup >("QActionGroup*");
    Shiboken::TypeResolver::createObjectTypeResolver<QActionGroup >(typeid(QActionGroup).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QActionGroup >(typeid(QActionGroupWrapper).name());
    PySide::initQtMetaType<QActionGroup* >();
}

