/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qbrush_wrapper.h"

// Extra includes
#include <QPixmap>
#include <qbrush.h>
#include <qcolor.h>
#include <qdatastream.h>
#include <qimage.h>
#include <qmatrix.h>
#include <qpixmap.h>
#include <qtransform.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQBrush_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QBrush >()))
        return -1;

    QBrush* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "bs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QBrush(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QBrush(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QBrush", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QBrush()
    // 1: QBrush(Qt::BrushStyle)
    // 2: QBrush(Qt::GlobalColor,Qt::BrushStyle)
    // 3: QBrush(Qt::GlobalColor,QPixmap)
    // 4: QBrush(QBrush)
    // 5: QBrush(QColor,Qt::BrushStyle)
    // 6: QBrush(QColor,QPixmap)
    // 7: QBrush(QGradient)
    // 8: QBrush(QImage)
    // 9: QBrush(QPixmap)
    if (numArgs == 0) {
        overloadId = 0; // QBrush()
    } else if (numArgs == 1 && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[0])) {
        overloadId = 9; // QBrush(QPixmap)
    } else if (numArgs == 1 && Shiboken::Converter<const QImage & >::isConvertible(pyargs[0])) {
        overloadId = 8; // QBrush(QImage)
    } else if (numArgs == 1 && Shiboken::Converter<const QGradient & >::isConvertible(pyargs[0])) {
        overloadId = 7; // QBrush(QGradient)
    } else if (Shiboken::Converter<Qt::GlobalColor >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QBrush(Qt::GlobalColor,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
            overloadId = 3; // QBrush(Qt::GlobalColor,QPixmap)
        } else if (Shiboken::Converter<Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 2; // QBrush(Qt::GlobalColor,Qt::BrushStyle)
        }
    } else if (Shiboken::Converter<const QColor & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 5; // QBrush(QColor,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
            overloadId = 6; // QBrush(QColor,QPixmap)
        } else if (Shiboken::Converter<Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 5; // QBrush(QColor,Qt::BrushStyle)
        }
    } else if (numArgs == 1 && Shiboken::Converter<Qt::BrushStyle >::isConvertible(pyargs[0])) {
        overloadId = 1; // QBrush(Qt::BrushStyle)
    } else if (numArgs == 1 && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[0])) {
        overloadId = 4; // QBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrush_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QBrush()
            {

                if(!PyErr_Occurred()) {
                // QBrush()
                cptr = new QBrush();
                }
                break;
            }
            case 1: // QBrush(Qt::BrushStyle)
            {
                Qt::BrushStyle cpp_arg0 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QBrush(Qt::BrushStyle)
                cptr = new QBrush(cpp_arg0);
                }
                break;
            }
            case 2: // QBrush(Qt::GlobalColor,Qt::BrushStyle)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "bs");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "bs";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QBrush(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                Qt::GlobalColor cpp_arg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[0]);
                Qt::BrushStyle cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]) : Qt::SolidPattern;

                if(!PyErr_Occurred()) {
                // QBrush(Qt::GlobalColor,Qt::BrushStyle)
                cptr = new QBrush(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QBrush(Qt::GlobalColor,QPixmap)
            {
                Qt::GlobalColor cpp_arg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QBrush(Qt::GlobalColor,QPixmap)
                cptr = new QBrush(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // QBrush(QBrush)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
                QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QBrush >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QBrush(QBrush)
                cptr = new QBrush(*cpp_arg0);
                }
                break;
            }
            case 5: // QBrush(QColor,Qt::BrushStyle)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "bs");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "bs";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QBrush(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);
                Qt::BrushStyle cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]) : Qt::SolidPattern;

                if(!PyErr_Occurred()) {
                // QBrush(QColor,Qt::BrushStyle)
                cptr = new QBrush(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 6: // QBrush(QColor,QPixmap)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QBrush(QColor,QPixmap)
                cptr = new QBrush(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 7: // QBrush(QGradient)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QGradient* cpp_arg0 = Shiboken::Converter<QGradient* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QBrush(QGradient)
                cptr = new QBrush(*cpp_arg0);
                }
                break;
            }
            case 8: // QBrush(QImage)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QBrush(QImage)
                cptr = new QBrush(*cpp_arg0);
                }
                break;
            }
            case 9: // QBrush(QPixmap)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
                QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QBrush(QPixmap)
                cptr = new QBrush(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QBrush >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQBrush_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQBrush_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.BrushStyle", "PySide.QtCore.Qt.GlobalColor, PySide.QtCore.Qt.BrushStyle = Qt.SolidPattern", "PySide.QtCore.Qt.GlobalColor, PySide.QtGui.QPixmap", "PySide.QtGui.QBrush", "PySide.QtGui.QColor, PySide.QtCore.Qt.BrushStyle = Qt.SolidPattern", "PySide.QtGui.QColor, PySide.QtGui.QPixmap", "PySide.QtGui.QGradient", "PySide.QtGui.QImage", "PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QBrush", overloads);
        return -1;
}

static PyObject* SbkQBrushFunc_color(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // color()const
            const QColor & cppResult = cppSelf->QBrush::color();
            pyResult = Shiboken::Converter<const QColor & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBrushFunc_gradient(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // gradient()const
            const QGradient * cppResult = cppSelf->QBrush::gradient();
            pyResult = Shiboken::Converter<const QGradient * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBrushFunc_isOpaque(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isOpaque()const
            bool cppResult = cppSelf->QBrush::isOpaque();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBrushFunc_matrix(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // matrix()const
            const QMatrix & cppResult = cppSelf->QBrush::matrix();
            pyResult = Shiboken::Converter<const QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBrushFunc_setColor(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColor(Qt::GlobalColor)
    // 1: setColor(QColor)
    if (Shiboken::Converter<Qt::GlobalColor >::isConvertible(arg)) {
        overloadId = 0; // setColor(Qt::GlobalColor)
    } else if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 1; // setColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc_setColor_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setColor(Qt::GlobalColor)
            {
                Qt::GlobalColor cpp_arg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setColor(Qt::GlobalColor)
                cppSelf->QBrush::setColor(cpp_arg0);
                }
                break;
            }
            case 1: // setColor(QColor)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
                if (!Shiboken::Converter<QColor >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setColor(QColor)
                cppSelf->QBrush::setColor(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQBrushFunc_setColor_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.GlobalColor", "PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setColor", overloads);
        return 0;
}

static PyObject* SbkQBrushFunc_setMatrix(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMatrix(QMatrix)
    if (Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // setMatrix(QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc_setMatrix_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMatrix(QMatrix)
            cppSelf->QBrush::setMatrix(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQBrushFunc_setMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setMatrix", overloads);
        return 0;
}

static PyObject* SbkQBrushFunc_setStyle(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(Qt::BrushStyle)
    if (Shiboken::Converter<Qt::BrushStyle >::isConvertible(arg)) {
        overloadId = 0; // setStyle(Qt::BrushStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            Qt::BrushStyle cpp_arg0 = Shiboken::Converter<Qt::BrushStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStyle(Qt::BrushStyle)
            cppSelf->QBrush::setStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQBrushFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.BrushStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setStyle", overloads);
        return 0;
}

static PyObject* SbkQBrushFunc_setTexture(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTexture(QPixmap)
    if (Shiboken::Converter<const QPixmap & >::isConvertible(arg)) {
        overloadId = 0; // setTexture(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc_setTexture_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
            QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(arg);
            if (!Shiboken::Converter<QPixmap >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setTexture(QPixmap)
            cppSelf->QBrush::setTexture(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQBrushFunc_setTexture_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setTexture", overloads);
        return 0;
}

static PyObject* SbkQBrushFunc_setTextureImage(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextureImage(QImage)
    if (Shiboken::Converter<const QImage & >::isConvertible(arg)) {
        overloadId = 0; // setTextureImage(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc_setTextureImage_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextureImage(QImage)
            cppSelf->QBrush::setTextureImage(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQBrushFunc_setTextureImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setTextureImage", overloads);
        return 0;
}

static PyObject* SbkQBrushFunc_setTransform(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransform(QTransform)
    if (Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 0; // setTransform(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc_setTransform_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTransform(QTransform)
            cppSelf->QBrush::setTransform(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQBrushFunc_setTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.setTransform", overloads);
        return 0;
}

static PyObject* SbkQBrushFunc_style(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()const
            Qt::BrushStyle cppResult = cppSelf->QBrush::style();
            pyResult = Shiboken::Converter<Qt::BrushStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBrushFunc_texture(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // texture()const
            QPixmap cppResult = cppSelf->QBrush::texture();
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBrushFunc_textureImage(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textureImage()const
            QImage cppResult = cppSelf->QBrush::textureImage();
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQBrushFunc_transform(PyObject* self)
{
    QBrush* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transform()const
            QTransform cppResult = cppSelf->QBrush::transform();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQBrush_methods[] = {
    {"color", (PyCFunction)SbkQBrushFunc_color, METH_NOARGS},
    {"gradient", (PyCFunction)SbkQBrushFunc_gradient, METH_NOARGS},
    {"isOpaque", (PyCFunction)SbkQBrushFunc_isOpaque, METH_NOARGS},
    {"matrix", (PyCFunction)SbkQBrushFunc_matrix, METH_NOARGS},
    {"setColor", (PyCFunction)SbkQBrushFunc_setColor, METH_O},
    {"setMatrix", (PyCFunction)SbkQBrushFunc_setMatrix, METH_O},
    {"setStyle", (PyCFunction)SbkQBrushFunc_setStyle, METH_O},
    {"setTexture", (PyCFunction)SbkQBrushFunc_setTexture, METH_O},
    {"setTextureImage", (PyCFunction)SbkQBrushFunc_setTextureImage, METH_O},
    {"setTransform", (PyCFunction)SbkQBrushFunc_setTransform, METH_O},
    {"style", (PyCFunction)SbkQBrushFunc_style, METH_NOARGS},
    {"texture", (PyCFunction)SbkQBrushFunc_texture, METH_NOARGS},
    {"textureImage", (PyCFunction)SbkQBrushFunc_textureImage, METH_NOARGS},
    {"transform", (PyCFunction)SbkQBrushFunc_transform, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQBrushFunc___lshift__(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QBrush >::checkType(arg) && !Shiboken::Converter<QBrush >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QBrush)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QBrush) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQBrushFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQBrushFunc___rshift__(PyObject* self, PyObject* arg)
{
    QBrush* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QBrush >::checkType(arg) && !Shiboken::Converter<QBrush >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QBrush* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QBrush&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QBrush&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQBrushFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QBrush&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQBrushFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QBrush.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQBrush_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQBrushFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQBrushFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQBrush_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QBrush& cpp_self = *Shiboken::Converter<QBrush* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QBrush & >::isConvertible(other)) {
                // operator!=(const QBrush & b) const
                QBrush* cpp_other = Shiboken::Converter<QBrush* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QBrush  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QBrush >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QBrush > cpp_other_auto_ptr;
                QBrush* cpp_other = Shiboken::Converter<QBrush* >::toCpp(other);
                if (!Shiboken::Converter<QBrush >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QBrush >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQBrush_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QBrush & >::isConvertible(other)) {
                // operator==(const QBrush & b) const
                QBrush* cpp_other = Shiboken::Converter<QBrush* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QBrush  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QBrush >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QBrush > cpp_other_auto_ptr;
                QBrush* cpp_other = Shiboken::Converter<QBrush* >::toCpp(other);
                if (!Shiboken::Converter<QBrush >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QBrush >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQBrush_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQBrush_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQBrush_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QBrush",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQBrush_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQBrush_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQBrush_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQBrush_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QBrush >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QBrush",
    /*user_data*/           0
};
} //extern


void init_QBrush(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QBRUSH_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQBrush_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQBrush_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQBrush_Type));
    PyModule_AddObject(module, "QBrush",
        ((PyObject*)&SbkQBrush_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QBrush >("QBrush");
    Shiboken::TypeResolver::createObjectTypeResolver<QBrush >("QBrush*");
    Shiboken::TypeResolver::createValueTypeResolver<QBrush >(typeid(QBrush).name());
    PySide::initQtMetaType<QBrush >();
}

