/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qbuttongroup_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractbutton.h>
#include <qbuttongroup.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QButtonGroupWrapper::QButtonGroupWrapper(QObject * parent) : QButtonGroup(parent), m_metaObject(0) {
    // ... middle
}

void QButtonGroupWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QButtonGroupWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QButtonGroupWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QButtonGroupWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QButtonGroupWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QButtonGroup.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QButtonGroupWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QButtonGroup.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QButtonGroupWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QButtonGroupWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QButtonGroup::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QButtonGroupWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QButtonGroup::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QButtonGroupWrapper::~QButtonGroupWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQButtonGroup_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QButtonGroup >()))
        return -1;

    QButtonGroupWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QButtonGroup", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QButtonGroup(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QButtonGroup(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QButtonGroup(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQButtonGroup_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QButtonGroup(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QButtonGroup(QObject*)
            cptr = new QButtonGroupWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QButtonGroup >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQButtonGroup_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQButtonGroup_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QButtonGroup", overloads);
        return -1;
}

static PyObject* SbkQButtonGroupFunc_addButton(PyObject* self, PyObject* args)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addButton", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addButton(QAbstractButton*)
    // 1: addButton(QAbstractButton*,int)
    if (Shiboken::Converter<QAbstractButton * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addButton(QAbstractButton*)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // addButton(QAbstractButton*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQButtonGroupFunc_addButton_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addButton(QAbstractButton*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addButton(QAbstractButton*)
                cppSelf->QButtonGroup::addButton(cpp_arg0);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // addButton(QAbstractButton*,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addButton(QAbstractButton*,int)
                cppSelf->QButtonGroup::addButton(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQButtonGroupFunc_addButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton", "PySide.QtGui.QAbstractButton, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QButtonGroup.addButton", overloads);
        return 0;
}

static PyObject* SbkQButtonGroupFunc_button(PyObject* self, PyObject* arg)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: button(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // button(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQButtonGroupFunc_button_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // button(int)const
            QAbstractButton * cppResult = cppSelf->QButtonGroup::button(cpp_arg0);
            pyResult = Shiboken::Converter<QAbstractButton * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQButtonGroupFunc_button_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QButtonGroup.button", overloads);
        return 0;
}

static PyObject* SbkQButtonGroupFunc_buttons(PyObject* self)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // buttons()const
            QList<QAbstractButton * > cppResult = cppSelf->QButtonGroup::buttons();
            pyResult = Shiboken::Converter<QList<QAbstractButton * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQButtonGroupFunc_checkedButton(PyObject* self)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // checkedButton()const
            QAbstractButton * cppResult = cppSelf->QButtonGroup::checkedButton();
            pyResult = Shiboken::Converter<QAbstractButton * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQButtonGroupFunc_checkedId(PyObject* self)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // checkedId()const
            int cppResult = cppSelf->QButtonGroup::checkedId();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQButtonGroupFunc_exclusive(PyObject* self)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // exclusive()const
            bool cppResult = cppSelf->QButtonGroup::exclusive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQButtonGroupFunc_id(PyObject* self, PyObject* arg)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: id(QAbstractButton*)const
    if (Shiboken::Converter<QAbstractButton * >::isConvertible(arg)) {
        overloadId = 0; // id(QAbstractButton*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQButtonGroupFunc_id_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // id(QAbstractButton*)const
            int cppResult = cppSelf->QButtonGroup::id(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQButtonGroupFunc_id_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QButtonGroup.id", overloads);
        return 0;
}

static PyObject* SbkQButtonGroupFunc_removeButton(PyObject* self, PyObject* arg)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeButton(QAbstractButton*)
    if (Shiboken::Converter<QAbstractButton * >::isConvertible(arg)) {
        overloadId = 0; // removeButton(QAbstractButton*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQButtonGroupFunc_removeButton_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeButton(QAbstractButton*)
            cppSelf->QButtonGroup::removeButton(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQButtonGroupFunc_removeButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QButtonGroup.removeButton", overloads);
        return 0;
}

static PyObject* SbkQButtonGroupFunc_setExclusive(PyObject* self, PyObject* arg)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setExclusive(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setExclusive(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQButtonGroupFunc_setExclusive_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setExclusive(bool)
            cppSelf->QButtonGroup::setExclusive(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQButtonGroupFunc_setExclusive_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QButtonGroup.setExclusive", overloads);
        return 0;
}

static PyObject* SbkQButtonGroupFunc_setId(PyObject* self, PyObject* args)
{
    QButtonGroup* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QButtonGroup* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setId", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setId(QAbstractButton*,int)
    if (numArgs == 2 && Shiboken::Converter<QAbstractButton * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setId(QAbstractButton*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQButtonGroupFunc_setId_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setId(QAbstractButton*,int)
            cppSelf->QButtonGroup::setId(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[0]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQButtonGroupFunc_setId_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QButtonGroup.setId", overloads);
        return 0;
}

static PyMethodDef SbkQButtonGroup_methods[] = {
    {"addButton", (PyCFunction)SbkQButtonGroupFunc_addButton, METH_VARARGS},
    {"button", (PyCFunction)SbkQButtonGroupFunc_button, METH_O},
    {"buttons", (PyCFunction)SbkQButtonGroupFunc_buttons, METH_NOARGS},
    {"checkedButton", (PyCFunction)SbkQButtonGroupFunc_checkedButton, METH_NOARGS},
    {"checkedId", (PyCFunction)SbkQButtonGroupFunc_checkedId, METH_NOARGS},
    {"exclusive", (PyCFunction)SbkQButtonGroupFunc_exclusive, METH_NOARGS},
    {"id", (PyCFunction)SbkQButtonGroupFunc_id, METH_O},
    {"removeButton", (PyCFunction)SbkQButtonGroupFunc_removeButton, METH_O},
    {"setExclusive", (PyCFunction)SbkQButtonGroupFunc_setExclusive, METH_O},
    {"setId", (PyCFunction)SbkQButtonGroupFunc_setId, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQButtonGroup_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QButtonGroup",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQButtonGroup_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQButtonGroup_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QButtonGroup >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QButtonGroup*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQButtonGroup_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QButtonGroup*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQButtonGroup_Type;
    return 0;
}


void init_QButtonGroup(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QBUTTONGROUP_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQButtonGroup_Type);

    SbkQButtonGroup_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQButtonGroup_Type.type_discovery = &SbkQButtonGroup_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQButtonGroup_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQButtonGroup_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQButtonGroup_Type));
    PyModule_AddObject(module, "QButtonGroup",
        ((PyObject*)&SbkQButtonGroup_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("buttonPressed", "QAbstractButton*", "int", NULL);
    PyDict_SetItemString(SbkQButtonGroup_Type.super.ht_type.tp_dict, "buttonPressed", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("buttonReleased", "QAbstractButton*", "int", NULL);
    PyDict_SetItemString(SbkQButtonGroup_Type.super.ht_type.tp_dict, "buttonReleased", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("buttonClicked", "QAbstractButton*", "int", NULL);
    PyDict_SetItemString(SbkQButtonGroup_Type.super.ht_type.tp_dict, "buttonClicked", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QButtonGroup >("QButtonGroup*");
    Shiboken::TypeResolver::createObjectTypeResolver<QButtonGroup >(typeid(QButtonGroup).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QButtonGroup >(typeid(QButtonGroupWrapper).name());
    PySide::initQtMetaType<QButtonGroup* >();
}

