/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qcolor_wrapper.h"

// Extra includes
#include <QStringList>
#include <QVariant>
#include <qcolor.h>
#include <qdatastream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQColor_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QColor >()))
        return -1;

    QColor* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor(): too many arguments");
        return -1;
    } else if (numArgs == 2)
        goto SbkQColor_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:QColor", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QColor()
    // 1: QColor(QVariant)
    // 2: QColor(Qt::GlobalColor)
    // 3: QColor(QColor)
    // 4: QColor(QString)
    // 5: QColor(int,int,int,int)
    // 6: QColor(uint)
    if (numArgs == 0) {
        overloadId = 0; // QColor()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 4; // QColor(QString)
    } else if (numArgs == 1 && Shiboken::Converter<Qt::GlobalColor >::isConvertible(pyargs[0])) {
        overloadId = 2; // QColor(Qt::GlobalColor)
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 6; // QColor(uint)
    } else if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 5; // QColor(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // QColor(int,int,int,int)
        }
    } else if (numArgs == 1 && Shiboken::Converter<QVariant >::isConvertible(pyargs[0])) {
        overloadId = 1; // QColor(QVariant)
    } else if (numArgs == 1 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColor_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QColor()
            {

                if(!PyErr_Occurred()) {
                // QColor()
                cptr = new QColor();
                }
                break;
            }
            case 1: // QColor(QVariant)
            {
                QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QColor(QVariant)
                // Begin code injection
                
                if (cpp_arg0.type() == QVariant::Color)
                    cptr = new QColor(cpp_arg0.value<QColor>());
                else
                    PyErr_SetString(PyExc_TypeError, "QVariant must be holding a QColor");
                
                // End of code injection

                }
                break;
            }
            case 2: // QColor(Qt::GlobalColor)
            {
                Qt::GlobalColor cpp_arg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QColor(Qt::GlobalColor)
                cptr = new QColor(cpp_arg0);
                }
                break;
            }
            case 3: // QColor(QColor)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QColor(QColor)
                cptr = new QColor(*cpp_arg0);
                }
                break;
            }
            case 4: // QColor(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QColor(QString)
                cptr = new QColor(cpp_arg0);
                }
                break;
            }
            case 5: // QColor(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "a");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "a";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

                if(!PyErr_Occurred()) {
                // QColor(int,int,int,int)
                cptr = new QColor(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 6: // QColor(uint)
            {
                unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QColor(uint)
                cptr = new QColor(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QColor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQColor_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQColor_Init_TypeError:
        const char* overloads[] = {"", "QVariant", "PySide.QtCore.Qt.GlobalColor", "PySide.QtGui.QColor", "QString", "int, int, int, int = 255", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor", overloads);
        return -1;
}

static PyObject* SbkQColorFunc_allowX11ColorNames(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // allowX11ColorNames()
            bool cppResult = QColor::allowX11ColorNames();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_alpha(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alpha()const
            int cppResult = cppSelf->QColor::alpha();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_alphaF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alphaF()const
            qreal cppResult = cppSelf->QColor::alphaF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_black(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // black()const
            int cppResult = cppSelf->QColor::black();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_blackF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blackF()const
            qreal cppResult = cppSelf->QColor::blackF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_blue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blue()const
            int cppResult = cppSelf->QColor::blue();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_blueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blueF()const
            qreal cppResult = cppSelf->QColor::blueF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_colorNames(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // colorNames()
            QStringList cppResult = QColor::colorNames();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_convertTo(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: convertTo(QColor::Spec)const
    if (Shiboken::Converter<QColor::Spec >::isConvertible(arg)) {
        overloadId = 0; // convertTo(QColor::Spec)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_convertTo_TypeError;

    // Call function/method
    {
        {
            QColor::Spec cpp_arg0 = Shiboken::Converter<QColor::Spec >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // convertTo(QColor::Spec)const
            QColor cppResult = cppSelf->QColor::convertTo(cpp_arg0);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_convertTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor.Spec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.convertTo", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_cyan(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cyan()const
            int cppResult = cppSelf->QColor::cyan();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_cyanF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cyanF()const
            qreal cppResult = cppSelf->QColor::cyanF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_darker(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.darker(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.darker(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:darker", &arg))
        return 0;


    // Overloaded function decisor
    // 0: darker(int)const
    if (numArgs == 0) {
        overloadId = 0; // darker(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // darker(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_darker_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (arg)
                        errorArgName = "f";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.darker(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 200;

            if(!PyErr_Occurred()) {
            // darker(int)const
            QColor cppResult = cppSelf->QColor::darker(cpp_arg0);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_darker_TypeError:
        const char* overloads[] = {"int = 200", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.darker", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromCmyk(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromCmyk(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmyk(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmyk(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:fromCmyk", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fromCmyk(int,int,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // fromCmyk(int,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // fromCmyk(int,int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromCmyk_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromCmyk(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 255;

            if(!PyErr_Occurred()) {
            // fromCmyk(int,int,int,int,int)
            QColor cppResult = QColor::fromCmyk(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromCmyk_TypeError:
        const char* overloads[] = {"int, int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromCmyk", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromCmykF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromCmykF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmykF(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmykF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:fromCmykF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fromCmykF(qreal,qreal,qreal,qreal,qreal)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // fromCmykF(qreal,qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // fromCmykF(qreal,qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromCmykF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromCmykF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cpp_arg4 = pyargs[4] ? Shiboken::Converter<qreal >::toCpp(pyargs[4]) : 1.0;

            if(!PyErr_Occurred()) {
            // fromCmykF(qreal,qreal,qreal,qreal,qreal)
            QColor cppResult = QColor::fromCmykF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromCmykF_TypeError:
        const char* overloads[] = {"float, float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromCmykF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromHsl(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsl(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHsl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHsl(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsl(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHsl(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromHsl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
            // fromHsl(int,int,int,int)
            QColor cppResult = QColor::fromHsl(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromHsl_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHsl", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromHslF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHslF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHslF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHslF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHslF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHslF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHslF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHslF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromHslF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHslF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
            // fromHslF(qreal,qreal,qreal,qreal)
            QColor cppResult = QColor::fromHslF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromHslF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHslF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromHsv(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsv(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsv(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsv(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHsv", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHsv(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsv(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHsv(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromHsv_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsv(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
            // fromHsv(int,int,int,int)
            QColor cppResult = QColor::fromHsv(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromHsv_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHsv", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromHsvF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsvF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsvF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsvF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHsvF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHsvF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsvF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHsvF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromHsvF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsvF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
            // fromHsvF(qreal,qreal,qreal,qreal)
            QColor cppResult = QColor::fromHsvF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromHsvF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHsvF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromRgb(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromRgb(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgb(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgb(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto SbkQColorFunc_fromRgb_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:fromRgb", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromRgb(int,int,int,int)
    // 1: fromRgb(uint)
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // fromRgb(uint)
    } else if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromRgb(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromRgb(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromRgb_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromRgb(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "a");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "a";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromRgb(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

                if(!PyErr_Occurred()) {
                // fromRgb(int,int,int,int)
                QColor cppResult = QColor::fromRgb(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromRgb(uint)
            {
                unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // fromRgb(uint)
                QColor cppResult = QColor::fromRgb(cpp_arg0);
                pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromRgb_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromRgb", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromRgbF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromRgbF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgbF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgbF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromRgbF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromRgbF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromRgbF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromRgbF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromRgbF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromRgbF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
            // fromRgbF(qreal,qreal,qreal,qreal)
            QColor cppResult = QColor::fromRgbF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromRgbF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromRgbF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_fromRgba(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromRgba(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fromRgba(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_fromRgba_TypeError;

    // Call function/method
    {
        {
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromRgba(uint)
            QColor cppResult = QColor::fromRgba(cpp_arg0);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_fromRgba_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.fromRgba", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_getCmyk(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getCmyk(int*,int*,int*,int*,int*)
            // Begin code injection
            
            // TEMPLATE - fix_int*,int*,int*,int*,int* - START
            int a, b, c, d, e;
            cppSelf->getCmyk(&a, &b, &c, &d, &e);
            pyResult = Shiboken::makeTuple(a, b, c, d, e);
            // TEMPLATE - fix_int*,int*,int*,int*,int* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_getCmykF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getCmykF(qreal*,qreal*,qreal*,qreal*,qreal*)
            // Begin code injection
            
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal*,qreal* - START
            qreal a, b, c, d, e;
            cppSelf->getCmykF(&a, &b, &c, &d, &e);
            pyResult = Shiboken::makeTuple(a, b, c, d, e);
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal*,qreal* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_getHsl(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getHsl(int*,int*,int*,int*)const
            // Begin code injection
            
            // TEMPLATE - fix_int*,int*,int*,int* - START
            int a, b, c, d;
            cppSelf->getHsl(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);
            // TEMPLATE - fix_int*,int*,int*,int* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_getHslF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getHslF(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection
            
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - START
            qreal a, b, c, d;
            cppSelf->getHslF(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_getHsv(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getHsv(int*,int*,int*,int*)const
            // Begin code injection
            
            // TEMPLATE - fix_int*,int*,int*,int* - START
            int a, b, c, d;
            cppSelf->getHsv(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);
            // TEMPLATE - fix_int*,int*,int*,int* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_getHsvF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getHsvF(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection
            
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - START
            qreal a, b, c, d;
            cppSelf->getHsvF(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_getRgb(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getRgb(int*,int*,int*,int*)const
            // Begin code injection
            
            // TEMPLATE - fix_int*,int*,int*,int* - START
            int a, b, c, d;
            cppSelf->getRgb(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);
            // TEMPLATE - fix_int*,int*,int*,int* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_getRgbF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // getRgbF(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection
            
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - START
            qreal a, b, c, d;
            cppSelf->getRgbF(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);
            // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_green(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // green()const
            int cppResult = cppSelf->QColor::green();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_greenF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // greenF()const
            qreal cppResult = cppSelf->QColor::greenF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hslHue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hslHue()const
            int cppResult = cppSelf->QColor::hslHue();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hslHueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hslHueF()const
            qreal cppResult = cppSelf->QColor::hslHueF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hslSaturation(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hslSaturation()const
            int cppResult = cppSelf->QColor::hslSaturation();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hslSaturationF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hslSaturationF()const
            qreal cppResult = cppSelf->QColor::hslSaturationF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hsvHue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hsvHue()const
            int cppResult = cppSelf->QColor::hsvHue();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hsvHueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hsvHueF()const
            qreal cppResult = cppSelf->QColor::hsvHueF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hsvSaturation(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hsvSaturation()const
            int cppResult = cppSelf->QColor::hsvSaturation();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hsvSaturationF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hsvSaturationF()const
            qreal cppResult = cppSelf->QColor::hsvSaturationF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hue()const
            int cppResult = cppSelf->QColor::hue();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_hueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hueF()const
            qreal cppResult = cppSelf->QColor::hueF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_isValid(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QColor::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_isValidColor(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isValidColor(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // isValidColor(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_isValidColor_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isValidColor(QString)
            bool cppResult = QColor::isValidColor(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_isValidColor_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.isValidColor", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_lighter(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.lighter(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.lighter(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:lighter", &arg))
        return 0;


    // Overloaded function decisor
    // 0: lighter(int)const
    if (numArgs == 0) {
        overloadId = 0; // lighter(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // lighter(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_lighter_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (arg)
                        errorArgName = "f";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.lighter(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 150;

            if(!PyErr_Occurred()) {
            // lighter(int)const
            QColor cppResult = cppSelf->QColor::lighter(cpp_arg0);
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc_lighter_TypeError:
        const char* overloads[] = {"int = 150", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.lighter", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_lightness(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lightness()const
            int cppResult = cppSelf->QColor::lightness();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_lightnessF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lightnessF()const
            qreal cppResult = cppSelf->QColor::lightnessF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_magenta(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // magenta()const
            int cppResult = cppSelf->QColor::magenta();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_magentaF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // magentaF()const
            qreal cppResult = cppSelf->QColor::magentaF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_name(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QColor::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_red(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // red()const
            int cppResult = cppSelf->QColor::red();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_redF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // redF()const
            qreal cppResult = cppSelf->QColor::redF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_rgb(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rgb()const
            unsigned int cppResult = cppSelf->QColor::rgb();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_rgba(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rgba()const
            unsigned int cppResult = cppSelf->QColor::rgba();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_saturation(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // saturation()const
            int cppResult = cppSelf->QColor::saturation();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_saturationF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // saturationF()const
            qreal cppResult = cppSelf->QColor::saturationF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_setAllowX11ColorNames(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAllowX11ColorNames(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAllowX11ColorNames(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setAllowX11ColorNames_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAllowX11ColorNames(bool)
            QColor::setAllowX11ColorNames(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setAllowX11ColorNames_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setAllowX11ColorNames", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setAlpha(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlpha(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAlpha(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setAlpha_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlpha(int)
            cppSelf->QColor::setAlpha(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setAlpha_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setAlpha", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setAlphaF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlphaF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAlphaF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setAlphaF_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlphaF(qreal)
            cppSelf->QColor::setAlphaF(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setAlphaF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setAlphaF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setBlue(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlue(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBlue(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setBlue_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBlue(int)
            cppSelf->QColor::setBlue(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setBlue_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setBlue", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setBlueF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlueF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBlueF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setBlueF_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBlueF(qreal)
            cppSelf->QColor::setBlueF(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setBlueF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setBlueF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setCmyk(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setCmyk(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmyk(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmyk(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:setCmyk", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setCmyk(int,int,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // setCmyk(int,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // setCmyk(int,int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setCmyk_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setCmyk(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 255;

            if(!PyErr_Occurred()) {
            // setCmyk(int,int,int,int,int)
            cppSelf->QColor::setCmyk(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setCmyk_TypeError:
        const char* overloads[] = {"int, int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setCmyk", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setCmykF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setCmykF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmykF(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmykF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:setCmykF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setCmykF(qreal,qreal,qreal,qreal,qreal)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // setCmykF(qreal,qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // setCmykF(qreal,qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setCmykF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setCmykF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cpp_arg4 = pyargs[4] ? Shiboken::Converter<qreal >::toCpp(pyargs[4]) : 1.0;

            if(!PyErr_Occurred()) {
            // setCmykF(qreal,qreal,qreal,qreal,qreal)
            cppSelf->QColor::setCmykF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setCmykF_TypeError:
        const char* overloads[] = {"float, float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setCmykF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setGreen(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGreen(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGreen(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setGreen_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGreen(int)
            cppSelf->QColor::setGreen(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setGreen_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setGreen", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setGreenF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGreenF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGreenF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setGreenF_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGreenF(qreal)
            cppSelf->QColor::setGreenF(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setGreenF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setGreenF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setHsl(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsl(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHsl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHsl(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHsl(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHsl(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setHsl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
            // setHsl(int,int,int,int)
            cppSelf->QColor::setHsl(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setHsl_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHsl", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setHslF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHslF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHslF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHslF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHslF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHslF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHslF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHslF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setHslF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHslF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
            // setHslF(qreal,qreal,qreal,qreal)
            cppSelf->QColor::setHslF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setHslF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHslF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setHsv(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsv(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsv(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsv(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHsv", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHsv(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHsv(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHsv(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setHsv_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsv(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
            // setHsv(int,int,int,int)
            cppSelf->QColor::setHsv(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setHsv_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHsv", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setHsvF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsvF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsvF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsvF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHsvF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHsvF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHsvF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHsvF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setHsvF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsvF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
            // setHsvF(qreal,qreal,qreal,qreal)
            cppSelf->QColor::setHsvF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setHsvF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHsvF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setNamedColor(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNamedColor(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setNamedColor(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setNamedColor_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNamedColor(QString)
            cppSelf->QColor::setNamedColor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setNamedColor_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setNamedColor", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setRed(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRed(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRed(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setRed_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRed(int)
            cppSelf->QColor::setRed(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setRed_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setRed", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setRedF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRedF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRedF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setRedF_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRedF(qreal)
            cppSelf->QColor::setRedF(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setRedF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setRedF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setRgb(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setRgb(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgb(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgb(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto SbkQColorFunc_setRgb_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:setRgb", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRgb(int,int,int,int)
    // 1: setRgb(uint)
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // setRgb(uint)
    } else if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setRgb(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setRgb(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setRgb_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setRgb(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "a");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "a";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setRgb(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

                if(!PyErr_Occurred()) {
                // setRgb(int,int,int,int)
                cppSelf->QColor::setRgb(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 1: // setRgb(uint)
            {
                unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setRgb(uint)
                cppSelf->QColor::setRgb(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setRgb_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setRgb", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setRgbF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "a" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setRgbF(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgbF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgbF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setRgbF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRgbF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setRgbF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setRgbF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setRgbF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setRgbF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
            // setRgbF(qreal,qreal,qreal,qreal)
            cppSelf->QColor::setRgbF(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setRgbF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setRgbF", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_setRgba(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRgba(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRgba(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc_setRgba_TypeError;

    // Call function/method
    {
        {
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRgba(uint)
            cppSelf->QColor::setRgba(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQColorFunc_setRgba_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setRgba", overloads);
        return 0;
}

static PyObject* SbkQColorFunc_spec(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // spec()const
            QColor::Spec cppResult = cppSelf->QColor::spec();
            pyResult = Shiboken::Converter<QColor::Spec >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_toCmyk(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toCmyk()const
            QColor cppResult = cppSelf->QColor::toCmyk();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_toHsl(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toHsl()const
            QColor cppResult = cppSelf->QColor::toHsl();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_toHsv(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toHsv()const
            QColor cppResult = cppSelf->QColor::toHsv();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_toRgb(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toRgb()const
            QColor cppResult = cppSelf->QColor::toRgb();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_value(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // value()const
            int cppResult = cppSelf->QColor::value();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_valueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // valueF()const
            qreal cppResult = cppSelf->QColor::valueF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_yellow(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // yellow()const
            int cppResult = cppSelf->QColor::yellow();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQColorFunc_yellowF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // yellowF()const
            qreal cppResult = cppSelf->QColor::yellowF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQColor_methods[] = {
    {"allowX11ColorNames", (PyCFunction)SbkQColorFunc_allowX11ColorNames, METH_NOARGS|METH_STATIC},
    {"alpha", (PyCFunction)SbkQColorFunc_alpha, METH_NOARGS},
    {"alphaF", (PyCFunction)SbkQColorFunc_alphaF, METH_NOARGS},
    {"black", (PyCFunction)SbkQColorFunc_black, METH_NOARGS},
    {"blackF", (PyCFunction)SbkQColorFunc_blackF, METH_NOARGS},
    {"blue", (PyCFunction)SbkQColorFunc_blue, METH_NOARGS},
    {"blueF", (PyCFunction)SbkQColorFunc_blueF, METH_NOARGS},
    {"colorNames", (PyCFunction)SbkQColorFunc_colorNames, METH_NOARGS|METH_STATIC},
    {"convertTo", (PyCFunction)SbkQColorFunc_convertTo, METH_O},
    {"cyan", (PyCFunction)SbkQColorFunc_cyan, METH_NOARGS},
    {"cyanF", (PyCFunction)SbkQColorFunc_cyanF, METH_NOARGS},
    {"darker", (PyCFunction)SbkQColorFunc_darker, METH_VARARGS|METH_KEYWORDS},
    {"fromCmyk", (PyCFunction)SbkQColorFunc_fromCmyk, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromCmykF", (PyCFunction)SbkQColorFunc_fromCmykF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHsl", (PyCFunction)SbkQColorFunc_fromHsl, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHslF", (PyCFunction)SbkQColorFunc_fromHslF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHsv", (PyCFunction)SbkQColorFunc_fromHsv, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHsvF", (PyCFunction)SbkQColorFunc_fromHsvF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromRgb", (PyCFunction)SbkQColorFunc_fromRgb, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromRgbF", (PyCFunction)SbkQColorFunc_fromRgbF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromRgba", (PyCFunction)SbkQColorFunc_fromRgba, METH_O|METH_STATIC},
    {"getCmyk", (PyCFunction)SbkQColorFunc_getCmyk, METH_NOARGS},
    {"getCmykF", (PyCFunction)SbkQColorFunc_getCmykF, METH_NOARGS},
    {"getHsl", (PyCFunction)SbkQColorFunc_getHsl, METH_NOARGS},
    {"getHslF", (PyCFunction)SbkQColorFunc_getHslF, METH_NOARGS},
    {"getHsv", (PyCFunction)SbkQColorFunc_getHsv, METH_NOARGS},
    {"getHsvF", (PyCFunction)SbkQColorFunc_getHsvF, METH_NOARGS},
    {"getRgb", (PyCFunction)SbkQColorFunc_getRgb, METH_NOARGS},
    {"getRgbF", (PyCFunction)SbkQColorFunc_getRgbF, METH_NOARGS},
    {"green", (PyCFunction)SbkQColorFunc_green, METH_NOARGS},
    {"greenF", (PyCFunction)SbkQColorFunc_greenF, METH_NOARGS},
    {"hslHue", (PyCFunction)SbkQColorFunc_hslHue, METH_NOARGS},
    {"hslHueF", (PyCFunction)SbkQColorFunc_hslHueF, METH_NOARGS},
    {"hslSaturation", (PyCFunction)SbkQColorFunc_hslSaturation, METH_NOARGS},
    {"hslSaturationF", (PyCFunction)SbkQColorFunc_hslSaturationF, METH_NOARGS},
    {"hsvHue", (PyCFunction)SbkQColorFunc_hsvHue, METH_NOARGS},
    {"hsvHueF", (PyCFunction)SbkQColorFunc_hsvHueF, METH_NOARGS},
    {"hsvSaturation", (PyCFunction)SbkQColorFunc_hsvSaturation, METH_NOARGS},
    {"hsvSaturationF", (PyCFunction)SbkQColorFunc_hsvSaturationF, METH_NOARGS},
    {"hue", (PyCFunction)SbkQColorFunc_hue, METH_NOARGS},
    {"hueF", (PyCFunction)SbkQColorFunc_hueF, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQColorFunc_isValid, METH_NOARGS},
    {"isValidColor", (PyCFunction)SbkQColorFunc_isValidColor, METH_O|METH_STATIC},
    {"lighter", (PyCFunction)SbkQColorFunc_lighter, METH_VARARGS|METH_KEYWORDS},
    {"lightness", (PyCFunction)SbkQColorFunc_lightness, METH_NOARGS},
    {"lightnessF", (PyCFunction)SbkQColorFunc_lightnessF, METH_NOARGS},
    {"magenta", (PyCFunction)SbkQColorFunc_magenta, METH_NOARGS},
    {"magentaF", (PyCFunction)SbkQColorFunc_magentaF, METH_NOARGS},
    {"name", (PyCFunction)SbkQColorFunc_name, METH_NOARGS},
    {"red", (PyCFunction)SbkQColorFunc_red, METH_NOARGS},
    {"redF", (PyCFunction)SbkQColorFunc_redF, METH_NOARGS},
    {"rgb", (PyCFunction)SbkQColorFunc_rgb, METH_NOARGS},
    {"rgba", (PyCFunction)SbkQColorFunc_rgba, METH_NOARGS},
    {"saturation", (PyCFunction)SbkQColorFunc_saturation, METH_NOARGS},
    {"saturationF", (PyCFunction)SbkQColorFunc_saturationF, METH_NOARGS},
    {"setAllowX11ColorNames", (PyCFunction)SbkQColorFunc_setAllowX11ColorNames, METH_O|METH_STATIC},
    {"setAlpha", (PyCFunction)SbkQColorFunc_setAlpha, METH_O},
    {"setAlphaF", (PyCFunction)SbkQColorFunc_setAlphaF, METH_O},
    {"setBlue", (PyCFunction)SbkQColorFunc_setBlue, METH_O},
    {"setBlueF", (PyCFunction)SbkQColorFunc_setBlueF, METH_O},
    {"setCmyk", (PyCFunction)SbkQColorFunc_setCmyk, METH_VARARGS|METH_KEYWORDS},
    {"setCmykF", (PyCFunction)SbkQColorFunc_setCmykF, METH_VARARGS|METH_KEYWORDS},
    {"setGreen", (PyCFunction)SbkQColorFunc_setGreen, METH_O},
    {"setGreenF", (PyCFunction)SbkQColorFunc_setGreenF, METH_O},
    {"setHsl", (PyCFunction)SbkQColorFunc_setHsl, METH_VARARGS|METH_KEYWORDS},
    {"setHslF", (PyCFunction)SbkQColorFunc_setHslF, METH_VARARGS|METH_KEYWORDS},
    {"setHsv", (PyCFunction)SbkQColorFunc_setHsv, METH_VARARGS|METH_KEYWORDS},
    {"setHsvF", (PyCFunction)SbkQColorFunc_setHsvF, METH_VARARGS|METH_KEYWORDS},
    {"setNamedColor", (PyCFunction)SbkQColorFunc_setNamedColor, METH_O},
    {"setRed", (PyCFunction)SbkQColorFunc_setRed, METH_O},
    {"setRedF", (PyCFunction)SbkQColorFunc_setRedF, METH_O},
    {"setRgb", (PyCFunction)SbkQColorFunc_setRgb, METH_VARARGS|METH_KEYWORDS},
    {"setRgbF", (PyCFunction)SbkQColorFunc_setRgbF, METH_VARARGS|METH_KEYWORDS},
    {"setRgba", (PyCFunction)SbkQColorFunc_setRgba, METH_O},
    {"spec", (PyCFunction)SbkQColorFunc_spec, METH_NOARGS},
    {"toCmyk", (PyCFunction)SbkQColorFunc_toCmyk, METH_NOARGS},
    {"toHsl", (PyCFunction)SbkQColorFunc_toHsl, METH_NOARGS},
    {"toHsv", (PyCFunction)SbkQColorFunc_toHsv, METH_NOARGS},
    {"toRgb", (PyCFunction)SbkQColorFunc_toRgb, METH_NOARGS},
    {"value", (PyCFunction)SbkQColorFunc_value, METH_NOARGS},
    {"valueF", (PyCFunction)SbkQColorFunc_valueF, METH_NOARGS},
    {"yellow", (PyCFunction)SbkQColorFunc_yellow, METH_NOARGS},
    {"yellowF", (PyCFunction)SbkQColorFunc_yellowF, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQColorFunc___lshift__(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QColor >::checkType(arg) && !Shiboken::Converter<QColor >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QColor)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QColor) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQColorFunc___rshift__(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QColor >::checkType(arg) && !Shiboken::Converter<QColor >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QColor&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QColor&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQColorFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QColor&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQColorFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQColor_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQColorFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQColorFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQColor_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QColor& cpp_self = *Shiboken::Converter<QColor* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QColor & >::isConvertible(other)) {
                // operator!=(const QColor & c) const
                QColor* cpp_other = Shiboken::Converter<QColor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QColor  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QColor >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QColor > cpp_other_auto_ptr;
                QColor* cpp_other = Shiboken::Converter<QColor* >::toCpp(other);
                if (!Shiboken::Converter<QColor >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QColor >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQColor_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QColor & >::isConvertible(other)) {
                // operator==(const QColor & c) const
                QColor* cpp_other = Shiboken::Converter<QColor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QColor  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QColor >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QColor > cpp_other_auto_ptr;
                QColor* cpp_other = Shiboken::Converter<QColor* >::toCpp(other);
                if (!Shiboken::Converter<QColor >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QColor >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQColor_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQColor_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQColor_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QColor",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQColor_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQColor_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQColor_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQColor_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QColor >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QColor",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QColor_Spec_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QColor_Spec_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QColor_Spec_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Spec",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QColor_Spec_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QColor_Spec_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QColor_Spec_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QColor(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QCOLOR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQColor_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQColor_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQColor_Type));
    PyModule_AddObject(module, "QColor",
        ((PyObject*)&SbkQColor_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Spec
    SbkPySide_QtGuiTypes[SBK_QCOLOR_SPEC_IDX] = &SbkPySide_QtGui_QColor_Spec_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QColor_Spec_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QColor_Spec_Type);
    PyDict_SetItemString(SbkQColor_Type.super.ht_type.tp_dict,
            "Spec",((PyObject*)&SbkPySide_QtGui_QColor_Spec_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QColor_Spec_Type,
        (long) QColor::Invalid, "Invalid");
    PyDict_SetItemString(SbkQColor_Type.super.ht_type.tp_dict,
        "Invalid", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec_Type.tp_dict,
        "Invalid", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QColor_Spec_Type,
        (long) QColor::Rgb, "Rgb");
    PyDict_SetItemString(SbkQColor_Type.super.ht_type.tp_dict,
        "Rgb", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec_Type.tp_dict,
        "Rgb", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QColor_Spec_Type,
        (long) QColor::Hsv, "Hsv");
    PyDict_SetItemString(SbkQColor_Type.super.ht_type.tp_dict,
        "Hsv", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec_Type.tp_dict,
        "Hsv", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QColor_Spec_Type,
        (long) QColor::Cmyk, "Cmyk");
    PyDict_SetItemString(SbkQColor_Type.super.ht_type.tp_dict,
        "Cmyk", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec_Type.tp_dict,
        "Cmyk", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QColor_Spec_Type,
        (long) QColor::Hsl, "Hsl");
    PyDict_SetItemString(SbkQColor_Type.super.ht_type.tp_dict,
        "Hsl", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec_Type.tp_dict,
        "Hsl", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QColor::Spec");


    Shiboken::TypeResolver::createValueTypeResolver<QColor >("QColor");
    Shiboken::TypeResolver::createObjectTypeResolver<QColor >("QColor*");
    Shiboken::TypeResolver::createValueTypeResolver<QColor >(typeid(QColor).name());
    PySide::initQtMetaType<QColor >();
}

