/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qcompleter_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qabstractitemmodel.h>
#include <qabstractitemview.h>
#include <qbytearray.h>
#include <qcompleter.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qthread.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QCompleterWrapper::QCompleterWrapper(QAbstractItemModel * model, QObject * parent) : QCompleter(model, parent), m_metaObject(0) {
    // ... middle
}

QCompleterWrapper::QCompleterWrapper(QObject * parent) : QCompleter(parent), m_metaObject(0) {
    // ... middle
}

QCompleterWrapper::QCompleterWrapper(const QStringList & completions, QObject * parent) : QCompleter(completions, parent), m_metaObject(0) {
    // ... middle
}

void QCompleterWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QCompleterWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QCompleterWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QCompleterWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QCompleterWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QCompleter::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCompleter.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QCompleterWrapper::eventFilter(QObject * o, QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QCompleter::eventFilter(o, e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(o),
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCompleter.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QString QCompleterWrapper::pathFromIndex(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pathFromIndex"));
    if (py_override.isNull()) {
        return this->QCompleter::pathFromIndex(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCompleter.pathFromIndex", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

QStringList QCompleterWrapper::splitPath(const QString & path) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "splitPath"));
    if (py_override.isNull()) {
        return this->QCompleter::splitPath(path);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(path)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCompleter.splitPath", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter<QStringList >::toCpp(pyResult));
    return cppResult;
}

void QCompleterWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QCompleterWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QCompleter::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QCompleterWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QCompleter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QCompleterWrapper::~QCompleterWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQCompleter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QCompleter >()))
        return -1;

    QCompleterWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QCompleter", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QCompleter(QAbstractItemModel*,QObject*)
    // 1: QCompleter(QObject*)
    // 2: QCompleter(QStringList,QObject*)
    if (numArgs == 0) {
        overloadId = 1; // QCompleter(QObject*)
    } else if (Shiboken::Converter< QStringList  >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QCompleter(QStringList,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 2; // QCompleter(QStringList,QObject*)
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QCompleter(QObject*)
    } else if (Shiboken::Converter<QAbstractItemModel * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QCompleter(QAbstractItemModel*,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QCompleter(QAbstractItemModel*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QCompleter(QAbstractItemModel*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCompleter(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QAbstractItemModel* cpp_arg0 = Shiboken::Converter<QAbstractItemModel* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QCompleter(QAbstractItemModel*,QObject*)
                cptr = new QCompleterWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QCompleter(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCompleter(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QCompleter(QObject*)
                cptr = new QCompleterWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 2: // QCompleter(QStringList,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCompleter(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QCompleter(QStringList,QObject*)
                cptr = new QCompleterWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QCompleter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQCompleter_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQCompleter_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel, PySide.QtCore.QObject = None", "PySide.QtCore.QObject = None", "list, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCompleter", overloads);
        return -1;
}

static PyObject* SbkQCompleterFunc_caseSensitivity(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // caseSensitivity()const
            Qt::CaseSensitivity cppResult = cppSelf->QCompleter::caseSensitivity();
            pyResult = Shiboken::Converter<Qt::CaseSensitivity >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_complete(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCompleter.complete(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCompleter.complete(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:complete", &arg))
        return 0;


    // Overloaded function decisor
    // 0: complete(QRect)
    if (numArgs == 0) {
        overloadId = 0; // complete(QRect)
    } else if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // complete(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_complete_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "rect");
                if (value) {
                    if (arg)
                        errorArgName = "rect";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCompleter.complete(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect cpp_arg0_tmp = QRect();
            QRect* cpp_arg0 = arg ? Shiboken::Converter<QRect* >::toCpp(arg) : &cpp_arg0_tmp;

            if(!PyErr_Occurred()) {
            // complete(QRect)
            cppSelf->QCompleter::complete(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_complete_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect = QRect()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.complete", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_completionColumn(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completionColumn()const
            int cppResult = cppSelf->QCompleter::completionColumn();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_completionCount(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completionCount()const
            int cppResult = cppSelf->QCompleter::completionCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_completionMode(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completionMode()const
            QCompleter::CompletionMode cppResult = cppSelf->QCompleter::completionMode();
            pyResult = Shiboken::Converter<QCompleter::CompletionMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_completionModel(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completionModel()const
            QAbstractItemModel * cppResult = cppSelf->QCompleter::completionModel();
            pyResult = Shiboken::Converter<QAbstractItemModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_completionPrefix(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completionPrefix()const
            QString cppResult = cppSelf->QCompleter::completionPrefix();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_completionRole(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // completionRole()const
            int cppResult = cppSelf->QCompleter::completionRole();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_currentCompletion(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentCompletion()const
            QString cppResult = cppSelf->QCompleter::currentCompletion();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_currentIndex(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentIndex()const
            QModelIndex cppResult = cppSelf->QCompleter::currentIndex();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_currentRow(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentRow()const
            int cppResult = cppSelf->QCompleter::currentRow();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_event(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QCompleter::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQCompleterFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.event", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_eventFilter(PyObject* self, PyObject* args)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: eventFilter(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_eventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = Shiboken::Converter<QEvent* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = cppSelf->QCompleter::eventFilter(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQCompleterFunc_eventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCompleter.eventFilter", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_maxVisibleItems(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maxVisibleItems()const
            int cppResult = cppSelf->QCompleter::maxVisibleItems();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_model(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // model()const
            QAbstractItemModel * cppResult = cppSelf->QCompleter::model();
            pyResult = Shiboken::Converter<QAbstractItemModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_modelSorting(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // modelSorting()const
            QCompleter::ModelSorting cppResult = cppSelf->QCompleter::modelSorting();
            pyResult = Shiboken::Converter<QCompleter::ModelSorting >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_pathFromIndex(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pathFromIndex(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // pathFromIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_pathFromIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // pathFromIndex(QModelIndex)const
            QString cppResult = cppSelf->QCompleter::pathFromIndex(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQCompleterFunc_pathFromIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.pathFromIndex", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_popup(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // popup()const
            QAbstractItemView * cppResult = cppSelf->QCompleter::popup();
            pyResult = Shiboken::Converter<QAbstractItemView * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_setCaseSensitivity(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCaseSensitivity(Qt::CaseSensitivity)
    if (Shiboken::Converter<Qt::CaseSensitivity >::isConvertible(arg)) {
        overloadId = 0; // setCaseSensitivity(Qt::CaseSensitivity)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setCaseSensitivity_TypeError;

    // Call function/method
    {
        {
            Qt::CaseSensitivity cpp_arg0 = Shiboken::Converter<Qt::CaseSensitivity >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCaseSensitivity(Qt::CaseSensitivity)
            cppSelf->QCompleter::setCaseSensitivity(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setCaseSensitivity_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CaseSensitivity", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setCaseSensitivity", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setCompletionColumn(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompletionColumn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCompletionColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setCompletionColumn_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCompletionColumn(int)
            cppSelf->QCompleter::setCompletionColumn(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setCompletionColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setCompletionColumn", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setCompletionMode(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompletionMode(QCompleter::CompletionMode)
    if (Shiboken::Converter<QCompleter::CompletionMode >::isConvertible(arg)) {
        overloadId = 0; // setCompletionMode(QCompleter::CompletionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setCompletionMode_TypeError;

    // Call function/method
    {
        {
            QCompleter::CompletionMode cpp_arg0 = Shiboken::Converter<QCompleter::CompletionMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCompletionMode(QCompleter::CompletionMode)
            cppSelf->QCompleter::setCompletionMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setCompletionMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCompleter.CompletionMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setCompletionMode", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setCompletionPrefix(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompletionPrefix(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setCompletionPrefix(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setCompletionPrefix_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCompletionPrefix(QString)
            cppSelf->QCompleter::setCompletionPrefix(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setCompletionPrefix_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setCompletionPrefix", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setCompletionRole(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompletionRole(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCompletionRole(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setCompletionRole_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCompletionRole(int)
            cppSelf->QCompleter::setCompletionRole(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setCompletionRole_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setCompletionRole", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setCurrentRow(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentRow(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentRow(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setCurrentRow_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentRow(int)
            bool cppResult = cppSelf->QCompleter::setCurrentRow(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQCompleterFunc_setCurrentRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setCurrentRow", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setMaxVisibleItems(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaxVisibleItems(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaxVisibleItems(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setMaxVisibleItems_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaxVisibleItems(int)
            cppSelf->QCompleter::setMaxVisibleItems(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setMaxVisibleItems_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setMaxVisibleItems", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setModel(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModel(QAbstractItemModel*)
    if (Shiboken::Converter<QAbstractItemModel * >::isConvertible(arg)) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setModel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractItemModel* cpp_arg0 = Shiboken::Converter<QAbstractItemModel* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setModel(QAbstractItemModel*)
            cppSelf->QCompleter::setModel(cpp_arg0);
            Shiboken::keepReference(reinterpret_cast<SbkBaseWrapper*>(self), "setModel(QAbstractItemModel*)1", arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setModel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setModel", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setModelSorting(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModelSorting(QCompleter::ModelSorting)
    if (Shiboken::Converter<QCompleter::ModelSorting >::isConvertible(arg)) {
        overloadId = 0; // setModelSorting(QCompleter::ModelSorting)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setModelSorting_TypeError;

    // Call function/method
    {
        {
            QCompleter::ModelSorting cpp_arg0 = Shiboken::Converter<QCompleter::ModelSorting >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setModelSorting(QCompleter::ModelSorting)
            cppSelf->QCompleter::setModelSorting(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setModelSorting_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCompleter.ModelSorting", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setModelSorting", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setPopup(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPopup(QAbstractItemView*)
    if (Shiboken::Converter<QAbstractItemView * >::isConvertible(arg)) {
        overloadId = 0; // setPopup(QAbstractItemView*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setPopup_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractItemView* cpp_arg0 = Shiboken::Converter<QAbstractItemView* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPopup(QAbstractItemView*)
            cppSelf->QCompleter::setPopup(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setPopup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setPopup", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setWidget(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidget(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidget(QWidget*)
            cppSelf->QCompleter::setWidget(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setWidget", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_setWrapAround(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWrapAround(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWrapAround(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_setWrapAround_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWrapAround(bool)
            cppSelf->QCompleter::setWrapAround(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQCompleterFunc_setWrapAround_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.setWrapAround", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_splitPath(PyObject* self, PyObject* arg)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: splitPath(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // splitPath(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQCompleterFunc_splitPath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // splitPath(QString)const
            QStringList cppResult = cppSelf->QCompleter::splitPath(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQCompleterFunc_splitPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCompleter.splitPath", overloads);
        return 0;
}

static PyObject* SbkQCompleterFunc_widget(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // widget()const
            QWidget * cppResult = cppSelf->QCompleter::widget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQCompleterFunc_wrapAround(PyObject* self)
{
    QCompleter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QCompleter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // wrapAround()const
            bool cppResult = cppSelf->QCompleter::wrapAround();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQCompleter_methods[] = {
    {"caseSensitivity", (PyCFunction)SbkQCompleterFunc_caseSensitivity, METH_NOARGS},
    {"complete", (PyCFunction)SbkQCompleterFunc_complete, METH_VARARGS|METH_KEYWORDS},
    {"completionColumn", (PyCFunction)SbkQCompleterFunc_completionColumn, METH_NOARGS},
    {"completionCount", (PyCFunction)SbkQCompleterFunc_completionCount, METH_NOARGS},
    {"completionMode", (PyCFunction)SbkQCompleterFunc_completionMode, METH_NOARGS},
    {"completionModel", (PyCFunction)SbkQCompleterFunc_completionModel, METH_NOARGS},
    {"completionPrefix", (PyCFunction)SbkQCompleterFunc_completionPrefix, METH_NOARGS},
    {"completionRole", (PyCFunction)SbkQCompleterFunc_completionRole, METH_NOARGS},
    {"currentCompletion", (PyCFunction)SbkQCompleterFunc_currentCompletion, METH_NOARGS},
    {"currentIndex", (PyCFunction)SbkQCompleterFunc_currentIndex, METH_NOARGS},
    {"currentRow", (PyCFunction)SbkQCompleterFunc_currentRow, METH_NOARGS},
    {"event", (PyCFunction)SbkQCompleterFunc_event, METH_O},
    {"eventFilter", (PyCFunction)SbkQCompleterFunc_eventFilter, METH_VARARGS},
    {"maxVisibleItems", (PyCFunction)SbkQCompleterFunc_maxVisibleItems, METH_NOARGS},
    {"model", (PyCFunction)SbkQCompleterFunc_model, METH_NOARGS},
    {"modelSorting", (PyCFunction)SbkQCompleterFunc_modelSorting, METH_NOARGS},
    {"pathFromIndex", (PyCFunction)SbkQCompleterFunc_pathFromIndex, METH_O},
    {"popup", (PyCFunction)SbkQCompleterFunc_popup, METH_NOARGS},
    {"setCaseSensitivity", (PyCFunction)SbkQCompleterFunc_setCaseSensitivity, METH_O},
    {"setCompletionColumn", (PyCFunction)SbkQCompleterFunc_setCompletionColumn, METH_O},
    {"setCompletionMode", (PyCFunction)SbkQCompleterFunc_setCompletionMode, METH_O},
    {"setCompletionPrefix", (PyCFunction)SbkQCompleterFunc_setCompletionPrefix, METH_O},
    {"setCompletionRole", (PyCFunction)SbkQCompleterFunc_setCompletionRole, METH_O},
    {"setCurrentRow", (PyCFunction)SbkQCompleterFunc_setCurrentRow, METH_O},
    {"setMaxVisibleItems", (PyCFunction)SbkQCompleterFunc_setMaxVisibleItems, METH_O},
    {"setModel", (PyCFunction)SbkQCompleterFunc_setModel, METH_O},
    {"setModelSorting", (PyCFunction)SbkQCompleterFunc_setModelSorting, METH_O},
    {"setPopup", (PyCFunction)SbkQCompleterFunc_setPopup, METH_O},
    {"setWidget", (PyCFunction)SbkQCompleterFunc_setWidget, METH_O},
    {"setWrapAround", (PyCFunction)SbkQCompleterFunc_setWrapAround, METH_O},
    {"splitPath", (PyCFunction)SbkQCompleterFunc_splitPath, METH_O},
    {"widget", (PyCFunction)SbkQCompleterFunc_widget, METH_NOARGS},
    {"wrapAround", (PyCFunction)SbkQCompleterFunc_wrapAround, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQCompleter_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QCompleter",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQCompleter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQCompleter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QCompleter >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QCompleter*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQCompleter_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QCompleter*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQCompleter_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QCompleter_ModelSorting_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QCompleter_ModelSorting_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QCompleter_ModelSorting_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ModelSorting",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QCompleter_ModelSorting_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QCompleter_ModelSorting_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QCompleter_ModelSorting_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QCompleter_CompletionMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QCompleter_CompletionMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QCompleter_CompletionMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CompletionMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QCompleter_CompletionMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QCompleter_CompletionMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QCompleter_CompletionMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QCompleter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QCOMPLETER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQCompleter_Type);

    SbkQCompleter_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQCompleter_Type.type_discovery = &SbkQCompleter_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQCompleter_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQCompleter_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQCompleter_Type));
    PyModule_AddObject(module, "QCompleter",
        ((PyObject*)&SbkQCompleter_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ModelSorting
    SbkPySide_QtGuiTypes[SBK_QCOMPLETER_MODELSORTING_IDX] = &SbkPySide_QtGui_QCompleter_ModelSorting_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QCompleter_ModelSorting_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QCompleter_ModelSorting_Type);
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
            "ModelSorting",((PyObject*)&SbkPySide_QtGui_QCompleter_ModelSorting_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QCompleter_ModelSorting_Type,
        (long) QCompleter::UnsortedModel, "UnsortedModel");
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
        "UnsortedModel", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QCompleter_ModelSorting_Type.tp_dict,
        "UnsortedModel", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QCompleter_ModelSorting_Type,
        (long) QCompleter::CaseSensitivelySortedModel, "CaseSensitivelySortedModel");
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
        "CaseSensitivelySortedModel", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QCompleter_ModelSorting_Type.tp_dict,
        "CaseSensitivelySortedModel", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QCompleter_ModelSorting_Type,
        (long) QCompleter::CaseInsensitivelySortedModel, "CaseInsensitivelySortedModel");
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
        "CaseInsensitivelySortedModel", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QCompleter_ModelSorting_Type.tp_dict,
        "CaseInsensitivelySortedModel", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QCompleter::ModelSorting");

    // init enum class: CompletionMode
    SbkPySide_QtGuiTypes[SBK_QCOMPLETER_COMPLETIONMODE_IDX] = &SbkPySide_QtGui_QCompleter_CompletionMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QCompleter_CompletionMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QCompleter_CompletionMode_Type);
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
            "CompletionMode",((PyObject*)&SbkPySide_QtGui_QCompleter_CompletionMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QCompleter_CompletionMode_Type,
        (long) QCompleter::PopupCompletion, "PopupCompletion");
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
        "PopupCompletion", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QCompleter_CompletionMode_Type.tp_dict,
        "PopupCompletion", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QCompleter_CompletionMode_Type,
        (long) QCompleter::UnfilteredPopupCompletion, "UnfilteredPopupCompletion");
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
        "UnfilteredPopupCompletion", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QCompleter_CompletionMode_Type.tp_dict,
        "UnfilteredPopupCompletion", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QCompleter_CompletionMode_Type,
        (long) QCompleter::InlineCompletion, "InlineCompletion");
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict,
        "InlineCompletion", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QCompleter_CompletionMode_Type.tp_dict,
        "InlineCompletion", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QCompleter::CompletionMode");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("highlighted", "const QModelIndex&", "const QString&", NULL);
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict, "highlighted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("activated", "const QModelIndex&", "const QString&", NULL);
    PyDict_SetItemString(SbkQCompleter_Type.super.ht_type.tp_dict, "activated", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QCompleter >("QCompleter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QCompleter >(typeid(QCompleter).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QCompleter >(typeid(QCompleterWrapper).name());
    PySide::initQtMetaType<QCompleter* >();
}

