/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qdatawidgetmapper_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemdelegate.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdatawidgetmapper.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDataWidgetMapperWrapper::QDataWidgetMapperWrapper(QObject * parent) : QDataWidgetMapper(parent), m_metaObject(0) {
    // ... middle
}

void QDataWidgetMapperWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QDataWidgetMapperWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDataWidgetMapperWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QDataWidgetMapperWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QDataWidgetMapperWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDataWidgetMapper.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QDataWidgetMapperWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDataWidgetMapper.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QDataWidgetMapperWrapper::setCurrentIndex(int index)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setCurrentIndex"));
    if (py_override.isNull()) {
        return this->QDataWidgetMapper::setCurrentIndex(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QDataWidgetMapperWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QDataWidgetMapperWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QDataWidgetMapper::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QDataWidgetMapperWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDataWidgetMapper::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDataWidgetMapperWrapper::~QDataWidgetMapperWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDataWidgetMapper_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDataWidgetMapper >()))
        return -1;

    QDataWidgetMapperWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QDataWidgetMapper", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDataWidgetMapper(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QDataWidgetMapper(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QDataWidgetMapper(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapper_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QDataWidgetMapper(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QDataWidgetMapper(QObject*)
            cptr = new QDataWidgetMapperWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDataWidgetMapper >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDataWidgetMapper_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQDataWidgetMapper_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDataWidgetMapper", overloads);
        return -1;
}

static PyObject* SbkQDataWidgetMapperFunc_addMapping(PyObject* self, PyObject* args)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addMapping", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addMapping(QWidget*,int)
    // 1: addMapping(QWidget*,int,QByteArray)
    if (numArgs >= 2 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // addMapping(QWidget*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[2])) {
            overloadId = 1; // addMapping(QWidget*,int,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_addMapping_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addMapping(QWidget*,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addMapping(QWidget*,int)
                cppSelf->QDataWidgetMapper::addMapping(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // addMapping(QWidget*,int,QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg2_auto_ptr;
                QByteArray* cpp_arg2 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // addMapping(QWidget*,int,QByteArray)
                cppSelf->QDataWidgetMapper::addMapping(cpp_arg0, cpp_arg1, *cpp_arg2);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_addMapping_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, int", "PySide.QtGui.QWidget, int, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDataWidgetMapper.addMapping", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_clearMapping(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearMapping()
            cppSelf->QDataWidgetMapper::clearMapping();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDataWidgetMapperFunc_currentIndex(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentIndex()const
            int cppResult = cppSelf->QDataWidgetMapper::currentIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataWidgetMapperFunc_itemDelegate(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // itemDelegate()const
            QAbstractItemDelegate * cppResult = cppSelf->QDataWidgetMapper::itemDelegate();
            pyResult = Shiboken::Converter<QAbstractItemDelegate * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataWidgetMapperFunc_mappedPropertyName(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mappedPropertyName(QWidget*)const
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // mappedPropertyName(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_mappedPropertyName_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mappedPropertyName(QWidget*)const
            QByteArray cppResult = cppSelf->QDataWidgetMapper::mappedPropertyName(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDataWidgetMapperFunc_mappedPropertyName_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.mappedPropertyName", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_mappedSection(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mappedSection(QWidget*)const
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // mappedSection(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_mappedSection_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mappedSection(QWidget*)const
            int cppResult = cppSelf->QDataWidgetMapper::mappedSection(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDataWidgetMapperFunc_mappedSection_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.mappedSection", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_mappedWidgetAt(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mappedWidgetAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // mappedWidgetAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_mappedWidgetAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mappedWidgetAt(int)const
            QWidget * cppResult = cppSelf->QDataWidgetMapper::mappedWidgetAt(cpp_arg0);
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDataWidgetMapperFunc_mappedWidgetAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.mappedWidgetAt", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_model(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // model()const
            QAbstractItemModel * cppResult = cppSelf->QDataWidgetMapper::model();
            pyResult = Shiboken::Converter<QAbstractItemModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataWidgetMapperFunc_orientation(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // orientation()const
            Qt::Orientation cppResult = cppSelf->QDataWidgetMapper::orientation();
            pyResult = Shiboken::Converter<Qt::Orientation >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataWidgetMapperFunc_removeMapping(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeMapping(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // removeMapping(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_removeMapping_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeMapping(QWidget*)
            cppSelf->QDataWidgetMapper::removeMapping(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_removeMapping_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.removeMapping", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_revert(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // revert()
            cppSelf->QDataWidgetMapper::revert();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDataWidgetMapperFunc_rootIndex(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rootIndex()const
            QModelIndex cppResult = cppSelf->QDataWidgetMapper::rootIndex();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataWidgetMapperFunc_setCurrentIndex(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentIndex(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_setCurrentIndex_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentIndex(int)
            cppSelf->QDataWidgetMapper::setCurrentIndex(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_setCurrentIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.setCurrentIndex", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_setCurrentModelIndex(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentModelIndex(QModelIndex)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // setCurrentModelIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_setCurrentModelIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentModelIndex(QModelIndex)
            cppSelf->QDataWidgetMapper::setCurrentModelIndex(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_setCurrentModelIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.setCurrentModelIndex", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_setItemDelegate(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItemDelegate(QAbstractItemDelegate*)
    if (Shiboken::Converter<QAbstractItemDelegate * >::isConvertible(arg)) {
        overloadId = 0; // setItemDelegate(QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_setItemDelegate_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractItemDelegate* cpp_arg0 = Shiboken::Converter<QAbstractItemDelegate* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setItemDelegate(QAbstractItemDelegate*)
            cppSelf->QDataWidgetMapper::setItemDelegate(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_setItemDelegate_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemDelegate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.setItemDelegate", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_setModel(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModel(QAbstractItemModel*)
    if (Shiboken::Converter<QAbstractItemModel * >::isConvertible(arg)) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_setModel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractItemModel* cpp_arg0 = Shiboken::Converter<QAbstractItemModel* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setModel(QAbstractItemModel*)
            cppSelf->QDataWidgetMapper::setModel(cpp_arg0);
            Shiboken::keepReference(reinterpret_cast<SbkBaseWrapper*>(self), "setModel(QAbstractItemModel*)1", arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_setModel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.setModel", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_setOrientation(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOrientation(Qt::Orientation)
    if (Shiboken::Converter<Qt::Orientation >::isConvertible(arg)) {
        overloadId = 0; // setOrientation(Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_setOrientation_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOrientation(Qt::Orientation)
            cppSelf->QDataWidgetMapper::setOrientation(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_setOrientation_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.setOrientation", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_setRootIndex(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRootIndex(QModelIndex)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // setRootIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_setRootIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRootIndex(QModelIndex)
            cppSelf->QDataWidgetMapper::setRootIndex(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_setRootIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.setRootIndex", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_setSubmitPolicy(PyObject* self, PyObject* arg)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSubmitPolicy(QDataWidgetMapper::SubmitPolicy)
    if (Shiboken::Converter<QDataWidgetMapper::SubmitPolicy >::isConvertible(arg)) {
        overloadId = 0; // setSubmitPolicy(QDataWidgetMapper::SubmitPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDataWidgetMapperFunc_setSubmitPolicy_TypeError;

    // Call function/method
    {
        {
            QDataWidgetMapper::SubmitPolicy cpp_arg0 = Shiboken::Converter<QDataWidgetMapper::SubmitPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSubmitPolicy(QDataWidgetMapper::SubmitPolicy)
            cppSelf->QDataWidgetMapper::setSubmitPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDataWidgetMapperFunc_setSubmitPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDataWidgetMapper.SubmitPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDataWidgetMapper.setSubmitPolicy", overloads);
        return 0;
}

static PyObject* SbkQDataWidgetMapperFunc_submit(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // submit()
            bool cppResult = cppSelf->QDataWidgetMapper::submit();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataWidgetMapperFunc_submitPolicy(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // submitPolicy()const
            QDataWidgetMapper::SubmitPolicy cppResult = cppSelf->QDataWidgetMapper::submitPolicy();
            pyResult = Shiboken::Converter<QDataWidgetMapper::SubmitPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDataWidgetMapperFunc_toFirst(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toFirst()
            cppSelf->QDataWidgetMapper::toFirst();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDataWidgetMapperFunc_toLast(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toLast()
            cppSelf->QDataWidgetMapper::toLast();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDataWidgetMapperFunc_toNext(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toNext()
            cppSelf->QDataWidgetMapper::toNext();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDataWidgetMapperFunc_toPrevious(PyObject* self)
{
    QDataWidgetMapper* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDataWidgetMapper* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPrevious()
            cppSelf->QDataWidgetMapper::toPrevious();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQDataWidgetMapper_methods[] = {
    {"addMapping", (PyCFunction)SbkQDataWidgetMapperFunc_addMapping, METH_VARARGS},
    {"clearMapping", (PyCFunction)SbkQDataWidgetMapperFunc_clearMapping, METH_NOARGS},
    {"currentIndex", (PyCFunction)SbkQDataWidgetMapperFunc_currentIndex, METH_NOARGS},
    {"itemDelegate", (PyCFunction)SbkQDataWidgetMapperFunc_itemDelegate, METH_NOARGS},
    {"mappedPropertyName", (PyCFunction)SbkQDataWidgetMapperFunc_mappedPropertyName, METH_O},
    {"mappedSection", (PyCFunction)SbkQDataWidgetMapperFunc_mappedSection, METH_O},
    {"mappedWidgetAt", (PyCFunction)SbkQDataWidgetMapperFunc_mappedWidgetAt, METH_O},
    {"model", (PyCFunction)SbkQDataWidgetMapperFunc_model, METH_NOARGS},
    {"orientation", (PyCFunction)SbkQDataWidgetMapperFunc_orientation, METH_NOARGS},
    {"removeMapping", (PyCFunction)SbkQDataWidgetMapperFunc_removeMapping, METH_O},
    {"revert", (PyCFunction)SbkQDataWidgetMapperFunc_revert, METH_NOARGS},
    {"rootIndex", (PyCFunction)SbkQDataWidgetMapperFunc_rootIndex, METH_NOARGS},
    {"setCurrentIndex", (PyCFunction)SbkQDataWidgetMapperFunc_setCurrentIndex, METH_O},
    {"setCurrentModelIndex", (PyCFunction)SbkQDataWidgetMapperFunc_setCurrentModelIndex, METH_O},
    {"setItemDelegate", (PyCFunction)SbkQDataWidgetMapperFunc_setItemDelegate, METH_O},
    {"setModel", (PyCFunction)SbkQDataWidgetMapperFunc_setModel, METH_O},
    {"setOrientation", (PyCFunction)SbkQDataWidgetMapperFunc_setOrientation, METH_O},
    {"setRootIndex", (PyCFunction)SbkQDataWidgetMapperFunc_setRootIndex, METH_O},
    {"setSubmitPolicy", (PyCFunction)SbkQDataWidgetMapperFunc_setSubmitPolicy, METH_O},
    {"submit", (PyCFunction)SbkQDataWidgetMapperFunc_submit, METH_NOARGS},
    {"submitPolicy", (PyCFunction)SbkQDataWidgetMapperFunc_submitPolicy, METH_NOARGS},
    {"toFirst", (PyCFunction)SbkQDataWidgetMapperFunc_toFirst, METH_NOARGS},
    {"toLast", (PyCFunction)SbkQDataWidgetMapperFunc_toLast, METH_NOARGS},
    {"toNext", (PyCFunction)SbkQDataWidgetMapperFunc_toNext, METH_NOARGS},
    {"toPrevious", (PyCFunction)SbkQDataWidgetMapperFunc_toPrevious, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDataWidgetMapper_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QDataWidgetMapper",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDataWidgetMapper_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDataWidgetMapper_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDataWidgetMapper >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDataWidgetMapper*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQDataWidgetMapper_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDataWidgetMapper*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQDataWidgetMapper_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SubmitPolicy",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDataWidgetMapper(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QDATAWIDGETMAPPER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDataWidgetMapper_Type);

    SbkQDataWidgetMapper_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQDataWidgetMapper_Type.type_discovery = &SbkQDataWidgetMapper_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQDataWidgetMapper_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDataWidgetMapper_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDataWidgetMapper_Type));
    PyModule_AddObject(module, "QDataWidgetMapper",
        ((PyObject*)&SbkQDataWidgetMapper_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: SubmitPolicy
    SbkPySide_QtGuiTypes[SBK_QDATAWIDGETMAPPER_SUBMITPOLICY_IDX] = &SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type);
    PyDict_SetItemString(SbkQDataWidgetMapper_Type.super.ht_type.tp_dict,
            "SubmitPolicy",((PyObject*)&SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type,
        (long) QDataWidgetMapper::AutoSubmit, "AutoSubmit");
    PyDict_SetItemString(SbkQDataWidgetMapper_Type.super.ht_type.tp_dict,
        "AutoSubmit", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type.tp_dict,
        "AutoSubmit", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type,
        (long) QDataWidgetMapper::ManualSubmit, "ManualSubmit");
    PyDict_SetItemString(SbkQDataWidgetMapper_Type.super.ht_type.tp_dict,
        "ManualSubmit", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QDataWidgetMapper_SubmitPolicy_Type.tp_dict,
        "ManualSubmit", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDataWidgetMapper::SubmitPolicy");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("currentIndexChanged", "int", NULL);
    PyDict_SetItemString(SbkQDataWidgetMapper_Type.super.ht_type.tp_dict, "currentIndexChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QDataWidgetMapper >("QDataWidgetMapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDataWidgetMapper >(typeid(QDataWidgetMapper).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDataWidgetMapper >(typeid(QDataWidgetMapperWrapper).name());
    PySide::initQtMetaType<QDataWidgetMapper* >();
}

