/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <set>
#include "pyside_qtgui_python.h"

#include "qdragmoveevent_wrapper.h"

// Extra includes
#include <qmimedata.h>
#include <qpoint.h>
#include <qrect.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDragMoveEventWrapper::QDragMoveEventWrapper(const QPoint & pos, QFlags<Qt::DropAction> actions, const QMimeData * data, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers, QEvent::Type type) : QDragMoveEvent(pos, actions, data, buttons, modifiers, type) {
    // ... middle
}

QDragMoveEventWrapper::~QDragMoveEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDragMoveEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDragMoveEvent >()))
        return -1;

    QDragMoveEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QDragMoveEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QDragMoveEvent(): too many arguments");
        return -1;
    } else if (numArgs < 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QDragMoveEvent(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:QDragMoveEvent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QDragMoveEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
    if (numArgs >= 5 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<QFlags<Qt::DropAction> >::isConvertible(pyargs[1]) && Shiboken::Converter<const QMimeData * >::isConvertible(pyargs[2]) && Shiboken::Converter<QFlags<Qt::MouseButton> >::isConvertible(pyargs[3]) && Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[4])) {
        if (numArgs == 5) {
            overloadId = 0; // QDragMoveEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
        } else if (Shiboken::Converter<QEvent::Type >::isConvertible(pyargs[5])) {
            overloadId = 0; // QDragMoveEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDragMoveEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "type";
                    else
                        pyargs[5] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QDragMoveEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
            QFlags<Qt::DropAction> cpp_arg1 = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return -1;
            QMimeData* cpp_arg2 = Shiboken::Converter<QMimeData* >::toCpp(pyargs[2]);
            QFlags<Qt::MouseButton> cpp_arg3 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(pyargs[3]);
            QFlags<Qt::KeyboardModifier> cpp_arg4 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[4]);
            QEvent::Type cpp_arg5 = pyargs[5] ? Shiboken::Converter<QEvent::Type >::toCpp(pyargs[5]) : QEvent::DragMove;

            if(!PyErr_Occurred()) {
            // QDragMoveEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
            cptr = new QDragMoveEventWrapper(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDragMoveEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDragMoveEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDragMoveEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtCore.Qt.DropActions, PySide.QtCore.QMimeData, PySide.QtCore.Qt.MouseButtons, PySide.QtCore.Qt.KeyboardModifiers, PySide.QtCore.QEvent.Type = DragMove", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDragMoveEvent", overloads);
        return -1;
}

static PyObject* SbkQDragMoveEventFunc_accept(PyObject* self, PyObject* arg)
{
    QDragMoveEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDragMoveEvent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: accept()
    // 1: accept(QRect)
    if (numArgs == 0) {
        overloadId = 0; // accept()
    } else if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 1; // accept(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDragMoveEventFunc_accept_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // accept()
            {

                if(!PyErr_Occurred()) {
                // accept()
                cppSelf->QDragMoveEvent::accept();
                }
                break;
            }
            case 1: // accept(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // accept(QRect)
                cppSelf->QDragMoveEvent::accept(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDragMoveEventFunc_accept_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDragMoveEvent.accept", overloads);
        return 0;
}

static PyObject* SbkQDragMoveEventFunc_answerRect(PyObject* self)
{
    QDragMoveEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDragMoveEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // answerRect()const
            QRect cppResult = cppSelf->QDragMoveEvent::answerRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDragMoveEventFunc_ignore(PyObject* self, PyObject* arg)
{
    QDragMoveEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDragMoveEvent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: ignore()
    // 1: ignore(QRect)
    if (numArgs == 0) {
        overloadId = 0; // ignore()
    } else if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 1; // ignore(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDragMoveEventFunc_ignore_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // ignore()
            {

                if(!PyErr_Occurred()) {
                // ignore()
                cppSelf->QDragMoveEvent::ignore();
                }
                break;
            }
            case 1: // ignore(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // ignore(QRect)
                cppSelf->QDragMoveEvent::ignore(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDragMoveEventFunc_ignore_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDragMoveEvent.ignore", overloads);
        return 0;
}

static PyMethodDef SbkQDragMoveEvent_methods[] = {
    {"accept", (PyCFunction)SbkQDragMoveEventFunc_accept, METH_NOARGS|METH_O},
    {"answerRect", (PyCFunction)SbkQDragMoveEventFunc_answerRect, METH_NOARGS},
    {"ignore", (PyCFunction)SbkQDragMoveEventFunc_ignore, METH_NOARGS|METH_O},
    {0} // Sentinel
};

static PyObject* SbkQDragMoveEvent_get_rect(PyObject* self, void*)
{
    return Shiboken::Converter<QRect >::toPython(Shiboken::Converter<QDragMoveEvent* >::toCpp(self)->rect);
}
static int SbkQDragMoveEvent_set_rect(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'rect' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QRect >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'rect', 'QRect' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDragMoveEvent* >::toCpp(self)->rect = Shiboken::Converter<QRect >::toCpp(value);

    return 0;
}

// Getters and Setters for QDragMoveEvent
static PyGetSetDef SbkQDragMoveEvent_getsetlist[] = {
    {const_cast<char*>("rect"), SbkQDragMoveEvent_get_rect, SbkQDragMoveEvent_set_rect},
    {0}  // Sentinel
};

} // extern "C"

static void* SbkQDragMoveEventSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QDragMoveEvent* me = reinterpret_cast<QDragMoveEvent*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX]))
        return static_cast<QDropEvent*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]))
        return static_cast<QEvent*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDragMoveEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QDragMoveEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDragMoveEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQDragMoveEvent_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDragMoveEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQDragMoveEventSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDragMoveEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDragMoveEvent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQDragMoveEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
     if ( reinterpret_cast<QDragMoveEvent*>(cptr)->type() == QEvent::DragMove)
        return &SbkQDragMoveEvent_Type;
    return 0;
}


void init_QDragMoveEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QDRAGMOVEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDragMoveEvent_Type);

    SbkQDragMoveEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX];
    SbkQDragMoveEvent_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX])->mi_init;

    // Fill type discovery information
    SbkQDragMoveEvent_Type.type_discovery = &SbkQDragMoveEvent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX]), &SbkQDragMoveEvent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDragMoveEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDragMoveEvent_Type));
    PyModule_AddObject(module, "QDragMoveEvent",
        ((PyObject*)&SbkQDragMoveEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QDragMoveEvent >("QDragMoveEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDragMoveEvent >(typeid(QDragMoveEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDragMoveEvent >(typeid(QDragMoveEventWrapper).name());
    PySide::initQtMetaType<QDragMoveEvent* >();
}

