/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <set>
#include "pyside_qtgui_python.h"

#include "qdropevent_wrapper.h"

// Extra includes
#include <qmimedata.h>
#include <qpoint.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QDropEventWrapper::QDropEventWrapper(const QPoint & pos, QFlags<Qt::DropAction> actions, const QMimeData * data, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers, QEvent::Type type) : QDropEvent(pos, actions, data, buttons, modifiers, type) {
    // ... middle
}

QDropEventWrapper::~QDropEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDropEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDropEvent >()))
        return -1;

    QDropEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX]);
    if (type != myType) {
        type->mi_init = myType->mi_init;
        type->mi_offsets = myType->mi_offsets;
        type->mi_specialcast = myType->mi_specialcast;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QDropEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QDropEvent(): too many arguments");
        return -1;
    } else if (numArgs < 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QDropEvent(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:QDropEvent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QDropEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
    if (numArgs >= 5 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<QFlags<Qt::DropAction> >::isConvertible(pyargs[1]) && Shiboken::Converter<const QMimeData * >::isConvertible(pyargs[2]) && Shiboken::Converter<QFlags<Qt::MouseButton> >::isConvertible(pyargs[3]) && Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[4])) {
        if (numArgs == 5) {
            overloadId = 0; // QDropEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
        } else if (Shiboken::Converter<QEvent::Type >::isConvertible(pyargs[5])) {
            overloadId = 0; // QDropEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDropEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "type";
                    else
                        pyargs[5] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QDropEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
            QFlags<Qt::DropAction> cpp_arg1 = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return -1;
            QMimeData* cpp_arg2 = Shiboken::Converter<QMimeData* >::toCpp(pyargs[2]);
            QFlags<Qt::MouseButton> cpp_arg3 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(pyargs[3]);
            QFlags<Qt::KeyboardModifier> cpp_arg4 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[4]);
            QEvent::Type cpp_arg5 = pyargs[5] ? Shiboken::Converter<QEvent::Type >::toCpp(pyargs[5]) : QEvent::Drop;

            if(!PyErr_Occurred()) {
            // QDropEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>,QEvent::Type)
            cptr = new QDropEventWrapper(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDropEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDropEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDropEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtCore.Qt.DropActions, PySide.QtCore.QMimeData, PySide.QtCore.Qt.MouseButtons, PySide.QtCore.Qt.KeyboardModifiers, PySide.QtCore.QEvent.Type = Drop", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDropEvent", overloads);
        return -1;
}

static PyObject* SbkQDropEventFunc_acceptProposedAction(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptProposedAction()
            cppSelf->QDropEvent::acceptProposedAction();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDropEventFunc_dropAction(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dropAction()const
            Qt::DropAction cppResult = cppSelf->QDropEvent::dropAction();
            pyResult = Shiboken::Converter<Qt::DropAction >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDropEventFunc_keyboardModifiers(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keyboardModifiers()const
            QFlags<Qt::KeyboardModifier> cppResult = cppSelf->QDropEvent::keyboardModifiers();
            pyResult = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDropEventFunc_mimeData(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mimeData()const
            const QMimeData * cppResult = cppSelf->QDropEvent::mimeData();
            pyResult = Shiboken::Converter<const QMimeData * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDropEventFunc_mouseButtons(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mouseButtons()const
            QFlags<Qt::MouseButton> cppResult = cppSelf->QDropEvent::mouseButtons();
            pyResult = Shiboken::Converter<QFlags<Qt::MouseButton> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDropEventFunc_pos(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            const QPoint & cppResult = cppSelf->QDropEvent::pos();
            pyResult = Shiboken::Converter<const QPoint & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDropEventFunc_possibleActions(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // possibleActions()const
            QFlags<Qt::DropAction> cppResult = cppSelf->QDropEvent::possibleActions();
            pyResult = Shiboken::Converter<QFlags<Qt::DropAction> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDropEventFunc_proposedAction(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // proposedAction()const
            Qt::DropAction cppResult = cppSelf->QDropEvent::proposedAction();
            pyResult = Shiboken::Converter<Qt::DropAction >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDropEventFunc_setDropAction(PyObject* self, PyObject* arg)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDropAction(Qt::DropAction)
    if (Shiboken::Converter<Qt::DropAction >::isConvertible(arg)) {
        overloadId = 0; // setDropAction(Qt::DropAction)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDropEventFunc_setDropAction_TypeError;

    // Call function/method
    {
        {
            Qt::DropAction cpp_arg0 = Shiboken::Converter<Qt::DropAction >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDropAction(Qt::DropAction)
            cppSelf->QDropEvent::setDropAction(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDropEventFunc_setDropAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DropAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QDropEvent.setDropAction", overloads);
        return 0;
}

static PyObject* SbkQDropEventFunc_source(PyObject* self)
{
    QDropEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDropEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // source()const
            QWidget * cppResult = cppSelf->QDropEvent::source();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);

            // Ownership transferences.
            SbkBaseWrapper_setOwnership(pyResult, true);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDropEvent_methods[] = {
    {"acceptProposedAction", (PyCFunction)SbkQDropEventFunc_acceptProposedAction, METH_NOARGS},
    {"dropAction", (PyCFunction)SbkQDropEventFunc_dropAction, METH_NOARGS},
    {"keyboardModifiers", (PyCFunction)SbkQDropEventFunc_keyboardModifiers, METH_NOARGS},
    {"mimeData", (PyCFunction)SbkQDropEventFunc_mimeData, METH_NOARGS},
    {"mouseButtons", (PyCFunction)SbkQDropEventFunc_mouseButtons, METH_NOARGS},
    {"pos", (PyCFunction)SbkQDropEventFunc_pos, METH_NOARGS},
    {"possibleActions", (PyCFunction)SbkQDropEventFunc_possibleActions, METH_NOARGS},
    {"proposedAction", (PyCFunction)SbkQDropEventFunc_proposedAction, METH_NOARGS},
    {"setDropAction", (PyCFunction)SbkQDropEventFunc_setDropAction, METH_O},
    {"source", (PyCFunction)SbkQDropEventFunc_source, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQDropEvent_get_mdata(PyObject* self, void*)
{
    return Shiboken::Converter<const QMimeData * >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->mdata);
}

static PyObject* SbkQDropEvent_get_default_action(PyObject* self, void*)
{
    return Shiboken::Converter<Qt::DropAction >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->default_action);
}
static int SbkQDropEvent_set_default_action(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'default_action' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<Qt::DropAction >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'default_action', 'DropAction' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDropEvent* >::toCpp(self)->default_action = Shiboken::Converter<Qt::DropAction >::toCpp(value);

    return 0;
}

static PyObject* SbkQDropEvent_get_modState(PyObject* self, void*)
{
    return Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->modState);
}
static int SbkQDropEvent_set_modState(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'modState' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'modState', 'KeyboardModifiers' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDropEvent* >::toCpp(self)->modState = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(value);

    return 0;
}

static PyObject* SbkQDropEvent_get_fmts(PyObject* self, void*)
{
    return Shiboken::Converter<QList<QByteArray > >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->fmts);
}
static int SbkQDropEvent_set_fmts(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'fmts' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QList<QByteArray > >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'fmts', 'QList' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDropEvent* >::toCpp(self)->fmts = Shiboken::Converter<QList<QByteArray > >::toCpp(value);

    return 0;
}

static PyObject* SbkQDropEvent_get_mouseState(PyObject* self, void*)
{
    return Shiboken::Converter<QFlags<Qt::MouseButton> >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->mouseState);
}
static int SbkQDropEvent_set_mouseState(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'mouseState' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QFlags<Qt::MouseButton> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'mouseState', 'MouseButtons' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDropEvent* >::toCpp(self)->mouseState = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(value);

    return 0;
}

static PyObject* SbkQDropEvent_get_drop_action(PyObject* self, void*)
{
    return Shiboken::Converter<Qt::DropAction >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->drop_action);
}
static int SbkQDropEvent_set_drop_action(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'drop_action' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<Qt::DropAction >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'drop_action', 'DropAction' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDropEvent* >::toCpp(self)->drop_action = Shiboken::Converter<Qt::DropAction >::toCpp(value);

    return 0;
}

static PyObject* SbkQDropEvent_get_p(PyObject* self, void*)
{
    return Shiboken::Converter<QPoint >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->p);
}
static int SbkQDropEvent_set_p(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'p' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QPoint >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'p', 'QPoint' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDropEvent* >::toCpp(self)->p = Shiboken::Converter<QPoint >::toCpp(value);

    return 0;
}

static PyObject* SbkQDropEvent_get_act(PyObject* self, void*)
{
    return Shiboken::Converter<QFlags<Qt::DropAction> >::toPython(Shiboken::Converter<QDropEvent* >::toCpp(self)->act);
}
static int SbkQDropEvent_set_act(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'act' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QFlags<Qt::DropAction> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'act', 'DropActions' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QDropEvent* >::toCpp(self)->act = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(value);

    return 0;
}

// Getters and Setters for QDropEvent
static PyGetSetDef SbkQDropEvent_getsetlist[] = {
    {const_cast<char*>("mdata"), SbkQDropEvent_get_mdata, 0},
    {const_cast<char*>("default_action"), SbkQDropEvent_get_default_action, SbkQDropEvent_set_default_action},
    {const_cast<char*>("modState"), SbkQDropEvent_get_modState, SbkQDropEvent_set_modState},
    {const_cast<char*>("fmts"), SbkQDropEvent_get_fmts, SbkQDropEvent_set_fmts},
    {const_cast<char*>("mouseState"), SbkQDropEvent_get_mouseState, SbkQDropEvent_set_mouseState},
    {const_cast<char*>("drop_action"), SbkQDropEvent_get_drop_action, SbkQDropEvent_set_drop_action},
    {const_cast<char*>("p"), SbkQDropEvent_get_p, SbkQDropEvent_set_p},
    {const_cast<char*>("act"), SbkQDropEvent_get_act, SbkQDropEvent_set_act},
    {0}  // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1 };
int*
SbkQDropEvent_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QDropEvent* class_ptr = reinterpret_cast<const QDropEvent*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QEvent*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QEvent*>((QDropEvent*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* SbkQDropEventSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QDropEvent* me = reinterpret_cast<QDropEvent*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]))
        return static_cast<QEvent*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDropEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QDropEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDropEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQDropEvent_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDropEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             SbkQDropEvent_mi_init,
    /*mi_specialcast*/      &SbkQDropEventSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDropEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDropEvent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQDropEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
     if ( reinterpret_cast<QDropEvent*>(cptr)->type() == QEvent::Drop)
        return &SbkQDropEvent_Type;
    return 0;
}


void init_QDropEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDropEvent_Type);

    SbkQDropEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    SbkQDropEvent_Type.super.ht_type.tp_bases = PyTuple_Pack(1,
        (PyTypeObject*)SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]);

    // Fill type discovery information
    SbkQDropEvent_Type.type_discovery = &SbkQDropEvent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]), &SbkQDropEvent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDropEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDropEvent_Type));
    PyModule_AddObject(module, "QDropEvent",
        ((PyObject*)&SbkQDropEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QDropEvent >("QDropEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDropEvent >(typeid(QDropEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDropEvent >(typeid(QDropEventWrapper).name());
    PySide::initQtMetaType<QDropEvent* >();
}

