/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qfiledialog_wrapper.h"

// Extra includes
#include <QAbstractProxyModel>
#include <QList>
#include <QStringList>
#include <QUrl>
#include <qabstractitemdelegate.h>
#include <qabstractproxymodel.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qdir.h>
#include <qevent.h>
#include <qfiledialog.h>
#include <qfileiconprovider.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qurl.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QFileDialogWrapper::QFileDialogWrapper(QWidget * parent, QFlags<Qt::WindowType> f) : QFileDialog(parent, f), m_metaObject(0) {
    // ... middle
}

QFileDialogWrapper::QFileDialogWrapper(QWidget * parent, const QString & caption, const QString & directory, const QString & filter) : QFileDialog(parent, caption, directory, filter), m_metaObject(0) {
    // ... middle
}

void QFileDialogWrapper::accept()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "accept"));
    if (py_override.isNull()) {
        return this->QFileDialog::accept();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::changeEvent(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QFileDialog::changeEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QDialog::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QDialog::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QFileDialogWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::done(int result)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "done"));
    if (py_override.isNull()) {
        return this->QFileDialog::done(result);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        result
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::dragEnterEvent(QDragEnterEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragEnterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::dragLeaveEvent(QDragLeaveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragLeaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::dragMoveEvent(QDragMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::dropEvent(QDropEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dropEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QFileDialogWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QWidget::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QFileDialogWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QDialog::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::focusInEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusInEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QFileDialogWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::focusOutEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusOutEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QFileDialogWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QFileDialogWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::keyPressEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QDialog::keyPressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::keyReleaseEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QFileDialogWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QFileDialogWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QDialog::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::mouseDoubleClickEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseDoubleClickEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::mouseMoveEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::mousePressEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mousePressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::mouseReleaseEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QFileDialogWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QFileDialog.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QFileDialogWrapper::paintEvent(QPaintEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QWidget::paintEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::reject()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reject"));
    if (py_override.isNull()) {
        return this->QDialog::reject();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::resizeEvent(QResizeEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QDialog::resizeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QFileDialog::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QDialog::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QFileDialogWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QDialog::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFileDialog.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QFileDialogWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFileDialogWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFileDialogWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QWidget::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QFileDialogWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QFileDialog::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QFileDialogWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QFileDialog::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QFileDialogWrapper::~QFileDialogWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFileDialog_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFileDialog >()))
        return -1;

    QFileDialogWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "caption", "directory", "filter", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOOO:QFileDialog", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QFileDialog(QWidget*,QFlags<Qt::WindowType>)
    // 1: QFileDialog(QWidget*,QString,QString,QString)
    if (numArgs == 0) {
        overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
                } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                    overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
                }
            }
        } else if (numArgs == 2 && Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialog_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QFlags<Qt::WindowType> cpp_arg1 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
                cptr = new QFileDialogWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QFileDialog(QWidget*,QString,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "caption");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "caption";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "directory");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "directory";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "filter");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "filter";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();

                if(!PyErr_Occurred()) {
                // QFileDialog(QWidget*,QString,QString,QString)
                cptr = new QFileDialogWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFileDialog >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFileDialog_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQFileDialog_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.Qt.WindowFlags", "PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog", overloads);
        return -1;
}

static PyObject* SbkQFileDialogFunc_accept(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // accept()
            cppSelf->QFileDialog::accept();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQFileDialogFunc_acceptMode(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptMode()const
            QFileDialog::AcceptMode cppResult = cppSelf->QFileDialog::acceptMode();
            pyResult = Shiboken::Converter<QFileDialog::AcceptMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_changeEvent(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_changeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // changeEvent(QEvent*)
            cppSelf->QFileDialog::changeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_changeEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.changeEvent", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_confirmOverwrite(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // confirmOverwrite()const
            bool cppResult = cppSelf->QFileDialog::confirmOverwrite();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_defaultSuffix(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultSuffix()const
            QString cppResult = cppSelf->QFileDialog::defaultSuffix();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_directory(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // directory()const
            QDir cppResult = cppSelf->QFileDialog::directory();
            pyResult = Shiboken::Converter<QDir >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_done(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: done(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // done(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_done_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // done(int)
            cppSelf->QFileDialog::done(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_done_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.done", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_fileMode(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileMode()const
            QFileDialog::FileMode cppResult = cppSelf->QFileDialog::fileMode();
            pyResult = Shiboken::Converter<QFileDialog::FileMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_filter(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // filter()const
            QFlags<QDir::Filter> cppResult = cppSelf->QFileDialog::filter();
            pyResult = Shiboken::Converter<QFlags<QDir::Filter> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_filters(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // filters()const
            QStringList cppResult = cppSelf->QFileDialog::filters();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_getExistingDirectory(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "caption", "dir", "options", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getExistingDirectory(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getExistingDirectory(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:getExistingDirectory", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter<QFlags<QFileDialog::Option> >::isConvertible(pyargs[3])) {
                    overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_getExistingDirectory_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "options";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getExistingDirectory(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QFlags<QFileDialog::Option> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[3]) : QFileDialog::ShowDirsOnly;

            if(!PyErr_Occurred()) {
            // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
            threadStateSaver.save();
            QString cppResult = QFileDialog::getExistingDirectory(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileDialogFunc_getExistingDirectory_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), PySide.QtGui.QFileDialog.Options = QFileDialog.ShowDirsOnly", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getExistingDirectory", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_getOpenFileName(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "caption", "dir", "filter", "options", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 5, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileName(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileName(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:getOpenFileName", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (Shiboken::Converter<QFlags<QFileDialog::Option> >::isConvertible(pyargs[4])) {
                        overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_getOpenFileName_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "filter";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "options";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            QFlags<QFileDialog::Option> cpp_arg4 = pyargs[4] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[4]) : QFlags<QFileDialog::Option>(0);

            if(!PyErr_Occurred()) {
            // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            threadStateSaver.save();

            threadStateSaver.restore();

            // Begin code injection
            
            // TEMPLATE - return_for_QFileDialog - START
            QString retval_ = QFileDialog::getOpenFileName(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, 0);
            pyResult = Shiboken::makeTuple(retval_, cpp_arg3);
            // TEMPLATE - return_for_QFileDialog - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileDialogFunc_getOpenFileName_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString(), QString = 0, PySide.QtGui.QFileDialog.Options = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getOpenFileName", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_getOpenFileNames(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "caption", "dir", "filter", "options", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 5, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileNames(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileNames(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:getOpenFileNames", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (Shiboken::Converter<QFlags<QFileDialog::Option> >::isConvertible(pyargs[4])) {
                        overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_getOpenFileNames_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "filter";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "options";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getOpenFileNames(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            QFlags<QFileDialog::Option> cpp_arg4 = pyargs[4] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[4]) : QFlags<QFileDialog::Option>(0);

            if(!PyErr_Occurred()) {
            // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            threadStateSaver.save();

            threadStateSaver.restore();

            // Begin code injection
            
            // TEMPLATE - return_for_QFileDialog - START
            QStringList retval_ = QFileDialog::getOpenFileNames(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, 0);
            pyResult = Shiboken::makeTuple(retval_, cpp_arg3);
            // TEMPLATE - return_for_QFileDialog - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileDialogFunc_getOpenFileNames_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString(), QString = 0, PySide.QtGui.QFileDialog.Options = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getOpenFileNames", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_getSaveFileName(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "caption", "dir", "filter", "options", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 5, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getSaveFileName(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.getSaveFileName(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:getSaveFileName", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    if (numArgs == 0) {
        overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (Shiboken::Converter<QFlags<QFileDialog::Option> >::isConvertible(pyargs[4])) {
                        overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_getSaveFileName_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "caption");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "caption";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "dir";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "filter";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "options";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.getSaveFileName(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            QFlags<QFileDialog::Option> cpp_arg4 = pyargs[4] ? Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(pyargs[4]) : QFlags<QFileDialog::Option>(0);

            if(!PyErr_Occurred()) {
            // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            threadStateSaver.save();

            threadStateSaver.restore();

            // Begin code injection
            
            // TEMPLATE - return_for_QFileDialog - START
            QString retval_ = QFileDialog::getSaveFileName(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, 0);
            pyResult = Shiboken::makeTuple(retval_, cpp_arg3);
            // TEMPLATE - return_for_QFileDialog - END
            
            // End of code injection
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileDialogFunc_getSaveFileName_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, QString = QString(), QString = QString(), QString = QString(), QString = 0, PySide.QtGui.QFileDialog.Options = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.getSaveFileName", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_history(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // history()const
            QStringList cppResult = cppSelf->QFileDialog::history();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_iconProvider(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // iconProvider()const
            QFileIconProvider * cppResult = cppSelf->QFileDialog::iconProvider();
            pyResult = Shiboken::Converter<QFileIconProvider * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_isNameFilterDetailsVisible(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNameFilterDetailsVisible()const
            bool cppResult = cppSelf->QFileDialog::isNameFilterDetailsVisible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_isReadOnly(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isReadOnly()const
            bool cppResult = cppSelf->QFileDialog::isReadOnly();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_itemDelegate(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // itemDelegate()const
            QAbstractItemDelegate * cppResult = cppSelf->QFileDialog::itemDelegate();
            pyResult = Shiboken::Converter<QAbstractItemDelegate * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_labelText(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: labelText(QFileDialog::DialogLabel)const
    if (Shiboken::Converter<QFileDialog::DialogLabel >::isConvertible(arg)) {
        overloadId = 0; // labelText(QFileDialog::DialogLabel)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_labelText_TypeError;

    // Call function/method
    {
        {
            QFileDialog::DialogLabel cpp_arg0 = Shiboken::Converter<QFileDialog::DialogLabel >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // labelText(QFileDialog::DialogLabel)const
            QString cppResult = cppSelf->QFileDialog::labelText(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileDialogFunc_labelText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.DialogLabel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.labelText", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_nameFilters(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nameFilters()const
            QStringList cppResult = cppSelf->QFileDialog::nameFilters();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_open(PyObject* self, PyObject* args)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto SbkQFileDialogFunc_open_TypeError;

    if (!PyArg_UnpackTuple(args, "open", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: open()
    // 1: open(QObject*,const char*)
    if (numArgs == 0) {
        overloadId = 0; // open()
    } else if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        overloadId = 1; // open(QObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_open_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // open()
            {

                if(!PyErr_Occurred()) {
                // open()
                cppSelf->QFileDialog::open();
                }
                break;
            }
            case 1: // open(QObject*,const char*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // open(QObject*,const char*)
                cppSelf->QFileDialog::open(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_open_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.open", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_options(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // options()const
            QFlags<QFileDialog::Option> cppResult = cppSelf->QFileDialog::options();
            pyResult = Shiboken::Converter<QFlags<QFileDialog::Option> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_proxyModel(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // proxyModel()const
            QAbstractProxyModel * cppResult = cppSelf->QFileDialog::proxyModel();
            pyResult = Shiboken::Converter<QAbstractProxyModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_resolveSymlinks(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resolveSymlinks()const
            bool cppResult = cppSelf->QFileDialog::resolveSymlinks();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_restoreState(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreState(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // restoreState(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_restoreState_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // restoreState(QByteArray)
            bool cppResult = cppSelf->QFileDialog::restoreState(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileDialogFunc_restoreState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.restoreState", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_saveState(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // saveState()const
            QByteArray cppResult = cppSelf->QFileDialog::saveState();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_selectFile(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: selectFile(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // selectFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_selectFile_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // selectFile(QString)
            cppSelf->QFileDialog::selectFile(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_selectFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.selectFile", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_selectFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: selectFilter(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // selectFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_selectFilter_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // selectFilter(QString)
            cppSelf->QFileDialog::selectFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_selectFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.selectFilter", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_selectNameFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: selectNameFilter(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // selectNameFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_selectNameFilter_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // selectNameFilter(QString)
            cppSelf->QFileDialog::selectNameFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_selectNameFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.selectNameFilter", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_selectedFiles(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectedFiles()const
            QStringList cppResult = cppSelf->QFileDialog::selectedFiles();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_selectedFilter(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectedFilter()const
            QString cppResult = cppSelf->QFileDialog::selectedFilter();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_selectedNameFilter(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectedNameFilter()const
            QString cppResult = cppSelf->QFileDialog::selectedNameFilter();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_setAcceptMode(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptMode(QFileDialog::AcceptMode)
    if (Shiboken::Converter<QFileDialog::AcceptMode >::isConvertible(arg)) {
        overloadId = 0; // setAcceptMode(QFileDialog::AcceptMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setAcceptMode_TypeError;

    // Call function/method
    {
        {
            QFileDialog::AcceptMode cpp_arg0 = Shiboken::Converter<QFileDialog::AcceptMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptMode(QFileDialog::AcceptMode)
            cppSelf->QFileDialog::setAcceptMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setAcceptMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.AcceptMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setAcceptMode", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setConfirmOverwrite(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setConfirmOverwrite(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setConfirmOverwrite(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setConfirmOverwrite_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setConfirmOverwrite(bool)
            cppSelf->QFileDialog::setConfirmOverwrite(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setConfirmOverwrite_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setConfirmOverwrite", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setDefaultSuffix(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultSuffix(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDefaultSuffix(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setDefaultSuffix_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultSuffix(QString)
            cppSelf->QFileDialog::setDefaultSuffix(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setDefaultSuffix_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setDefaultSuffix", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setDirectory(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDirectory(QDir)
    // 1: setDirectory(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // setDirectory(QString)
    } else if (Shiboken::Converter<const QDir & >::isConvertible(arg)) {
        overloadId = 0; // setDirectory(QDir)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setDirectory_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setDirectory(QDir)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QDir > cpp_arg0_auto_ptr;
                QDir* cpp_arg0 = Shiboken::Converter<QDir* >::toCpp(arg);
                if (!Shiboken::Converter<QDir >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QDir >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setDirectory(QDir)
                cppSelf->QFileDialog::setDirectory(*cpp_arg0);
                }
                break;
            }
            case 1: // setDirectory(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setDirectory(QString)
                cppSelf->QFileDialog::setDirectory(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setDirectory_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setDirectory", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setFileMode(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileMode(QFileDialog::FileMode)
    if (Shiboken::Converter<QFileDialog::FileMode >::isConvertible(arg)) {
        overloadId = 0; // setFileMode(QFileDialog::FileMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setFileMode_TypeError;

    // Call function/method
    {
        {
            QFileDialog::FileMode cpp_arg0 = Shiboken::Converter<QFileDialog::FileMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFileMode(QFileDialog::FileMode)
            cppSelf->QFileDialog::setFileMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setFileMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.FileMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setFileMode", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFilter(QFlags<QDir::Filter>)
    // 1: setFilter(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // setFilter(QString)
    } else if (Shiboken::Converter<QFlags<QDir::Filter> >::isConvertible(arg)) {
        overloadId = 0; // setFilter(QFlags<QDir::Filter>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setFilter_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFilter(QFlags<QDir::Filter>)
            {
                QFlags<QDir::Filter> cpp_arg0 = Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setFilter(QFlags<QDir::Filter>)
                cppSelf->QFileDialog::setFilter(cpp_arg0);
                }
                break;
            }
            case 1: // setFilter(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setFilter(QString)
                cppSelf->QFileDialog::setFilter(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir.Filters", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setFilter", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setFilters(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFilters(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setFilters_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFilters(QStringList)
            cppSelf->QFileDialog::setFilters(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setFilters_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setFilters", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setHistory(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHistory(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setHistory(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setHistory_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHistory(QStringList)
            cppSelf->QFileDialog::setHistory(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setHistory_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setHistory", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setIconProvider(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconProvider(QFileIconProvider*)
    if (Shiboken::Converter<QFileIconProvider * >::isConvertible(arg)) {
        overloadId = 0; // setIconProvider(QFileIconProvider*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setIconProvider_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFileIconProvider* cpp_arg0 = Shiboken::Converter<QFileIconProvider* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIconProvider(QFileIconProvider*)
            cppSelf->QFileDialog::setIconProvider(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setIconProvider_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileIconProvider", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setIconProvider", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setItemDelegate(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItemDelegate(QAbstractItemDelegate*)
    if (Shiboken::Converter<QAbstractItemDelegate * >::isConvertible(arg)) {
        overloadId = 0; // setItemDelegate(QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setItemDelegate_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractItemDelegate* cpp_arg0 = Shiboken::Converter<QAbstractItemDelegate* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setItemDelegate(QAbstractItemDelegate*)
            cppSelf->QFileDialog::setItemDelegate(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setItemDelegate_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemDelegate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setItemDelegate", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setLabelText(PyObject* self, PyObject* args)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setLabelText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setLabelText(QFileDialog::DialogLabel,QString)
    if (numArgs == 2 && Shiboken::Converter<QFileDialog::DialogLabel >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setLabelText(QFileDialog::DialogLabel,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setLabelText_TypeError;

    // Call function/method
    {
        {
            QFileDialog::DialogLabel cpp_arg0 = Shiboken::Converter<QFileDialog::DialogLabel >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setLabelText(QFileDialog::DialogLabel,QString)
            cppSelf->QFileDialog::setLabelText(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setLabelText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.DialogLabel, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.setLabelText", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setNameFilter(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNameFilter(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setNameFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setNameFilter_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNameFilter(QString)
            cppSelf->QFileDialog::setNameFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setNameFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setNameFilter", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setNameFilterDetailsVisible(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNameFilterDetailsVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNameFilterDetailsVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setNameFilterDetailsVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNameFilterDetailsVisible(bool)
            cppSelf->QFileDialog::setNameFilterDetailsVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setNameFilterDetailsVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setNameFilterDetailsVisible", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setNameFilters(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNameFilters(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setNameFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setNameFilters_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNameFilters(QStringList)
            cppSelf->QFileDialog::setNameFilters(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setNameFilters_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setNameFilters", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setOption(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "on" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.setOption(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.setOption(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFileDialog.setOption(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setOption", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOption(QFileDialog::Option,bool)
    if (Shiboken::Converter<QFileDialog::Option >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QFileDialog::Option,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setOption(QFileDialog::Option,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setOption_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFileDialog.setOption(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFileDialog::Option cpp_arg0 = Shiboken::Converter<QFileDialog::Option >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setOption(QFileDialog::Option,bool)
            cppSelf->QFileDialog::setOption(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.Option, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFileDialog.setOption", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setOptions(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOptions(QFlags<QFileDialog::Option>)
    if (Shiboken::Converter<QFlags<QFileDialog::Option> >::isConvertible(arg)) {
        overloadId = 0; // setOptions(QFlags<QFileDialog::Option>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setOptions_TypeError;

    // Call function/method
    {
        {
            QFlags<QFileDialog::Option> cpp_arg0 = Shiboken::Converter<QFlags<QFileDialog::Option> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOptions(QFlags<QFileDialog::Option>)
            cppSelf->QFileDialog::setOptions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setOptions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.Options", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setOptions", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setProxyModel(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProxyModel(QAbstractProxyModel*)
    if (Shiboken::Converter<QAbstractProxyModel * >::isConvertible(arg)) {
        overloadId = 0; // setProxyModel(QAbstractProxyModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setProxyModel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractProxyModel* cpp_arg0 = Shiboken::Converter<QAbstractProxyModel* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setProxyModel(QAbstractProxyModel*)
            cppSelf->QFileDialog::setProxyModel(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setProxyModel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractProxyModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setProxyModel", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setReadOnly(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadOnly(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setReadOnly_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setReadOnly(bool)
            cppSelf->QFileDialog::setReadOnly(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setReadOnly_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setReadOnly", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setResolveSymlinks(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setResolveSymlinks(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setResolveSymlinks(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setResolveSymlinks_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setResolveSymlinks(bool)
            cppSelf->QFileDialog::setResolveSymlinks(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setResolveSymlinks_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setResolveSymlinks", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setSidebarUrls(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSidebarUrls(QList<QUrl>)
    if (Shiboken::Converter< QList<QUrl >  >::isConvertible(arg)) {
        overloadId = 0; // setSidebarUrls(QList<QUrl>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setSidebarUrls_TypeError;

    // Call function/method
    {
        {
            QList<QUrl > cpp_arg0 = Shiboken::Converter<QList<QUrl > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSidebarUrls(QList<QUrl>)
            cppSelf->QFileDialog::setSidebarUrls(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setSidebarUrls_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setSidebarUrls", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setViewMode(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewMode(QFileDialog::ViewMode)
    if (Shiboken::Converter<QFileDialog::ViewMode >::isConvertible(arg)) {
        overloadId = 0; // setViewMode(QFileDialog::ViewMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setViewMode_TypeError;

    // Call function/method
    {
        {
            QFileDialog::ViewMode cpp_arg0 = Shiboken::Converter<QFileDialog::ViewMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setViewMode(QFileDialog::ViewMode)
            cppSelf->QFileDialog::setViewMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setViewMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.ViewMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setViewMode", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_setVisible(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisible(bool)
            cppSelf->QFileDialog::setVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFileDialogFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.setVisible", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_sidebarUrls(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sidebarUrls()const
            QList<QUrl > cppResult = cppSelf->QFileDialog::sidebarUrls();
            pyResult = Shiboken::Converter<QList<QUrl > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFileDialogFunc_testOption(PyObject* self, PyObject* arg)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testOption(QFileDialog::Option)const
    if (Shiboken::Converter<QFileDialog::Option >::isConvertible(arg)) {
        overloadId = 0; // testOption(QFileDialog::Option)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFileDialogFunc_testOption_TypeError;

    // Call function/method
    {
        {
            QFileDialog::Option cpp_arg0 = Shiboken::Converter<QFileDialog::Option >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // testOption(QFileDialog::Option)const
            bool cppResult = cppSelf->QFileDialog::testOption(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFileDialogFunc_testOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileDialog.Option", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFileDialog.testOption", overloads);
        return 0;
}

static PyObject* SbkQFileDialogFunc_viewMode(PyObject* self)
{
    QFileDialog* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFileDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewMode()const
            QFileDialog::ViewMode cppResult = cppSelf->QFileDialog::viewMode();
            pyResult = Shiboken::Converter<QFileDialog::ViewMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFileDialog_methods[] = {
    {"accept", (PyCFunction)SbkQFileDialogFunc_accept, METH_NOARGS},
    {"acceptMode", (PyCFunction)SbkQFileDialogFunc_acceptMode, METH_NOARGS},
    {"changeEvent", (PyCFunction)SbkQFileDialogFunc_changeEvent, METH_O},
    {"confirmOverwrite", (PyCFunction)SbkQFileDialogFunc_confirmOverwrite, METH_NOARGS},
    {"defaultSuffix", (PyCFunction)SbkQFileDialogFunc_defaultSuffix, METH_NOARGS},
    {"directory", (PyCFunction)SbkQFileDialogFunc_directory, METH_NOARGS},
    {"done", (PyCFunction)SbkQFileDialogFunc_done, METH_O},
    {"fileMode", (PyCFunction)SbkQFileDialogFunc_fileMode, METH_NOARGS},
    {"filter", (PyCFunction)SbkQFileDialogFunc_filter, METH_NOARGS},
    {"filters", (PyCFunction)SbkQFileDialogFunc_filters, METH_NOARGS},
    {"getExistingDirectory", (PyCFunction)SbkQFileDialogFunc_getExistingDirectory, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getOpenFileName", (PyCFunction)SbkQFileDialogFunc_getOpenFileName, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getOpenFileNames", (PyCFunction)SbkQFileDialogFunc_getOpenFileNames, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getSaveFileName", (PyCFunction)SbkQFileDialogFunc_getSaveFileName, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"history", (PyCFunction)SbkQFileDialogFunc_history, METH_NOARGS},
    {"iconProvider", (PyCFunction)SbkQFileDialogFunc_iconProvider, METH_NOARGS},
    {"isNameFilterDetailsVisible", (PyCFunction)SbkQFileDialogFunc_isNameFilterDetailsVisible, METH_NOARGS},
    {"isReadOnly", (PyCFunction)SbkQFileDialogFunc_isReadOnly, METH_NOARGS},
    {"itemDelegate", (PyCFunction)SbkQFileDialogFunc_itemDelegate, METH_NOARGS},
    {"labelText", (PyCFunction)SbkQFileDialogFunc_labelText, METH_O},
    {"nameFilters", (PyCFunction)SbkQFileDialogFunc_nameFilters, METH_NOARGS},
    {"open", (PyCFunction)SbkQFileDialogFunc_open, METH_VARARGS},
    {"options", (PyCFunction)SbkQFileDialogFunc_options, METH_NOARGS},
    {"proxyModel", (PyCFunction)SbkQFileDialogFunc_proxyModel, METH_NOARGS},
    {"resolveSymlinks", (PyCFunction)SbkQFileDialogFunc_resolveSymlinks, METH_NOARGS},
    {"restoreState", (PyCFunction)SbkQFileDialogFunc_restoreState, METH_O},
    {"saveState", (PyCFunction)SbkQFileDialogFunc_saveState, METH_NOARGS},
    {"selectFile", (PyCFunction)SbkQFileDialogFunc_selectFile, METH_O},
    {"selectFilter", (PyCFunction)SbkQFileDialogFunc_selectFilter, METH_O},
    {"selectNameFilter", (PyCFunction)SbkQFileDialogFunc_selectNameFilter, METH_O},
    {"selectedFiles", (PyCFunction)SbkQFileDialogFunc_selectedFiles, METH_NOARGS},
    {"selectedFilter", (PyCFunction)SbkQFileDialogFunc_selectedFilter, METH_NOARGS},
    {"selectedNameFilter", (PyCFunction)SbkQFileDialogFunc_selectedNameFilter, METH_NOARGS},
    {"setAcceptMode", (PyCFunction)SbkQFileDialogFunc_setAcceptMode, METH_O},
    {"setConfirmOverwrite", (PyCFunction)SbkQFileDialogFunc_setConfirmOverwrite, METH_O},
    {"setDefaultSuffix", (PyCFunction)SbkQFileDialogFunc_setDefaultSuffix, METH_O},
    {"setDirectory", (PyCFunction)SbkQFileDialogFunc_setDirectory, METH_O},
    {"setFileMode", (PyCFunction)SbkQFileDialogFunc_setFileMode, METH_O},
    {"setFilter", (PyCFunction)SbkQFileDialogFunc_setFilter, METH_O},
    {"setFilters", (PyCFunction)SbkQFileDialogFunc_setFilters, METH_O},
    {"setHistory", (PyCFunction)SbkQFileDialogFunc_setHistory, METH_O},
    {"setIconProvider", (PyCFunction)SbkQFileDialogFunc_setIconProvider, METH_O},
    {"setItemDelegate", (PyCFunction)SbkQFileDialogFunc_setItemDelegate, METH_O},
    {"setLabelText", (PyCFunction)SbkQFileDialogFunc_setLabelText, METH_VARARGS},
    {"setNameFilter", (PyCFunction)SbkQFileDialogFunc_setNameFilter, METH_O},
    {"setNameFilterDetailsVisible", (PyCFunction)SbkQFileDialogFunc_setNameFilterDetailsVisible, METH_O},
    {"setNameFilters", (PyCFunction)SbkQFileDialogFunc_setNameFilters, METH_O},
    {"setOption", (PyCFunction)SbkQFileDialogFunc_setOption, METH_VARARGS|METH_KEYWORDS},
    {"setOptions", (PyCFunction)SbkQFileDialogFunc_setOptions, METH_O},
    {"setProxyModel", (PyCFunction)SbkQFileDialogFunc_setProxyModel, METH_O},
    {"setReadOnly", (PyCFunction)SbkQFileDialogFunc_setReadOnly, METH_O},
    {"setResolveSymlinks", (PyCFunction)SbkQFileDialogFunc_setResolveSymlinks, METH_O},
    {"setSidebarUrls", (PyCFunction)SbkQFileDialogFunc_setSidebarUrls, METH_O},
    {"setViewMode", (PyCFunction)SbkQFileDialogFunc_setViewMode, METH_O},
    {"setVisible", (PyCFunction)SbkQFileDialogFunc_setVisible, METH_O},
    {"sidebarUrls", (PyCFunction)SbkQFileDialogFunc_sidebarUrls, METH_NOARGS},
    {"testOption", (PyCFunction)SbkQFileDialogFunc_testOption, METH_O},
    {"viewMode", (PyCFunction)SbkQFileDialogFunc_viewMode, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQFileDialogSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QFileDialog* me = reinterpret_cast<QFileDialog*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]))
        return static_cast<QDialog*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFileDialog_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFileDialog",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFileDialog_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFileDialog_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQFileDialogSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFileDialog >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFileDialog*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQFileDialog_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QFileDialog*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQFileDialog_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QFileDialog*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQFileDialog_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QFileDialog_FileMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFileDialog_FileMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFileDialog_FileMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FileMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFileDialog_FileMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFileDialog_FileMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFileDialog_FileMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QFileDialog::Options >::checkType(self) && Shiboken::Converter<QFileDialog::Options >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QFileDialog::Options >::toPython(
        Shiboken::Converter<QFileDialog::Options>::toCpp(self)
        & Shiboken::Converter< QFileDialog::Options >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QFileDialog::Options >::checkType(self) && Shiboken::Converter<QFileDialog::Options >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QFileDialog::Options >::toPython(
        Shiboken::Converter<QFileDialog::Options>::toCpp(self)
        | Shiboken::Converter< QFileDialog::Options >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QFileDialog::Options >::checkType(self) && Shiboken::Converter<QFileDialog::Options >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QFileDialog::Options >::toPython(
        Shiboken::Converter<QFileDialog::Options>::toCpp(self)
        ^ Shiboken::Converter< QFileDialog::Options >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QFileDialog_Option___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QFileDialog::Options >::toPython(
        ~Shiboken::Converter<QFileDialog::Options >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QFileDialog_Option_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QFileDialog_Option___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QFileDialog_Option___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QFileDialog_Option___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QFileDialog_Option___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QFileDialog_Option_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFileDialog_Option_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFileDialog_Option_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Option",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QFileDialog_Option_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFileDialog_Option_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFileDialog_Option_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFileDialog_Option_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QFileDialog_Options_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Options",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QFileDialog_Option_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QFileDialog_DialogLabel_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFileDialog_DialogLabel_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFileDialog_DialogLabel_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DialogLabel",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFileDialog_DialogLabel_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFileDialog_DialogLabel_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFileDialog_DialogLabel_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QFileDialog_ViewMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFileDialog_ViewMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFileDialog_ViewMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ViewMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFileDialog_ViewMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFileDialog_ViewMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFileDialog_ViewMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QFileDialog_AcceptMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFileDialog_AcceptMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFileDialog_AcceptMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "AcceptMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFileDialog_AcceptMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFileDialog_AcceptMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFileDialog_AcceptMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QFileDialog(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFileDialog_Type);

    SbkQFileDialog_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX];
    SbkQFileDialog_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX])->mi_init;

    // Fill type discovery information
    SbkQFileDialog_Type.type_discovery = &SbkQFileDialog_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]), &SbkQFileDialog_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFileDialog_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFileDialog_Type));
    PyModule_AddObject(module, "QFileDialog",
        ((PyObject*)&SbkQFileDialog_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: FileMode
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_FILEMODE_IDX] = &SbkPySide_QtGui_QFileDialog_FileMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFileDialog_FileMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFileDialog_FileMode_Type);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
            "FileMode",((PyObject*)&SbkPySide_QtGui_QFileDialog_FileMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_FileMode_Type,
        (long) QFileDialog::AnyFile, "AnyFile");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "AnyFile", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode_Type.tp_dict,
        "AnyFile", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_FileMode_Type,
        (long) QFileDialog::ExistingFile, "ExistingFile");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "ExistingFile", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode_Type.tp_dict,
        "ExistingFile", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_FileMode_Type,
        (long) QFileDialog::Directory, "Directory");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "Directory", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode_Type.tp_dict,
        "Directory", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_FileMode_Type,
        (long) QFileDialog::ExistingFiles, "ExistingFiles");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "ExistingFiles", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode_Type.tp_dict,
        "ExistingFiles", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_FileMode_Type,
        (long) QFileDialog::DirectoryOnly, "DirectoryOnly");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "DirectoryOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_FileMode_Type.tp_dict,
        "DirectoryOnly", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::FileMode");

    // init enum class: Option
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_OPTION_IDX] = &SbkPySide_QtGui_QFileDialog_Option_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFileDialog_Option_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFileDialog_Option_Type);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
            "Option",((PyObject*)&SbkPySide_QtGui_QFileDialog_Option_Type));

    // init flags class: QFlags<QFileDialog::Option>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QFILEDIALOG_OPTION__IDX] = &SbkPySide_QtGui_QFileDialog_Options_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFileDialog_Options_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFileDialog_Options_Type);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
            "Options",((PyObject*)&SbkPySide_QtGui_QFileDialog_Options_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_Option_Type,
        (long) QFileDialog::ShowDirsOnly, "ShowDirsOnly");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "ShowDirsOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option_Type.tp_dict,
        "ShowDirsOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_Option_Type,
        (long) QFileDialog::DontResolveSymlinks, "DontResolveSymlinks");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "DontResolveSymlinks", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option_Type.tp_dict,
        "DontResolveSymlinks", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_Option_Type,
        (long) QFileDialog::DontConfirmOverwrite, "DontConfirmOverwrite");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "DontConfirmOverwrite", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option_Type.tp_dict,
        "DontConfirmOverwrite", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_Option_Type,
        (long) QFileDialog::DontUseSheet, "DontUseSheet");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "DontUseSheet", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option_Type.tp_dict,
        "DontUseSheet", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_Option_Type,
        (long) QFileDialog::DontUseNativeDialog, "DontUseNativeDialog");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "DontUseNativeDialog", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option_Type.tp_dict,
        "DontUseNativeDialog", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_Option_Type,
        (long) QFileDialog::ReadOnly, "ReadOnly");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "ReadOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option_Type.tp_dict,
        "ReadOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_Option_Type,
        (long) QFileDialog::HideNameFilterDetails, "HideNameFilterDetails");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "HideNameFilterDetails", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_Option_Type.tp_dict,
        "HideNameFilterDetails", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::Option");

    // init enum class: DialogLabel
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_DIALOGLABEL_IDX] = &SbkPySide_QtGui_QFileDialog_DialogLabel_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFileDialog_DialogLabel_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFileDialog_DialogLabel_Type);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
            "DialogLabel",((PyObject*)&SbkPySide_QtGui_QFileDialog_DialogLabel_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_DialogLabel_Type,
        (long) QFileDialog::LookIn, "LookIn");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "LookIn", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel_Type.tp_dict,
        "LookIn", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_DialogLabel_Type,
        (long) QFileDialog::FileName, "FileName");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "FileName", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel_Type.tp_dict,
        "FileName", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_DialogLabel_Type,
        (long) QFileDialog::FileType, "FileType");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "FileType", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel_Type.tp_dict,
        "FileType", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_DialogLabel_Type,
        (long) QFileDialog::Accept, "Accept");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "Accept", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel_Type.tp_dict,
        "Accept", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_DialogLabel_Type,
        (long) QFileDialog::Reject, "Reject");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "Reject", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_DialogLabel_Type.tp_dict,
        "Reject", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::DialogLabel");

    // init enum class: ViewMode
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_VIEWMODE_IDX] = &SbkPySide_QtGui_QFileDialog_ViewMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFileDialog_ViewMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFileDialog_ViewMode_Type);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
            "ViewMode",((PyObject*)&SbkPySide_QtGui_QFileDialog_ViewMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_ViewMode_Type,
        (long) QFileDialog::Detail, "Detail");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "Detail", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_ViewMode_Type.tp_dict,
        "Detail", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_ViewMode_Type,
        (long) QFileDialog::List, "List");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "List", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_ViewMode_Type.tp_dict,
        "List", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::ViewMode");

    // init enum class: AcceptMode
    SbkPySide_QtGuiTypes[SBK_QFILEDIALOG_ACCEPTMODE_IDX] = &SbkPySide_QtGui_QFileDialog_AcceptMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFileDialog_AcceptMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFileDialog_AcceptMode_Type);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
            "AcceptMode",((PyObject*)&SbkPySide_QtGui_QFileDialog_AcceptMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_AcceptMode_Type,
        (long) QFileDialog::AcceptOpen, "AcceptOpen");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "AcceptOpen", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_AcceptMode_Type.tp_dict,
        "AcceptOpen", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFileDialog_AcceptMode_Type,
        (long) QFileDialog::AcceptSave, "AcceptSave");
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict,
        "AcceptSave", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFileDialog_AcceptMode_Type.tp_dict,
        "AcceptSave", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFileDialog::AcceptMode");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("directoryEntered", "const QString&", NULL);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict, "directoryEntered", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("filesSelected", "const QStringList&", NULL);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict, "filesSelected", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("filterSelected", "const QString&", NULL);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict, "filterSelected", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("fileSelected", "const QString&", NULL);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict, "fileSelected", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("currentChanged", "const QString&", NULL);
    PyDict_SetItemString(SbkQFileDialog_Type.super.ht_type.tp_dict, "currentChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QFileDialog >("QFileDialog*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFileDialog >(typeid(QFileDialog).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFileDialog >(typeid(QFileDialogWrapper).name());
    PySide::initQtMetaType<QFileDialog* >();
}

