/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfocusevent_wrapper.h"

// Extra includes

using namespace Shiboken;

// Native ---------------------------------------------------------

QFocusEventWrapper::QFocusEventWrapper(QEvent::Type type, Qt::FocusReason reason) : QFocusEvent(type, reason) {
    // ... middle
}

QFocusEventWrapper::~QFocusEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFocusEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFocusEvent >()))
        return -1;

    QFocusEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "reason" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFocusEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFocusEvent(): too many arguments");
        return -1;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFocusEvent(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QFocusEvent", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QFocusEvent(QEvent::Type,Qt::FocusReason)
    if (Shiboken::Converter<QEvent::Type >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QFocusEvent(QEvent::Type,Qt::FocusReason)
        } else if (Shiboken::Converter<Qt::FocusReason >::isConvertible(pyargs[1])) {
            overloadId = 0; // QFocusEvent(QEvent::Type,Qt::FocusReason)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFocusEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "reason");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "reason";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFocusEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QEvent::Type cpp_arg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
            Qt::FocusReason cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::FocusReason >::toCpp(pyargs[1]) : Qt::OtherFocusReason;

            if(!PyErr_Occurred()) {
            // QFocusEvent(QEvent::Type,Qt::FocusReason)
            cptr = new QFocusEventWrapper(cpp_arg0, cpp_arg1);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFocusEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFocusEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQFocusEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, PySide.QtCore.Qt.FocusReason = Qt.OtherFocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFocusEvent", overloads);
        return -1;
}

static PyObject* SbkQFocusEventFunc_gotFocus(PyObject* self)
{
    QFocusEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFocusEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // gotFocus()const
            bool cppResult = cppSelf->QFocusEvent::gotFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFocusEventFunc_lostFocus(PyObject* self)
{
    QFocusEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFocusEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lostFocus()const
            bool cppResult = cppSelf->QFocusEvent::lostFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFocusEventFunc_reason(PyObject* self)
{
    QFocusEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFocusEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reason()
            Qt::FocusReason cppResult = cppSelf->QFocusEvent::reason();
            pyResult = Shiboken::Converter<Qt::FocusReason >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFocusEvent_methods[] = {
    {"gotFocus", (PyCFunction)SbkQFocusEventFunc_gotFocus, METH_NOARGS},
    {"lostFocus", (PyCFunction)SbkQFocusEventFunc_lostFocus, METH_NOARGS},
    {"reason", (PyCFunction)SbkQFocusEventFunc_reason, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFocusEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFocusEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFocusEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFocusEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFocusEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFocusEvent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQFocusEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
     if ( reinterpret_cast<QFocusEvent*>(cptr)->type() == QEvent::FocusIn ||  reinterpret_cast<QFocusEvent*>(cptr)->type() == QEvent::FocusOut)
        return &SbkQFocusEvent_Type;
    return 0;
}


void init_QFocusEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFOCUSEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFocusEvent_Type);

    SbkQFocusEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    // Fill type discovery information
    SbkQFocusEvent_Type.type_discovery = &SbkQFocusEvent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]), &SbkQFocusEvent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFocusEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFocusEvent_Type));
    PyModule_AddObject(module, "QFocusEvent",
        ((PyObject*)&SbkQFocusEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QFocusEvent >("QFocusEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFocusEvent >(typeid(QFocusEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFocusEvent >(typeid(QFocusEventWrapper).name());
    PySide::initQtMetaType<QFocusEvent* >();
}

