/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfontdatabase_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qfont.h>
#include <qfontinfo.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFontDatabase_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFontDatabase >()))
        return -1;

    QFontDatabase* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFontDatabase", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QFontDatabase(QFontDatabase)
    // 1: QFontDatabase()
    if (numArgs == 0) {
        overloadId = 1; // QFontDatabase()
    } else if (numArgs == 1 && Shiboken::Converter<const QFontDatabase & >::isConvertible(arg)) {
        overloadId = 0; // QFontDatabase(QFontDatabase)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabase_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFontDatabase(QFontDatabase)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QFontDatabase* cpp_arg0 = Shiboken::Converter<QFontDatabase* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QFontDatabase(QFontDatabase)
                cptr = new QFontDatabase(*cpp_arg0);
                }
                break;
            }
            case 1: // QFontDatabase()
            {

                if(!PyErr_Occurred()) {
                // QFontDatabase()
                cptr = new QFontDatabase();
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFontDatabase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFontDatabase_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQFontDatabase_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFontDatabase", "", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase", overloads);
        return -1;
}

static PyObject* SbkQFontDatabaseFunc_addApplicationFont(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addApplicationFont(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // addApplicationFont(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_addApplicationFont_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addApplicationFont(QString)
            int cppResult = QFontDatabase::addApplicationFont(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_addApplicationFont_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.addApplicationFont", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_addApplicationFontFromData(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addApplicationFontFromData(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // addApplicationFontFromData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_addApplicationFontFromData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // addApplicationFontFromData(QByteArray)
            int cppResult = QFontDatabase::addApplicationFontFromData(*cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_addApplicationFontFromData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.addApplicationFontFromData", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_applicationFontFamilies(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: applicationFontFamilies(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // applicationFontFamilies(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_applicationFontFamilies_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // applicationFontFamilies(int)
            QStringList cppResult = QFontDatabase::applicationFontFamilies(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_applicationFontFamilies_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.applicationFontFamilies", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_bold(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "bold", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bold(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // bold(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_bold_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // bold(QString,QString)const
            bool cppResult = cppSelf->QFontDatabase::bold(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_bold_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.bold", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_families(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "writingSystem" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.families(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.families(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:families", &arg))
        return 0;


    // Overloaded function decisor
    // 0: families(QFontDatabase::WritingSystem)const
    if (numArgs == 0) {
        overloadId = 0; // families(QFontDatabase::WritingSystem)const
    } else if (Shiboken::Converter<QFontDatabase::WritingSystem >::isConvertible(arg)) {
        overloadId = 0; // families(QFontDatabase::WritingSystem)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_families_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "writingSystem");
                if (value) {
                    if (arg)
                        errorArgName = "writingSystem";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.families(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFontDatabase::WritingSystem cpp_arg0 = arg ? Shiboken::Converter<QFontDatabase::WritingSystem >::toCpp(arg) : QFontDatabase::Any;

            if(!PyErr_Occurred()) {
            // families(QFontDatabase::WritingSystem)const
            QStringList cppResult = cppSelf->QFontDatabase::families(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_families_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFontDatabase.WritingSystem = Any", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.families", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_font(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "font", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: font(QString,QString,int)const
    if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // font(QString,QString,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_font_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // font(QString,QString,int)const
            QFont cppResult = cppSelf->QFontDatabase::font(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_font_TypeError:
        const char* overloads[] = {"QString, QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.font", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_isBitmapScalable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "style" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isBitmapScalable(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isBitmapScalable(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isBitmapScalable(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isBitmapScalable", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isBitmapScalable(QString,QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isBitmapScalable(QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isBitmapScalable(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_isBitmapScalable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isBitmapScalable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // isBitmapScalable(QString,QString)const
            bool cppResult = cppSelf->QFontDatabase::isBitmapScalable(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_isBitmapScalable_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isBitmapScalable", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_isFixedPitch(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "style" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isFixedPitch(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isFixedPitch(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isFixedPitch(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isFixedPitch", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isFixedPitch(QString,QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isFixedPitch(QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isFixedPitch(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_isFixedPitch_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isFixedPitch(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // isFixedPitch(QString,QString)const
            bool cppResult = cppSelf->QFontDatabase::isFixedPitch(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_isFixedPitch_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isFixedPitch", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_isScalable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "style" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isScalable(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isScalable(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isScalable(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isScalable", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isScalable(QString,QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isScalable(QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isScalable(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_isScalable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isScalable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // isScalable(QString,QString)const
            bool cppResult = cppSelf->QFontDatabase::isScalable(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_isScalable_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isScalable", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_isSmoothlyScalable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "style" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isSmoothlyScalable(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isSmoothlyScalable(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isSmoothlyScalable(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isSmoothlyScalable", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isSmoothlyScalable(QString,QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isSmoothlyScalable(QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isSmoothlyScalable(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_isSmoothlyScalable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isSmoothlyScalable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // isSmoothlyScalable(QString,QString)const
            bool cppResult = cppSelf->QFontDatabase::isSmoothlyScalable(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_isSmoothlyScalable_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isSmoothlyScalable", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_italic(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "italic", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: italic(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // italic(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_italic_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // italic(QString,QString)const
            bool cppResult = cppSelf->QFontDatabase::italic(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_italic_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.italic", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_pointSizes(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "style" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.pointSizes(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.pointSizes(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.pointSizes(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:pointSizes", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: pointSizes(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // pointSizes(QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // pointSizes(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_pointSizes_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.pointSizes(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // pointSizes(QString,QString)
            QList<int > cppResult = cppSelf->QFontDatabase::pointSizes(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_pointSizes_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.pointSizes", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_removeAllApplicationFonts(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // removeAllApplicationFonts()
            bool cppResult = QFontDatabase::removeAllApplicationFonts();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontDatabaseFunc_removeApplicationFont(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeApplicationFont(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removeApplicationFont(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_removeApplicationFont_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeApplicationFont(int)
            bool cppResult = QFontDatabase::removeApplicationFont(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_removeApplicationFont_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.removeApplicationFont", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_smoothSizes(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "smoothSizes", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: smoothSizes(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // smoothSizes(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_smoothSizes_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // smoothSizes(QString,QString)
            QList<int > cppResult = cppSelf->QFontDatabase::smoothSizes(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_smoothSizes_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.smoothSizes", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_standardSizes(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // standardSizes()
            QList<int > cppResult = QFontDatabase::standardSizes();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontDatabaseFunc_styleString(PyObject* self, PyObject* arg)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: styleString(QFont)
    // 1: styleString(QFontInfo)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // styleString(QFont)
    } else if (Shiboken::Converter<const QFontInfo & >::isConvertible(arg)) {
        overloadId = 1; // styleString(QFontInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_styleString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // styleString(QFont)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QFont > cpp_arg0_auto_ptr;
                QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
                if (!Shiboken::Converter<QFont >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // styleString(QFont)
                QString cppResult = cppSelf->QFontDatabase::styleString(*cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // styleString(QFontInfo)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QFontInfo > cpp_arg0_auto_ptr;
                QFontInfo* cpp_arg0 = Shiboken::Converter<QFontInfo* >::toCpp(arg);
                if (!Shiboken::Converter<QFontInfo >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFontInfo >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // styleString(QFontInfo)
                QString cppResult = cppSelf->QFontDatabase::styleString(*cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_styleString_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", "PySide.QtGui.QFontInfo", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.styleString", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_styles(PyObject* self, PyObject* arg)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: styles(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // styles(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_styles_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // styles(QString)const
            QStringList cppResult = cppSelf->QFontDatabase::styles(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_styles_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.styles", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_supportsThreadedFontRendering(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportsThreadedFontRendering()
            bool cppResult = QFontDatabase::supportsThreadedFontRendering();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontDatabaseFunc_weight(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "weight", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: weight(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // weight(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_weight_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // weight(QString,QString)const
            int cppResult = cppSelf->QFontDatabase::weight(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_weight_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.weight", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_writingSystemName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writingSystemName(QFontDatabase::WritingSystem)
    if (Shiboken::Converter<QFontDatabase::WritingSystem >::isConvertible(arg)) {
        overloadId = 0; // writingSystemName(QFontDatabase::WritingSystem)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_writingSystemName_TypeError;

    // Call function/method
    {
        {
            QFontDatabase::WritingSystem cpp_arg0 = Shiboken::Converter<QFontDatabase::WritingSystem >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writingSystemName(QFontDatabase::WritingSystem)
            QString cppResult = QFontDatabase::writingSystemName(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_writingSystemName_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFontDatabase.WritingSystem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.writingSystemName", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_writingSystemSample(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writingSystemSample(QFontDatabase::WritingSystem)
    if (Shiboken::Converter<QFontDatabase::WritingSystem >::isConvertible(arg)) {
        overloadId = 0; // writingSystemSample(QFontDatabase::WritingSystem)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_writingSystemSample_TypeError;

    // Call function/method
    {
        {
            QFontDatabase::WritingSystem cpp_arg0 = Shiboken::Converter<QFontDatabase::WritingSystem >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // writingSystemSample(QFontDatabase::WritingSystem)
            QString cppResult = QFontDatabase::writingSystemSample(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_writingSystemSample_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFontDatabase.WritingSystem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.writingSystemSample", overloads);
        return 0;
}

static PyObject* SbkQFontDatabaseFunc_writingSystems(PyObject* self, PyObject* arg)
{
    QFontDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: writingSystems()const
    // 1: writingSystems(QString)const
    if (numArgs == 0) {
        overloadId = 0; // writingSystems()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // writingSystems(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontDatabaseFunc_writingSystems_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // writingSystems()const
            {

                if(!PyErr_Occurred()) {
                // writingSystems()const
                QList<QFontDatabase::WritingSystem > cppResult = cppSelf->QFontDatabase::writingSystems();
                pyResult = Shiboken::Converter<QList<QFontDatabase::WritingSystem > >::toPython(cppResult);
                }
                break;
            }
            case 1: // writingSystems(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // writingSystems(QString)const
                QList<QFontDatabase::WritingSystem > cppResult = cppSelf->QFontDatabase::writingSystems(cpp_arg0);
                pyResult = Shiboken::Converter<QList<QFontDatabase::WritingSystem > >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontDatabaseFunc_writingSystems_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.writingSystems", overloads);
        return 0;
}

static PyMethodDef SbkQFontDatabase_methods[] = {
    {"addApplicationFont", (PyCFunction)SbkQFontDatabaseFunc_addApplicationFont, METH_O|METH_STATIC},
    {"addApplicationFontFromData", (PyCFunction)SbkQFontDatabaseFunc_addApplicationFontFromData, METH_O|METH_STATIC},
    {"applicationFontFamilies", (PyCFunction)SbkQFontDatabaseFunc_applicationFontFamilies, METH_O|METH_STATIC},
    {"bold", (PyCFunction)SbkQFontDatabaseFunc_bold, METH_VARARGS},
    {"families", (PyCFunction)SbkQFontDatabaseFunc_families, METH_VARARGS|METH_KEYWORDS},
    {"font", (PyCFunction)SbkQFontDatabaseFunc_font, METH_VARARGS},
    {"isBitmapScalable", (PyCFunction)SbkQFontDatabaseFunc_isBitmapScalable, METH_VARARGS|METH_KEYWORDS},
    {"isFixedPitch", (PyCFunction)SbkQFontDatabaseFunc_isFixedPitch, METH_VARARGS|METH_KEYWORDS},
    {"isScalable", (PyCFunction)SbkQFontDatabaseFunc_isScalable, METH_VARARGS|METH_KEYWORDS},
    {"isSmoothlyScalable", (PyCFunction)SbkQFontDatabaseFunc_isSmoothlyScalable, METH_VARARGS|METH_KEYWORDS},
    {"italic", (PyCFunction)SbkQFontDatabaseFunc_italic, METH_VARARGS},
    {"pointSizes", (PyCFunction)SbkQFontDatabaseFunc_pointSizes, METH_VARARGS|METH_KEYWORDS},
    {"removeAllApplicationFonts", (PyCFunction)SbkQFontDatabaseFunc_removeAllApplicationFonts, METH_NOARGS|METH_STATIC},
    {"removeApplicationFont", (PyCFunction)SbkQFontDatabaseFunc_removeApplicationFont, METH_O|METH_STATIC},
    {"smoothSizes", (PyCFunction)SbkQFontDatabaseFunc_smoothSizes, METH_VARARGS},
    {"standardSizes", (PyCFunction)SbkQFontDatabaseFunc_standardSizes, METH_NOARGS|METH_STATIC},
    {"styleString", (PyCFunction)SbkQFontDatabaseFunc_styleString, METH_O},
    {"styles", (PyCFunction)SbkQFontDatabaseFunc_styles, METH_O},
    {"supportsThreadedFontRendering", (PyCFunction)SbkQFontDatabaseFunc_supportsThreadedFontRendering, METH_NOARGS|METH_STATIC},
    {"weight", (PyCFunction)SbkQFontDatabaseFunc_weight, METH_VARARGS},
    {"writingSystemName", (PyCFunction)SbkQFontDatabaseFunc_writingSystemName, METH_O|METH_STATIC},
    {"writingSystemSample", (PyCFunction)SbkQFontDatabaseFunc_writingSystemSample, METH_O|METH_STATIC},
    {"writingSystems", (PyCFunction)SbkQFontDatabaseFunc_writingSystems, METH_NOARGS|METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFontDatabase_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFontDatabase",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFontDatabase_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFontDatabase_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFontDatabase >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFontDatabase",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QFontDatabase_WritingSystem_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFontDatabase_WritingSystem_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFontDatabase_WritingSystem_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WritingSystem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFontDatabase_WritingSystem_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFontDatabase_WritingSystem_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFontDatabase_WritingSystem_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QFontDatabase(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFONTDATABASE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFontDatabase_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFontDatabase_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFontDatabase_Type));
    PyModule_AddObject(module, "QFontDatabase",
        ((PyObject*)&SbkQFontDatabase_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: WritingSystem
    SbkPySide_QtGuiTypes[SBK_QFONTDATABASE_WRITINGSYSTEM_IDX] = &SbkPySide_QtGui_QFontDatabase_WritingSystem_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type);
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
            "WritingSystem",((PyObject*)&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Any, "Any");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Any", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Any", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Latin, "Latin");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Latin", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Latin", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Greek, "Greek");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Greek", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Greek", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Cyrillic, "Cyrillic");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Cyrillic", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Cyrillic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Armenian, "Armenian");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Armenian", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Armenian", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Hebrew, "Hebrew");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Hebrew", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Hebrew", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Arabic, "Arabic");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Arabic", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Arabic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Syriac, "Syriac");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Syriac", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Syriac", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Thaana, "Thaana");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Thaana", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Thaana", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Devanagari, "Devanagari");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Devanagari", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Devanagari", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Bengali, "Bengali");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Bengali", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Bengali", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Gurmukhi, "Gurmukhi");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Gurmukhi", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Gurmukhi", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Gujarati, "Gujarati");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Gujarati", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Gujarati", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Oriya, "Oriya");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Oriya", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Oriya", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Tamil, "Tamil");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Tamil", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Tamil", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Telugu, "Telugu");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Telugu", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Telugu", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Kannada, "Kannada");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Kannada", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Kannada", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Malayalam, "Malayalam");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Malayalam", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Malayalam", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Sinhala, "Sinhala");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Sinhala", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Sinhala", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Thai, "Thai");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Thai", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Thai", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Lao, "Lao");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Lao", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Lao", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Tibetan, "Tibetan");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Tibetan", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Tibetan", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Myanmar, "Myanmar");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Myanmar", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Myanmar", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Georgian, "Georgian");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Georgian", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Georgian", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Khmer, "Khmer");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Khmer", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Khmer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::SimplifiedChinese, "SimplifiedChinese");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "SimplifiedChinese", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "SimplifiedChinese", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::TraditionalChinese, "TraditionalChinese");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "TraditionalChinese", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "TraditionalChinese", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Japanese, "Japanese");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Japanese", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Japanese", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Korean, "Korean");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Korean", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Korean", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Vietnamese, "Vietnamese");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Vietnamese", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Vietnamese", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Symbol, "Symbol");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Symbol", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Symbol", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Other, "Other");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Other", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Other", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Ogham, "Ogham");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Ogham", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Ogham", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Runic, "Runic");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Runic", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Runic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::Nko, "Nko");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "Nko", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "Nko", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFontDatabase_WritingSystem_Type,
        (long) QFontDatabase::WritingSystemsCount, "WritingSystemsCount");
    PyDict_SetItemString(SbkQFontDatabase_Type.super.ht_type.tp_dict,
        "WritingSystemsCount", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem_Type.tp_dict,
        "WritingSystemsCount", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFontDatabase::WritingSystem");


    Shiboken::TypeResolver::createValueTypeResolver<QFontDatabase >("QFontDatabase");
    Shiboken::TypeResolver::createObjectTypeResolver<QFontDatabase >("QFontDatabase*");
    Shiboken::TypeResolver::createValueTypeResolver<QFontDatabase >(typeid(QFontDatabase).name());
    PySide::initQtMetaType<QFontDatabase >();
}

