/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfontinfo_wrapper.h"

// Extra includes
#include <qfont.h>
#include <qfontinfo.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFontInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFontInfo >()))
        return -1;

    QFontInfo* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFontInfo", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QFontInfo(QFont)
    // 1: QFontInfo(QFontInfo)
    if (numArgs == 1 && Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // QFontInfo(QFont)
    } else if (numArgs == 1 && Shiboken::Converter<const QFontInfo & >::isConvertible(arg)) {
        overloadId = 1; // QFontInfo(QFontInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontInfo_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFontInfo(QFont)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QFont > cpp_arg0_auto_ptr;
                QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
                if (!Shiboken::Converter<QFont >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFontInfo(QFont)
                cptr = new QFontInfo(*cpp_arg0);
                }
                break;
            }
            case 1: // QFontInfo(QFontInfo)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QFontInfo > cpp_arg0_auto_ptr;
                QFontInfo* cpp_arg0 = Shiboken::Converter<QFontInfo* >::toCpp(arg);
                if (!Shiboken::Converter<QFontInfo >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFontInfo >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFontInfo(QFontInfo)
                cptr = new QFontInfo(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFontInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFontInfo_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQFontInfo_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", "PySide.QtGui.QFontInfo", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontInfo", overloads);
        return -1;
}

static PyObject* SbkQFontInfoFunc_bold(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bold()const
            bool cppResult = cppSelf->QFontInfo::bold();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_exactMatch(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // exactMatch()const
            bool cppResult = cppSelf->QFontInfo::exactMatch();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_family(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // family()const
            QString cppResult = cppSelf->QFontInfo::family();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_fixedPitch(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fixedPitch()const
            bool cppResult = cppSelf->QFontInfo::fixedPitch();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_italic(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // italic()const
            bool cppResult = cppSelf->QFontInfo::italic();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_overline(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // overline()const
            bool cppResult = cppSelf->QFontInfo::overline();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_pixelSize(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pixelSize()const
            int cppResult = cppSelf->QFontInfo::pixelSize();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_pointSize(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pointSize()const
            int cppResult = cppSelf->QFontInfo::pointSize();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_pointSizeF(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pointSizeF()const
            qreal cppResult = cppSelf->QFontInfo::pointSizeF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_rawMode(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rawMode()const
            bool cppResult = cppSelf->QFontInfo::rawMode();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_strikeOut(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // strikeOut()const
            bool cppResult = cppSelf->QFontInfo::strikeOut();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_style(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()const
            QFont::Style cppResult = cppSelf->QFontInfo::style();
            pyResult = Shiboken::Converter<QFont::Style >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_styleHint(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // styleHint()const
            QFont::StyleHint cppResult = cppSelf->QFontInfo::styleHint();
            pyResult = Shiboken::Converter<QFont::StyleHint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_underline(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // underline()const
            bool cppResult = cppSelf->QFontInfo::underline();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontInfoFunc_weight(PyObject* self)
{
    QFontInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // weight()const
            int cppResult = cppSelf->QFontInfo::weight();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFontInfo_methods[] = {
    {"bold", (PyCFunction)SbkQFontInfoFunc_bold, METH_NOARGS},
    {"exactMatch", (PyCFunction)SbkQFontInfoFunc_exactMatch, METH_NOARGS},
    {"family", (PyCFunction)SbkQFontInfoFunc_family, METH_NOARGS},
    {"fixedPitch", (PyCFunction)SbkQFontInfoFunc_fixedPitch, METH_NOARGS},
    {"italic", (PyCFunction)SbkQFontInfoFunc_italic, METH_NOARGS},
    {"overline", (PyCFunction)SbkQFontInfoFunc_overline, METH_NOARGS},
    {"pixelSize", (PyCFunction)SbkQFontInfoFunc_pixelSize, METH_NOARGS},
    {"pointSize", (PyCFunction)SbkQFontInfoFunc_pointSize, METH_NOARGS},
    {"pointSizeF", (PyCFunction)SbkQFontInfoFunc_pointSizeF, METH_NOARGS},
    {"rawMode", (PyCFunction)SbkQFontInfoFunc_rawMode, METH_NOARGS},
    {"strikeOut", (PyCFunction)SbkQFontInfoFunc_strikeOut, METH_NOARGS},
    {"style", (PyCFunction)SbkQFontInfoFunc_style, METH_NOARGS},
    {"styleHint", (PyCFunction)SbkQFontInfoFunc_styleHint, METH_NOARGS},
    {"underline", (PyCFunction)SbkQFontInfoFunc_underline, METH_NOARGS},
    {"weight", (PyCFunction)SbkQFontInfoFunc_weight, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFontInfo_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFontInfo",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFontInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFontInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFontInfo >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFontInfo",
    /*user_data*/           0
};
} //extern


void init_QFontInfo(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFONTINFO_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFontInfo_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFontInfo_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFontInfo_Type));
    PyModule_AddObject(module, "QFontInfo",
        ((PyObject*)&SbkQFontInfo_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QFontInfo >("QFontInfo");
    Shiboken::TypeResolver::createObjectTypeResolver<QFontInfo >("QFontInfo*");
    Shiboken::TypeResolver::createValueTypeResolver<QFontInfo >(typeid(QFontInfo).name());
    PySide::initQtMetaType<QFontInfo >();
}

