/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfontmetrics_wrapper.h"

// Extra includes
#include <qfont.h>
#include <qfontmetrics.h>
#include <qpaintdevice.h>
#include <qrect.h>
#include <qsize.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFontMetrics_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFontMetrics >()))
        return -1;

    QFontMetrics* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFontMetrics", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QFontMetrics(QFont)
    // 1: QFontMetrics(QFont,QPaintDevice*)
    // 2: QFontMetrics(QFontMetrics)
    if (Shiboken::Converter<const QFont & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QFontMetrics(QFont)
        } else if (numArgs == 2 && Shiboken::Converter<QPaintDevice * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QFontMetrics(QFont,QPaintDevice*)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QFontMetrics & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QFontMetrics(QFontMetrics)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetrics_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFontMetrics(QFont)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFont > cpp_arg0_auto_ptr;
                QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFont >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFontMetrics(QFont)
                cptr = new QFontMetrics(*cpp_arg0);
                }
                break;
            }
            case 1: // QFontMetrics(QFont,QPaintDevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFont > cpp_arg0_auto_ptr;
                QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFont >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QPaintDevice* cpp_arg1 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QFontMetrics(QFont,QPaintDevice*)
                cptr = new QFontMetrics(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QFontMetrics(QFontMetrics)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFontMetrics > cpp_arg0_auto_ptr;
                QFontMetrics* cpp_arg0 = Shiboken::Converter<QFontMetrics* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFontMetrics >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFontMetrics >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFontMetrics(QFontMetrics)
                cptr = new QFontMetrics(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFontMetrics >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFontMetrics_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQFontMetrics_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", "PySide.QtGui.QFont, PySide.QtGui.QPaintDevice", "PySide.QtGui.QFontMetrics", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetrics", overloads);
        return -1;
}

static PyObject* SbkQFontMetricsFunc_ascent(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ascent()const
            int cppResult = cppSelf->QFontMetrics::ascent();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_averageCharWidth(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // averageCharWidth()const
            int cppResult = cppSelf->QFontMetrics::averageCharWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_boundingRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "tabarray", "tabstops" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.boundingRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.boundingRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.boundingRect(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto SbkQFontMetricsFunc_boundingRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:boundingRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: boundingRect(QRect,int,QString,int,int*)const
    // 1: boundingRect(QString)const
    // 2: boundingRect(int,int,int,int,int,QString,int,int*)const
    if (numArgs >= 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter<QString >::isConvertible(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 2; // boundingRect(int,int,int,int,int,QString,int,int*)const
        } else if (SbkNumber_Check(pyargs[6])) {
            if (numArgs == 7) {
                overloadId = 2; // boundingRect(int,int,int,int,int,QString,int,int*)const
            } else if (PyObject_Check(pyargs[7])) {
                overloadId = 2; // boundingRect(int,int,int,int,int,QString,int,int*)const
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // boundingRect(QString)const
    } else if (numArgs >= 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // boundingRect(QRect,int,QString,int,int*)const
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // boundingRect(QRect,int,QString,int,int*)const
            } else if (PyObject_Check(pyargs[4])) {
                overloadId = 0; // boundingRect(QRect,int,QString,int,int*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_boundingRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // boundingRect(QRect,int,QString,int,int*)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "tabstops");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "tabstops";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "tabarray");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "tabarray";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.boundingRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // boundingRect(QRect,int,QString,int,int*)const
                // Begin code injection
                
                int* array = NULL;
                bool errorOccurred = false;
                
                if (numArgs == 5) {
                    array = Shiboken::sequenceToIntArray(pyargs[5-1], true);
                    if (PyErr_Occurred()) {
                        if (array)
                            delete []array;
                        errorOccurred = true;
                    }
                }
                
                if (!errorOccurred) {
                    QRect retval = cppSelf->boundingRect((*cpp_arg0), cpp_arg1, cpp_arg2, cpp_arg3, array);
                
                    if (array)
                        delete []array;
                
                    pyResult = Shiboken::Converter<QRect >::toPython(retval);
                }
                
                // End of code injection


                }
                break;
            }
            case 1: // boundingRect(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // boundingRect(QString)const
                QRect cppResult = cppSelf->QFontMetrics::boundingRect(cpp_arg0);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
            case 2: // boundingRect(int,int,int,int,int,QString,int,int*)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "tabstops");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "tabstops";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "tabarray");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "tabarray";
                        else
                            pyargs[7] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.boundingRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QString cpp_arg5 = Shiboken::Converter<QString >::toCpp(pyargs[5]);
                int cpp_arg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : 0;

                if(!PyErr_Occurred()) {
                // boundingRect(int,int,int,int,int,QString,int,int*)const
                // Begin code injection
                
                int* array = NULL;
                bool errorOccurred = false;
                
                if (numArgs == 8) {
                    array = Shiboken::sequenceToIntArray(pyargs[8-1], true);
                    if (PyErr_Occurred()) {
                        if (array)
                            delete []array;
                        errorOccurred = true;
                    }
                }
                
                if (!errorOccurred) {
                    QRect retval = cppSelf->boundingRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6, array);
                
                    if (array)
                        delete []array;
                
                    pyResult = Shiboken::Converter<QRect >::toPython(retval);
                }
                
                // End of code injection


                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_boundingRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, QString, int = 0, int = 0", "QString", "int, int, int, int, int, QString, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetrics.boundingRect", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_boundingRectChar(PyObject* self, PyObject* arg)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundingRect(QChar)const
    if (PyString_Check(arg)) {
        overloadId = 0; // boundingRect(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_boundingRectChar_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect(QChar)const
            // Begin code injection
            
            // TEMPLATE - QFontCharFix - START
            int size = PyString_GET_SIZE(arg);
            if (size == 1) {
            char *str = PyString_AS_STRING(arg);
            QChar ch(str[0]);
            pyResult = Shiboken::Converter<QRect >::toPython(cppSelf->boundingRect(ch));
            } else {
            PyErr_SetString(PyExc_TypeError, "String must have only one character");
            }
            // TEMPLATE - QFontCharFix - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_boundingRectChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetrics.boundingRectChar", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_charWidth(PyObject* self, PyObject* args)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "charWidth", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: charWidth(QString,int)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // charWidth(QString,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_charWidth_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // charWidth(QString,int)const
            int cppResult = cppSelf->QFontMetrics::charWidth(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_charWidth_TypeError:
        const char* overloads[] = {"QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetrics.charWidth", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_descent(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // descent()const
            int cppResult = cppSelf->QFontMetrics::descent();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_elidedText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.elidedText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.elidedText(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.elidedText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:elidedText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: elidedText(QString,Qt::TextElideMode,int,int)const
    if (numArgs >= 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::TextElideMode >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // elidedText(QString,Qt::TextElideMode,int,int)const
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // elidedText(QString,Qt::TextElideMode,int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_elidedText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "flags";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.elidedText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            Qt::TextElideMode cpp_arg1 = Shiboken::Converter<Qt::TextElideMode >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
            // elidedText(QString,Qt::TextElideMode,int,int)const
            QString cppResult = cppSelf->QFontMetrics::elidedText(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_elidedText_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.TextElideMode, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetrics.elidedText", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_height(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            int cppResult = cppSelf->QFontMetrics::height();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_inFont(PyObject* self, PyObject* arg)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inFont(QChar)const
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // inFont(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_inFont_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inFont(QChar)const
            bool cppResult = cppSelf->QFontMetrics::inFont(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_inFont_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetrics.inFont", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_leading(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // leading()const
            int cppResult = cppSelf->QFontMetrics::leading();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_leftBearing(PyObject* self, PyObject* arg)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: leftBearing(QChar)const
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // leftBearing(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_leftBearing_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // leftBearing(QChar)const
            int cppResult = cppSelf->QFontMetrics::leftBearing(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_leftBearing_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetrics.leftBearing", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_lineSpacing(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineSpacing()const
            int cppResult = cppSelf->QFontMetrics::lineSpacing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_lineWidth(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineWidth()const
            int cppResult = cppSelf->QFontMetrics::lineWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_maxWidth(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maxWidth()const
            int cppResult = cppSelf->QFontMetrics::maxWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_minLeftBearing(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minLeftBearing()const
            int cppResult = cppSelf->QFontMetrics::minLeftBearing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_minRightBearing(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minRightBearing()const
            int cppResult = cppSelf->QFontMetrics::minRightBearing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_overlinePos(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // overlinePos()const
            int cppResult = cppSelf->QFontMetrics::overlinePos();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_rightBearing(PyObject* self, PyObject* arg)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rightBearing(QChar)const
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // rightBearing(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_rightBearing_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rightBearing(QChar)const
            int cppResult = cppSelf->QFontMetrics::rightBearing(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_rightBearing_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetrics.rightBearing", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_size(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "tabarray", "tabstops" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.size(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.size(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.size(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:size", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: size(int,QString,int,int*)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // size(int,QString,int,int*)const
        } else if (SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // size(int,QString,int,int*)const
            } else if (PyObject_Check(pyargs[3])) {
                overloadId = 0; // size(int,QString,int,int*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_size_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tabstops");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "tabstops";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "tabarray");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "tabarray";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.size(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
            // size(int,QString,int,int*)const
            // Begin code injection
            
            int* array = NULL;
            bool errorOccurred = false;
            
            if (numArgs == 4) {
                array = Shiboken::sequenceToIntArray(pyargs[4-1], true);
                if (PyErr_Occurred()) {
                    if (array)
                        delete []array;
                    errorOccurred = true;
                }
            }
            
            if (!errorOccurred) {
                QSize retval = cppSelf->size(cpp_arg0, cpp_arg1, cpp_arg2, array);
            
                if (array)
                    delete []array;
            
                pyResult = Shiboken::Converter<QSize >::toPython(retval);
            }
            
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_size_TypeError:
        const char* overloads[] = {"int, QString, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetrics.size", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_strikeOutPos(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // strikeOutPos()const
            int cppResult = cppSelf->QFontMetrics::strikeOutPos();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_tightBoundingRect(PyObject* self, PyObject* arg)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tightBoundingRect(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // tightBoundingRect(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_tightBoundingRect_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // tightBoundingRect(QString)const
            QRect cppResult = cppSelf->QFontMetrics::tightBoundingRect(cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_tightBoundingRect_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetrics.tightBoundingRect", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_underlinePos(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // underlinePos()const
            int cppResult = cppSelf->QFontMetrics::underlinePos();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFunc_width(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "len" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.width(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.width(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetrics.width(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:width", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: width(QString,int)const
    // 1: width(QString,int,int)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // width(QString,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // width(QString,int)const
            } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // width(QString,int,int)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_width_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // width(QString,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "len");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "len";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetrics.width(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

                if(!PyErr_Occurred()) {
                // width(QString,int)const
                int cppResult = cppSelf->QFontMetrics::width(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // width(QString,int,int)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // width(QString,int,int)const
                int cppResult = cppSelf->QFontMetrics::width(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_width_TypeError:
        const char* overloads[] = {"QString, int = -1", "QString, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetrics.width", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_widthChar(PyObject* self, PyObject* arg)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: width(QChar)const
    if (PyString_Check(arg)) {
        overloadId = 0; // width(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFunc_widthChar_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width(QChar)const
            // Begin code injection
            
            // TEMPLATE - QFontCharFix - START
            int size = PyString_GET_SIZE(arg);
            if (size == 1) {
            char *str = PyString_AS_STRING(arg);
            QChar ch(str[0]);
            pyResult = Shiboken::Converter<int >::toPython(cppSelf->width(ch));
            } else {
            PyErr_SetString(PyExc_TypeError, "String must have only one character");
            }
            // TEMPLATE - QFontCharFix - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFunc_widthChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetrics.widthChar", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFunc_xHeight(PyObject* self)
{
    QFontMetrics* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetrics* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // xHeight()const
            int cppResult = cppSelf->QFontMetrics::xHeight();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFontMetrics_methods[] = {
    {"ascent", (PyCFunction)SbkQFontMetricsFunc_ascent, METH_NOARGS},
    {"averageCharWidth", (PyCFunction)SbkQFontMetricsFunc_averageCharWidth, METH_NOARGS},
    {"boundingRect", (PyCFunction)SbkQFontMetricsFunc_boundingRect, METH_VARARGS|METH_KEYWORDS},
    {"boundingRectChar", (PyCFunction)SbkQFontMetricsFunc_boundingRectChar, METH_O},
    {"charWidth", (PyCFunction)SbkQFontMetricsFunc_charWidth, METH_VARARGS},
    {"descent", (PyCFunction)SbkQFontMetricsFunc_descent, METH_NOARGS},
    {"elidedText", (PyCFunction)SbkQFontMetricsFunc_elidedText, METH_VARARGS|METH_KEYWORDS},
    {"height", (PyCFunction)SbkQFontMetricsFunc_height, METH_NOARGS},
    {"inFont", (PyCFunction)SbkQFontMetricsFunc_inFont, METH_O},
    {"leading", (PyCFunction)SbkQFontMetricsFunc_leading, METH_NOARGS},
    {"leftBearing", (PyCFunction)SbkQFontMetricsFunc_leftBearing, METH_O},
    {"lineSpacing", (PyCFunction)SbkQFontMetricsFunc_lineSpacing, METH_NOARGS},
    {"lineWidth", (PyCFunction)SbkQFontMetricsFunc_lineWidth, METH_NOARGS},
    {"maxWidth", (PyCFunction)SbkQFontMetricsFunc_maxWidth, METH_NOARGS},
    {"minLeftBearing", (PyCFunction)SbkQFontMetricsFunc_minLeftBearing, METH_NOARGS},
    {"minRightBearing", (PyCFunction)SbkQFontMetricsFunc_minRightBearing, METH_NOARGS},
    {"overlinePos", (PyCFunction)SbkQFontMetricsFunc_overlinePos, METH_NOARGS},
    {"rightBearing", (PyCFunction)SbkQFontMetricsFunc_rightBearing, METH_O},
    {"size", (PyCFunction)SbkQFontMetricsFunc_size, METH_VARARGS|METH_KEYWORDS},
    {"strikeOutPos", (PyCFunction)SbkQFontMetricsFunc_strikeOutPos, METH_NOARGS},
    {"tightBoundingRect", (PyCFunction)SbkQFontMetricsFunc_tightBoundingRect, METH_O},
    {"underlinePos", (PyCFunction)SbkQFontMetricsFunc_underlinePos, METH_NOARGS},
    {"width", (PyCFunction)SbkQFontMetricsFunc_width, METH_VARARGS|METH_KEYWORDS},
    {"widthChar", (PyCFunction)SbkQFontMetricsFunc_widthChar, METH_O},
    {"xHeight", (PyCFunction)SbkQFontMetricsFunc_xHeight, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQFontMetrics_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QFontMetrics& cpp_self = *Shiboken::Converter<QFontMetrics* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QFontMetrics & >::isConvertible(other)) {
                // operator!=(const QFontMetrics & other)
                QFontMetrics* cpp_other = Shiboken::Converter<QFontMetrics* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetrics  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<const QFontMetrics & >::isConvertible(other)) {
                // operator!=(const QFontMetrics & other) const
                QFontMetrics* cpp_other = Shiboken::Converter<QFontMetrics* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetrics  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QFontMetrics >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QFontMetrics > cpp_other_auto_ptr;
                QFontMetrics* cpp_other = Shiboken::Converter<QFontMetrics* >::toCpp(other);
                if (!Shiboken::Converter<QFontMetrics >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QFontMetrics >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQFontMetrics_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QFontMetrics & >::isConvertible(other)) {
                // operator==(const QFontMetrics & other)
                QFontMetrics* cpp_other = Shiboken::Converter<QFontMetrics* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetrics  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<const QFontMetrics & >::isConvertible(other)) {
                // operator==(const QFontMetrics & other) const
                QFontMetrics* cpp_other = Shiboken::Converter<QFontMetrics* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetrics  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QFontMetrics >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QFontMetrics > cpp_other_auto_ptr;
                QFontMetrics* cpp_other = Shiboken::Converter<QFontMetrics* >::toCpp(other);
                if (!Shiboken::Converter<QFontMetrics >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QFontMetrics >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQFontMetrics_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQFontMetrics_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFontMetrics_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFontMetrics",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQFontMetrics_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFontMetrics_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFontMetrics_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFontMetrics >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFontMetrics",
    /*user_data*/           0
};
} //extern


void init_QFontMetrics(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFONTMETRICS_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFontMetrics_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFontMetrics_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFontMetrics_Type));
    PyModule_AddObject(module, "QFontMetrics",
        ((PyObject*)&SbkQFontMetrics_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QFontMetrics >("QFontMetrics");
    Shiboken::TypeResolver::createObjectTypeResolver<QFontMetrics >("QFontMetrics*");
    Shiboken::TypeResolver::createValueTypeResolver<QFontMetrics >(typeid(QFontMetrics).name());
    PySide::initQtMetaType<QFontMetrics >();
}

