/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfontmetricsf_wrapper.h"

// Extra includes
#include <qfont.h>
#include <qfontmetrics.h>
#include <qpaintdevice.h>
#include <qrect.h>
#include <qsize.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFontMetricsF_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFontMetricsF >()))
        return -1;

    QFontMetricsF* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFontMetricsF", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QFontMetricsF(QFont)
    // 1: QFontMetricsF(QFont,QPaintDevice*)
    // 2: QFontMetricsF(QFontMetrics)
    // 3: QFontMetricsF(QFontMetricsF)
    if (Shiboken::Converter<const QFont & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QFontMetricsF(QFont)
        } else if (numArgs == 2 && Shiboken::Converter<QPaintDevice * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QFontMetricsF(QFont,QPaintDevice*)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QFontMetrics & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QFontMetricsF(QFontMetrics)
    } else if (numArgs == 1 && Shiboken::Converter<const QFontMetricsF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QFontMetricsF(QFontMetricsF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsF_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFontMetricsF(QFont)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFont > cpp_arg0_auto_ptr;
                QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFont >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFontMetricsF(QFont)
                cptr = new QFontMetricsF(*cpp_arg0);
                }
                break;
            }
            case 1: // QFontMetricsF(QFont,QPaintDevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFont > cpp_arg0_auto_ptr;
                QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFont >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QPaintDevice* cpp_arg1 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QFontMetricsF(QFont,QPaintDevice*)
                cptr = new QFontMetricsF(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QFontMetricsF(QFontMetrics)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFontMetrics > cpp_arg0_auto_ptr;
                QFontMetrics* cpp_arg0 = Shiboken::Converter<QFontMetrics* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFontMetrics >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFontMetrics >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFontMetricsF(QFontMetrics)
                cptr = new QFontMetricsF(*cpp_arg0);
                }
                break;
            }
            case 3: // QFontMetricsF(QFontMetricsF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QFontMetricsF > cpp_arg0_auto_ptr;
                QFontMetricsF* cpp_arg0 = Shiboken::Converter<QFontMetricsF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QFontMetricsF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QFontMetricsF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QFontMetricsF(QFontMetricsF)
                cptr = new QFontMetricsF(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFontMetricsF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFontMetricsF_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQFontMetricsF_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", "PySide.QtGui.QFont, PySide.QtGui.QPaintDevice", "PySide.QtGui.QFontMetrics", "PySide.QtGui.QFontMetricsF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetricsF", overloads);
        return -1;
}

static PyObject* SbkQFontMetricsFFunc_ascent(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ascent()const
            qreal cppResult = cppSelf->QFontMetricsF::ascent();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_averageCharWidth(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // averageCharWidth()const
            qreal cppResult = cppSelf->QFontMetricsF::averageCharWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_boundingRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "tabarray", "tabstops" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.boundingRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.boundingRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.boundingRect(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto SbkQFontMetricsFFunc_boundingRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:boundingRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: boundingRect(QRectF,int,QString,int,int*)const
    // 1: boundingRect(QString)const
    if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // boundingRect(QString)const
    } else if (numArgs >= 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // boundingRect(QRectF,int,QString,int,int*)const
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // boundingRect(QRectF,int,QString,int,int*)const
            } else if (PyObject_Check(pyargs[4])) {
                overloadId = 0; // boundingRect(QRectF,int,QString,int,int*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_boundingRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // boundingRect(QRectF,int,QString,int,int*)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "tabstops");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "tabstops";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "tabarray");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "tabarray";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.boundingRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // boundingRect(QRectF,int,QString,int,int*)const
                // Begin code injection
                
                int* array = NULL;
                bool errorOccurred = false;
                
                if (numArgs == 5) {
                    array = Shiboken::sequenceToIntArray(pyargs[5-1], true);
                    if (PyErr_Occurred()) {
                        if (array)
                            delete []array;
                        errorOccurred = true;
                    }
                }
                
                if (!errorOccurred) {
                    QRectF retval = cppSelf->boundingRect((*cpp_arg0), cpp_arg1, cpp_arg2, cpp_arg3, array);
                
                    if (array)
                        delete []array;
                
                    pyResult = Shiboken::Converter<QRectF >::toPython(retval);
                }
                
                // End of code injection


                }
                break;
            }
            case 1: // boundingRect(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // boundingRect(QString)const
                QRectF cppResult = cppSelf->QFontMetricsF::boundingRect(cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_boundingRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, int, QString, int = 0, int = 0", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetricsF.boundingRect", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_boundingRectChar(PyObject* self, PyObject* arg)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundingRect(QChar)const
    if (PyString_Check(arg)) {
        overloadId = 0; // boundingRect(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_boundingRectChar_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect(QChar)const
            // Begin code injection
            
            // TEMPLATE - QFontCharFix - START
            int size = PyString_GET_SIZE(arg);
            if (size == 1) {
            char *str = PyString_AS_STRING(arg);
            QChar ch(str[0]);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppSelf->boundingRect(ch));
            } else {
            PyErr_SetString(PyExc_TypeError, "String must have only one character");
            }
            // TEMPLATE - QFontCharFix - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_boundingRectChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetricsF.boundingRectChar", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_descent(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // descent()const
            qreal cppResult = cppSelf->QFontMetricsF::descent();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_elidedText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.elidedText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.elidedText(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.elidedText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:elidedText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: elidedText(QString,Qt::TextElideMode,qreal,int)const
    if (numArgs >= 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::TextElideMode >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // elidedText(QString,Qt::TextElideMode,qreal,int)const
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // elidedText(QString,Qt::TextElideMode,qreal,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_elidedText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "flags";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.elidedText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            Qt::TextElideMode cpp_arg1 = Shiboken::Converter<Qt::TextElideMode >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
            // elidedText(QString,Qt::TextElideMode,qreal,int)const
            QString cppResult = cppSelf->QFontMetricsF::elidedText(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_elidedText_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.TextElideMode, float, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetricsF.elidedText", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_height(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            qreal cppResult = cppSelf->QFontMetricsF::height();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_inFont(PyObject* self, PyObject* arg)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inFont(QChar)const
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // inFont(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_inFont_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inFont(QChar)const
            bool cppResult = cppSelf->QFontMetricsF::inFont(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_inFont_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetricsF.inFont", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_leading(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // leading()const
            qreal cppResult = cppSelf->QFontMetricsF::leading();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_leftBearing(PyObject* self, PyObject* arg)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: leftBearing(QChar)const
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // leftBearing(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_leftBearing_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // leftBearing(QChar)const
            qreal cppResult = cppSelf->QFontMetricsF::leftBearing(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_leftBearing_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetricsF.leftBearing", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_lineSpacing(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineSpacing()const
            qreal cppResult = cppSelf->QFontMetricsF::lineSpacing();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_lineWidth(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineWidth()const
            qreal cppResult = cppSelf->QFontMetricsF::lineWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_maxWidth(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maxWidth()const
            qreal cppResult = cppSelf->QFontMetricsF::maxWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_minLeftBearing(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minLeftBearing()const
            qreal cppResult = cppSelf->QFontMetricsF::minLeftBearing();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_minRightBearing(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minRightBearing()const
            qreal cppResult = cppSelf->QFontMetricsF::minRightBearing();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_overlinePos(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // overlinePos()const
            qreal cppResult = cppSelf->QFontMetricsF::overlinePos();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_rightBearing(PyObject* self, PyObject* arg)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rightBearing(QChar)const
    if (Shiboken::Converter<QChar >::isConvertible(arg)) {
        overloadId = 0; // rightBearing(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_rightBearing_TypeError;

    // Call function/method
    {
        {
            QChar cpp_arg0 = Shiboken::Converter<QChar >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rightBearing(QChar)const
            qreal cppResult = cppSelf->QFontMetricsF::rightBearing(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_rightBearing_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetricsF.rightBearing", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_size(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "tabarray", "tabstops" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.size(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.size(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.size(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:size", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: size(int,QString,int,int*)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // size(int,QString,int,int*)const
        } else if (SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // size(int,QString,int,int*)const
            } else if (PyObject_Check(pyargs[3])) {
                overloadId = 0; // size(int,QString,int,int*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_size_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tabstops");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "tabstops";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "tabarray");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "tabarray";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontMetricsF.size(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
            // size(int,QString,int,int*)const
            // Begin code injection
            
            int* array = NULL;
            bool errorOccurred = false;
            
            if (numArgs == 4) {
                array = Shiboken::sequenceToIntArray(pyargs[4-1], true);
                if (PyErr_Occurred()) {
                    if (array)
                        delete []array;
                    errorOccurred = true;
                }
            }
            
            if (!errorOccurred) {
                QSizeF retval = cppSelf->size(cpp_arg0, cpp_arg1, cpp_arg2, array);
            
                if (array)
                    delete []array;
            
                pyResult = Shiboken::Converter<QSizeF >::toPython(retval);
            }
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_size_TypeError:
        const char* overloads[] = {"int, QString, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontMetricsF.size", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_strikeOutPos(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // strikeOutPos()const
            qreal cppResult = cppSelf->QFontMetricsF::strikeOutPos();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_tightBoundingRect(PyObject* self, PyObject* arg)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tightBoundingRect(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // tightBoundingRect(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_tightBoundingRect_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // tightBoundingRect(QString)const
            QRectF cppResult = cppSelf->QFontMetricsF::tightBoundingRect(cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_tightBoundingRect_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetricsF.tightBoundingRect", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_underlinePos(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // underlinePos()const
            qreal cppResult = cppSelf->QFontMetricsF::underlinePos();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFontMetricsFFunc_width(PyObject* self, PyObject* arg)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: width(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // width(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_width_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // width(QString)const
            qreal cppResult = cppSelf->QFontMetricsF::width(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_width_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetricsF.width", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_widthChar(PyObject* self, PyObject* arg)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: width(QChar)const
    if (PyString_Check(arg)) {
        overloadId = 0; // width(QChar)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFontMetricsFFunc_widthChar_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width(QChar)const
            // Begin code injection
            
            // TEMPLATE - QFontCharFix - START
            int size = PyString_GET_SIZE(arg);
            if (size == 1) {
            char *str = PyString_AS_STRING(arg);
            QChar ch(str[0]);
            pyResult = Shiboken::Converter<qreal >::toPython(cppSelf->width(ch));
            } else {
            PyErr_SetString(PyExc_TypeError, "String must have only one character");
            }
            // TEMPLATE - QFontCharFix - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFontMetricsFFunc_widthChar_TypeError:
        const char* overloads[] = {"QChar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontMetricsF.widthChar", overloads);
        return 0;
}

static PyObject* SbkQFontMetricsFFunc_xHeight(PyObject* self)
{
    QFontMetricsF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // xHeight()const
            qreal cppResult = cppSelf->QFontMetricsF::xHeight();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFontMetricsF_methods[] = {
    {"ascent", (PyCFunction)SbkQFontMetricsFFunc_ascent, METH_NOARGS},
    {"averageCharWidth", (PyCFunction)SbkQFontMetricsFFunc_averageCharWidth, METH_NOARGS},
    {"boundingRect", (PyCFunction)SbkQFontMetricsFFunc_boundingRect, METH_VARARGS|METH_KEYWORDS},
    {"boundingRectChar", (PyCFunction)SbkQFontMetricsFFunc_boundingRectChar, METH_O},
    {"descent", (PyCFunction)SbkQFontMetricsFFunc_descent, METH_NOARGS},
    {"elidedText", (PyCFunction)SbkQFontMetricsFFunc_elidedText, METH_VARARGS|METH_KEYWORDS},
    {"height", (PyCFunction)SbkQFontMetricsFFunc_height, METH_NOARGS},
    {"inFont", (PyCFunction)SbkQFontMetricsFFunc_inFont, METH_O},
    {"leading", (PyCFunction)SbkQFontMetricsFFunc_leading, METH_NOARGS},
    {"leftBearing", (PyCFunction)SbkQFontMetricsFFunc_leftBearing, METH_O},
    {"lineSpacing", (PyCFunction)SbkQFontMetricsFFunc_lineSpacing, METH_NOARGS},
    {"lineWidth", (PyCFunction)SbkQFontMetricsFFunc_lineWidth, METH_NOARGS},
    {"maxWidth", (PyCFunction)SbkQFontMetricsFFunc_maxWidth, METH_NOARGS},
    {"minLeftBearing", (PyCFunction)SbkQFontMetricsFFunc_minLeftBearing, METH_NOARGS},
    {"minRightBearing", (PyCFunction)SbkQFontMetricsFFunc_minRightBearing, METH_NOARGS},
    {"overlinePos", (PyCFunction)SbkQFontMetricsFFunc_overlinePos, METH_NOARGS},
    {"rightBearing", (PyCFunction)SbkQFontMetricsFFunc_rightBearing, METH_O},
    {"size", (PyCFunction)SbkQFontMetricsFFunc_size, METH_VARARGS|METH_KEYWORDS},
    {"strikeOutPos", (PyCFunction)SbkQFontMetricsFFunc_strikeOutPos, METH_NOARGS},
    {"tightBoundingRect", (PyCFunction)SbkQFontMetricsFFunc_tightBoundingRect, METH_O},
    {"underlinePos", (PyCFunction)SbkQFontMetricsFFunc_underlinePos, METH_NOARGS},
    {"width", (PyCFunction)SbkQFontMetricsFFunc_width, METH_O},
    {"widthChar", (PyCFunction)SbkQFontMetricsFFunc_widthChar, METH_O},
    {"xHeight", (PyCFunction)SbkQFontMetricsFFunc_xHeight, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQFontMetricsF_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QFontMetricsF& cpp_self = *Shiboken::Converter<QFontMetricsF* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QFontMetricsF & >::isConvertible(other)) {
                // operator!=(const QFontMetricsF & other)
                QFontMetricsF* cpp_other = Shiboken::Converter<QFontMetricsF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetricsF  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<const QFontMetricsF & >::isConvertible(other)) {
                // operator!=(const QFontMetricsF & other) const
                QFontMetricsF* cpp_other = Shiboken::Converter<QFontMetricsF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetricsF  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QFontMetricsF >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QFontMetricsF > cpp_other_auto_ptr;
                QFontMetricsF* cpp_other = Shiboken::Converter<QFontMetricsF* >::toCpp(other);
                if (!Shiboken::Converter<QFontMetricsF >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QFontMetricsF >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQFontMetricsF_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QFontMetricsF & >::isConvertible(other)) {
                // operator==(const QFontMetricsF & other)
                QFontMetricsF* cpp_other = Shiboken::Converter<QFontMetricsF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetricsF  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<const QFontMetricsF & >::isConvertible(other)) {
                // operator==(const QFontMetricsF & other) const
                QFontMetricsF* cpp_other = Shiboken::Converter<QFontMetricsF* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QFontMetricsF  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QFontMetricsF >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QFontMetricsF > cpp_other_auto_ptr;
                QFontMetricsF* cpp_other = Shiboken::Converter<QFontMetricsF* >::toCpp(other);
                if (!Shiboken::Converter<QFontMetricsF >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QFontMetricsF >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQFontMetricsF_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQFontMetricsF_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFontMetricsF_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFontMetricsF",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQFontMetricsF_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFontMetricsF_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFontMetricsF_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFontMetricsF >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFontMetricsF",
    /*user_data*/           0
};
} //extern


void init_QFontMetricsF(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFONTMETRICSF_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFontMetricsF_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFontMetricsF_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFontMetricsF_Type));
    PyModule_AddObject(module, "QFontMetricsF",
        ((PyObject*)&SbkQFontMetricsF_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QFontMetricsF >("QFontMetricsF");
    Shiboken::TypeResolver::createObjectTypeResolver<QFontMetricsF >("QFontMetricsF*");
    Shiboken::TypeResolver::createValueTypeResolver<QFontMetricsF >(typeid(QFontMetricsF).name());
    PySide::initQtMetaType<QFontMetricsF >();
}

