/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qformlayout_wrapper.h"

// Extra includes
#include "glue/qlayout_help_functions.h"
#include <qcoreevent.h>
#include <qlayout.h>
#include <qlayoutitem.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qsize.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QFormLayoutWrapper::QFormLayoutWrapper(QWidget * parent) : QFormLayout(parent), m_metaObject(0) {
    // ... middle
}

void QFormLayoutWrapper::addItem(QLayoutItem * item)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "addItem"));
    if (py_override.isNull()) {

        return this->QFormLayout::addItem(item);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QLayoutItem * >::toPython(item)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));

}

void QFormLayoutWrapper::childEvent(QChildEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QLayout::childEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFormLayoutWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QFormLayoutWrapper::count() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "count"));
    if (py_override.isNull()) {
        return this->QFormLayout::count();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.count", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QFormLayoutWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFormLayoutWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QFormLayoutWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QFormLayoutWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QFlags<Qt::Orientation> QFormLayoutWrapper::expandingDirections() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "expandingDirections"));
    if (py_override.isNull()) {
        return this->QFormLayout::expandingDirections();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::Orientation>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QFlags<Qt::Orientation> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.expandingDirections", SbkType<QFlags<Qt::Orientation> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::Orientation>();
    }
    QFlags<Qt::Orientation> cppResult(Shiboken::Converter<QFlags<Qt::Orientation> >::toCpp(pyResult));
    return cppResult;
}

QRect QFormLayoutWrapper::geometry() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "geometry"));
    if (py_override.isNull()) {
        return this->QLayout::geometry();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.geometry", SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter<QRect >::toCpp(pyResult));
    return cppResult;
}

bool QFormLayoutWrapper::hasHeightForWidth() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasHeightForWidth"));
    if (py_override.isNull()) {
        return this->QFormLayout::hasHeightForWidth();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.hasHeightForWidth", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

int QFormLayoutWrapper::heightForWidth(int width) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QFormLayout::heightForWidth(width);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        width
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QFormLayoutWrapper::indexOf(QWidget * arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "indexOf"));
    if (py_override.isNull()) {
        return this->QLayout::indexOf(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWidget * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.indexOf", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QFormLayoutWrapper::invalidate()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "invalidate"));
    if (py_override.isNull()) {
        return this->QFormLayout::invalidate();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QFormLayoutWrapper::isEmpty() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isEmpty"));
    if (py_override.isNull()) {
        return this->QLayout::isEmpty();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.isEmpty", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QLayoutItem * QFormLayoutWrapper::itemAt(int index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "itemAt"));
    if (py_override.isNull()) {

        return this->QFormLayout::itemAt(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.itemAt", SbkType<QLayoutItem * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter<QLayoutItem * >::toCpp(pyResult));

    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QFormLayout.itemAt");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QLayout * QFormLayoutWrapper::layout()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "layout"));
    if (py_override.isNull()) {
        return this->QLayout::layout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QLayout * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.layout", SbkType<QLayout * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayout * cppResult(Shiboken::Converter<QLayout * >::toCpp(pyResult));
    return cppResult;
}

QSize QFormLayoutWrapper::maximumSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "maximumSize"));
    if (py_override.isNull()) {
        return this->QLayout::maximumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.maximumSize", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

int QFormLayoutWrapper::minimumHeightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumHeightForWidth"));
    if (py_override.isNull()) {
        return this->QLayoutItem::minimumHeightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.minimumHeightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QFormLayoutWrapper::minimumSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSize"));
    if (py_override.isNull()) {
        return this->QFormLayout::minimumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.minimumSize", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QFormLayoutWrapper::setGeometry(const QRect & rect)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setGeometry"));
    if (py_override.isNull()) {
        return this->QFormLayout::setGeometry(rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QRect & >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QSize QFormLayoutWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QFormLayout::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

QSpacerItem * QFormLayoutWrapper::spacerItem()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "spacerItem"));
    if (py_override.isNull()) {
        return this->QLayoutItem::spacerItem();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSpacerItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.spacerItem", SbkType<QSpacerItem * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QSpacerItem * cppResult(Shiboken::Converter<QSpacerItem * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QFormLayout.spacerItem");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QLayoutItem * QFormLayoutWrapper::takeAt(int index)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "takeAt"));
    if (py_override.isNull()) {
        return this->QFormLayout::takeAt(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.takeAt", SbkType<QLayoutItem * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter<QLayoutItem * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QFormLayout.takeAt");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QFormLayoutWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QWidget * QFormLayoutWrapper::widget()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "widget"));
    if (py_override.isNull()) {
        return this->QLayoutItem::widget();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QWidget * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFormLayout.widget", SbkType<QWidget * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QWidget * cppResult(Shiboken::Converter<QWidget * >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QFormLayoutWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QFormLayout::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QFormLayoutWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QFormLayout::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QFormLayoutWrapper::~QFormLayoutWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFormLayout_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFormLayout >()))
        return -1;

    QFormLayoutWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QFormLayout", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QFormLayout(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QFormLayout(QWidget*)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // QFormLayout(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayout_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFormLayout(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QWidget* cpp_arg0 = arg ? Shiboken::Converter<QWidget* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QFormLayout(QWidget*)
            cptr = new QFormLayoutWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFormLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFormLayout_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQFormLayout_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout", overloads);
        return -1;
}

static PyObject* SbkQFormLayoutFunc_addItem(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addItem(QLayoutItem*)
    if (Shiboken::Converter<QLayoutItem * >::isConvertible(arg)) {
        overloadId = 0; // addItem(QLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_addItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QLayoutItem* cpp_arg0 = Shiboken::Converter<QLayoutItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addItem(QLayoutItem*)
            // Begin code injection
            
            addLayoutOwnership(cppSelf, cpp_arg0);
            
            // End of code injection

            cppSelf->QFormLayout::addItem(cpp_arg0);

            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_addItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayoutItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.addItem", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_addRow(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addRow", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addRow(QLayout*)
    // 1: addRow(QWidget*,QLayout*)
    // 2: addRow(QWidget*,QWidget*)
    // 3: addRow(QWidget*)
    // 4: addRow(QString,QLayout*)
    // 5: addRow(QString,QWidget*)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 5; // addRow(QString,QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter<QLayout * >::isConvertible(pyargs[1])) {
            overloadId = 4; // addRow(QString,QLayout*)
        }
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // addRow(QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 2; // addRow(QWidget*,QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter<QLayout * >::isConvertible(pyargs[1])) {
            overloadId = 1; // addRow(QWidget*,QLayout*)
        }
    } else if (numArgs == 1 && Shiboken::Converter<QLayout * >::isConvertible(pyargs[0])) {
        overloadId = 0; // addRow(QLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_addRow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRow(QLayout*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QLayout* cpp_arg0 = Shiboken::Converter<QLayout* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addRow(QLayout*)
                cppSelf->QFormLayout::addRow(cpp_arg0);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // addRow(QWidget*,QLayout*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QLayout* cpp_arg1 = Shiboken::Converter<QLayout* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addRow(QWidget*,QLayout*)
                cppSelf->QFormLayout::addRow(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[0]);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
            case 2: // addRow(QWidget*,QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addRow(QWidget*,QWidget*)
                cppSelf->QFormLayout::addRow(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[0]);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
            case 3: // addRow(QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addRow(QWidget*)
                cppSelf->QFormLayout::addRow(cpp_arg0);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
            case 4: // addRow(QString,QLayout*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QLayout* cpp_arg1 = Shiboken::Converter<QLayout* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addRow(QString,QLayout*)
                cppSelf->QFormLayout::addRow(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
            case 5: // addRow(QString,QWidget*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addRow(QString,QWidget*)
                cppSelf->QFormLayout::addRow(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_addRow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout", "PySide.QtGui.QWidget, PySide.QtGui.QLayout", "PySide.QtGui.QWidget, PySide.QtGui.QWidget", "PySide.QtGui.QWidget", "QString, PySide.QtGui.QLayout", "QString, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.addRow", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_count(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // count()const
            int cppResult = cppSelf->QFormLayout::count();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_expandingDirections(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // expandingDirections()const
            QFlags<Qt::Orientation> cppResult = cppSelf->QFormLayout::expandingDirections();
            pyResult = Shiboken::Converter<QFlags<Qt::Orientation> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_fieldGrowthPolicy(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fieldGrowthPolicy()const
            QFormLayout::FieldGrowthPolicy cppResult = cppSelf->QFormLayout::fieldGrowthPolicy();
            pyResult = Shiboken::Converter<QFormLayout::FieldGrowthPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_formAlignment(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // formAlignment()const
            QFlags<Qt::AlignmentFlag> cppResult = cppSelf->QFormLayout::formAlignment();
            pyResult = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_hasHeightForWidth(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasHeightForWidth()const
            bool cppResult = cppSelf->QFormLayout::hasHeightForWidth();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_heightForWidth(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: heightForWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // heightForWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_heightForWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // heightForWidth(int)const
            int cppResult = cppSelf->QFormLayout::heightForWidth(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFormLayoutFunc_heightForWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.heightForWidth", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_horizontalSpacing(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // horizontalSpacing()const
            int cppResult = cppSelf->QFormLayout::horizontalSpacing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_insertRow(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertRow", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insertRow(int,QLayout*)
    // 1: insertRow(int,QWidget*,QLayout*)
    // 2: insertRow(int,QWidget*,QWidget*)
    // 3: insertRow(int,QWidget*)
    // 4: insertRow(int,QString,QLayout*)
    // 5: insertRow(int,QString,QWidget*)
    if (SbkNumber_Check(pyargs[0])) {
        if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 3 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 5; // insertRow(int,QString,QWidget*)
            } else if (numArgs == 3 && Shiboken::Converter<QLayout * >::isConvertible(pyargs[2])) {
                overloadId = 4; // insertRow(int,QString,QLayout*)
            }
        } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // insertRow(int,QWidget*)
            } else if (numArgs == 3 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 2; // insertRow(int,QWidget*,QWidget*)
            } else if (numArgs == 3 && Shiboken::Converter<QLayout * >::isConvertible(pyargs[2])) {
                overloadId = 1; // insertRow(int,QWidget*,QLayout*)
            }
        } else if (numArgs == 2 && Shiboken::Converter<QLayout * >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertRow(int,QLayout*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_insertRow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertRow(int,QLayout*)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QLayout* cpp_arg1 = Shiboken::Converter<QLayout* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // insertRow(int,QLayout*)
                cppSelf->QFormLayout::insertRow(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
            case 1: // insertRow(int,QWidget*,QLayout*)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QLayout* cpp_arg2 = Shiboken::Converter<QLayout* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // insertRow(int,QWidget*,QLayout*)
                cppSelf->QFormLayout::insertRow(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(self, pyargs[1]);
                Shiboken::setParent(self, pyargs[2]);
                }
                break;
            }
            case 2: // insertRow(int,QWidget*,QWidget*)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QWidget* cpp_arg2 = Shiboken::Converter<QWidget* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // insertRow(int,QWidget*,QWidget*)
                cppSelf->QFormLayout::insertRow(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(self, pyargs[1]);
                Shiboken::setParent(self, pyargs[2]);
                }
                break;
            }
            case 3: // insertRow(int,QWidget*)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // insertRow(int,QWidget*)
                cppSelf->QFormLayout::insertRow(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
            case 4: // insertRow(int,QString,QLayout*)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QLayout* cpp_arg2 = Shiboken::Converter<QLayout* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // insertRow(int,QString,QLayout*)
                cppSelf->QFormLayout::insertRow(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(self, pyargs[2]);
                }
                break;
            }
            case 5: // insertRow(int,QString,QWidget*)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QWidget* cpp_arg2 = Shiboken::Converter<QWidget* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // insertRow(int,QString,QWidget*)
                cppSelf->QFormLayout::insertRow(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(self, pyargs[2]);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_insertRow_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QLayout", "int, PySide.QtGui.QWidget, PySide.QtGui.QLayout", "int, PySide.QtGui.QWidget, PySide.QtGui.QWidget", "int, PySide.QtGui.QWidget", "int, QString, PySide.QtGui.QLayout", "int, QString, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.insertRow", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_invalidate(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // invalidate()
            cppSelf->QFormLayout::invalidate();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQFormLayoutFunc_itemAt(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(int)const
    // 1: itemAt(int,QFormLayout::ItemRole)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // itemAt(int)const
        } else if (numArgs == 2 && Shiboken::Converter<QFormLayout::ItemRole >::isConvertible(pyargs[1])) {
            overloadId = 1; // itemAt(int,QFormLayout::ItemRole)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // itemAt(int)const

                QLayoutItem * cppResult = cppSelf->QFormLayout::itemAt(cpp_arg0);
                pyResult = Shiboken::Converter<QLayoutItem * >::toPython(cppResult);

                // Begin code injection
                
                addLayoutOwnership(cppSelf, cppResult);
                
                // End of code injection

                // Ownership transferences.
                }
                break;
            }
            case 1: // itemAt(int,QFormLayout::ItemRole)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QFormLayout::ItemRole cpp_arg1 = Shiboken::Converter<QFormLayout::ItemRole >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // itemAt(int,QFormLayout::ItemRole)const
                QLayoutItem * cppResult = cppSelf->QFormLayout::itemAt(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QLayoutItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFormLayoutFunc_itemAt_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtGui.QFormLayout.ItemRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.itemAt", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_labelAlignment(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // labelAlignment()const
            QFlags<Qt::AlignmentFlag> cppResult = cppSelf->QFormLayout::labelAlignment();
            pyResult = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_labelForField(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: labelForField(QLayout*)const
    // 1: labelForField(QWidget*)const
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 1; // labelForField(QWidget*)const
    } else if (Shiboken::Converter<QLayout * >::isConvertible(arg)) {
        overloadId = 0; // labelForField(QLayout*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_labelForField_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // labelForField(QLayout*)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QLayout* cpp_arg0 = Shiboken::Converter<QLayout* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // labelForField(QLayout*)const
                QWidget * cppResult = cppSelf->QFormLayout::labelForField(cpp_arg0);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // labelForField(QWidget*)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // labelForField(QWidget*)const
                QWidget * cppResult = cppSelf->QFormLayout::labelForField(cpp_arg0);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFormLayoutFunc_labelForField_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.labelForField", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_minimumSize(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumSize()const
            QSize cppResult = cppSelf->QFormLayout::minimumSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_rowCount(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rowCount()const
            int cppResult = cppSelf->QFormLayout::rowCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_rowWrapPolicy(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rowWrapPolicy()const
            QFormLayout::RowWrapPolicy cppResult = cppSelf->QFormLayout::rowWrapPolicy();
            pyResult = Shiboken::Converter<QFormLayout::RowWrapPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_setFieldGrowthPolicy(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy)
    if (Shiboken::Converter<QFormLayout::FieldGrowthPolicy >::isConvertible(arg)) {
        overloadId = 0; // setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setFieldGrowthPolicy_TypeError;

    // Call function/method
    {
        {
            QFormLayout::FieldGrowthPolicy cpp_arg0 = Shiboken::Converter<QFormLayout::FieldGrowthPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy)
            cppSelf->QFormLayout::setFieldGrowthPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setFieldGrowthPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFormLayout.FieldGrowthPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setFieldGrowthPolicy", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setFormAlignment(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setFormAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setFormAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFormAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->QFormLayout::setFormAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setFormAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setFormAlignment", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setGeometry(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometry(QRect)
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setGeometry_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGeometry(QRect)
            cppSelf->QFormLayout::setGeometry(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setGeometry", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setHorizontalSpacing(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHorizontalSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setHorizontalSpacing_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHorizontalSpacing(int)
            cppSelf->QFormLayout::setHorizontalSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setHorizontalSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setHorizontalSpacing", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setLabelAlignment(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLabelAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setLabelAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setLabelAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLabelAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->QFormLayout::setLabelAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setLabelAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setLabelAlignment", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setLayout(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setLayout", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setLayout(int,QFormLayout::ItemRole,QLayout*)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QFormLayout::ItemRole >::isConvertible(pyargs[1]) && Shiboken::Converter<QLayout * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setLayout(int,QFormLayout::ItemRole,QLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setLayout_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QFormLayout::ItemRole cpp_arg1 = Shiboken::Converter<QFormLayout::ItemRole >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QLayout* cpp_arg2 = Shiboken::Converter<QLayout* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setLayout(int,QFormLayout::ItemRole,QLayout*)
            cppSelf->QFormLayout::setLayout(cpp_arg0, cpp_arg1, cpp_arg2);
            Shiboken::setParent(self, pyargs[2]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setLayout_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QFormLayout.ItemRole, PySide.QtGui.QLayout", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.setLayout", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setRowWrapPolicy(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRowWrapPolicy(QFormLayout::RowWrapPolicy)
    if (Shiboken::Converter<QFormLayout::RowWrapPolicy >::isConvertible(arg)) {
        overloadId = 0; // setRowWrapPolicy(QFormLayout::RowWrapPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setRowWrapPolicy_TypeError;

    // Call function/method
    {
        {
            QFormLayout::RowWrapPolicy cpp_arg0 = Shiboken::Converter<QFormLayout::RowWrapPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRowWrapPolicy(QFormLayout::RowWrapPolicy)
            cppSelf->QFormLayout::setRowWrapPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setRowWrapPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFormLayout.RowWrapPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setRowWrapPolicy", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setSpacing(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setSpacing_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSpacing(int)
            cppSelf->QFormLayout::setSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setSpacing", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setVerticalSpacing(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVerticalSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setVerticalSpacing_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVerticalSpacing(int)
            cppSelf->QFormLayout::setVerticalSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setVerticalSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.setVerticalSpacing", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_setWidget(PyObject* self, PyObject* args)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setWidget", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setWidget(int,QFormLayout::ItemRole,QWidget*)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QFormLayout::ItemRole >::isConvertible(pyargs[1]) && Shiboken::Converter<QWidget * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setWidget(int,QFormLayout::ItemRole,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_setWidget_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QFormLayout::ItemRole cpp_arg1 = Shiboken::Converter<QFormLayout::ItemRole >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QWidget* cpp_arg2 = Shiboken::Converter<QWidget* >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setWidget(int,QFormLayout::ItemRole,QWidget*)
            cppSelf->QFormLayout::setWidget(cpp_arg0, cpp_arg1, cpp_arg2);
            Shiboken::setParent(self, pyargs[2]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQFormLayoutFunc_setWidget_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QFormLayout.ItemRole, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFormLayout.setWidget", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_sizeHint(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizeHint()const
            QSize cppResult = cppSelf->QFormLayout::sizeHint();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_spacing(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // spacing()const
            int cppResult = cppSelf->QFormLayout::spacing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFormLayoutFunc_takeAt(PyObject* self, PyObject* arg)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeAt(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFormLayoutFunc_takeAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // takeAt(int)
            QLayoutItem * cppResult = cppSelf->QFormLayout::takeAt(cpp_arg0);
            pyResult = Shiboken::Converter<QLayoutItem * >::toPython(cppResult);
            Shiboken::setParent(Py_None, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFormLayoutFunc_takeAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFormLayout.takeAt", overloads);
        return 0;
}

static PyObject* SbkQFormLayoutFunc_verticalSpacing(PyObject* self)
{
    QFormLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFormLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // verticalSpacing()const
            int cppResult = cppSelf->QFormLayout::verticalSpacing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFormLayout_methods[] = {
    {"addItem", (PyCFunction)SbkQFormLayoutFunc_addItem, METH_O},
    {"addRow", (PyCFunction)SbkQFormLayoutFunc_addRow, METH_VARARGS},
    {"count", (PyCFunction)SbkQFormLayoutFunc_count, METH_NOARGS},
    {"expandingDirections", (PyCFunction)SbkQFormLayoutFunc_expandingDirections, METH_NOARGS},
    {"fieldGrowthPolicy", (PyCFunction)SbkQFormLayoutFunc_fieldGrowthPolicy, METH_NOARGS},
    {"formAlignment", (PyCFunction)SbkQFormLayoutFunc_formAlignment, METH_NOARGS},
    {"hasHeightForWidth", (PyCFunction)SbkQFormLayoutFunc_hasHeightForWidth, METH_NOARGS},
    {"heightForWidth", (PyCFunction)SbkQFormLayoutFunc_heightForWidth, METH_O},
    {"horizontalSpacing", (PyCFunction)SbkQFormLayoutFunc_horizontalSpacing, METH_NOARGS},
    {"insertRow", (PyCFunction)SbkQFormLayoutFunc_insertRow, METH_VARARGS},
    {"invalidate", (PyCFunction)SbkQFormLayoutFunc_invalidate, METH_NOARGS},
    {"itemAt", (PyCFunction)SbkQFormLayoutFunc_itemAt, METH_VARARGS},
    {"labelAlignment", (PyCFunction)SbkQFormLayoutFunc_labelAlignment, METH_NOARGS},
    {"labelForField", (PyCFunction)SbkQFormLayoutFunc_labelForField, METH_O},
    {"minimumSize", (PyCFunction)SbkQFormLayoutFunc_minimumSize, METH_NOARGS},
    {"rowCount", (PyCFunction)SbkQFormLayoutFunc_rowCount, METH_NOARGS},
    {"rowWrapPolicy", (PyCFunction)SbkQFormLayoutFunc_rowWrapPolicy, METH_NOARGS},
    {"setFieldGrowthPolicy", (PyCFunction)SbkQFormLayoutFunc_setFieldGrowthPolicy, METH_O},
    {"setFormAlignment", (PyCFunction)SbkQFormLayoutFunc_setFormAlignment, METH_O},
    {"setGeometry", (PyCFunction)SbkQFormLayoutFunc_setGeometry, METH_O},
    {"setHorizontalSpacing", (PyCFunction)SbkQFormLayoutFunc_setHorizontalSpacing, METH_O},
    {"setLabelAlignment", (PyCFunction)SbkQFormLayoutFunc_setLabelAlignment, METH_O},
    {"setLayout", (PyCFunction)SbkQFormLayoutFunc_setLayout, METH_VARARGS},
    {"setRowWrapPolicy", (PyCFunction)SbkQFormLayoutFunc_setRowWrapPolicy, METH_O},
    {"setSpacing", (PyCFunction)SbkQFormLayoutFunc_setSpacing, METH_O},
    {"setVerticalSpacing", (PyCFunction)SbkQFormLayoutFunc_setVerticalSpacing, METH_O},
    {"setWidget", (PyCFunction)SbkQFormLayoutFunc_setWidget, METH_VARARGS},
    {"sizeHint", (PyCFunction)SbkQFormLayoutFunc_sizeHint, METH_NOARGS},
    {"spacing", (PyCFunction)SbkQFormLayoutFunc_spacing, METH_NOARGS},
    {"takeAt", (PyCFunction)SbkQFormLayoutFunc_takeAt, METH_O},
    {"verticalSpacing", (PyCFunction)SbkQFormLayoutFunc_verticalSpacing, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQFormLayoutSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QFormLayout* me = reinterpret_cast<QFormLayout*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]))
        return static_cast<QLayout*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX]))
        return static_cast<QLayoutItem*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFormLayout_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFormLayout",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFormLayout_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFormLayout_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQFormLayoutSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFormLayout >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFormLayout*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQFormLayout_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QFormLayout*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQFormLayout_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QLayoutItem >()) && dynamic_cast<QFormLayout*>(reinterpret_cast<QLayoutItem*>(cptr)))
        return &SbkQFormLayout_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FieldGrowthPolicy",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QFormLayout_RowWrapPolicy_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFormLayout_RowWrapPolicy_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RowWrapPolicy",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFormLayout_RowWrapPolicy_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFormLayout_RowWrapPolicy_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFormLayout_RowWrapPolicy_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QFormLayout_ItemRole_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QFormLayout_ItemRole_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QFormLayout_ItemRole_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ItemRole",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QFormLayout_ItemRole_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QFormLayout_ItemRole_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QFormLayout_ItemRole_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QFormLayout(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFormLayout_Type);

    SbkQFormLayout_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX];
    SbkQFormLayout_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX])->mi_init;

    // Fill type discovery information
    SbkQFormLayout_Type.type_discovery = &SbkQFormLayout_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]), &SbkQFormLayout_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFormLayout_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFormLayout_Type));
    PyModule_AddObject(module, "QFormLayout",
        ((PyObject*)&SbkQFormLayout_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: FieldGrowthPolicy
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_FIELDGROWTHPOLICY_IDX] = &SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type);
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
            "FieldGrowthPolicy",((PyObject*)&SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type,
        (long) QFormLayout::FieldsStayAtSizeHint, "FieldsStayAtSizeHint");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "FieldsStayAtSizeHint", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type.tp_dict,
        "FieldsStayAtSizeHint", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type,
        (long) QFormLayout::ExpandingFieldsGrow, "ExpandingFieldsGrow");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "ExpandingFieldsGrow", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type.tp_dict,
        "ExpandingFieldsGrow", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type,
        (long) QFormLayout::AllNonFixedFieldsGrow, "AllNonFixedFieldsGrow");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "AllNonFixedFieldsGrow", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_FieldGrowthPolicy_Type.tp_dict,
        "AllNonFixedFieldsGrow", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFormLayout::FieldGrowthPolicy");

    // init enum class: RowWrapPolicy
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_ROWWRAPPOLICY_IDX] = &SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type);
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
            "RowWrapPolicy",((PyObject*)&SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type,
        (long) QFormLayout::DontWrapRows, "DontWrapRows");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "DontWrapRows", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type.tp_dict,
        "DontWrapRows", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type,
        (long) QFormLayout::WrapLongRows, "WrapLongRows");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "WrapLongRows", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type.tp_dict,
        "WrapLongRows", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type,
        (long) QFormLayout::WrapAllRows, "WrapAllRows");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "WrapAllRows", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_RowWrapPolicy_Type.tp_dict,
        "WrapAllRows", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFormLayout::RowWrapPolicy");

    // init enum class: ItemRole
    SbkPySide_QtGuiTypes[SBK_QFORMLAYOUT_ITEMROLE_IDX] = &SbkPySide_QtGui_QFormLayout_ItemRole_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QFormLayout_ItemRole_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QFormLayout_ItemRole_Type);
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
            "ItemRole",((PyObject*)&SbkPySide_QtGui_QFormLayout_ItemRole_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_ItemRole_Type,
        (long) QFormLayout::LabelRole, "LabelRole");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "LabelRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_ItemRole_Type.tp_dict,
        "LabelRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_ItemRole_Type,
        (long) QFormLayout::FieldRole, "FieldRole");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "FieldRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_ItemRole_Type.tp_dict,
        "FieldRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QFormLayout_ItemRole_Type,
        (long) QFormLayout::SpanningRole, "SpanningRole");
    PyDict_SetItemString(SbkQFormLayout_Type.super.ht_type.tp_dict,
        "SpanningRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QFormLayout_ItemRole_Type.tp_dict,
        "SpanningRole", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFormLayout::ItemRole");


    Shiboken::TypeResolver::createObjectTypeResolver<QFormLayout >("QFormLayout*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFormLayout >(typeid(QFormLayout).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFormLayout >(typeid(QFormLayoutWrapper).name());
    PySide::initQtMetaType<QFormLayout* >();
}

