/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qgraphicsdropshadoweffect_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qgraphicseffect.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsDropShadowEffectWrapper::QGraphicsDropShadowEffectWrapper(QObject * parent) : QGraphicsDropShadowEffect(parent), m_metaObject(0) {
    // ... middle
}

QRectF QGraphicsDropShadowEffectWrapper::boundingRectFor(const QRectF & rect) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "boundingRectFor"));
    if (py_override.isNull()) {
        return this->QGraphicsDropShadowEffect::boundingRectFor(rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QRectF & >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRectF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRectF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsDropShadowEffect.boundingRectFor", SbkType<QRectF >()->tp_name, pyResult->ob_type->tp_name);
        return QRectF();
    }
    QRectF cppResult(Shiboken::Converter<QRectF >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsDropShadowEffectWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsDropShadowEffectWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsDropShadowEffectWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsDropShadowEffectWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsDropShadowEffectWrapper::draw(QPainter * painter)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "draw"));
    if (py_override.isNull()) {
        return this->QGraphicsDropShadowEffect::draw(painter);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPainter * >::toPython(painter)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGraphicsDropShadowEffectWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsDropShadowEffect.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsDropShadowEffectWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsDropShadowEffect.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGraphicsDropShadowEffectWrapper::sourceChanged(QFlags<QGraphicsEffect::ChangeFlag> flags)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sourceChanged"));
    if (py_override.isNull()) {
        return this->QGraphicsEffect::sourceChanged(flags);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFlags<QGraphicsEffect::ChangeFlag> >::toPython(flags)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsDropShadowEffectWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsDropShadowEffectWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGraphicsDropShadowEffect::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGraphicsDropShadowEffectWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsDropShadowEffect::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsDropShadowEffectWrapper::~QGraphicsDropShadowEffectWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsDropShadowEffect_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsDropShadowEffect >()))
        return -1;

    QGraphicsDropShadowEffectWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QGraphicsDropShadowEffect", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsDropShadowEffect(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsDropShadowEffect(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QGraphicsDropShadowEffect(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffect_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsDropShadowEffect(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QGraphicsDropShadowEffect(QObject*)
            cptr = new QGraphicsDropShadowEffectWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsDropShadowEffect >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsDropShadowEffect_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGraphicsDropShadowEffect_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsDropShadowEffect", overloads);
        return -1;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_blurRadius(PyObject* self)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blurRadius()const
            qreal cppResult = cppSelf->QGraphicsDropShadowEffect::blurRadius();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_boundingRectFor(PyObject* self, PyObject* arg)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundingRectFor(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // boundingRectFor(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffectFunc_boundingRectFor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // boundingRectFor(QRectF)const
            QRectF cppResult = cppSelf->QGraphicsDropShadowEffect::boundingRectFor(*cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsDropShadowEffectFunc_boundingRectFor_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsDropShadowEffect.boundingRectFor", overloads);
        return 0;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_color(PyObject* self)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // color()const
            QColor cppResult = cppSelf->QGraphicsDropShadowEffect::color();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_draw(PyObject* self, PyObject* arg)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: draw(QPainter*)
    if (Shiboken::Converter<QPainter * >::isConvertible(arg)) {
        overloadId = 0; // draw(QPainter*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffectFunc_draw_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // draw(QPainter*)
            cppSelf->QGraphicsDropShadowEffect::draw(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsDropShadowEffectFunc_draw_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsDropShadowEffect.draw", overloads);
        return 0;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_offset(PyObject* self)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // offset()const
            QPointF cppResult = cppSelf->QGraphicsDropShadowEffect::offset();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_setBlurRadius(PyObject* self, PyObject* arg)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlurRadius(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBlurRadius(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffectFunc_setBlurRadius_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBlurRadius(qreal)
            cppSelf->QGraphicsDropShadowEffect::setBlurRadius(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsDropShadowEffectFunc_setBlurRadius_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsDropShadowEffect.setBlurRadius", overloads);
        return 0;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_setColor(PyObject* self, PyObject* arg)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColor(QColor)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // setColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffectFunc_setColor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setColor(QColor)
            cppSelf->QGraphicsDropShadowEffect::setColor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsDropShadowEffectFunc_setColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsDropShadowEffect.setColor", overloads);
        return 0;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_setOffset(PyObject* self, PyObject* args)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setOffset", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOffset(QPointF)
    // 1: setOffset(qreal)
    // 2: setOffset(qreal,qreal)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setOffset(qreal)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // setOffset(qreal,qreal)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setOffset(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffectFunc_setOffset_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setOffset(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setOffset(QPointF)
                cppSelf->QGraphicsDropShadowEffect::setOffset(*cpp_arg0);
                }
                break;
            }
            case 1: // setOffset(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setOffset(qreal)
                cppSelf->QGraphicsDropShadowEffect::setOffset(cpp_arg0);
                }
                break;
            }
            case 2: // setOffset(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setOffset(qreal,qreal)
                cppSelf->QGraphicsDropShadowEffect::setOffset(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsDropShadowEffectFunc_setOffset_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsDropShadowEffect.setOffset", overloads);
        return 0;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_setXOffset(PyObject* self, PyObject* arg)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setXOffset(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setXOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffectFunc_setXOffset_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setXOffset(qreal)
            cppSelf->QGraphicsDropShadowEffect::setXOffset(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsDropShadowEffectFunc_setXOffset_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsDropShadowEffect.setXOffset", overloads);
        return 0;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_setYOffset(PyObject* self, PyObject* arg)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setYOffset(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setYOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsDropShadowEffectFunc_setYOffset_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setYOffset(qreal)
            cppSelf->QGraphicsDropShadowEffect::setYOffset(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsDropShadowEffectFunc_setYOffset_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsDropShadowEffect.setYOffset", overloads);
        return 0;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_xOffset(PyObject* self)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // xOffset()const
            qreal cppResult = cppSelf->QGraphicsDropShadowEffect::xOffset();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsDropShadowEffectFunc_yOffset(PyObject* self)
{
    QGraphicsDropShadowEffect* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsDropShadowEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // yOffset()const
            qreal cppResult = cppSelf->QGraphicsDropShadowEffect::yOffset();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGraphicsDropShadowEffect_methods[] = {
    {"blurRadius", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_blurRadius, METH_NOARGS},
    {"boundingRectFor", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_boundingRectFor, METH_O},
    {"color", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_color, METH_NOARGS},
    {"draw", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_draw, METH_O},
    {"offset", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_offset, METH_NOARGS},
    {"setBlurRadius", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_setBlurRadius, METH_O},
    {"setColor", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_setColor, METH_O},
    {"setOffset", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_setOffset, METH_VARARGS},
    {"setXOffset", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_setXOffset, METH_O},
    {"setYOffset", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_setYOffset, METH_O},
    {"xOffset", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_xOffset, METH_NOARGS},
    {"yOffset", (PyCFunction)SbkQGraphicsDropShadowEffectFunc_yOffset, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsDropShadowEffect_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsDropShadowEffect",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsDropShadowEffect_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsDropShadowEffect_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsDropShadowEffect >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsDropShadowEffect*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsDropShadowEffect_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsDropShadowEffect*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGraphicsDropShadowEffect_Type;
    return 0;
}


void init_QGraphicsDropShadowEffect(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSDROPSHADOWEFFECT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsDropShadowEffect_Type);

    SbkQGraphicsDropShadowEffect_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSEFFECT_IDX];
    // Fill type discovery information
    SbkQGraphicsDropShadowEffect_Type.type_discovery = &SbkQGraphicsDropShadowEffect_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSEFFECT_IDX]), &SbkQGraphicsDropShadowEffect_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsDropShadowEffect_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsDropShadowEffect_Type));
    PyModule_AddObject(module, "QGraphicsDropShadowEffect",
        ((PyObject*)&SbkQGraphicsDropShadowEffect_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("colorChanged", "const QColor&", NULL);
    PyDict_SetItemString(SbkQGraphicsDropShadowEffect_Type.super.ht_type.tp_dict, "colorChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("offsetChanged", "const QPointF&", NULL);
    PyDict_SetItemString(SbkQGraphicsDropShadowEffect_Type.super.ht_type.tp_dict, "offsetChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("blurRadiusChanged", "qreal", NULL);
    PyDict_SetItemString(SbkQGraphicsDropShadowEffect_Type.super.ht_type.tp_dict, "blurRadiusChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsDropShadowEffect >("QGraphicsDropShadowEffect*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsDropShadowEffect >(typeid(QGraphicsDropShadowEffect).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsDropShadowEffect >(typeid(QGraphicsDropShadowEffectWrapper).name());
    PySide::initQtMetaType<QGraphicsDropShadowEffect* >();
}

