/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qgraphicsitemanimation_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qgraphicsitem.h>
#include <qgraphicsitemanimation.h>
#include <qmatrix.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qthread.h>
#include <qtimeline.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsItemAnimationWrapper::QGraphicsItemAnimationWrapper(QObject * parent) : QGraphicsItemAnimation(parent), m_metaObject(0) {
    // ... middle
}

void QGraphicsItemAnimationWrapper::afterAnimationStep(qreal step)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "afterAnimationStep"));
    if (py_override.isNull()) {
        return this->QGraphicsItemAnimation::afterAnimationStep(step);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(d)",
        Shiboken::Converter<double >::toPython(step)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsItemAnimationWrapper::beforeAnimationStep(qreal step)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "beforeAnimationStep"));
    if (py_override.isNull()) {
        return this->QGraphicsItemAnimation::beforeAnimationStep(step);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(d)",
        Shiboken::Converter<double >::toPython(step)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsItemAnimationWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemAnimationWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsItemAnimationWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsItemAnimationWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGraphicsItemAnimationWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItemAnimation.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsItemAnimationWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsItemAnimation.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGraphicsItemAnimationWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsItemAnimationWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGraphicsItemAnimation::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGraphicsItemAnimationWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsItemAnimation::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsItemAnimationWrapper::~QGraphicsItemAnimationWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsItemAnimation_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsItemAnimation >()))
        return -1;

    QGraphicsItemAnimationWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QGraphicsItemAnimation", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsItemAnimation(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsItemAnimation(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QGraphicsItemAnimation(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimation_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsItemAnimation(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QGraphicsItemAnimation(QObject*)
            cptr = new QGraphicsItemAnimationWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsItemAnimation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsItemAnimation_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGraphicsItemAnimation_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItemAnimation", overloads);
        return -1;
}

static PyObject* SbkQGraphicsItemAnimationFunc_afterAnimationStep(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: afterAnimationStep(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // afterAnimationStep(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_afterAnimationStep_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // afterAnimationStep(qreal)
            cppSelf->QGraphicsItemAnimation::afterAnimationStep(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_afterAnimationStep_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.afterAnimationStep", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_beforeAnimationStep(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: beforeAnimationStep(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // beforeAnimationStep(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_beforeAnimationStep_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // beforeAnimationStep(qreal)
            cppSelf->QGraphicsItemAnimation::beforeAnimationStep(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_beforeAnimationStep_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.beforeAnimationStep", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_clear(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QGraphicsItemAnimation::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemAnimationFunc_horizontalScaleAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: horizontalScaleAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // horizontalScaleAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_horizontalScaleAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // horizontalScaleAt(qreal)const
            qreal cppResult = cppSelf->QGraphicsItemAnimation::horizontalScaleAt(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_horizontalScaleAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.horizontalScaleAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_horizontalShearAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: horizontalShearAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // horizontalShearAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_horizontalShearAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // horizontalShearAt(qreal)const
            qreal cppResult = cppSelf->QGraphicsItemAnimation::horizontalShearAt(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_horizontalShearAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.horizontalShearAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_item(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // item()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsItemAnimation::item();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemAnimationFunc_matrixAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: matrixAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // matrixAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_matrixAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // matrixAt(qreal)const
            QMatrix cppResult = cppSelf->QGraphicsItemAnimation::matrixAt(cpp_arg0);
            pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_matrixAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.matrixAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_posAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: posAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // posAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_posAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // posAt(qreal)const
            QPointF cppResult = cppSelf->QGraphicsItemAnimation::posAt(cpp_arg0);
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_posAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.posAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_posList(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // posList()const
            QList<QPair<qreal, QPointF > > cppResult = cppSelf->QGraphicsItemAnimation::posList();
            pyResult = Shiboken::Converter<QList<QPair<qreal, QPointF > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemAnimationFunc_reset(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QGraphicsItemAnimation::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsItemAnimationFunc_rotationAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotationAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotationAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_rotationAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rotationAt(qreal)const
            qreal cppResult = cppSelf->QGraphicsItemAnimation::rotationAt(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_rotationAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.rotationAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_rotationList(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rotationList()const
            QList<QPair<qreal, qreal > > cppResult = cppSelf->QGraphicsItemAnimation::rotationList();
            pyResult = Shiboken::Converter<QList<QPair<qreal, qreal > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemAnimationFunc_scaleList(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scaleList()const
            QList<QPair<qreal, QPointF > > cppResult = cppSelf->QGraphicsItemAnimation::scaleList();
            pyResult = Shiboken::Converter<QList<QPair<qreal, QPointF > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setItem(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItem(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // setItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setItem(QGraphicsItem*)
            cppSelf->QGraphicsItemAnimation::setItem(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.setItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setPosAt(PyObject* self, PyObject* args)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPosAt", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPosAt(qreal,QPointF)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPosAt(qreal,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setPosAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
            QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setPosAt(qreal,QPointF)
            cppSelf->QGraphicsItemAnimation::setPosAt(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setPosAt_TypeError:
        const char* overloads[] = {"float, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItemAnimation.setPosAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setRotationAt(PyObject* self, PyObject* args)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRotationAt", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRotationAt(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setRotationAt(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setRotationAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setRotationAt(qreal,qreal)
            cppSelf->QGraphicsItemAnimation::setRotationAt(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setRotationAt_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItemAnimation.setRotationAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setScaleAt(PyObject* self, PyObject* args)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setScaleAt", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setScaleAt(qreal,qreal,qreal)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setScaleAt(qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setScaleAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setScaleAt(qreal,qreal,qreal)
            cppSelf->QGraphicsItemAnimation::setScaleAt(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setScaleAt_TypeError:
        const char* overloads[] = {"float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItemAnimation.setScaleAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setShearAt(PyObject* self, PyObject* args)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setShearAt", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setShearAt(qreal,qreal,qreal)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setShearAt(qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setShearAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setShearAt(qreal,qreal,qreal)
            cppSelf->QGraphicsItemAnimation::setShearAt(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setShearAt_TypeError:
        const char* overloads[] = {"float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItemAnimation.setShearAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setStep(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStep(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStep(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setStep_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStep(qreal)
            cppSelf->QGraphicsItemAnimation::setStep(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setStep_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.setStep", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setTimeLine(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTimeLine(QTimeLine*)
    if (Shiboken::Converter<QTimeLine * >::isConvertible(arg)) {
        overloadId = 0; // setTimeLine(QTimeLine*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setTimeLine_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTimeLine* cpp_arg0 = Shiboken::Converter<QTimeLine* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTimeLine(QTimeLine*)
            cppSelf->QGraphicsItemAnimation::setTimeLine(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setTimeLine_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimeLine", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.setTimeLine", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_setTranslationAt(PyObject* self, PyObject* args)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setTranslationAt", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setTranslationAt(qreal,qreal,qreal)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setTranslationAt(qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_setTranslationAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setTranslationAt(qreal,qreal,qreal)
            cppSelf->QGraphicsItemAnimation::setTranslationAt(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsItemAnimationFunc_setTranslationAt_TypeError:
        const char* overloads[] = {"float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsItemAnimation.setTranslationAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_shearList(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shearList()const
            QList<QPair<qreal, QPointF > > cppResult = cppSelf->QGraphicsItemAnimation::shearList();
            pyResult = Shiboken::Converter<QList<QPair<qreal, QPointF > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemAnimationFunc_timeLine(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // timeLine()const
            QTimeLine * cppResult = cppSelf->QGraphicsItemAnimation::timeLine();
            pyResult = Shiboken::Converter<QTimeLine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemAnimationFunc_translationList(PyObject* self)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // translationList()const
            QList<QPair<qreal, QPointF > > cppResult = cppSelf->QGraphicsItemAnimation::translationList();
            pyResult = Shiboken::Converter<QList<QPair<qreal, QPointF > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsItemAnimationFunc_verticalScaleAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: verticalScaleAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // verticalScaleAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_verticalScaleAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // verticalScaleAt(qreal)const
            qreal cppResult = cppSelf->QGraphicsItemAnimation::verticalScaleAt(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_verticalScaleAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.verticalScaleAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_verticalShearAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: verticalShearAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // verticalShearAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_verticalShearAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // verticalShearAt(qreal)const
            qreal cppResult = cppSelf->QGraphicsItemAnimation::verticalShearAt(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_verticalShearAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.verticalShearAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_xTranslationAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: xTranslationAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // xTranslationAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_xTranslationAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // xTranslationAt(qreal)const
            qreal cppResult = cppSelf->QGraphicsItemAnimation::xTranslationAt(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_xTranslationAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.xTranslationAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsItemAnimationFunc_yTranslationAt(PyObject* self, PyObject* arg)
{
    QGraphicsItemAnimation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsItemAnimation* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: yTranslationAt(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // yTranslationAt(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsItemAnimationFunc_yTranslationAt_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // yTranslationAt(qreal)const
            qreal cppResult = cppSelf->QGraphicsItemAnimation::yTranslationAt(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsItemAnimationFunc_yTranslationAt_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsItemAnimation.yTranslationAt", overloads);
        return 0;
}

static PyMethodDef SbkQGraphicsItemAnimation_methods[] = {
    {"afterAnimationStep", (PyCFunction)SbkQGraphicsItemAnimationFunc_afterAnimationStep, METH_O},
    {"beforeAnimationStep", (PyCFunction)SbkQGraphicsItemAnimationFunc_beforeAnimationStep, METH_O},
    {"clear", (PyCFunction)SbkQGraphicsItemAnimationFunc_clear, METH_NOARGS},
    {"horizontalScaleAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_horizontalScaleAt, METH_O},
    {"horizontalShearAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_horizontalShearAt, METH_O},
    {"item", (PyCFunction)SbkQGraphicsItemAnimationFunc_item, METH_NOARGS},
    {"matrixAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_matrixAt, METH_O},
    {"posAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_posAt, METH_O},
    {"posList", (PyCFunction)SbkQGraphicsItemAnimationFunc_posList, METH_NOARGS},
    {"reset", (PyCFunction)SbkQGraphicsItemAnimationFunc_reset, METH_NOARGS},
    {"rotationAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_rotationAt, METH_O},
    {"rotationList", (PyCFunction)SbkQGraphicsItemAnimationFunc_rotationList, METH_NOARGS},
    {"scaleList", (PyCFunction)SbkQGraphicsItemAnimationFunc_scaleList, METH_NOARGS},
    {"setItem", (PyCFunction)SbkQGraphicsItemAnimationFunc_setItem, METH_O},
    {"setPosAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_setPosAt, METH_VARARGS},
    {"setRotationAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_setRotationAt, METH_VARARGS},
    {"setScaleAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_setScaleAt, METH_VARARGS},
    {"setShearAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_setShearAt, METH_VARARGS},
    {"setStep", (PyCFunction)SbkQGraphicsItemAnimationFunc_setStep, METH_O},
    {"setTimeLine", (PyCFunction)SbkQGraphicsItemAnimationFunc_setTimeLine, METH_O},
    {"setTranslationAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_setTranslationAt, METH_VARARGS},
    {"shearList", (PyCFunction)SbkQGraphicsItemAnimationFunc_shearList, METH_NOARGS},
    {"timeLine", (PyCFunction)SbkQGraphicsItemAnimationFunc_timeLine, METH_NOARGS},
    {"translationList", (PyCFunction)SbkQGraphicsItemAnimationFunc_translationList, METH_NOARGS},
    {"verticalScaleAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_verticalScaleAt, METH_O},
    {"verticalShearAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_verticalShearAt, METH_O},
    {"xTranslationAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_xTranslationAt, METH_O},
    {"yTranslationAt", (PyCFunction)SbkQGraphicsItemAnimationFunc_yTranslationAt, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsItemAnimation_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsItemAnimation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsItemAnimation_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsItemAnimation_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsItemAnimation >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsItemAnimation*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsItemAnimation_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsItemAnimation*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGraphicsItemAnimation_Type;
    return 0;
}


void init_QGraphicsItemAnimation(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSITEMANIMATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsItemAnimation_Type);

    SbkQGraphicsItemAnimation_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQGraphicsItemAnimation_Type.type_discovery = &SbkQGraphicsItemAnimation_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQGraphicsItemAnimation_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsItemAnimation_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsItemAnimation_Type));
    PyModule_AddObject(module, "QGraphicsItemAnimation",
        ((PyObject*)&SbkQGraphicsItemAnimation_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsItemAnimation >("QGraphicsItemAnimation*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsItemAnimation >(typeid(QGraphicsItemAnimation).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsItemAnimation >(typeid(QGraphicsItemAnimationWrapper).name());
    PySide::initQtMetaType<QGraphicsItemAnimation* >();
}

