/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qgraphicsrotation_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmatrix4x4.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvector3d.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsRotationWrapper::QGraphicsRotationWrapper(QObject * parent) : QGraphicsRotation(parent), m_metaObject(0) {
    // ... middle
}

void QGraphicsRotationWrapper::applyTo(QMatrix4x4 * matrix) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "applyTo"));
    if (py_override.isNull()) {
        return this->QGraphicsRotation::applyTo(matrix);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMatrix4x4 * >::toPython(matrix)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsRotationWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsRotationWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsRotationWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsRotationWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGraphicsRotationWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsRotation.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsRotationWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsRotation.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGraphicsRotationWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsRotationWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGraphicsRotation::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGraphicsRotationWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsRotation::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsRotationWrapper::~QGraphicsRotationWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsRotation_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsRotation >()))
        return -1;

    QGraphicsRotationWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QGraphicsRotation", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsRotation(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsRotation(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QGraphicsRotation(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsRotation_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsRotation(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QGraphicsRotation(QObject*)
            cptr = new QGraphicsRotationWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsRotation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsRotation_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGraphicsRotation_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsRotation", overloads);
        return -1;
}

static PyObject* SbkQGraphicsRotationFunc_angle(PyObject* self)
{
    QGraphicsRotation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsRotation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // angle()const
            qreal cppResult = cppSelf->QGraphicsRotation::angle();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsRotationFunc_applyTo(PyObject* self, PyObject* arg)
{
    QGraphicsRotation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsRotation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: applyTo(QMatrix4x4*)const
    if (Shiboken::Converter<QMatrix4x4 * >::isConvertible(arg)) {
        overloadId = 0; // applyTo(QMatrix4x4*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsRotationFunc_applyTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
            QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(arg);
            if (!Shiboken::Converter<QMatrix4x4 >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // applyTo(QMatrix4x4*)const
            cppSelf->QGraphicsRotation::applyTo(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsRotationFunc_applyTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsRotation.applyTo", overloads);
        return 0;
}

static PyObject* SbkQGraphicsRotationFunc_axis(PyObject* self)
{
    QGraphicsRotation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsRotation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // axis()const
            QVector3D cppResult = cppSelf->QGraphicsRotation::axis();
            pyResult = Shiboken::Converter<QVector3D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsRotationFunc_origin(PyObject* self)
{
    QGraphicsRotation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsRotation* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // origin()const
            QVector3D cppResult = cppSelf->QGraphicsRotation::origin();
            pyResult = Shiboken::Converter<QVector3D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsRotationFunc_setAngle(PyObject* self, PyObject* arg)
{
    QGraphicsRotation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsRotation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsRotationFunc_setAngle_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAngle(qreal)
            cppSelf->QGraphicsRotation::setAngle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsRotationFunc_setAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsRotation.setAngle", overloads);
        return 0;
}

static PyObject* SbkQGraphicsRotationFunc_setAxis(PyObject* self, PyObject* arg)
{
    QGraphicsRotation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsRotation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAxis(Qt::Axis)
    // 1: setAxis(QVector3D)
    if (Shiboken::Converter<const QVector3D & >::isConvertible(arg)) {
        overloadId = 1; // setAxis(QVector3D)
    } else if (Shiboken::Converter<Qt::Axis >::isConvertible(arg)) {
        overloadId = 0; // setAxis(Qt::Axis)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsRotationFunc_setAxis_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAxis(Qt::Axis)
            {
                Qt::Axis cpp_arg0 = Shiboken::Converter<Qt::Axis >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setAxis(Qt::Axis)
                cppSelf->QGraphicsRotation::setAxis(cpp_arg0);
                }
                break;
            }
            case 1: // setAxis(QVector3D)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
                QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(arg);
                if (!Shiboken::Converter<QVector3D >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setAxis(QVector3D)
                cppSelf->QGraphicsRotation::setAxis(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsRotationFunc_setAxis_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Axis", "PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsRotation.setAxis", overloads);
        return 0;
}

static PyObject* SbkQGraphicsRotationFunc_setOrigin(PyObject* self, PyObject* arg)
{
    QGraphicsRotation* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsRotation* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOrigin(QVector3D)
    if (Shiboken::Converter<const QVector3D & >::isConvertible(arg)) {
        overloadId = 0; // setOrigin(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsRotationFunc_setOrigin_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
            QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(arg);
            if (!Shiboken::Converter<QVector3D >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setOrigin(QVector3D)
            cppSelf->QGraphicsRotation::setOrigin(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsRotationFunc_setOrigin_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsRotation.setOrigin", overloads);
        return 0;
}

static PyMethodDef SbkQGraphicsRotation_methods[] = {
    {"angle", (PyCFunction)SbkQGraphicsRotationFunc_angle, METH_NOARGS},
    {"applyTo", (PyCFunction)SbkQGraphicsRotationFunc_applyTo, METH_O},
    {"axis", (PyCFunction)SbkQGraphicsRotationFunc_axis, METH_NOARGS},
    {"origin", (PyCFunction)SbkQGraphicsRotationFunc_origin, METH_NOARGS},
    {"setAngle", (PyCFunction)SbkQGraphicsRotationFunc_setAngle, METH_O},
    {"setAxis", (PyCFunction)SbkQGraphicsRotationFunc_setAxis, METH_O},
    {"setOrigin", (PyCFunction)SbkQGraphicsRotationFunc_setOrigin, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsRotation_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsRotation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsRotation_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsRotation_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsRotation >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsRotation*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsRotation_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsRotation*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGraphicsRotation_Type;
    return 0;
}


void init_QGraphicsRotation(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSROTATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsRotation_Type);

    SbkQGraphicsRotation_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSTRANSFORM_IDX];
    // Fill type discovery information
    SbkQGraphicsRotation_Type.type_discovery = &SbkQGraphicsRotation_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSTRANSFORM_IDX]), &SbkQGraphicsRotation_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsRotation_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsRotation_Type));
    PyModule_AddObject(module, "QGraphicsRotation",
        ((PyObject*)&SbkQGraphicsRotation_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("axisChanged", "void", NULL);
    PyDict_SetItemString(SbkQGraphicsRotation_Type.super.ht_type.tp_dict, "axisChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("angleChanged", "void", NULL);
    PyDict_SetItemString(SbkQGraphicsRotation_Type.super.ht_type.tp_dict, "angleChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("originChanged", "void", NULL);
    PyDict_SetItemString(SbkQGraphicsRotation_Type.super.ht_type.tp_dict, "originChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsRotation >("QGraphicsRotation*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsRotation >(typeid(QGraphicsRotation).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsRotation >(typeid(QGraphicsRotationWrapper).name());
    PySide::initQtMetaType<QGraphicsRotation* >();
}

