/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicsscenecontextmenuevent_wrapper.h"

// Extra includes
#include <qgraphicssceneevent.h>
#include <qpoint.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsSceneContextMenuEventWrapper::QGraphicsSceneContextMenuEventWrapper(QEvent::Type type) : QGraphicsSceneContextMenuEvent(type) {
    // ... middle
}

QGraphicsSceneContextMenuEventWrapper::~QGraphicsSceneContextMenuEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsSceneContextMenuEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsSceneContextMenuEvent >()))
        return -1;

    QGraphicsSceneContextMenuEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneContextMenuEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneContextMenuEvent(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QGraphicsSceneContextMenuEvent", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsSceneContextMenuEvent(QEvent::Type)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsSceneContextMenuEvent(QEvent::Type)
    } else if (Shiboken::Converter<QEvent::Type >::isConvertible(arg)) {
        overloadId = 0; // QGraphicsSceneContextMenuEvent(QEvent::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneContextMenuEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (arg)
                        errorArgName = "type";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneContextMenuEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QEvent::Type cpp_arg0 = arg ? Shiboken::Converter<QEvent::Type >::toCpp(arg) : QEvent::None;

            if(!PyErr_Occurred()) {
            // QGraphicsSceneContextMenuEvent(QEvent::Type)
            cptr = new QGraphicsSceneContextMenuEventWrapper(cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsSceneContextMenuEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsSceneContextMenuEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGraphicsSceneContextMenuEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsSceneContextMenuEvent", overloads);
        return -1;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_modifiers(PyObject* self)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // modifiers()const
            QFlags<Qt::KeyboardModifier> cppResult = cppSelf->QGraphicsSceneContextMenuEvent::modifiers();
            pyResult = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_pos(PyObject* self)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            QPointF cppResult = cppSelf->QGraphicsSceneContextMenuEvent::pos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_reason(PyObject* self)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reason()const
            QGraphicsSceneContextMenuEvent::Reason cppResult = cppSelf->QGraphicsSceneContextMenuEvent::reason();
            pyResult = Shiboken::Converter<QGraphicsSceneContextMenuEvent::Reason >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_scenePos(PyObject* self)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scenePos()const
            QPointF cppResult = cppSelf->QGraphicsSceneContextMenuEvent::scenePos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_screenPos(PyObject* self)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // screenPos()const
            QPoint cppResult = cppSelf->QGraphicsSceneContextMenuEvent::screenPos();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_setModifiers(PyObject* self, PyObject* arg)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModifiers(QFlags<Qt::KeyboardModifier>)
    if (Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(arg)) {
        overloadId = 0; // setModifiers(QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneContextMenuEventFunc_setModifiers_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::KeyboardModifier> cpp_arg0 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setModifiers(QFlags<Qt::KeyboardModifier>)
            cppSelf->QGraphicsSceneContextMenuEvent::setModifiers(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneContextMenuEventFunc_setModifiers_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneContextMenuEvent.setModifiers", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_setPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneContextMenuEventFunc_setPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPos(QPointF)
            cppSelf->QGraphicsSceneContextMenuEvent::setPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneContextMenuEventFunc_setPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneContextMenuEvent.setPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_setReason(PyObject* self, PyObject* arg)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReason(QGraphicsSceneContextMenuEvent::Reason)
    if (Shiboken::Converter<QGraphicsSceneContextMenuEvent::Reason >::isConvertible(arg)) {
        overloadId = 0; // setReason(QGraphicsSceneContextMenuEvent::Reason)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneContextMenuEventFunc_setReason_TypeError;

    // Call function/method
    {
        {
            QGraphicsSceneContextMenuEvent::Reason cpp_arg0 = Shiboken::Converter<QGraphicsSceneContextMenuEvent::Reason >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setReason(QGraphicsSceneContextMenuEvent::Reason)
            cppSelf->QGraphicsSceneContextMenuEvent::setReason(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneContextMenuEventFunc_setReason_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneContextMenuEvent.Reason", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneContextMenuEvent.setReason", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_setScenePos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScenePos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setScenePos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneContextMenuEventFunc_setScenePos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setScenePos(QPointF)
            cppSelf->QGraphicsSceneContextMenuEvent::setScenePos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneContextMenuEventFunc_setScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneContextMenuEvent.setScenePos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneContextMenuEventFunc_setScreenPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneContextMenuEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScreenPos(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setScreenPos(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneContextMenuEventFunc_setScreenPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScreenPos(QPoint)
            cppSelf->QGraphicsSceneContextMenuEvent::setScreenPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneContextMenuEventFunc_setScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneContextMenuEvent.setScreenPos", overloads);
        return 0;
}

static PyMethodDef SbkQGraphicsSceneContextMenuEvent_methods[] = {
    {"modifiers", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_modifiers, METH_NOARGS},
    {"pos", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_pos, METH_NOARGS},
    {"reason", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_reason, METH_NOARGS},
    {"scenePos", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_scenePos, METH_NOARGS},
    {"screenPos", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_screenPos, METH_NOARGS},
    {"setModifiers", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_setModifiers, METH_O},
    {"setPos", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_setPos, METH_O},
    {"setReason", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_setReason, METH_O},
    {"setScenePos", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_setScenePos, METH_O},
    {"setScreenPos", (PyCFunction)SbkQGraphicsSceneContextMenuEventFunc_setScreenPos, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsSceneContextMenuEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsSceneContextMenuEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsSceneContextMenuEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsSceneContextMenuEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsSceneContextMenuEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsSceneContextMenuEvent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsSceneContextMenuEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
     if ( reinterpret_cast<QGraphicsSceneContextMenuEvent*>(cptr)->type() == QEvent::GraphicsSceneContextMenu)
        return &SbkQGraphicsSceneContextMenuEvent_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Reason",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QGraphicsSceneContextMenuEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENECONTEXTMENUEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsSceneContextMenuEvent_Type);

    SbkQGraphicsSceneContextMenuEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX];
    // Fill type discovery information
    SbkQGraphicsSceneContextMenuEvent_Type.type_discovery = &SbkQGraphicsSceneContextMenuEvent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX]), &SbkQGraphicsSceneContextMenuEvent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsSceneContextMenuEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsSceneContextMenuEvent_Type));
    PyModule_AddObject(module, "QGraphicsSceneContextMenuEvent",
        ((PyObject*)&SbkQGraphicsSceneContextMenuEvent_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Reason
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENECONTEXTMENUEVENT_REASON_IDX] = &SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type);
    PyDict_SetItemString(SbkQGraphicsSceneContextMenuEvent_Type.super.ht_type.tp_dict,
            "Reason",((PyObject*)&SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type,
        (long) QGraphicsSceneContextMenuEvent::Mouse, "Mouse");
    PyDict_SetItemString(SbkQGraphicsSceneContextMenuEvent_Type.super.ht_type.tp_dict,
        "Mouse", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type.tp_dict,
        "Mouse", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type,
        (long) QGraphicsSceneContextMenuEvent::Keyboard, "Keyboard");
    PyDict_SetItemString(SbkQGraphicsSceneContextMenuEvent_Type.super.ht_type.tp_dict,
        "Keyboard", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type.tp_dict,
        "Keyboard", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type,
        (long) QGraphicsSceneContextMenuEvent::Other, "Other");
    PyDict_SetItemString(SbkQGraphicsSceneContextMenuEvent_Type.super.ht_type.tp_dict,
        "Other", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsSceneContextMenuEvent_Reason_Type.tp_dict,
        "Other", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsSceneContextMenuEvent::Reason");


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneContextMenuEvent >("QGraphicsSceneContextMenuEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneContextMenuEvent >(typeid(QGraphicsSceneContextMenuEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneContextMenuEvent >(typeid(QGraphicsSceneContextMenuEventWrapper).name());
    PySide::initQtMetaType<QGraphicsSceneContextMenuEvent* >();
}

