/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicsscenemouseevent_wrapper.h"

// Extra includes
#include <qgraphicssceneevent.h>
#include <qpoint.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsSceneMouseEventWrapper::QGraphicsSceneMouseEventWrapper(QEvent::Type type) : QGraphicsSceneMouseEvent(type) {
    // ... middle
}

QGraphicsSceneMouseEventWrapper::~QGraphicsSceneMouseEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsSceneMouseEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsSceneMouseEvent >()))
        return -1;

    QGraphicsSceneMouseEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneMouseEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneMouseEvent(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QGraphicsSceneMouseEvent", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsSceneMouseEvent(QEvent::Type)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsSceneMouseEvent(QEvent::Type)
    } else if (Shiboken::Converter<QEvent::Type >::isConvertible(arg)) {
        overloadId = 0; // QGraphicsSceneMouseEvent(QEvent::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (arg)
                        errorArgName = "type";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneMouseEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QEvent::Type cpp_arg0 = arg ? Shiboken::Converter<QEvent::Type >::toCpp(arg) : QEvent::None;

            if(!PyErr_Occurred()) {
            // QGraphicsSceneMouseEvent(QEvent::Type)
            cptr = new QGraphicsSceneMouseEventWrapper(cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsSceneMouseEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsSceneMouseEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGraphicsSceneMouseEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsSceneMouseEvent", overloads);
        return -1;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_button(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // button()const
            Qt::MouseButton cppResult = cppSelf->QGraphicsSceneMouseEvent::button();
            pyResult = Shiboken::Converter<Qt::MouseButton >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_buttonDownPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: buttonDownPos(Qt::MouseButton)const
    if (Shiboken::Converter<Qt::MouseButton >::isConvertible(arg)) {
        overloadId = 0; // buttonDownPos(Qt::MouseButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_buttonDownPos_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // buttonDownPos(Qt::MouseButton)const
            QPointF cppResult = cppSelf->QGraphicsSceneMouseEvent::buttonDownPos(cpp_arg0);
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneMouseEventFunc_buttonDownPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.buttonDownPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_buttonDownScenePos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: buttonDownScenePos(Qt::MouseButton)const
    if (Shiboken::Converter<Qt::MouseButton >::isConvertible(arg)) {
        overloadId = 0; // buttonDownScenePos(Qt::MouseButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_buttonDownScenePos_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // buttonDownScenePos(Qt::MouseButton)const
            QPointF cppResult = cppSelf->QGraphicsSceneMouseEvent::buttonDownScenePos(cpp_arg0);
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneMouseEventFunc_buttonDownScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.buttonDownScenePos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_buttonDownScreenPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: buttonDownScreenPos(Qt::MouseButton)const
    if (Shiboken::Converter<Qt::MouseButton >::isConvertible(arg)) {
        overloadId = 0; // buttonDownScreenPos(Qt::MouseButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_buttonDownScreenPos_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // buttonDownScreenPos(Qt::MouseButton)const
            QPoint cppResult = cppSelf->QGraphicsSceneMouseEvent::buttonDownScreenPos(cpp_arg0);
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneMouseEventFunc_buttonDownScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.buttonDownScreenPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_buttons(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // buttons()const
            QFlags<Qt::MouseButton> cppResult = cppSelf->QGraphicsSceneMouseEvent::buttons();
            pyResult = Shiboken::Converter<QFlags<Qt::MouseButton> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_lastPos(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastPos()const
            QPointF cppResult = cppSelf->QGraphicsSceneMouseEvent::lastPos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_lastScenePos(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastScenePos()const
            QPointF cppResult = cppSelf->QGraphicsSceneMouseEvent::lastScenePos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_lastScreenPos(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastScreenPos()const
            QPoint cppResult = cppSelf->QGraphicsSceneMouseEvent::lastScreenPos();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_modifiers(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // modifiers()const
            QFlags<Qt::KeyboardModifier> cppResult = cppSelf->QGraphicsSceneMouseEvent::modifiers();
            pyResult = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_pos(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            QPointF cppResult = cppSelf->QGraphicsSceneMouseEvent::pos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_scenePos(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scenePos()const
            QPointF cppResult = cppSelf->QGraphicsSceneMouseEvent::scenePos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_screenPos(PyObject* self)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // screenPos()const
            QPoint cppResult = cppSelf->QGraphicsSceneMouseEvent::screenPos();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setButton(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setButton(Qt::MouseButton)
    if (Shiboken::Converter<Qt::MouseButton >::isConvertible(arg)) {
        overloadId = 0; // setButton(Qt::MouseButton)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setButton_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setButton(Qt::MouseButton)
            cppSelf->QGraphicsSceneMouseEvent::setButton(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setButton_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setButton", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setButtonDownPos(PyObject* self, PyObject* args)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setButtonDownPos", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setButtonDownPos(Qt::MouseButton,QPointF)
    if (numArgs == 2 && Shiboken::Converter<Qt::MouseButton >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setButtonDownPos(Qt::MouseButton,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setButtonDownPos_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
            QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setButtonDownPos(Qt::MouseButton,QPointF)
            cppSelf->QGraphicsSceneMouseEvent::setButtonDownPos(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setButtonDownPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsSceneMouseEvent.setButtonDownPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setButtonDownScenePos(PyObject* self, PyObject* args)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setButtonDownScenePos", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setButtonDownScenePos(Qt::MouseButton,QPointF)
    if (numArgs == 2 && Shiboken::Converter<Qt::MouseButton >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setButtonDownScenePos(Qt::MouseButton,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setButtonDownScenePos_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
            QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setButtonDownScenePos(Qt::MouseButton,QPointF)
            cppSelf->QGraphicsSceneMouseEvent::setButtonDownScenePos(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setButtonDownScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsSceneMouseEvent.setButtonDownScenePos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setButtonDownScreenPos(PyObject* self, PyObject* args)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setButtonDownScreenPos", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setButtonDownScreenPos(Qt::MouseButton,QPoint)
    if (numArgs == 2 && Shiboken::Converter<Qt::MouseButton >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setButtonDownScreenPos(Qt::MouseButton,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setButtonDownScreenPos_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setButtonDownScreenPos(Qt::MouseButton,QPoint)
            cppSelf->QGraphicsSceneMouseEvent::setButtonDownScreenPos(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setButtonDownScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsSceneMouseEvent.setButtonDownScreenPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setButtons(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setButtons(QFlags<Qt::MouseButton>)
    if (Shiboken::Converter<QFlags<Qt::MouseButton> >::isConvertible(arg)) {
        overloadId = 0; // setButtons(QFlags<Qt::MouseButton>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setButtons_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::MouseButton> cpp_arg0 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setButtons(QFlags<Qt::MouseButton>)
            cppSelf->QGraphicsSceneMouseEvent::setButtons(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setButtons_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButtons", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setButtons", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setLastPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastPos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setLastPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setLastPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setLastPos(QPointF)
            cppSelf->QGraphicsSceneMouseEvent::setLastPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setLastPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setLastPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setLastScenePos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastScenePos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setLastScenePos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setLastScenePos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setLastScenePos(QPointF)
            cppSelf->QGraphicsSceneMouseEvent::setLastScenePos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setLastScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setLastScenePos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setLastScreenPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastScreenPos(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setLastScreenPos(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setLastScreenPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLastScreenPos(QPoint)
            cppSelf->QGraphicsSceneMouseEvent::setLastScreenPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setLastScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setLastScreenPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setModifiers(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModifiers(QFlags<Qt::KeyboardModifier>)
    if (Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(arg)) {
        overloadId = 0; // setModifiers(QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setModifiers_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::KeyboardModifier> cpp_arg0 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setModifiers(QFlags<Qt::KeyboardModifier>)
            cppSelf->QGraphicsSceneMouseEvent::setModifiers(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setModifiers_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setModifiers", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPos(QPointF)
            cppSelf->QGraphicsSceneMouseEvent::setPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setScenePos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScenePos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setScenePos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setScenePos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setScenePos(QPointF)
            cppSelf->QGraphicsSceneMouseEvent::setScenePos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setScenePos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMouseEventFunc_setScreenPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMouseEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScreenPos(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setScreenPos(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMouseEventFunc_setScreenPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScreenPos(QPoint)
            cppSelf->QGraphicsSceneMouseEvent::setScreenPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMouseEventFunc_setScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMouseEvent.setScreenPos", overloads);
        return 0;
}

static PyMethodDef SbkQGraphicsSceneMouseEvent_methods[] = {
    {"button", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_button, METH_NOARGS},
    {"buttonDownPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_buttonDownPos, METH_O},
    {"buttonDownScenePos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_buttonDownScenePos, METH_O},
    {"buttonDownScreenPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_buttonDownScreenPos, METH_O},
    {"buttons", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_buttons, METH_NOARGS},
    {"lastPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_lastPos, METH_NOARGS},
    {"lastScenePos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_lastScenePos, METH_NOARGS},
    {"lastScreenPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_lastScreenPos, METH_NOARGS},
    {"modifiers", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_modifiers, METH_NOARGS},
    {"pos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_pos, METH_NOARGS},
    {"scenePos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_scenePos, METH_NOARGS},
    {"screenPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_screenPos, METH_NOARGS},
    {"setButton", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setButton, METH_O},
    {"setButtonDownPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setButtonDownPos, METH_VARARGS},
    {"setButtonDownScenePos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setButtonDownScenePos, METH_VARARGS},
    {"setButtonDownScreenPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setButtonDownScreenPos, METH_VARARGS},
    {"setButtons", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setButtons, METH_O},
    {"setLastPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setLastPos, METH_O},
    {"setLastScenePos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setLastScenePos, METH_O},
    {"setLastScreenPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setLastScreenPos, METH_O},
    {"setModifiers", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setModifiers, METH_O},
    {"setPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setPos, METH_O},
    {"setScenePos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setScenePos, METH_O},
    {"setScreenPos", (PyCFunction)SbkQGraphicsSceneMouseEventFunc_setScreenPos, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsSceneMouseEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsSceneMouseEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsSceneMouseEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsSceneMouseEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsSceneMouseEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsSceneMouseEvent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsSceneMouseEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
     if ( reinterpret_cast<QGraphicsSceneMouseEvent*>(cptr)->type() == QEvent::GraphicsSceneMouseDoubleClick ||  reinterpret_cast<QGraphicsSceneMouseEvent*>(cptr)->type() == QEvent::GraphicsSceneMouseMove ||  reinterpret_cast<QGraphicsSceneMouseEvent*>(cptr)->type() == QEvent::GraphicsSceneMousePress ||  reinterpret_cast<QGraphicsSceneMouseEvent*>(cptr)->type() == QEvent::GraphicsSceneMouseRelease)
        return &SbkQGraphicsSceneMouseEvent_Type;
    return 0;
}


void init_QGraphicsSceneMouseEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEMOUSEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsSceneMouseEvent_Type);

    SbkQGraphicsSceneMouseEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX];
    // Fill type discovery information
    SbkQGraphicsSceneMouseEvent_Type.type_discovery = &SbkQGraphicsSceneMouseEvent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX]), &SbkQGraphicsSceneMouseEvent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsSceneMouseEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsSceneMouseEvent_Type));
    PyModule_AddObject(module, "QGraphicsSceneMouseEvent",
        ((PyObject*)&SbkQGraphicsSceneMouseEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMouseEvent >("QGraphicsSceneMouseEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMouseEvent >(typeid(QGraphicsSceneMouseEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMouseEvent >(typeid(QGraphicsSceneMouseEventWrapper).name());
    PySide::initQtMetaType<QGraphicsSceneMouseEvent* >();
}

