/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicsscenemoveevent_wrapper.h"

// Extra includes
#include <qgraphicssceneevent.h>
#include <qpoint.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsSceneMoveEventWrapper::QGraphicsSceneMoveEventWrapper() : QGraphicsSceneMoveEvent() {
    // ... middle
}

QGraphicsSceneMoveEventWrapper::~QGraphicsSceneMoveEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsSceneMoveEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsSceneMoveEvent >()))
        return -1;

    QGraphicsSceneMoveEventWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QGraphicsSceneMoveEvent()
            cptr = new QGraphicsSceneMoveEventWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsSceneMoveEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQGraphicsSceneMoveEventFunc_newPos(PyObject* self)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMoveEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // newPos()const
            QPointF cppResult = cppSelf->QGraphicsSceneMoveEvent::newPos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMoveEventFunc_oldPos(PyObject* self)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMoveEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // oldPos()const
            QPointF cppResult = cppSelf->QGraphicsSceneMoveEvent::oldPos();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneMoveEventFunc_setNewPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMoveEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNewPos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setNewPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMoveEventFunc_setNewPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setNewPos(QPointF)
            cppSelf->QGraphicsSceneMoveEvent::setNewPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMoveEventFunc_setNewPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMoveEvent.setNewPos", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneMoveEventFunc_setOldPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsSceneMoveEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOldPos(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setOldPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneMoveEventFunc_setOldPos_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setOldPos(QPointF)
            cppSelf->QGraphicsSceneMoveEvent::setOldPos(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneMoveEventFunc_setOldPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMoveEvent.setOldPos", overloads);
        return 0;
}

static PyMethodDef SbkQGraphicsSceneMoveEvent_methods[] = {
    {"newPos", (PyCFunction)SbkQGraphicsSceneMoveEventFunc_newPos, METH_NOARGS},
    {"oldPos", (PyCFunction)SbkQGraphicsSceneMoveEventFunc_oldPos, METH_NOARGS},
    {"setNewPos", (PyCFunction)SbkQGraphicsSceneMoveEventFunc_setNewPos, METH_O},
    {"setOldPos", (PyCFunction)SbkQGraphicsSceneMoveEventFunc_setOldPos, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsSceneMoveEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsSceneMoveEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsSceneMoveEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsSceneMoveEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsSceneMoveEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsSceneMoveEvent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsSceneMoveEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
     if ( reinterpret_cast<QGraphicsSceneMoveEvent*>(cptr)->type() == QEvent::GraphicsSceneMove)
        return &SbkQGraphicsSceneMoveEvent_Type;
    return 0;
}


void init_QGraphicsSceneMoveEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEMOVEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsSceneMoveEvent_Type);

    SbkQGraphicsSceneMoveEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX];
    // Fill type discovery information
    SbkQGraphicsSceneMoveEvent_Type.type_discovery = &SbkQGraphicsSceneMoveEvent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX]), &SbkQGraphicsSceneMoveEvent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsSceneMoveEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsSceneMoveEvent_Type));
    PyModule_AddObject(module, "QGraphicsSceneMoveEvent",
        ((PyObject*)&SbkQGraphicsSceneMoveEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMoveEvent >("QGraphicsSceneMoveEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMoveEvent >(typeid(QGraphicsSceneMoveEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMoveEvent >(typeid(QGraphicsSceneMoveEventWrapper).name());
    PySide::initQtMetaType<QGraphicsSceneMoveEvent* >();
}

