/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qgridlayout_wrapper.h"

// Extra includes
#include "glue/qlayout_help_functions.h"
#include <qcoreevent.h>
#include <qgridlayout.h>
#include <qlayout.h>
#include <qlayoutitem.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qsize.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGridLayoutWrapper::QGridLayoutWrapper() : QGridLayout(), m_metaObject(0) {
    // ... middle
}

QGridLayoutWrapper::QGridLayoutWrapper(QWidget * parent) : QGridLayout(parent), m_metaObject(0) {
    // ... middle
}

void QGridLayoutWrapper::addItem(QLayoutItem * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "addItem"));
    if (py_override.isNull()) {

        return this->QGridLayout::addItem(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QLayoutItem * >::toPython(arg__1)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));

}

void QGridLayoutWrapper::childEvent(QChildEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QLayout::childEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGridLayoutWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QGridLayoutWrapper::count() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "count"));
    if (py_override.isNull()) {
        return this->QGridLayout::count();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.count", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QGridLayoutWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGridLayoutWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGridLayoutWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QGridLayoutWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QFlags<Qt::Orientation> QGridLayoutWrapper::expandingDirections() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "expandingDirections"));
    if (py_override.isNull()) {
        return this->QGridLayout::expandingDirections();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::Orientation>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QFlags<Qt::Orientation> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.expandingDirections", SbkType<QFlags<Qt::Orientation> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::Orientation>();
    }
    QFlags<Qt::Orientation> cppResult(Shiboken::Converter<QFlags<Qt::Orientation> >::toCpp(pyResult));
    return cppResult;
}

QRect QGridLayoutWrapper::geometry() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "geometry"));
    if (py_override.isNull()) {
        return this->QLayout::geometry();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.geometry", SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter<QRect >::toCpp(pyResult));
    return cppResult;
}

bool QGridLayoutWrapper::hasHeightForWidth() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasHeightForWidth"));
    if (py_override.isNull()) {
        return this->QGridLayout::hasHeightForWidth();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.hasHeightForWidth", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

int QGridLayoutWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QGridLayout::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QGridLayoutWrapper::indexOf(QWidget * arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "indexOf"));
    if (py_override.isNull()) {
        return this->QLayout::indexOf(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWidget * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.indexOf", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QGridLayoutWrapper::invalidate()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "invalidate"));
    if (py_override.isNull()) {
        return this->QGridLayout::invalidate();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGridLayoutWrapper::isEmpty() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isEmpty"));
    if (py_override.isNull()) {
        return this->QLayout::isEmpty();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.isEmpty", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QLayoutItem * QGridLayoutWrapper::itemAt(int index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "itemAt"));
    if (py_override.isNull()) {

        return this->QGridLayout::itemAt(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.itemAt", SbkType<QLayoutItem * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter<QLayoutItem * >::toCpp(pyResult));

    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QGridLayout.itemAt");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QLayout * QGridLayoutWrapper::layout()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "layout"));
    if (py_override.isNull()) {
        return this->QLayout::layout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QLayout * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.layout", SbkType<QLayout * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayout * cppResult(Shiboken::Converter<QLayout * >::toCpp(pyResult));
    return cppResult;
}

QSize QGridLayoutWrapper::maximumSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "maximumSize"));
    if (py_override.isNull()) {
        return this->QGridLayout::maximumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.maximumSize", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

int QGridLayoutWrapper::minimumHeightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumHeightForWidth"));
    if (py_override.isNull()) {
        return this->QGridLayout::minimumHeightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.minimumHeightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QGridLayoutWrapper::minimumSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSize"));
    if (py_override.isNull()) {
        return this->QGridLayout::minimumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.minimumSize", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QGridLayoutWrapper::setGeometry(const QRect & arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setGeometry"));
    if (py_override.isNull()) {
        return this->QGridLayout::setGeometry(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QRect & >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QSize QGridLayoutWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QGridLayout::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

QSpacerItem * QGridLayoutWrapper::spacerItem()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "spacerItem"));
    if (py_override.isNull()) {
        return this->QLayoutItem::spacerItem();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSpacerItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.spacerItem", SbkType<QSpacerItem * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QSpacerItem * cppResult(Shiboken::Converter<QSpacerItem * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QGridLayout.spacerItem");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QLayoutItem * QGridLayoutWrapper::takeAt(int index)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "takeAt"));
    if (py_override.isNull()) {
        return this->QGridLayout::takeAt(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.takeAt", SbkType<QLayoutItem * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter<QLayoutItem * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QGridLayout.takeAt");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QGridLayoutWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QWidget * QGridLayoutWrapper::widget()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "widget"));
    if (py_override.isNull()) {
        return this->QLayoutItem::widget();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QWidget * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGridLayout.widget", SbkType<QWidget * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QWidget * cppResult(Shiboken::Converter<QWidget * >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QGridLayoutWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGridLayout::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGridLayoutWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGridLayout::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGridLayoutWrapper::~QGridLayoutWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGridLayout_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGridLayout >()))
        return -1;

    QGridLayoutWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGridLayout", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGridLayout()
    // 1: QGridLayout(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QGridLayout()
    } else if (numArgs == 1 && Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 1; // QGridLayout(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayout_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGridLayout()
            {

                if(!PyErr_Occurred()) {
                // QGridLayout()
                cptr = new QGridLayoutWrapper();
                }
                break;
            }
            case 1: // QGridLayout(QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QGridLayout(QWidget*)
                cptr = new QGridLayoutWrapper(cpp_arg0);
                Shiboken::setParent(arg, self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGridLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGridLayout_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGridLayout_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout", overloads);
        return -1;
}

static PyObject* SbkQGridLayoutFunc_addItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "alignment", "columnSpan", "rowSpan" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addItem(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGridLayout.addItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGridLayout.addItem(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto SbkQGridLayoutFunc_addItem_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOO:addItem", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addItem(QLayoutItem*)
    // 1: addItem(QLayoutItem*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter<QLayoutItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addItem(QLayoutItem*)
        } else if (numArgs >= 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // addItem(QLayoutItem*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
            } else if (SbkNumber_Check(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 1; // addItem(QLayoutItem*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                } else if (SbkNumber_Check(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 1; // addItem(QLayoutItem*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                    } else if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[5])) {
                        overloadId = 1; // addItem(QLayoutItem*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_addItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addItem(QLayoutItem*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QLayoutItem* cpp_arg0 = Shiboken::Converter<QLayoutItem* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addItem(QLayoutItem*)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cpp_arg0);
                
                // End of code injection

                cppSelf->QGridLayout::addItem(cpp_arg0);

                }
                break;
            }
            case 1: // addItem(QLayoutItem*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rowSpan");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "rowSpan";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "columnSpan");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "columnSpan";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "alignment";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addItem(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QLayoutItem* cpp_arg0 = Shiboken::Converter<QLayoutItem* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 1;
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 1;
                QFlags<Qt::AlignmentFlag> cpp_arg5 = pyargs[5] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[5]) : QFlags<Qt::AlignmentFlag>(0);

                if(!PyErr_Occurred()) {
                // addItem(QLayoutItem*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cpp_arg0);
                
                // End of code injection

                cppSelf->QGridLayout::addItem(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);

                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_addItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayoutItem", "PySide.QtGui.QLayoutItem, int, int, int = 1, int = 1, PySide.QtCore.Qt.Alignment = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.addItem", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_addLayout(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "alignment" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addLayout(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGridLayout.addLayout(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGridLayout.addLayout(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:addLayout", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addLayout(QLayout*,int,int,QFlags<Qt::AlignmentFlag>)
    // 1: addLayout(QLayout*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
    if (numArgs >= 3 && Shiboken::Converter<QLayout * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // addLayout(QLayout*,int,int,QFlags<Qt::AlignmentFlag>)
        } else if (numArgs >= 5 && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // addLayout(QLayout*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[5])) {
                overloadId = 1; // addLayout(QLayout*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
            }
        } else if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[3])) {
            overloadId = 0; // addLayout(QLayout*,int,int,QFlags<Qt::AlignmentFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_addLayout_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addLayout(QLayout*,int,int,QFlags<Qt::AlignmentFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "alignment";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addLayout(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QLayout* cpp_arg0 = Shiboken::Converter<QLayout* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QFlags<Qt::AlignmentFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[3]) : QFlags<Qt::AlignmentFlag>(0);

                if(!PyErr_Occurred()) {
                // addLayout(QLayout*,int,int,QFlags<Qt::AlignmentFlag>)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cpp_arg0);
                
                // End of code injection

                cppSelf->QGridLayout::addLayout(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);

                }
                break;
            }
            case 1: // addLayout(QLayout*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "alignment";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addLayout(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QLayout* cpp_arg0 = Shiboken::Converter<QLayout* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QFlags<Qt::AlignmentFlag> cpp_arg5 = pyargs[5] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[5]) : QFlags<Qt::AlignmentFlag>(0);

                if(!PyErr_Occurred()) {
                // addLayout(QLayout*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cpp_arg0);
                
                // End of code injection

                cppSelf->QGridLayout::addLayout(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);

                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_addLayout_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout, int, int, PySide.QtCore.Qt.Alignment = 0", "PySide.QtGui.QLayout, int, int, int, int, PySide.QtCore.Qt.Alignment = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.addLayout", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_addWidget(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "alignment" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addWidget(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGridLayout.addWidget(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGridLayout.addWidget(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto SbkQGridLayoutFunc_addWidget_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOO:addWidget", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addWidget(QWidget*,int,int,QFlags<Qt::AlignmentFlag>)
    // 1: addWidget(QWidget*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
    // 2: addWidget(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // addWidget(QWidget*)
        } else if (numArgs >= 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // addWidget(QWidget*,int,int,QFlags<Qt::AlignmentFlag>)
            } else if (numArgs >= 5 && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 1; // addWidget(QWidget*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                } else if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[5])) {
                    overloadId = 1; // addWidget(QWidget*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                }
            } else if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[3])) {
                overloadId = 0; // addWidget(QWidget*,int,int,QFlags<Qt::AlignmentFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_addWidget_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addWidget(QWidget*,int,int,QFlags<Qt::AlignmentFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "alignment";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addWidget(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QFlags<Qt::AlignmentFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[3]) : QFlags<Qt::AlignmentFlag>(0);

                if(!PyErr_Occurred()) {
                // addWidget(QWidget*,int,int,QFlags<Qt::AlignmentFlag>)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cpp_arg0);
                
                // End of code injection

                cppSelf->QGridLayout::addWidget(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);

                }
                break;
            }
            case 1: // addWidget(QWidget*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "alignment";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGridLayout.addWidget(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QFlags<Qt::AlignmentFlag> cpp_arg5 = pyargs[5] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[5]) : QFlags<Qt::AlignmentFlag>(0);

                if(!PyErr_Occurred()) {
                // addWidget(QWidget*,int,int,int,int,QFlags<Qt::AlignmentFlag>)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cpp_arg0);
                
                // End of code injection

                cppSelf->QGridLayout::addWidget(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);

                }
                break;
            }
            case 2: // addWidget(QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addWidget(QWidget*)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cpp_arg0);
                
                // End of code injection

                cppSelf->QGridLayout::addWidget(cpp_arg0);

                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_addWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, int, int, PySide.QtCore.Qt.Alignment = 0", "PySide.QtGui.QWidget, int, int, int, int, PySide.QtCore.Qt.Alignment = 0", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.addWidget", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_cellRect(PyObject* self, PyObject* args)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "cellRect", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: cellRect(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // cellRect(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_cellRect_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // cellRect(int,int)const
            QRect cppResult = cppSelf->QGridLayout::cellRect(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_cellRect_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.cellRect", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_columnCount(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columnCount()const
            int cppResult = cppSelf->QGridLayout::columnCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_columnMinimumWidth(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: columnMinimumWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // columnMinimumWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_columnMinimumWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // columnMinimumWidth(int)const
            int cppResult = cppSelf->QGridLayout::columnMinimumWidth(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_columnMinimumWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.columnMinimumWidth", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_columnStretch(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: columnStretch(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // columnStretch(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_columnStretch_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // columnStretch(int)const
            int cppResult = cppSelf->QGridLayout::columnStretch(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_columnStretch_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.columnStretch", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_count(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // count()const
            int cppResult = cppSelf->QGridLayout::count();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_expandingDirections(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // expandingDirections()const
            QFlags<Qt::Orientation> cppResult = cppSelf->QGridLayout::expandingDirections();
            pyResult = Shiboken::Converter<QFlags<Qt::Orientation> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_hasHeightForWidth(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasHeightForWidth()const
            bool cppResult = cppSelf->QGridLayout::hasHeightForWidth();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_heightForWidth(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: heightForWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // heightForWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_heightForWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // heightForWidth(int)const
            int cppResult = cppSelf->QGridLayout::heightForWidth(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_heightForWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.heightForWidth", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_horizontalSpacing(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // horizontalSpacing()const
            int cppResult = cppSelf->QGridLayout::horizontalSpacing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_invalidate(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // invalidate()
            cppSelf->QGridLayout::invalidate();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGridLayoutFunc_itemAt(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // itemAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_itemAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // itemAt(int)const

            QLayoutItem * cppResult = cppSelf->QGridLayout::itemAt(cpp_arg0);
            pyResult = Shiboken::Converter<QLayoutItem * >::toPython(cppResult);

            // Begin code injection
            
            addLayoutOwnership(cppSelf, cppResult);
            
            // End of code injection

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_itemAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.itemAt", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_itemAtPosition(PyObject* self, PyObject* args)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAtPosition", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemAtPosition(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // itemAtPosition(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_itemAtPosition_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // itemAtPosition(int,int)const
            QLayoutItem * cppResult = cppSelf->QGridLayout::itemAtPosition(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QLayoutItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_itemAtPosition_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.itemAtPosition", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_maximumSize(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumSize()const
            QSize cppResult = cppSelf->QGridLayout::maximumSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_minimumHeightForWidth(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: minimumHeightForWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // minimumHeightForWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_minimumHeightForWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // minimumHeightForWidth(int)const
            int cppResult = cppSelf->QGridLayout::minimumHeightForWidth(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_minimumHeightForWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.minimumHeightForWidth", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_minimumSize(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumSize()const
            QSize cppResult = cppSelf->QGridLayout::minimumSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_originCorner(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // originCorner()const
            Qt::Corner cppResult = cppSelf->QGridLayout::originCorner();
            pyResult = Shiboken::Converter<Qt::Corner >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_rowCount(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rowCount()const
            int cppResult = cppSelf->QGridLayout::rowCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_rowMinimumHeight(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rowMinimumHeight(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rowMinimumHeight(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_rowMinimumHeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rowMinimumHeight(int)const
            int cppResult = cppSelf->QGridLayout::rowMinimumHeight(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_rowMinimumHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.rowMinimumHeight", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_rowStretch(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rowStretch(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rowStretch(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_rowStretch_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rowStretch(int)const
            int cppResult = cppSelf->QGridLayout::rowStretch(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_rowStretch_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.rowStretch", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setColumnMinimumWidth(PyObject* self, PyObject* args)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColumnMinimumWidth", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setColumnMinimumWidth(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setColumnMinimumWidth(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setColumnMinimumWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setColumnMinimumWidth(int,int)
            cppSelf->QGridLayout::setColumnMinimumWidth(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setColumnMinimumWidth_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.setColumnMinimumWidth", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setColumnStretch(PyObject* self, PyObject* args)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColumnStretch", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setColumnStretch(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setColumnStretch(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setColumnStretch_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setColumnStretch(int,int)
            cppSelf->QGridLayout::setColumnStretch(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setColumnStretch_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.setColumnStretch", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setDefaultPositioning(PyObject* self, PyObject* args)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDefaultPositioning", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setDefaultPositioning(int,Qt::Orientation)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<Qt::Orientation >::isConvertible(pyargs[1])) {
        overloadId = 0; // setDefaultPositioning(int,Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setDefaultPositioning_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::Orientation cpp_arg1 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setDefaultPositioning(int,Qt::Orientation)
            cppSelf->QGridLayout::setDefaultPositioning(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setDefaultPositioning_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.setDefaultPositioning", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setGeometry(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometry(QRect)
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setGeometry_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGeometry(QRect)
            cppSelf->QGridLayout::setGeometry(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.setGeometry", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setHorizontalSpacing(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHorizontalSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setHorizontalSpacing_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHorizontalSpacing(int)
            cppSelf->QGridLayout::setHorizontalSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setHorizontalSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.setHorizontalSpacing", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setOriginCorner(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOriginCorner(Qt::Corner)
    if (Shiboken::Converter<Qt::Corner >::isConvertible(arg)) {
        overloadId = 0; // setOriginCorner(Qt::Corner)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setOriginCorner_TypeError;

    // Call function/method
    {
        {
            Qt::Corner cpp_arg0 = Shiboken::Converter<Qt::Corner >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOriginCorner(Qt::Corner)
            cppSelf->QGridLayout::setOriginCorner(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setOriginCorner_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Corner", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.setOriginCorner", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setRowMinimumHeight(PyObject* self, PyObject* args)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRowMinimumHeight", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRowMinimumHeight(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setRowMinimumHeight(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setRowMinimumHeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setRowMinimumHeight(int,int)
            cppSelf->QGridLayout::setRowMinimumHeight(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setRowMinimumHeight_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.setRowMinimumHeight", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setRowStretch(PyObject* self, PyObject* args)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRowStretch", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRowStretch(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setRowStretch(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setRowStretch_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setRowStretch(int,int)
            cppSelf->QGridLayout::setRowStretch(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setRowStretch_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGridLayout.setRowStretch", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setSpacing(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setSpacing_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSpacing(int)
            cppSelf->QGridLayout::setSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.setSpacing", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_setVerticalSpacing(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVerticalSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_setVerticalSpacing_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVerticalSpacing(int)
            cppSelf->QGridLayout::setVerticalSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGridLayoutFunc_setVerticalSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.setVerticalSpacing", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_sizeHint(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizeHint()const
            QSize cppResult = cppSelf->QGridLayout::sizeHint();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_spacing(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // spacing()const
            int cppResult = cppSelf->QGridLayout::spacing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGridLayoutFunc_takeAt(PyObject* self, PyObject* arg)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeAt(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGridLayoutFunc_takeAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // takeAt(int)
            QLayoutItem * cppResult = cppSelf->QGridLayout::takeAt(cpp_arg0);
            pyResult = Shiboken::Converter<QLayoutItem * >::toPython(cppResult);
            Shiboken::setParent(Py_None, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGridLayoutFunc_takeAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGridLayout.takeAt", overloads);
        return 0;
}

static PyObject* SbkQGridLayoutFunc_verticalSpacing(PyObject* self)
{
    QGridLayout* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGridLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // verticalSpacing()const
            int cppResult = cppSelf->QGridLayout::verticalSpacing();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGridLayout_methods[] = {
    {"addItem", (PyCFunction)SbkQGridLayoutFunc_addItem, METH_VARARGS|METH_KEYWORDS},
    {"addLayout", (PyCFunction)SbkQGridLayoutFunc_addLayout, METH_VARARGS|METH_KEYWORDS},
    {"addWidget", (PyCFunction)SbkQGridLayoutFunc_addWidget, METH_VARARGS|METH_KEYWORDS},
    {"cellRect", (PyCFunction)SbkQGridLayoutFunc_cellRect, METH_VARARGS},
    {"columnCount", (PyCFunction)SbkQGridLayoutFunc_columnCount, METH_NOARGS},
    {"columnMinimumWidth", (PyCFunction)SbkQGridLayoutFunc_columnMinimumWidth, METH_O},
    {"columnStretch", (PyCFunction)SbkQGridLayoutFunc_columnStretch, METH_O},
    {"count", (PyCFunction)SbkQGridLayoutFunc_count, METH_NOARGS},
    {"expandingDirections", (PyCFunction)SbkQGridLayoutFunc_expandingDirections, METH_NOARGS},
    {"hasHeightForWidth", (PyCFunction)SbkQGridLayoutFunc_hasHeightForWidth, METH_NOARGS},
    {"heightForWidth", (PyCFunction)SbkQGridLayoutFunc_heightForWidth, METH_O},
    {"horizontalSpacing", (PyCFunction)SbkQGridLayoutFunc_horizontalSpacing, METH_NOARGS},
    {"invalidate", (PyCFunction)SbkQGridLayoutFunc_invalidate, METH_NOARGS},
    {"itemAt", (PyCFunction)SbkQGridLayoutFunc_itemAt, METH_O},
    {"itemAtPosition", (PyCFunction)SbkQGridLayoutFunc_itemAtPosition, METH_VARARGS},
    {"maximumSize", (PyCFunction)SbkQGridLayoutFunc_maximumSize, METH_NOARGS},
    {"minimumHeightForWidth", (PyCFunction)SbkQGridLayoutFunc_minimumHeightForWidth, METH_O},
    {"minimumSize", (PyCFunction)SbkQGridLayoutFunc_minimumSize, METH_NOARGS},
    {"originCorner", (PyCFunction)SbkQGridLayoutFunc_originCorner, METH_NOARGS},
    {"rowCount", (PyCFunction)SbkQGridLayoutFunc_rowCount, METH_NOARGS},
    {"rowMinimumHeight", (PyCFunction)SbkQGridLayoutFunc_rowMinimumHeight, METH_O},
    {"rowStretch", (PyCFunction)SbkQGridLayoutFunc_rowStretch, METH_O},
    {"setColumnMinimumWidth", (PyCFunction)SbkQGridLayoutFunc_setColumnMinimumWidth, METH_VARARGS},
    {"setColumnStretch", (PyCFunction)SbkQGridLayoutFunc_setColumnStretch, METH_VARARGS},
    {"setDefaultPositioning", (PyCFunction)SbkQGridLayoutFunc_setDefaultPositioning, METH_VARARGS},
    {"setGeometry", (PyCFunction)SbkQGridLayoutFunc_setGeometry, METH_O},
    {"setHorizontalSpacing", (PyCFunction)SbkQGridLayoutFunc_setHorizontalSpacing, METH_O},
    {"setOriginCorner", (PyCFunction)SbkQGridLayoutFunc_setOriginCorner, METH_O},
    {"setRowMinimumHeight", (PyCFunction)SbkQGridLayoutFunc_setRowMinimumHeight, METH_VARARGS},
    {"setRowStretch", (PyCFunction)SbkQGridLayoutFunc_setRowStretch, METH_VARARGS},
    {"setSpacing", (PyCFunction)SbkQGridLayoutFunc_setSpacing, METH_O},
    {"setVerticalSpacing", (PyCFunction)SbkQGridLayoutFunc_setVerticalSpacing, METH_O},
    {"sizeHint", (PyCFunction)SbkQGridLayoutFunc_sizeHint, METH_NOARGS},
    {"spacing", (PyCFunction)SbkQGridLayoutFunc_spacing, METH_NOARGS},
    {"takeAt", (PyCFunction)SbkQGridLayoutFunc_takeAt, METH_O},
    {"verticalSpacing", (PyCFunction)SbkQGridLayoutFunc_verticalSpacing, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQGridLayoutSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QGridLayout* me = reinterpret_cast<QGridLayout*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]))
        return static_cast<QLayout*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX]))
        return static_cast<QLayoutItem*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGridLayout_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGridLayout",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGridLayout_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGridLayout_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQGridLayoutSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGridLayout >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGridLayout*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGridLayout_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGridLayout*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGridLayout_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QLayoutItem >()) && dynamic_cast<QGridLayout*>(reinterpret_cast<QLayoutItem*>(cptr)))
        return &SbkQGridLayout_Type;
    return 0;
}


void init_QGridLayout(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRIDLAYOUT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGridLayout_Type);

    SbkQGridLayout_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX];
    SbkQGridLayout_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX])->mi_init;

    // Fill type discovery information
    SbkQGridLayout_Type.type_discovery = &SbkQGridLayout_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]), &SbkQGridLayout_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGridLayout_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGridLayout_Type));
    PyModule_AddObject(module, "QGridLayout",
        ((PyObject*)&SbkQGridLayout_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGridLayout >("QGridLayout*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGridLayout >(typeid(QGridLayout).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGridLayout >(typeid(QGridLayoutWrapper).name());
    PySide::initQtMetaType<QGridLayout* >();
}

