/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qicon_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qdatastream.h>
#include <qicon.h>
#include <qiconengine.h>
#include <qpainter.h>
#include <qpixmap.h>
#include <qrect.h>
#include <qsize.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQIcon_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QIcon >()))
        return -1;

    QIcon* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QIcon", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QIcon()
    // 1: QIcon(QIconEngine*)
    // 2: QIcon(QIconEngineV2*)
    // 3: QIcon(QIcon)
    // 4: QIcon(QPixmap)
    // 5: QIcon(QString)
    if (numArgs == 0) {
        overloadId = 0; // QIcon()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 5; // QIcon(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QPixmap & >::isConvertible(arg)) {
        overloadId = 4; // QIcon(QPixmap)
    } else if (numArgs == 1 && Shiboken::Converter<const QIcon & >::isConvertible(arg)) {
        overloadId = 3; // QIcon(QIcon)
    } else if (numArgs == 1 && Shiboken::Converter<QIconEngineV2 * >::isConvertible(arg)) {
        overloadId = 2; // QIcon(QIconEngineV2*)
    } else if (numArgs == 1 && Shiboken::Converter<QIconEngine * >::isConvertible(arg)) {
        overloadId = 1; // QIcon(QIconEngine*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIcon_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QIcon()
            {

                if(!PyErr_Occurred()) {
                // QIcon()
                cptr = new QIcon();
                }
                break;
            }
            case 1: // QIcon(QIconEngine*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QIconEngine* cpp_arg0 = Shiboken::Converter<QIconEngine* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QIcon(QIconEngine*)
                cptr = new QIcon(cpp_arg0);
                Shiboken::setParent(self, arg);
                }
                break;
            }
            case 2: // QIcon(QIconEngineV2*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QIconEngineV2* cpp_arg0 = Shiboken::Converter<QIconEngineV2* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QIcon(QIconEngineV2*)
                cptr = new QIcon(cpp_arg0);
                Shiboken::setParent(self, arg);
                }
                break;
            }
            case 3: // QIcon(QIcon)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QIcon > cpp_arg0_auto_ptr;
                QIcon* cpp_arg0 = Shiboken::Converter<QIcon* >::toCpp(arg);
                if (!Shiboken::Converter<QIcon >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QIcon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QIcon(QIcon)
                cptr = new QIcon(*cpp_arg0);
                }
                break;
            }
            case 4: // QIcon(QPixmap)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
                QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(arg);
                if (!Shiboken::Converter<QPixmap >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QIcon(QPixmap)
                cptr = new QIcon(*cpp_arg0);
                }
                break;
            }
            case 5: // QIcon(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QIcon(QString)
                cptr = new QIcon(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QIcon >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQIcon_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQIcon_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QIconEngine", "PySide.QtGui.QIconEngineV2", "PySide.QtGui.QIcon", "PySide.QtGui.QPixmap", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon", overloads);
        return -1;
}

static PyObject* SbkQIconFunc_actualSize(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.actualSize(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.actualSize(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.actualSize(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:actualSize", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: actualSize(QSize,QIcon::Mode,QIcon::State)const
    if (Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // actualSize(QSize,QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // actualSize(QSize,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 0; // actualSize(QSize,QIcon::Mode,QIcon::State)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_actualSize_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "state";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.actualSize(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
            QIcon::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
            QIcon::State cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

            if(!PyErr_Occurred()) {
            // actualSize(QSize,QIcon::Mode,QIcon::State)const
            QSize cppResult = cppSelf->QIcon::actualSize(*cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIconFunc_actualSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.actualSize", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_addFile(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode", "size", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.addFile(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addFile(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addFile(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:addFile", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addFile(QString,QSize,QIcon::Mode,QIcon::State)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
        } else if (Shiboken::Converter<const QSize & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
            } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
                } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[3])) {
                    overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_addFile_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "size";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "mode";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "state";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.addFile(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QSize cpp_arg1_tmp = QSize();
            QSize* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSize* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            QIcon::Mode cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[2]) : QIcon::Normal;
            QIcon::State cpp_arg3 = pyargs[3] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[3]) : QIcon::Off;

            if(!PyErr_Occurred()) {
            // addFile(QString,QSize,QIcon::Mode,QIcon::State)
            cppSelf->QIcon::addFile(cpp_arg0, *cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIconFunc_addFile_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QSize = QSize(), PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.addFile", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_addPixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.addPixmap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addPixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addPixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addPixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addPixmap(QPixmap,QIcon::Mode,QIcon::State)
    if (Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
        } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
            } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 0; // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_addPixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "state";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.addPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
            QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPixmap >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);
            QIcon::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
            QIcon::State cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

            if(!PyErr_Occurred()) {
            // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
            cppSelf->QIcon::addPixmap(*cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIconFunc_addPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.addPixmap", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_availableSizes(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.availableSizes(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.availableSizes(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:availableSizes", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: availableSizes(QIcon::Mode,QIcon::State)const
    if (numArgs == 0) {
        overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)const
    } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[1])) {
            overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_availableSizes_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "state";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.availableSizes(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QIcon::Mode cpp_arg0 = pyargs[0] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[0]) : QIcon::Normal;
            QIcon::State cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[1]) : QIcon::Off;

            if(!PyErr_Occurred()) {
            // availableSizes(QIcon::Mode,QIcon::State)const
            QList<QSize > cppResult = cppSelf->QIcon::availableSizes(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QList<QSize > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIconFunc_availableSizes_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.availableSizes", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_cacheKey(PyObject* self)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cacheKey()const
            qint64 cppResult = cppSelf->QIcon::cacheKey();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIconFunc_fromTheme(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fallback" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.fromTheme(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.fromTheme(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.fromTheme(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromTheme", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromTheme(QString,QIcon)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromTheme(QString,QIcon)
        } else if (Shiboken::Converter<const QIcon & >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromTheme(QString,QIcon)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_fromTheme_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "fallback");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "fallback";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.fromTheme(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QIcon > cpp_arg1_auto_ptr;
            QIcon cpp_arg1_tmp = QIcon();
            QIcon* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIcon* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QIcon >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QIcon >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // fromTheme(QString,QIcon)
            QIcon cppResult = QIcon::fromTheme(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIconFunc_fromTheme_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QIcon = QIcon()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.fromTheme", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_hasThemeIcon(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasThemeIcon(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasThemeIcon(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_hasThemeIcon_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasThemeIcon(QString)
            bool cppResult = QIcon::hasThemeIcon(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIconFunc_hasThemeIcon_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.hasThemeIcon", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_isNull(PyObject* self)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QIcon::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIconFunc_name(PyObject* self)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QIcon::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIconFunc_paint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "alignment", "mode", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:paint", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
    // 1: paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
    if (Shiboken::Converter<QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs >= 5 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[5])) {
                if (numArgs == 6) {
                    overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[6])) {
                    if (numArgs == 7) {
                        overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[7])) {
                        overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    }
                }
            }
        } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[4])) {
                        overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_paint_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "alignment";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "state";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QRect* cpp_arg1 = Shiboken::Converter<QRect* >::toCpp(pyargs[1]);
                QFlags<Qt::AlignmentFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[2]) : Qt::AlignCenter;
                QIcon::Mode cpp_arg3 = pyargs[3] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[3]) : QIcon::Normal;
                QIcon::State cpp_arg4 = pyargs[4] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[4]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                cppSelf->QIcon::paint(cpp_arg0, *cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 1: // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "alignment";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "mode";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "state";
                        else
                            pyargs[7] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QFlags<Qt::AlignmentFlag> cpp_arg5 = pyargs[5] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[5]) : Qt::AlignCenter;
                QIcon::Mode cpp_arg6 = pyargs[6] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[6]) : QIcon::Normal;
                QIcon::State cpp_arg7 = pyargs[7] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[7]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                cppSelf->QIcon::paint(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6, cpp_arg7);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIconFunc_paint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, PySide.QtCore.Qt.Alignment = Qt.AlignCenter, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", "PySide.QtGui.QPainter, int, int, int, int, PySide.QtCore.Qt.Alignment = Qt.AlignCenter, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.paint", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_pixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:pixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: pixmap(QSize,QIcon::Mode,QIcon::State)const
    // 1: pixmap(int,QIcon::Mode,QIcon::State)const
    // 2: pixmap(int,int,QIcon::Mode,QIcon::State)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // pixmap(int,QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // pixmap(int,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 1; // pixmap(int,QIcon::Mode,QIcon::State)const
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // pixmap(int,int,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 2; // pixmap(int,int,QIcon::Mode,QIcon::State)const
                } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[3])) {
                    overloadId = 2; // pixmap(int,int,QIcon::Mode,QIcon::State)const
                }
            }
        }
    } else if (Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // pixmap(QSize,QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter<QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // pixmap(QSize,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter<QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 0; // pixmap(QSize,QIcon::Mode,QIcon::State)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_pixmap_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pixmap(QSize,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "state";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
                QIcon::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
                QIcon::State cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                // pixmap(QSize,QIcon::Mode,QIcon::State)const
                QPixmap cppResult = cppSelf->QIcon::pixmap(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 1: // pixmap(int,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "state";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QIcon::Mode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
                QIcon::State cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                // pixmap(int,QIcon::Mode,QIcon::State)const
                QPixmap cppResult = cppSelf->QIcon::pixmap(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 2: // pixmap(int,int,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "state";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QIcon::Mode cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[2]) : QIcon::Normal;
                QIcon::State cpp_arg3 = pyargs[3] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[3]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                // pixmap(int,int,QIcon::Mode,QIcon::State)const
                QPixmap cppResult = cppSelf->QIcon::pixmap(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIconFunc_pixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", "int, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", "int, int, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.pixmap", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_setThemeName(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setThemeName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setThemeName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_setThemeName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setThemeName(QString)
            QIcon::setThemeName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIconFunc_setThemeName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.setThemeName", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_setThemeSearchPaths(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setThemeSearchPaths(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setThemeSearchPaths(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc_setThemeSearchPaths_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setThemeSearchPaths(QStringList)
            QIcon::setThemeSearchPaths(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQIconFunc_setThemeSearchPaths_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.setThemeSearchPaths", overloads);
        return 0;
}

static PyObject* SbkQIconFunc_themeName(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // themeName()
            QString cppResult = QIcon::themeName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQIconFunc_themeSearchPaths(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // themeSearchPaths()
            QStringList cppResult = QIcon::themeSearchPaths();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQIcon_methods[] = {
    {"actualSize", (PyCFunction)SbkQIconFunc_actualSize, METH_VARARGS|METH_KEYWORDS},
    {"addFile", (PyCFunction)SbkQIconFunc_addFile, METH_VARARGS|METH_KEYWORDS},
    {"addPixmap", (PyCFunction)SbkQIconFunc_addPixmap, METH_VARARGS|METH_KEYWORDS},
    {"availableSizes", (PyCFunction)SbkQIconFunc_availableSizes, METH_VARARGS|METH_KEYWORDS},
    {"cacheKey", (PyCFunction)SbkQIconFunc_cacheKey, METH_NOARGS},
    {"fromTheme", (PyCFunction)SbkQIconFunc_fromTheme, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"hasThemeIcon", (PyCFunction)SbkQIconFunc_hasThemeIcon, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)SbkQIconFunc_isNull, METH_NOARGS},
    {"name", (PyCFunction)SbkQIconFunc_name, METH_NOARGS},
    {"paint", (PyCFunction)SbkQIconFunc_paint, METH_VARARGS|METH_KEYWORDS},
    {"pixmap", (PyCFunction)SbkQIconFunc_pixmap, METH_VARARGS|METH_KEYWORDS},
    {"setThemeName", (PyCFunction)SbkQIconFunc_setThemeName, METH_O|METH_STATIC},
    {"setThemeSearchPaths", (PyCFunction)SbkQIconFunc_setThemeSearchPaths, METH_O|METH_STATIC},
    {"themeName", (PyCFunction)SbkQIconFunc_themeName, METH_NOARGS|METH_STATIC},
    {"themeSearchPaths", (PyCFunction)SbkQIconFunc_themeSearchPaths, METH_NOARGS|METH_STATIC},
    {0} // Sentinel
};

static PyObject* SbkQIconFunc___lshift__(PyObject* self, PyObject* arg)
{
    QIcon* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QIcon >::checkType(arg) && !Shiboken::Converter<QIcon >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QIcon)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QIcon) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIconFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQIconFunc___rshift__(PyObject* self, PyObject* arg)
{
    QIcon* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QIcon >::checkType(arg) && !Shiboken::Converter<QIcon >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QIcon&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QIcon&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQIconFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QIcon&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQIconFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQIcon_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQIconFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQIconFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQIcon_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QIcon",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQIcon_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQIcon_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQIcon_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QIcon >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QIcon",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QIcon_Mode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QIcon_Mode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QIcon_Mode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Mode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QIcon_Mode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QIcon_Mode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QIcon_Mode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QIcon_State_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QIcon_State_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QIcon_State_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "State",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QIcon_State_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QIcon_State_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QIcon_State_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QIcon(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QICON_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQIcon_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQIcon_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQIcon_Type));
    PyModule_AddObject(module, "QIcon",
        ((PyObject*)&SbkQIcon_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Mode
    SbkPySide_QtGuiTypes[SBK_QICON_MODE_IDX] = &SbkPySide_QtGui_QIcon_Mode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QIcon_Mode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QIcon_Mode_Type);
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
            "Mode",((PyObject*)&SbkPySide_QtGui_QIcon_Mode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QIcon_Mode_Type,
        (long) QIcon::Normal, "Normal");
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
        "Normal", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode_Type.tp_dict,
        "Normal", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QIcon_Mode_Type,
        (long) QIcon::Disabled, "Disabled");
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
        "Disabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode_Type.tp_dict,
        "Disabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QIcon_Mode_Type,
        (long) QIcon::Active, "Active");
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
        "Active", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode_Type.tp_dict,
        "Active", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QIcon_Mode_Type,
        (long) QIcon::Selected, "Selected");
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
        "Selected", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode_Type.tp_dict,
        "Selected", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QIcon::Mode");

    // init enum class: State
    SbkPySide_QtGuiTypes[SBK_QICON_STATE_IDX] = &SbkPySide_QtGui_QIcon_State_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QIcon_State_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QIcon_State_Type);
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
            "State",((PyObject*)&SbkPySide_QtGui_QIcon_State_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QIcon_State_Type,
        (long) QIcon::On, "On");
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
        "On", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_State_Type.tp_dict,
        "On", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QIcon_State_Type,
        (long) QIcon::Off, "Off");
    PyDict_SetItemString(SbkQIcon_Type.super.ht_type.tp_dict,
        "Off", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_State_Type.tp_dict,
        "Off", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QIcon::State");


    Shiboken::TypeResolver::createValueTypeResolver<QIcon >("QIcon");
    Shiboken::TypeResolver::createObjectTypeResolver<QIcon >("QIcon*");
    Shiboken::TypeResolver::createValueTypeResolver<QIcon >(typeid(QIcon).name());
    PySide::initQtMetaType<QIcon >();
}

