/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qimagereader_wrapper.h"

// Extra includes
#include <QColor>
#include <QImage>
#include <QList>
#include <QRect>
#include <QSize>
#include <QStringList>
#include <qbytearray.h>
#include <qcolor.h>
#include <qimage.h>
#include <qimagereader.h>
#include <qiodevice.h>
#include <qrect.h>
#include <qsize.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQImageReader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QImageReader >()))
        return -1;

    QImageReader* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageReader(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImageReader(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QImageReader", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QImageReader()
    // 1: QImageReader(QIODevice*,QByteArray)
    // 2: QImageReader(QString,QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QImageReader()
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QImageReader(QString,QByteArray)
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 2; // QImageReader(QString,QByteArray)
        }
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QImageReader(QIODevice*,QByteArray)
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 1; // QImageReader(QIODevice*,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QImageReader()
            {

                if(!PyErr_Occurred()) {
                // QImageReader()
                cptr = new QImageReader();
                }
                break;
            }
            case 1: // QImageReader(QIODevice*,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageReader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray cpp_arg1_tmp = QByteArray();
                QByteArray* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QImageReader(QIODevice*,QByteArray)
                cptr = new QImageReader(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // QImageReader(QString,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageReader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray cpp_arg1_tmp = QByteArray();
                QByteArray* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QImageReader(QString,QByteArray)
                cptr = new QImageReader(cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QImageReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQImageReader_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQImageReader_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice, PySide.QtCore.QByteArray = QByteArray()", "QString, PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImageReader", overloads);
        return -1;
}

static PyObject* SbkQImageReaderFunc_autoDetectImageFormat(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoDetectImageFormat()const
            bool cppResult = cppSelf->QImageReader::autoDetectImageFormat();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_backgroundColor(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundColor()const
            QColor cppResult = cppSelf->QImageReader::backgroundColor();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_canRead(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canRead()const
            bool cppResult = cppSelf->QImageReader::canRead();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_clipRect(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipRect()const
            QRect cppResult = cppSelf->QImageReader::clipRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_currentImageNumber(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentImageNumber()const
            int cppResult = cppSelf->QImageReader::currentImageNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_currentImageRect(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentImageRect()const
            QRect cppResult = cppSelf->QImageReader::currentImageRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_decideFormatFromContent(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // decideFormatFromContent()const
            bool cppResult = cppSelf->QImageReader::decideFormatFromContent();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_device(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QImageReader::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_error(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QImageReader::ImageReaderError cppResult = cppSelf->QImageReader::error();
            pyResult = Shiboken::Converter<QImageReader::ImageReaderError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_errorString(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QImageReader::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_fileName(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QImageReader::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_format(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QByteArray cppResult = cppSelf->QImageReader::format();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_imageCount(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // imageCount()const
            int cppResult = cppSelf->QImageReader::imageCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_imageFormat(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: imageFormat()const
    // 1: imageFormat(QIODevice*)
    // 2: imageFormat(QString)
    if (numArgs == 0) {
        overloadId = 0; // imageFormat()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 2; // imageFormat(QString)
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 1; // imageFormat(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_imageFormat_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // imageFormat()const
            {

                if(!PyErr_Occurred()) {
                // imageFormat()const
                QImage::Format cppResult = cppSelf->QImageReader::imageFormat();
                pyResult = Shiboken::Converter<QImage::Format >::toPython(cppResult);
                }
                break;
            }
            case 1: // imageFormat(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // imageFormat(QIODevice*)
                QByteArray cppResult = QImageReader::imageFormat(cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 2: // imageFormat(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // imageFormat(QString)
                QByteArray cppResult = QImageReader::imageFormat(cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageReaderFunc_imageFormat_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.imageFormat", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_jumpToImage(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: jumpToImage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // jumpToImage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_jumpToImage_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // jumpToImage(int)
            bool cppResult = cppSelf->QImageReader::jumpToImage(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageReaderFunc_jumpToImage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.jumpToImage", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_jumpToNextImage(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // jumpToNextImage()
            bool cppResult = cppSelf->QImageReader::jumpToNextImage();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_loopCount(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // loopCount()const
            int cppResult = cppSelf->QImageReader::loopCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_nextImageDelay(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextImageDelay()const
            int cppResult = cppSelf->QImageReader::nextImageDelay();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_quality(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // quality()const
            int cppResult = cppSelf->QImageReader::quality();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_read(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // read()
            QImage cppResult = cppSelf->QImageReader::read();
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_scaledClipRect(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scaledClipRect()const
            QRect cppResult = cppSelf->QImageReader::scaledClipRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_scaledSize(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scaledSize()const
            QSize cppResult = cppSelf->QImageReader::scaledSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_setAutoDetectImageFormat(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoDetectImageFormat(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoDetectImageFormat(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setAutoDetectImageFormat_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoDetectImageFormat(bool)
            cppSelf->QImageReader::setAutoDetectImageFormat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setAutoDetectImageFormat_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setAutoDetectImageFormat", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setBackgroundColor(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundColor(QColor)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setBackgroundColor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBackgroundColor(QColor)
            cppSelf->QImageReader::setBackgroundColor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setBackgroundColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setBackgroundColor", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setClipRect(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setClipRect(QRect)
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // setClipRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setClipRect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setClipRect(QRect)
            cppSelf->QImageReader::setClipRect(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setClipRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setClipRect", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setDecideFormatFromContent(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDecideFormatFromContent(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDecideFormatFromContent(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setDecideFormatFromContent_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDecideFormatFromContent(bool)
            cppSelf->QImageReader::setDecideFormatFromContent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setDecideFormatFromContent_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setDecideFormatFromContent", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setDevice(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QImageReader::setDevice(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setDevice", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setFileName(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFileName(QString)
            cppSelf->QImageReader::setFileName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setFileName", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setFormat(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormat(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setFormat(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFormat(QByteArray)
            cppSelf->QImageReader::setFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setFormat", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setQuality(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQuality(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setQuality(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setQuality_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setQuality(int)
            cppSelf->QImageReader::setQuality(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setQuality_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setQuality", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setScaledClipRect(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaledClipRect(QRect)
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // setScaledClipRect(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setScaledClipRect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScaledClipRect(QRect)
            cppSelf->QImageReader::setScaledClipRect(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setScaledClipRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setScaledClipRect", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_setScaledSize(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaledSize(QSize)
    if (Shiboken::Converter<const QSize & >::isConvertible(arg)) {
        overloadId = 0; // setScaledSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_setScaledSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScaledSize(QSize)
            cppSelf->QImageReader::setScaledSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageReaderFunc_setScaledSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.setScaledSize", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_size(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSize cppResult = cppSelf->QImageReader::size();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_supportedImageFormats(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedImageFormats()
            QList<QByteArray > cppResult = QImageReader::supportedImageFormats();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_supportsAnimation(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportsAnimation()const
            bool cppResult = cppSelf->QImageReader::supportsAnimation();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageReaderFunc_supportsOption(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsOption(QImageIOHandler::ImageOption)const
    if (Shiboken::Converter<QImageIOHandler::ImageOption >::isConvertible(arg)) {
        overloadId = 0; // supportsOption(QImageIOHandler::ImageOption)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_supportsOption_TypeError;

    // Call function/method
    {
        {
            QImageIOHandler::ImageOption cpp_arg0 = Shiboken::Converter<QImageIOHandler::ImageOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // supportsOption(QImageIOHandler::ImageOption)const
            bool cppResult = cppSelf->QImageReader::supportsOption(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageReaderFunc_supportsOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImageIOHandler.ImageOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.supportsOption", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_text(PyObject* self, PyObject* arg)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: text(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // text(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageReaderFunc_text_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // text(QString)const
            QString cppResult = cppSelf->QImageReader::text(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageReaderFunc_text_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageReader.text", overloads);
        return 0;
}

static PyObject* SbkQImageReaderFunc_textKeys(PyObject* self)
{
    QImageReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textKeys()const
            QStringList cppResult = cppSelf->QImageReader::textKeys();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQImageReaderMethod_imageFormat = {
    "imageFormat", (PyCFunction)SbkQImageReaderFunc_imageFormat, METH_NOARGS|METH_O|METH_STATIC
};

static PyMethodDef SbkQImageReader_methods[] = {
    {"autoDetectImageFormat", (PyCFunction)SbkQImageReaderFunc_autoDetectImageFormat, METH_NOARGS},
    {"backgroundColor", (PyCFunction)SbkQImageReaderFunc_backgroundColor, METH_NOARGS},
    {"canRead", (PyCFunction)SbkQImageReaderFunc_canRead, METH_NOARGS},
    {"clipRect", (PyCFunction)SbkQImageReaderFunc_clipRect, METH_NOARGS},
    {"currentImageNumber", (PyCFunction)SbkQImageReaderFunc_currentImageNumber, METH_NOARGS},
    {"currentImageRect", (PyCFunction)SbkQImageReaderFunc_currentImageRect, METH_NOARGS},
    {"decideFormatFromContent", (PyCFunction)SbkQImageReaderFunc_decideFormatFromContent, METH_NOARGS},
    {"device", (PyCFunction)SbkQImageReaderFunc_device, METH_NOARGS},
    {"error", (PyCFunction)SbkQImageReaderFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQImageReaderFunc_errorString, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQImageReaderFunc_fileName, METH_NOARGS},
    {"format", (PyCFunction)SbkQImageReaderFunc_format, METH_NOARGS},
    {"imageCount", (PyCFunction)SbkQImageReaderFunc_imageCount, METH_NOARGS},
    SbkQImageReaderMethod_imageFormat,
    {"jumpToImage", (PyCFunction)SbkQImageReaderFunc_jumpToImage, METH_O},
    {"jumpToNextImage", (PyCFunction)SbkQImageReaderFunc_jumpToNextImage, METH_NOARGS},
    {"loopCount", (PyCFunction)SbkQImageReaderFunc_loopCount, METH_NOARGS},
    {"nextImageDelay", (PyCFunction)SbkQImageReaderFunc_nextImageDelay, METH_NOARGS},
    {"quality", (PyCFunction)SbkQImageReaderFunc_quality, METH_NOARGS},
    {"read", (PyCFunction)SbkQImageReaderFunc_read, METH_NOARGS},
    {"scaledClipRect", (PyCFunction)SbkQImageReaderFunc_scaledClipRect, METH_NOARGS},
    {"scaledSize", (PyCFunction)SbkQImageReaderFunc_scaledSize, METH_NOARGS},
    {"setAutoDetectImageFormat", (PyCFunction)SbkQImageReaderFunc_setAutoDetectImageFormat, METH_O},
    {"setBackgroundColor", (PyCFunction)SbkQImageReaderFunc_setBackgroundColor, METH_O},
    {"setClipRect", (PyCFunction)SbkQImageReaderFunc_setClipRect, METH_O},
    {"setDecideFormatFromContent", (PyCFunction)SbkQImageReaderFunc_setDecideFormatFromContent, METH_O},
    {"setDevice", (PyCFunction)SbkQImageReaderFunc_setDevice, METH_O},
    {"setFileName", (PyCFunction)SbkQImageReaderFunc_setFileName, METH_O},
    {"setFormat", (PyCFunction)SbkQImageReaderFunc_setFormat, METH_O},
    {"setQuality", (PyCFunction)SbkQImageReaderFunc_setQuality, METH_O},
    {"setScaledClipRect", (PyCFunction)SbkQImageReaderFunc_setScaledClipRect, METH_O},
    {"setScaledSize", (PyCFunction)SbkQImageReaderFunc_setScaledSize, METH_O},
    {"size", (PyCFunction)SbkQImageReaderFunc_size, METH_NOARGS},
    {"supportedImageFormats", (PyCFunction)SbkQImageReaderFunc_supportedImageFormats, METH_NOARGS|METH_STATIC},
    {"supportsAnimation", (PyCFunction)SbkQImageReaderFunc_supportsAnimation, METH_NOARGS},
    {"supportsOption", (PyCFunction)SbkQImageReaderFunc_supportsOption, METH_O},
    {"text", (PyCFunction)SbkQImageReaderFunc_text, METH_O},
    {"textKeys", (PyCFunction)SbkQImageReaderFunc_textKeys, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQImageReader_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (SbkBaseWrapper_instanceDict(self)) {
            PyObject* meth = PyDict_GetItem(SbkBaseWrapper_instanceDict(self), name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "imageFormat") == 0)
            return PyCFunction_NewEx(&SbkQImageReaderMethod_imageFormat, self, 0);
    }
    PyObject* attr = PyObject_GenericGetAttr(self, name);
    if (attr && PySide::isQPropertyType(attr)) {
        PyObject *value = PySide::qproperty_get(attr, self);
        Py_DECREF(attr);
        Py_INCREF(value);
        attr = value;
    }
    return attr;
}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQImageReader_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QImageReader",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         SbkQImageReader_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQImageReader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQImageReader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QImageReader >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QImageReader*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QImageReader_ImageReaderError_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QImageReader_ImageReaderError_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QImageReader_ImageReaderError_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ImageReaderError",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QImageReader_ImageReaderError_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QImageReader_ImageReaderError_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QImageReader_ImageReaderError_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QImageReader(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QIMAGEREADER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQImageReader_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQImageReader_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQImageReader_Type));
    PyModule_AddObject(module, "QImageReader",
        ((PyObject*)&SbkQImageReader_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ImageReaderError
    SbkPySide_QtGuiTypes[SBK_QIMAGEREADER_IMAGEREADERERROR_IDX] = &SbkPySide_QtGui_QImageReader_ImageReaderError_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QImageReader_ImageReaderError_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QImageReader_ImageReaderError_Type);
    PyDict_SetItemString(SbkQImageReader_Type.super.ht_type.tp_dict,
            "ImageReaderError",((PyObject*)&SbkPySide_QtGui_QImageReader_ImageReaderError_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageReader_ImageReaderError_Type,
        (long) QImageReader::UnknownError, "UnknownError");
    PyDict_SetItemString(SbkQImageReader_Type.super.ht_type.tp_dict,
        "UnknownError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError_Type.tp_dict,
        "UnknownError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageReader_ImageReaderError_Type,
        (long) QImageReader::FileNotFoundError, "FileNotFoundError");
    PyDict_SetItemString(SbkQImageReader_Type.super.ht_type.tp_dict,
        "FileNotFoundError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError_Type.tp_dict,
        "FileNotFoundError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageReader_ImageReaderError_Type,
        (long) QImageReader::DeviceError, "DeviceError");
    PyDict_SetItemString(SbkQImageReader_Type.super.ht_type.tp_dict,
        "DeviceError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError_Type.tp_dict,
        "DeviceError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageReader_ImageReaderError_Type,
        (long) QImageReader::UnsupportedFormatError, "UnsupportedFormatError");
    PyDict_SetItemString(SbkQImageReader_Type.super.ht_type.tp_dict,
        "UnsupportedFormatError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError_Type.tp_dict,
        "UnsupportedFormatError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageReader_ImageReaderError_Type,
        (long) QImageReader::InvalidDataError, "InvalidDataError");
    PyDict_SetItemString(SbkQImageReader_Type.super.ht_type.tp_dict,
        "InvalidDataError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageReader_ImageReaderError_Type.tp_dict,
        "InvalidDataError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImageReader::ImageReaderError");


    Shiboken::TypeResolver::createObjectTypeResolver<QImageReader >("QImageReader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QImageReader >(typeid(QImageReader).name());
    PySide::initQtMetaType<QImageReader* >();
}

