/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qimagewriter_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qimage.h>
#include <qimagewriter.h>
#include <qiodevice.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQImageWriter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QImageWriter >()))
        return -1;

    QImageWriter* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageWriter(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImageWriter(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QImageWriter", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QImageWriter()
    // 1: QImageWriter(QIODevice*,QByteArray)
    // 2: QImageWriter(QString,QByteArray)
    if (numArgs == 0) {
        overloadId = 0; // QImageWriter()
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QImageWriter(QString,QByteArray)
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 2; // QImageWriter(QString,QByteArray)
        }
    } else if (numArgs == 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
        overloadId = 1; // QImageWriter(QIODevice*,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QImageWriter()
            {

                if(!PyErr_Occurred()) {
                // QImageWriter()
                cptr = new QImageWriter();
                }
                break;
            }
            case 1: // QImageWriter(QIODevice*,QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QImageWriter(QIODevice*,QByteArray)
                cptr = new QImageWriter(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // QImageWriter(QString,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImageWriter(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray cpp_arg1_tmp = QByteArray();
                QByteArray* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QImageWriter(QString,QByteArray)
                cptr = new QImageWriter(cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QImageWriter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQImageWriter_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQImageWriter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice, PySide.QtCore.QByteArray", "QString, PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImageWriter", overloads);
        return -1;
}

static PyObject* SbkQImageWriterFunc_canWrite(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canWrite()const
            bool cppResult = cppSelf->QImageWriter::canWrite();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_compression(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // compression()const
            int cppResult = cppSelf->QImageWriter::compression();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_device(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QImageWriter::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_error(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QImageWriter::ImageWriterError cppResult = cppSelf->QImageWriter::error();
            pyResult = Shiboken::Converter<QImageWriter::ImageWriterError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_errorString(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QImageWriter::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_fileName(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QImageWriter::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_format(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QByteArray cppResult = cppSelf->QImageWriter::format();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_gamma(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // gamma()const
            float cppResult = cppSelf->QImageWriter::gamma();
            pyResult = Shiboken::Converter<float >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_quality(PyObject* self)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // quality()const
            int cppResult = cppSelf->QImageWriter::quality();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_setCompression(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompression(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCompression(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_setCompression_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCompression(int)
            cppSelf->QImageWriter::setCompression(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageWriterFunc_setCompression_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setCompression", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_setDevice(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QImageWriter::setDevice(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageWriterFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setDevice", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_setFileName(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFileName(QString)
            cppSelf->QImageWriter::setFileName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageWriterFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setFileName", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_setFormat(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormat(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setFormat(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_setFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFormat(QByteArray)
            cppSelf->QImageWriter::setFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageWriterFunc_setFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setFormat", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_setGamma(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGamma(float)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGamma(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_setGamma_TypeError;

    // Call function/method
    {
        {
            float cpp_arg0 = Shiboken::Converter<float >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGamma(float)
            cppSelf->QImageWriter::setGamma(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageWriterFunc_setGamma_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setGamma", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_setQuality(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQuality(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setQuality(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_setQuality_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setQuality(int)
            cppSelf->QImageWriter::setQuality(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageWriterFunc_setQuality_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.setQuality", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_setText(PyObject* self, PyObject* args)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setText(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setText(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setText(QString,QString)
            cppSelf->QImageWriter::setText(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQImageWriterFunc_setText_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImageWriter.setText", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_supportedImageFormats(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedImageFormats()
            QList<QByteArray > cppResult = QImageWriter::supportedImageFormats();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQImageWriterFunc_supportsOption(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsOption(QImageIOHandler::ImageOption)const
    if (Shiboken::Converter<QImageIOHandler::ImageOption >::isConvertible(arg)) {
        overloadId = 0; // supportsOption(QImageIOHandler::ImageOption)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_supportsOption_TypeError;

    // Call function/method
    {
        {
            QImageIOHandler::ImageOption cpp_arg0 = Shiboken::Converter<QImageIOHandler::ImageOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // supportsOption(QImageIOHandler::ImageOption)const
            bool cppResult = cppSelf->QImageWriter::supportsOption(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageWriterFunc_supportsOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImageIOHandler.ImageOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.supportsOption", overloads);
        return 0;
}

static PyObject* SbkQImageWriterFunc_write(PyObject* self, PyObject* arg)
{
    QImageWriter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QImageWriter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: write(QImage)
    if (Shiboken::Converter<const QImage & >::isConvertible(arg)) {
        overloadId = 0; // write(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQImageWriterFunc_write_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // write(QImage)
            threadStateSaver.save();
            bool cppResult = cppSelf->QImageWriter::write(*cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQImageWriterFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImageWriter.write", overloads);
        return 0;
}

static PyMethodDef SbkQImageWriter_methods[] = {
    {"canWrite", (PyCFunction)SbkQImageWriterFunc_canWrite, METH_NOARGS},
    {"compression", (PyCFunction)SbkQImageWriterFunc_compression, METH_NOARGS},
    {"device", (PyCFunction)SbkQImageWriterFunc_device, METH_NOARGS},
    {"error", (PyCFunction)SbkQImageWriterFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQImageWriterFunc_errorString, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQImageWriterFunc_fileName, METH_NOARGS},
    {"format", (PyCFunction)SbkQImageWriterFunc_format, METH_NOARGS},
    {"gamma", (PyCFunction)SbkQImageWriterFunc_gamma, METH_NOARGS},
    {"quality", (PyCFunction)SbkQImageWriterFunc_quality, METH_NOARGS},
    {"setCompression", (PyCFunction)SbkQImageWriterFunc_setCompression, METH_O},
    {"setDevice", (PyCFunction)SbkQImageWriterFunc_setDevice, METH_O},
    {"setFileName", (PyCFunction)SbkQImageWriterFunc_setFileName, METH_O},
    {"setFormat", (PyCFunction)SbkQImageWriterFunc_setFormat, METH_O},
    {"setGamma", (PyCFunction)SbkQImageWriterFunc_setGamma, METH_O},
    {"setQuality", (PyCFunction)SbkQImageWriterFunc_setQuality, METH_O},
    {"setText", (PyCFunction)SbkQImageWriterFunc_setText, METH_VARARGS},
    {"supportedImageFormats", (PyCFunction)SbkQImageWriterFunc_supportedImageFormats, METH_NOARGS|METH_STATIC},
    {"supportsOption", (PyCFunction)SbkQImageWriterFunc_supportsOption, METH_O},
    {"write", (PyCFunction)SbkQImageWriterFunc_write, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQImageWriter_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QImageWriter",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQImageWriter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQImageWriter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QImageWriter >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QImageWriter*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QImageWriter_ImageWriterError_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QImageWriter_ImageWriterError_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QImageWriter_ImageWriterError_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ImageWriterError",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QImageWriter_ImageWriterError_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QImageWriter_ImageWriterError_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QImageWriter_ImageWriterError_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QImageWriter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QIMAGEWRITER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQImageWriter_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQImageWriter_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQImageWriter_Type));
    PyModule_AddObject(module, "QImageWriter",
        ((PyObject*)&SbkQImageWriter_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ImageWriterError
    SbkPySide_QtGuiTypes[SBK_QIMAGEWRITER_IMAGEWRITERERROR_IDX] = &SbkPySide_QtGui_QImageWriter_ImageWriterError_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QImageWriter_ImageWriterError_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QImageWriter_ImageWriterError_Type);
    PyDict_SetItemString(SbkQImageWriter_Type.super.ht_type.tp_dict,
            "ImageWriterError",((PyObject*)&SbkPySide_QtGui_QImageWriter_ImageWriterError_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageWriter_ImageWriterError_Type,
        (long) QImageWriter::UnknownError, "UnknownError");
    PyDict_SetItemString(SbkQImageWriter_Type.super.ht_type.tp_dict,
        "UnknownError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageWriter_ImageWriterError_Type.tp_dict,
        "UnknownError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageWriter_ImageWriterError_Type,
        (long) QImageWriter::DeviceError, "DeviceError");
    PyDict_SetItemString(SbkQImageWriter_Type.super.ht_type.tp_dict,
        "DeviceError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageWriter_ImageWriterError_Type.tp_dict,
        "DeviceError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QImageWriter_ImageWriterError_Type,
        (long) QImageWriter::UnsupportedFormatError, "UnsupportedFormatError");
    PyDict_SetItemString(SbkQImageWriter_Type.super.ht_type.tp_dict,
        "UnsupportedFormatError", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QImageWriter_ImageWriterError_Type.tp_dict,
        "UnsupportedFormatError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImageWriter::ImageWriterError");


    Shiboken::TypeResolver::createObjectTypeResolver<QImageWriter >("QImageWriter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QImageWriter >(typeid(QImageWriter).name());
    PySide::initQtMetaType<QImageWriter* >();
}

