/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qitemselectionmodel_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qitemselectionmodel.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QItemSelectionModelWrapper::QItemSelectionModelWrapper(QAbstractItemModel * model) : QItemSelectionModel(model), m_metaObject(0) {
    // ... middle
}

QItemSelectionModelWrapper::QItemSelectionModelWrapper(QAbstractItemModel * model, QObject * parent) : QItemSelectionModel(model, parent), m_metaObject(0) {
    // ... middle
}

void QItemSelectionModelWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QItemSelectionModelWrapper::clear()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "clear"));
    if (py_override.isNull()) {
        return this->QItemSelectionModel::clear();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QItemSelectionModelWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QItemSelectionModelWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QItemSelectionModelWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QItemSelectionModelWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QItemSelectionModel.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QItemSelectionModelWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QItemSelectionModel.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QItemSelectionModelWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QItemSelectionModel::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QItemSelectionModelWrapper::select(const QItemSelection & selection, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "select"));
    if (py_override.isNull()) {
        return this->QItemSelectionModel::select(selection, command);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QItemSelection & >::toPython(selection),
        Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QItemSelectionModelWrapper::select(const QModelIndex & index, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "select"));
    if (py_override.isNull()) {
        return this->QItemSelectionModel::select(index, command);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QModelIndex & >::toPython(index),
        Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QItemSelectionModelWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QItemSelectionModelWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QItemSelectionModel::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QItemSelectionModelWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QItemSelectionModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QItemSelectionModelWrapper::~QItemSelectionModelWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQItemSelectionModel_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QItemSelectionModel >()))
        return -1;

    QItemSelectionModelWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QItemSelectionModel", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QItemSelectionModel(QAbstractItemModel*)
    // 1: QItemSelectionModel(QAbstractItemModel*,QObject*)
    if (Shiboken::Converter<QAbstractItemModel * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QItemSelectionModel(QAbstractItemModel*)
        } else if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QItemSelectionModel(QAbstractItemModel*,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModel_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QItemSelectionModel(QAbstractItemModel*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QAbstractItemModel* cpp_arg0 = Shiboken::Converter<QAbstractItemModel* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QItemSelectionModel(QAbstractItemModel*)
                cptr = new QItemSelectionModelWrapper(cpp_arg0);
                }
                break;
            }
            case 1: // QItemSelectionModel(QAbstractItemModel*,QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QAbstractItemModel* cpp_arg0 = Shiboken::Converter<QAbstractItemModel* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QItemSelectionModel(QAbstractItemModel*,QObject*)
                cptr = new QItemSelectionModelWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QItemSelectionModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQItemSelectionModel_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQItemSelectionModel_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", "PySide.QtCore.QAbstractItemModel, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel", overloads);
        return -1;
}

static PyObject* SbkQItemSelectionModelFunc_clear(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QItemSelectionModel::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQItemSelectionModelFunc_clearSelection(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearSelection()
            cppSelf->QItemSelectionModel::clearSelection();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQItemSelectionModelFunc_columnIntersectsSelection(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "columnIntersectsSelection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: columnIntersectsSelection(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // columnIntersectsSelection(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_columnIntersectsSelection_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // columnIntersectsSelection(int,QModelIndex)const
            bool cppResult = cppSelf->QItemSelectionModel::columnIntersectsSelection(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionModelFunc_columnIntersectsSelection_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.columnIntersectsSelection", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_currentIndex(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentIndex()const
            QModelIndex cppResult = cppSelf->QItemSelectionModel::currentIndex();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionModelFunc_emitSelectionChanged(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "emitSelectionChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: emitSelectionChanged(QItemSelection,QItemSelection)
    if (numArgs == 2 && Shiboken::Converter<const QItemSelection & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QItemSelection & >::isConvertible(pyargs[1])) {
        overloadId = 0; // emitSelectionChanged(QItemSelection,QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_emitSelectionChanged_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QItemSelection* cpp_arg0 = Shiboken::Converter<QItemSelection* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QItemSelection* cpp_arg1 = Shiboken::Converter<QItemSelection* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // emitSelectionChanged(QItemSelection,QItemSelection)
            cppSelf->QItemSelectionModel::emitSelectionChanged(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQItemSelectionModelFunc_emitSelectionChanged_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection, PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.emitSelectionChanged", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_hasSelection(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasSelection()const
            bool cppResult = cppSelf->QItemSelectionModel::hasSelection();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionModelFunc_isColumnSelected(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isColumnSelected", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isColumnSelected(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // isColumnSelected(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_isColumnSelected_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // isColumnSelected(int,QModelIndex)const
            bool cppResult = cppSelf->QItemSelectionModel::isColumnSelected(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionModelFunc_isColumnSelected_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.isColumnSelected", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_isRowSelected(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isRowSelected", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isRowSelected(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // isRowSelected(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_isRowSelected_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // isRowSelected(int,QModelIndex)const
            bool cppResult = cppSelf->QItemSelectionModel::isRowSelected(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionModelFunc_isRowSelected_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.isRowSelected", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_isSelected(PyObject* self, PyObject* arg)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSelected(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // isSelected(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_isSelected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isSelected(QModelIndex)const
            bool cppResult = cppSelf->QItemSelectionModel::isSelected(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionModelFunc_isSelected_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelectionModel.isSelected", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_model(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // model()const
            const QAbstractItemModel * cppResult = cppSelf->QItemSelectionModel::model();
            pyResult = Shiboken::Converter<const QAbstractItemModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionModelFunc_reset(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QItemSelectionModel::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQItemSelectionModelFunc_rowIntersectsSelection(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rowIntersectsSelection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rowIntersectsSelection(int,QModelIndex)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // rowIntersectsSelection(int,QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_rowIntersectsSelection_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // rowIntersectsSelection(int,QModelIndex)const
            bool cppResult = cppSelf->QItemSelectionModel::rowIntersectsSelection(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionModelFunc_rowIntersectsSelection_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.rowIntersectsSelection", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_select(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "select", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    // 1: select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 1; // select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    } else if (numArgs == 2 && Shiboken::Converter<const QItemSelection & >::isConvertible(pyargs[0]) && Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_select_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QItemSelection* cpp_arg0 = Shiboken::Converter<QItemSelection* >::toCpp(pyargs[0]);
                QFlags<QItemSelectionModel::SelectionFlag> cpp_arg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // select(QItemSelection,QFlags<QItemSelectionModel::SelectionFlag>)
                cppSelf->QItemSelectionModel::select(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
                QFlags<QItemSelectionModel::SelectionFlag> cpp_arg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // select(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
                cppSelf->QItemSelectionModel::select(*cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQItemSelectionModelFunc_select_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection, PySide.QtGui.QItemSelectionModel.SelectionFlags", "PySide.QtCore.QModelIndex, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.select", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_selectedColumns(PyObject* self, PyObject* args, PyObject* kwds)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "row" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedColumns(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedColumns(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:selectedColumns", &arg))
        return 0;


    // Overloaded function decisor
    // 0: selectedColumns(int)const
    if (numArgs == 0) {
        overloadId = 0; // selectedColumns(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // selectedColumns(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_selectedColumns_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "row");
                if (value) {
                    if (arg)
                        errorArgName = "row";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedColumns(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // selectedColumns(int)const
            QList<QModelIndex > cppResult = cppSelf->QItemSelectionModel::selectedColumns(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QModelIndex > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionModelFunc_selectedColumns_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelectionModel.selectedColumns", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_selectedIndexes(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectedIndexes()const
            QList<QModelIndex > cppResult = cppSelf->QItemSelectionModel::selectedIndexes();
            pyResult = Shiboken::Converter<QList<QModelIndex > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionModelFunc_selectedRows(PyObject* self, PyObject* args, PyObject* kwds)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "column" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedRows(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedRows(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:selectedRows", &arg))
        return 0;


    // Overloaded function decisor
    // 0: selectedRows(int)const
    if (numArgs == 0) {
        overloadId = 0; // selectedRows(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // selectedRows(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_selectedRows_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (arg)
                        errorArgName = "column";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QItemSelectionModel.selectedRows(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // selectedRows(int)const
            QList<QModelIndex > cppResult = cppSelf->QItemSelectionModel::selectedRows(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QModelIndex > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionModelFunc_selectedRows_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelectionModel.selectedRows", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionModelFunc_selection(PyObject* self)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selection()const
            const QItemSelection cppResult = cppSelf->QItemSelectionModel::selection();
            pyResult = Shiboken::Converter< QItemSelection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionModelFunc_setCurrentIndex(PyObject* self, PyObject* args)
{
    QItemSelectionModel* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionModel* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCurrentIndex", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCurrentIndex(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // setCurrentIndex(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionModelFunc_setCurrentIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            QFlags<QItemSelectionModel::SelectionFlag> cpp_arg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setCurrentIndex(QModelIndex,QFlags<QItemSelectionModel::SelectionFlag>)
            cppSelf->QItemSelectionModel::setCurrentIndex(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQItemSelectionModelFunc_setCurrentIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionModel.setCurrentIndex", overloads);
        return 0;
}

static PyMethodDef SbkQItemSelectionModel_methods[] = {
    {"clear", (PyCFunction)SbkQItemSelectionModelFunc_clear, METH_NOARGS},
    {"clearSelection", (PyCFunction)SbkQItemSelectionModelFunc_clearSelection, METH_NOARGS},
    {"columnIntersectsSelection", (PyCFunction)SbkQItemSelectionModelFunc_columnIntersectsSelection, METH_VARARGS},
    {"currentIndex", (PyCFunction)SbkQItemSelectionModelFunc_currentIndex, METH_NOARGS},
    {"emitSelectionChanged", (PyCFunction)SbkQItemSelectionModelFunc_emitSelectionChanged, METH_VARARGS},
    {"hasSelection", (PyCFunction)SbkQItemSelectionModelFunc_hasSelection, METH_NOARGS},
    {"isColumnSelected", (PyCFunction)SbkQItemSelectionModelFunc_isColumnSelected, METH_VARARGS},
    {"isRowSelected", (PyCFunction)SbkQItemSelectionModelFunc_isRowSelected, METH_VARARGS},
    {"isSelected", (PyCFunction)SbkQItemSelectionModelFunc_isSelected, METH_O},
    {"model", (PyCFunction)SbkQItemSelectionModelFunc_model, METH_NOARGS},
    {"reset", (PyCFunction)SbkQItemSelectionModelFunc_reset, METH_NOARGS},
    {"rowIntersectsSelection", (PyCFunction)SbkQItemSelectionModelFunc_rowIntersectsSelection, METH_VARARGS},
    {"select", (PyCFunction)SbkQItemSelectionModelFunc_select, METH_VARARGS},
    {"selectedColumns", (PyCFunction)SbkQItemSelectionModelFunc_selectedColumns, METH_VARARGS|METH_KEYWORDS},
    {"selectedIndexes", (PyCFunction)SbkQItemSelectionModelFunc_selectedIndexes, METH_NOARGS},
    {"selectedRows", (PyCFunction)SbkQItemSelectionModelFunc_selectedRows, METH_VARARGS|METH_KEYWORDS},
    {"selection", (PyCFunction)SbkQItemSelectionModelFunc_selection, METH_NOARGS},
    {"setCurrentIndex", (PyCFunction)SbkQItemSelectionModelFunc_setCurrentIndex, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQItemSelectionModel_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QItemSelectionModel",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQItemSelectionModel_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQItemSelectionModel_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QItemSelectionModel >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QItemSelectionModel*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQItemSelectionModel_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QItemSelectionModel*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQItemSelectionModel_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QItemSelectionModel::SelectionFlags >::checkType(self) && Shiboken::Converter<QItemSelectionModel::SelectionFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        Shiboken::Converter<QItemSelectionModel::SelectionFlags>::toCpp(self)
        & Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QItemSelectionModel::SelectionFlags >::checkType(self) && Shiboken::Converter<QItemSelectionModel::SelectionFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        Shiboken::Converter<QItemSelectionModel::SelectionFlags>::toCpp(self)
        | Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QItemSelectionModel::SelectionFlags >::checkType(self) && Shiboken::Converter<QItemSelectionModel::SelectionFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        Shiboken::Converter<QItemSelectionModel::SelectionFlags>::toCpp(self)
        ^ Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QItemSelectionModel::SelectionFlags >::toPython(
        ~Shiboken::Converter<QItemSelectionModel::SelectionFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QItemSelectionModel_SelectionFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SelectionFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SelectionFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QItemSelectionModel(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QITEMSELECTIONMODEL_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQItemSelectionModel_Type);

    SbkQItemSelectionModel_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQItemSelectionModel_Type.type_discovery = &SbkQItemSelectionModel_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQItemSelectionModel_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQItemSelectionModel_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQItemSelectionModel_Type));
    PyModule_AddObject(module, "QItemSelectionModel",
        ((PyObject*)&SbkQItemSelectionModel_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: SelectionFlag
    SbkPySide_QtGuiTypes[SBK_QITEMSELECTIONMODEL_SELECTIONFLAG_IDX] = &SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type);
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
            "SelectionFlag",((PyObject*)&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type));

    // init flags class: QFlags<QItemSelectionModel::SelectionFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QITEMSELECTIONMODEL_SELECTIONFLAG__IDX] = &SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type);
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
            "SelectionFlags",((PyObject*)&SbkPySide_QtGui_QItemSelectionModel_SelectionFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::NoUpdate, "NoUpdate");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "NoUpdate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "NoUpdate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::Clear, "Clear");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "Clear", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "Clear", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::Select, "Select");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "Select", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "Select", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::Deselect, "Deselect");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "Deselect", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "Deselect", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::Toggle, "Toggle");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "Toggle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "Toggle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::Current, "Current");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "Current", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "Current", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::Rows, "Rows");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "Rows", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "Rows", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::Columns, "Columns");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "Columns", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "Columns", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::SelectCurrent, "SelectCurrent");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "SelectCurrent", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "SelectCurrent", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::ToggleCurrent, "ToggleCurrent");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "ToggleCurrent", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "ToggleCurrent", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type,
        (long) QItemSelectionModel::ClearAndSelect, "ClearAndSelect");
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict,
        "ClearAndSelect", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QItemSelectionModel_SelectionFlag_Type.tp_dict,
        "ClearAndSelect", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QItemSelectionModel::SelectionFlag");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("currentColumnChanged", "const QModelIndex&,const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict, "currentColumnChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("selectionChanged", "const QItemSelection&,const QItemSelection&", NULL);
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict, "selectionChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("currentRowChanged", "const QModelIndex&,const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict, "currentRowChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("currentChanged", "const QModelIndex&,const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQItemSelectionModel_Type.super.ht_type.tp_dict, "currentChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelectionModel >("QItemSelectionModel*");
    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelectionModel >(typeid(QItemSelectionModel).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelectionModel >(typeid(QItemSelectionModelWrapper).name());
    PySide::initQtMetaType<QItemSelectionModel* >();
}

