/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qitemselectionrange_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemmodel.h>
#include <qitemselectionmodel.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQItemSelectionRange_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QItemSelectionRange >()))
        return -1;

    QItemSelectionRange* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QItemSelectionRange", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QItemSelectionRange()
    // 1: QItemSelectionRange(QItemSelectionRange)
    // 2: QItemSelectionRange(QModelIndex)
    // 3: QItemSelectionRange(QModelIndex,QModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QItemSelectionRange()
    } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QItemSelectionRange(QModelIndex)
        } else if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
            overloadId = 3; // QItemSelectionRange(QModelIndex,QModelIndex)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QItemSelectionRange & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QItemSelectionRange(QItemSelectionRange)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionRange_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QItemSelectionRange()
            {

                if(!PyErr_Occurred()) {
                // QItemSelectionRange()
                cptr = new QItemSelectionRange();
                }
                break;
            }
            case 1: // QItemSelectionRange(QItemSelectionRange)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QItemSelectionRange* cpp_arg0 = Shiboken::Converter<QItemSelectionRange* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QItemSelectionRange(QItemSelectionRange)
                cptr = new QItemSelectionRange(*cpp_arg0);
                }
                break;
            }
            case 2: // QItemSelectionRange(QModelIndex)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QItemSelectionRange(QModelIndex)
                cptr = new QItemSelectionRange(*cpp_arg0);
                }
                break;
            }
            case 3: // QItemSelectionRange(QModelIndex,QModelIndex)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QItemSelectionRange(QModelIndex,QModelIndex)
                cptr = new QItemSelectionRange(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QItemSelectionRange >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQItemSelectionRange_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQItemSelectionRange_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QItemSelectionRange", "PySide.QtCore.QModelIndex", "PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionRange", overloads);
        return -1;
}

static PyObject* SbkQItemSelectionRangeFunc_bottom(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottom()const
            int cppResult = cppSelf->QItemSelectionRange::bottom();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_bottomRight(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottomRight()const
            QModelIndex cppResult = cppSelf->QItemSelectionRange::bottomRight();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_contains(PyObject* self, PyObject* args)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQItemSelectionRangeFunc_contains_TypeError;

    if (!PyArg_UnpackTuple(args, "contains", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: contains(QModelIndex)const
    // 1: contains(int,int,QModelIndex)const
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[2])) {
        overloadId = 1; // contains(int,int,QModelIndex)const
    } else if (numArgs == 1 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0])) {
        overloadId = 0; // contains(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionRangeFunc_contains_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // contains(QModelIndex)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // contains(QModelIndex)const
                bool cppResult = cppSelf->QItemSelectionRange::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // contains(int,int,QModelIndex)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QModelIndex* cpp_arg2 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // contains(int,int,QModelIndex)const
                bool cppResult = cppSelf->QItemSelectionRange::contains(cpp_arg0, cpp_arg1, *cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionRangeFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", "int, int, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QItemSelectionRange.contains", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionRangeFunc_height(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            int cppResult = cppSelf->QItemSelectionRange::height();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_indexes(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // indexes()const
            QList<QModelIndex > cppResult = cppSelf->QItemSelectionRange::indexes();
            pyResult = Shiboken::Converter<QList<QModelIndex > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_intersected(PyObject* self, PyObject* arg)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QItemSelectionRange)const
    if (Shiboken::Converter<const QItemSelectionRange & >::isConvertible(arg)) {
        overloadId = 0; // intersected(QItemSelectionRange)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionRangeFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QItemSelectionRange* cpp_arg0 = Shiboken::Converter<QItemSelectionRange* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // intersected(QItemSelectionRange)const
            QItemSelectionRange cppResult = cppSelf->QItemSelectionRange::intersected(*cpp_arg0);
            pyResult = Shiboken::Converter<QItemSelectionRange >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionRangeFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelectionRange.intersected", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionRangeFunc_intersects(PyObject* self, PyObject* arg)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QItemSelectionRange)const
    if (Shiboken::Converter<const QItemSelectionRange & >::isConvertible(arg)) {
        overloadId = 0; // intersects(QItemSelectionRange)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQItemSelectionRangeFunc_intersects_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QItemSelectionRange* cpp_arg0 = Shiboken::Converter<QItemSelectionRange* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // intersects(QItemSelectionRange)const
            bool cppResult = cppSelf->QItemSelectionRange::intersects(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQItemSelectionRangeFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionRange", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QItemSelectionRange.intersects", overloads);
        return 0;
}

static PyObject* SbkQItemSelectionRangeFunc_isEmpty(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QItemSelectionRange::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_isValid(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QItemSelectionRange::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_left(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // left()const
            int cppResult = cppSelf->QItemSelectionRange::left();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_model(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // model()const
            const QAbstractItemModel * cppResult = cppSelf->QItemSelectionRange::model();
            pyResult = Shiboken::Converter<const QAbstractItemModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_parent(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parent()const
            QModelIndex cppResult = cppSelf->QItemSelectionRange::parent();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_right(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // right()const
            int cppResult = cppSelf->QItemSelectionRange::right();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_top(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // top()const
            int cppResult = cppSelf->QItemSelectionRange::top();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_topLeft(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topLeft()const
            QModelIndex cppResult = cppSelf->QItemSelectionRange::topLeft();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQItemSelectionRangeFunc_width(PyObject* self)
{
    QItemSelectionRange* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            int cppResult = cppSelf->QItemSelectionRange::width();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQItemSelectionRange_methods[] = {
    {"bottom", (PyCFunction)SbkQItemSelectionRangeFunc_bottom, METH_NOARGS},
    {"bottomRight", (PyCFunction)SbkQItemSelectionRangeFunc_bottomRight, METH_NOARGS},
    {"contains", (PyCFunction)SbkQItemSelectionRangeFunc_contains, METH_VARARGS},
    {"height", (PyCFunction)SbkQItemSelectionRangeFunc_height, METH_NOARGS},
    {"indexes", (PyCFunction)SbkQItemSelectionRangeFunc_indexes, METH_NOARGS},
    {"intersected", (PyCFunction)SbkQItemSelectionRangeFunc_intersected, METH_O},
    {"intersects", (PyCFunction)SbkQItemSelectionRangeFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)SbkQItemSelectionRangeFunc_isEmpty, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQItemSelectionRangeFunc_isValid, METH_NOARGS},
    {"left", (PyCFunction)SbkQItemSelectionRangeFunc_left, METH_NOARGS},
    {"model", (PyCFunction)SbkQItemSelectionRangeFunc_model, METH_NOARGS},
    {"parent", (PyCFunction)SbkQItemSelectionRangeFunc_parent, METH_NOARGS},
    {"right", (PyCFunction)SbkQItemSelectionRangeFunc_right, METH_NOARGS},
    {"top", (PyCFunction)SbkQItemSelectionRangeFunc_top, METH_NOARGS},
    {"topLeft", (PyCFunction)SbkQItemSelectionRangeFunc_topLeft, METH_NOARGS},
    {"width", (PyCFunction)SbkQItemSelectionRangeFunc_width, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQItemSelectionRange_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QItemSelectionRange& cpp_self = *Shiboken::Converter<QItemSelectionRange* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QItemSelectionRange & >::isConvertible(other)) {
                // operator!=(const QItemSelectionRange & other) const
                QItemSelectionRange* cpp_other = Shiboken::Converter<QItemSelectionRange* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QItemSelectionRange  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQItemSelectionRange_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QItemSelectionRange & >::isConvertible(other)) {
                // operator==(const QItemSelectionRange & other) const
                QItemSelectionRange* cpp_other = Shiboken::Converter<QItemSelectionRange* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QItemSelectionRange  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQItemSelectionRange_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQItemSelectionRange_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQItemSelectionRange_HashFunc(PyObject* obj){
    return qHash(Shiboken::Converter<QItemSelectionRange >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQItemSelectionRange_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QItemSelectionRange",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQItemSelectionRange_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQItemSelectionRange_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQItemSelectionRange_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQItemSelectionRange_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QItemSelectionRange >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QItemSelectionRange",
    /*user_data*/           0
};
} //extern


void init_QItemSelectionRange(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QITEMSELECTIONRANGE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQItemSelectionRange_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQItemSelectionRange_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQItemSelectionRange_Type));
    PyModule_AddObject(module, "QItemSelectionRange",
        ((PyObject*)&SbkQItemSelectionRange_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QItemSelectionRange >("QItemSelectionRange");
    Shiboken::TypeResolver::createObjectTypeResolver<QItemSelectionRange >("QItemSelectionRange*");
    Shiboken::TypeResolver::createValueTypeResolver<QItemSelectionRange >(typeid(QItemSelectionRange).name());
    PySide::initQtMetaType<QItemSelectionRange >();
}

