/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qkeyevent_wrapper.h"

// Extra includes
#include <qevent.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QKeyEventWrapper::QKeyEventWrapper(QEvent::Type type, int key, QFlags<Qt::KeyboardModifier> modifiers, const QString & text, bool autorep, ushort count) : QKeyEvent(type, key, modifiers, text, autorep, count) {
    // ... middle
}

QKeyEventWrapper::~QKeyEventWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQKeyEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QKeyEvent >()))
        return -1;

    QKeyEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "autorep", "count", "text" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeyEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent(): too many arguments");
        return -1;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:QKeyEvent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
    if (numArgs >= 3 && Shiboken::Converter<QEvent::Type >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
            } else if (SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                } else if (SbkNumber_Check(pyargs[5])) {
                    overloadId = 0; // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQKeyEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "text");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "text";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "autorep");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "autorep";
                    else
                        pyargs[4] = value;
                }
                value = PyDict_GetItemString(kwds, "count");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "count";
                    else
                        pyargs[5] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeyEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QEvent::Type cpp_arg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QFlags<Qt::KeyboardModifier> cpp_arg2 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[2]);
            QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            bool cpp_arg4 = pyargs[4] ? Shiboken::Converter<bool >::toCpp(pyargs[4]) : false;
            ushort cpp_arg5 = pyargs[5] ? Shiboken::Converter<ushort >::toCpp(pyargs[5]) : 1;

            if(!PyErr_Occurred()) {
            // QKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,QString,bool,ushort)
            cptr = new QKeyEventWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QKeyEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQKeyEvent_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQKeyEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, int, PySide.QtCore.Qt.KeyboardModifiers, QString = QString(), bool = false, ushort = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QKeyEvent", overloads);
        return -1;
}

static PyObject* SbkQKeyEventFunc_count(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // count()const
            int cppResult = cppSelf->QKeyEvent::count();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_createExtendedKeyEvent(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "autorep", "count", "text" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 9) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent(): too many arguments");
        return 0;
    } else if (numArgs < 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOOO:createExtendedKeyEvent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8])))
        return 0;


    // Overloaded function decisor
    // 0: createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
    if (numArgs >= 6 && Shiboken::Converter<QEvent::Type >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[6])) {
            if (numArgs == 7) {
                overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
            } else if (SbkNumber_Check(pyargs[7])) {
                if (numArgs == 8) {
                    overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
                } else if (SbkNumber_Check(pyargs[8])) {
                    overloadId = 0; // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQKeyEventFunc_createExtendedKeyEvent_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "text");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "text";
                    else
                        pyargs[6] = value;
                }
                value = PyDict_GetItemString(kwds, "autorep");
                if (value) {
                    if (pyargs[7])
                        errorArgName = "autorep";
                    else
                        pyargs[7] = value;
                }
                value = PyDict_GetItemString(kwds, "count");
                if (value) {
                    if (pyargs[8])
                        errorArgName = "count";
                    else
                        pyargs[8] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QEvent::Type cpp_arg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QFlags<Qt::KeyboardModifier> cpp_arg2 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[2]);
            quint32 cpp_arg3 = Shiboken::Converter<quint32 >::toCpp(pyargs[3]);
            quint32 cpp_arg4 = Shiboken::Converter<quint32 >::toCpp(pyargs[4]);
            quint32 cpp_arg5 = Shiboken::Converter<quint32 >::toCpp(pyargs[5]);
            QString cpp_arg6 = pyargs[6] ? Shiboken::Converter<QString >::toCpp(pyargs[6]) : QString();
            bool cpp_arg7 = pyargs[7] ? Shiboken::Converter<bool >::toCpp(pyargs[7]) : false;
            ushort cpp_arg8 = pyargs[8] ? Shiboken::Converter<ushort >::toCpp(pyargs[8]) : 1;

            if(!PyErr_Occurred()) {
            // createExtendedKeyEvent(QEvent::Type,int,QFlags<Qt::KeyboardModifier>,quint32,quint32,quint32,QString,bool,ushort)
            QKeyEvent * cppResult = QKeyEvent::createExtendedKeyEvent(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6, cpp_arg7, cpp_arg8);
            pyResult = Shiboken::Converter<QKeyEvent * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQKeyEventFunc_createExtendedKeyEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, int, PySide.QtCore.Qt.KeyboardModifiers, unsigned int, unsigned int, unsigned int, QString = QString(), bool = false, ushort = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QKeyEvent.createExtendedKeyEvent", overloads);
        return 0;
}

static PyObject* SbkQKeyEventFunc_hasExtendedInfo(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasExtendedInfo()const
            bool cppResult = cppSelf->QKeyEvent::hasExtendedInfo();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_isAutoRepeat(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAutoRepeat()const
            bool cppResult = cppSelf->QKeyEvent::isAutoRepeat();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_key(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // key()const
            int cppResult = cppSelf->QKeyEvent::key();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_matches(PyObject* self, PyObject* arg)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: matches(QKeySequence::StandardKey)const
    if (Shiboken::Converter<QKeySequence::StandardKey >::isConvertible(arg)) {
        overloadId = 0; // matches(QKeySequence::StandardKey)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQKeyEventFunc_matches_TypeError;

    // Call function/method
    {
        {
            QKeySequence::StandardKey cpp_arg0 = Shiboken::Converter<QKeySequence::StandardKey >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // matches(QKeySequence::StandardKey)const
            bool cppResult = cppSelf->QKeyEvent::matches(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQKeyEventFunc_matches_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence.StandardKey", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QKeyEvent.matches", overloads);
        return 0;
}

static PyObject* SbkQKeyEventFunc_modifiers(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // modifiers()const
            QFlags<Qt::KeyboardModifier> cppResult = cppSelf->QKeyEvent::modifiers();
            pyResult = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_nativeModifiers(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nativeModifiers()const
            quint32 cppResult = cppSelf->QKeyEvent::nativeModifiers();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_nativeScanCode(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nativeScanCode()const
            quint32 cppResult = cppSelf->QKeyEvent::nativeScanCode();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_nativeVirtualKey(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nativeVirtualKey()const
            quint32 cppResult = cppSelf->QKeyEvent::nativeVirtualKey();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQKeyEventFunc_text(PyObject* self)
{
    QKeyEvent* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QKeyEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QString cppResult = cppSelf->QKeyEvent::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQKeyEvent_methods[] = {
    {"count", (PyCFunction)SbkQKeyEventFunc_count, METH_NOARGS},
    {"createExtendedKeyEvent", (PyCFunction)SbkQKeyEventFunc_createExtendedKeyEvent, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"hasExtendedInfo", (PyCFunction)SbkQKeyEventFunc_hasExtendedInfo, METH_NOARGS},
    {"isAutoRepeat", (PyCFunction)SbkQKeyEventFunc_isAutoRepeat, METH_NOARGS},
    {"key", (PyCFunction)SbkQKeyEventFunc_key, METH_NOARGS},
    {"matches", (PyCFunction)SbkQKeyEventFunc_matches, METH_O},
    {"modifiers", (PyCFunction)SbkQKeyEventFunc_modifiers, METH_NOARGS},
    {"nativeModifiers", (PyCFunction)SbkQKeyEventFunc_nativeModifiers, METH_NOARGS},
    {"nativeScanCode", (PyCFunction)SbkQKeyEventFunc_nativeScanCode, METH_NOARGS},
    {"nativeVirtualKey", (PyCFunction)SbkQKeyEventFunc_nativeVirtualKey, METH_NOARGS},
    {"text", (PyCFunction)SbkQKeyEventFunc_text, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQKeyEvent_get_k(PyObject* self, void*)
{
    return Shiboken::Converter<int >::toPython(Shiboken::Converter<QKeyEvent* >::toCpp(self)->k);
}
static int SbkQKeyEvent_set_k(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'k' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'k', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QKeyEvent* >::toCpp(self)->k = Shiboken::Converter<int >::toCpp(value);

    return 0;
}

static PyObject* SbkQKeyEvent_get_txt(PyObject* self, void*)
{
    return Shiboken::Converter<QString >::toPython(Shiboken::Converter<QKeyEvent* >::toCpp(self)->txt);
}
static int SbkQKeyEvent_set_txt(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'txt' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'txt', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QKeyEvent* >::toCpp(self)->txt = Shiboken::Converter<QString >::toCpp(value);

    return 0;
}

static PyObject* SbkQKeyEvent_get_c(PyObject* self, void*)
{
    return Shiboken::Converter<ushort >::toPython(Shiboken::Converter<QKeyEvent* >::toCpp(self)->c);
}
static int SbkQKeyEvent_set_c(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'c' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'c', 'ushort' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QKeyEvent* >::toCpp(self)->c = Shiboken::Converter<ushort >::toCpp(value);

    return 0;
}

static PyObject* SbkQKeyEvent_get_autor(PyObject* self, void*)
{
    return Shiboken::Converter<unsigned int >::toPython(Shiboken::Converter<QKeyEvent* >::toCpp(self)->autor);
}
static int SbkQKeyEvent_set_autor(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'autor' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'autor', 'uint' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QKeyEvent* >::toCpp(self)->autor = Shiboken::Converter<unsigned int >::toCpp(value);

    return 0;
}

// Getters and Setters for QKeyEvent
static PyGetSetDef SbkQKeyEvent_getsetlist[] = {
    {const_cast<char*>("k"), SbkQKeyEvent_get_k, SbkQKeyEvent_set_k},
    {const_cast<char*>("txt"), SbkQKeyEvent_get_txt, SbkQKeyEvent_set_txt},
    {const_cast<char*>("c"), SbkQKeyEvent_get_c, SbkQKeyEvent_set_c},
    {const_cast<char*>("autor"), SbkQKeyEvent_get_autor, SbkQKeyEvent_set_autor},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQKeyEvent_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QKeyEvent",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQKeyEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQKeyEvent_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQKeyEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QKeyEvent >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QKeyEvent*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQKeyEvent_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
     if ( reinterpret_cast<QKeyEvent*>(cptr)->type() == QEvent::KeyPress ||  reinterpret_cast<QKeyEvent*>(cptr)->type() == QEvent::KeyRelease)
        return &SbkQKeyEvent_Type;
    return 0;
}


void init_QKeyEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QKEYEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQKeyEvent_Type);

    SbkQKeyEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX];
    // Fill type discovery information
    SbkQKeyEvent_Type.type_discovery = &SbkQKeyEvent_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX]), &SbkQKeyEvent_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQKeyEvent_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQKeyEvent_Type));
    PyModule_AddObject(module, "QKeyEvent",
        ((PyObject*)&SbkQKeyEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QKeyEvent >("QKeyEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QKeyEvent >(typeid(QKeyEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QKeyEvent >(typeid(QKeyEventWrapper).name());
    PySide::initQtMetaType<QKeyEvent* >();
}

