/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qmainwindow_wrapper.h"

// Extra includes
#include <QList>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qdockwidget.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmainwindow.h>
#include <qmargins.h>
#include <qmenu.h>
#include <qmenubar.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstatusbar.h>
#include <qstyle.h>
#include <qtoolbar.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QMainWindowWrapper::QMainWindowWrapper(QWidget * parent, QFlags<Qt::WindowType> flags) : QMainWindow(parent, flags), m_metaObject(0) {
    // ... middle
}

void QMainWindowWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMainWindowWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMainWindowWrapper::contextMenuEvent(QContextMenuEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QMainWindow::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QMenu * QMainWindowWrapper::createPopupMenu()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createPopupMenu"));
    if (py_override.isNull()) {
        return this->QMainWindow::createPopupMenu();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QMenu * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.createPopupMenu", SbkType<QMenu * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QMenu * cppResult(Shiboken::Converter<QMenu * >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QMainWindowWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMainWindowWrapper::dragEnterEvent(QDragEnterEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragEnterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::dragLeaveEvent(QDragLeaveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragLeaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::dragMoveEvent(QDragMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::dropEvent(QDropEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dropEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QMainWindowWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QMainWindow::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QMainWindowWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::focusInEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusInEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QMainWindowWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::focusOutEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusOutEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QMainWindowWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QMainWindowWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::keyPressEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyPressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::keyReleaseEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMainWindowWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QMainWindowWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QMainWindowWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QWidget::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::mouseDoubleClickEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseDoubleClickEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::mouseMoveEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::mousePressEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mousePressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::mouseReleaseEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QMainWindowWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QMainWindow.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QMainWindowWrapper::paintEvent(QPaintEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QWidget::paintEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::resizeEvent(QResizeEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::resizeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMainWindowWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QWidget::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QMainWindowWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QWidget::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMainWindowWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QWidget::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QMainWindowWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QMainWindow::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QMainWindowWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QMainWindow::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QMainWindowWrapper::~QMainWindowWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMainWindow_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMainWindow >()))
        return -1;

    QMainWindowWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QMainWindow", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QMainWindow(QWidget*,QFlags<Qt::WindowType>)
    if (numArgs == 0) {
        overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindow_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
            QFlags<Qt::WindowType> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
            // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
            cptr = new QMainWindowWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[0], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMainWindow >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMainWindow_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQMainWindow_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow", overloads);
        return -1;
}

static PyObject* SbkQMainWindowFunc_addDockWidget(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addDockWidget", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addDockWidget(Qt::DockWidgetArea,QDockWidget*)
    // 1: addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
    if (numArgs >= 2 && Shiboken::Converter<Qt::DockWidgetArea >::isConvertible(pyargs[0]) && Shiboken::Converter<QDockWidget * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
        } else if (numArgs == 3 && Shiboken::Converter<Qt::Orientation >::isConvertible(pyargs[2])) {
            overloadId = 1; // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_addDockWidget_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
            {
                Qt::DockWidgetArea cpp_arg0 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QDockWidget* cpp_arg1 = Shiboken::Converter<QDockWidget* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
                cppSelf->QMainWindow::addDockWidget(cpp_arg0, cpp_arg1);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
            case 1: // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
            {
                Qt::DockWidgetArea cpp_arg0 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QDockWidget* cpp_arg1 = Shiboken::Converter<QDockWidget* >::toCpp(pyargs[1]);
                Qt::Orientation cpp_arg2 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
                cppSelf->QMainWindow::addDockWidget(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(self, pyargs[1]);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_addDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DockWidgetArea, PySide.QtGui.QDockWidget", "PySide.QtCore.Qt.DockWidgetArea, PySide.QtGui.QDockWidget, PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.addDockWidget", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_addToolBar(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addToolBar", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addToolBar(QToolBar*)
    // 1: addToolBar(Qt::ToolBarArea,QToolBar*)
    // 2: addToolBar(QString)
    if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 2; // addToolBar(QString)
    } else if (numArgs == 2 && Shiboken::Converter<Qt::ToolBarArea >::isConvertible(pyargs[0]) && Shiboken::Converter<QToolBar * >::isConvertible(pyargs[1])) {
        overloadId = 1; // addToolBar(Qt::ToolBarArea,QToolBar*)
    } else if (numArgs == 1 && Shiboken::Converter<QToolBar * >::isConvertible(pyargs[0])) {
        overloadId = 0; // addToolBar(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_addToolBar_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addToolBar(QToolBar*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QToolBar* cpp_arg0 = Shiboken::Converter<QToolBar* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addToolBar(QToolBar*)
                cppSelf->QMainWindow::addToolBar(cpp_arg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // addToolBar(Qt::ToolBarArea,QToolBar*)
            {
                Qt::ToolBarArea cpp_arg0 = Shiboken::Converter<Qt::ToolBarArea >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QToolBar* cpp_arg1 = Shiboken::Converter<QToolBar* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addToolBar(Qt::ToolBarArea,QToolBar*)
                cppSelf->QMainWindow::addToolBar(cpp_arg0, cpp_arg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 2: // addToolBar(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addToolBar(QString)
                QToolBar * cppResult = cppSelf->QMainWindow::addToolBar(cpp_arg0);
                pyResult = Shiboken::Converter<QToolBar * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_addToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", "PySide.QtCore.Qt.ToolBarArea, PySide.QtGui.QToolBar", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.addToolBar", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_addToolBarBreak(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "area" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.addToolBarBreak(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.addToolBarBreak(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:addToolBarBreak", &arg))
        return 0;


    // Overloaded function decisor
    // 0: addToolBarBreak(Qt::ToolBarArea)
    if (numArgs == 0) {
        overloadId = 0; // addToolBarBreak(Qt::ToolBarArea)
    } else if (Shiboken::Converter<Qt::ToolBarArea >::isConvertible(arg)) {
        overloadId = 0; // addToolBarBreak(Qt::ToolBarArea)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_addToolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "area");
                if (value) {
                    if (arg)
                        errorArgName = "area";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.addToolBarBreak(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::ToolBarArea cpp_arg0 = arg ? Shiboken::Converter<Qt::ToolBarArea >::toCpp(arg) : Qt::TopToolBarArea;

            if(!PyErr_Occurred()) {
            // addToolBarBreak(Qt::ToolBarArea)
            cppSelf->QMainWindow::addToolBarBreak(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_addToolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ToolBarArea = Qt.TopToolBarArea", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.addToolBarBreak", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_centralWidget(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // centralWidget()const
            QWidget * cppResult = cppSelf->QMainWindow::centralWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter<QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QContextMenuEvent* cpp_arg0 = Shiboken::Converter<QContextMenuEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contextMenuEvent(QContextMenuEvent*)
            cppSelf->QMainWindow::contextMenuEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.contextMenuEvent", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_corner(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: corner(Qt::Corner)const
    if (Shiboken::Converter<Qt::Corner >::isConvertible(arg)) {
        overloadId = 0; // corner(Qt::Corner)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_corner_TypeError;

    // Call function/method
    {
        {
            Qt::Corner cpp_arg0 = Shiboken::Converter<Qt::Corner >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // corner(Qt::Corner)const
            Qt::DockWidgetArea cppResult = cppSelf->QMainWindow::corner(cpp_arg0);
            pyResult = Shiboken::Converter<Qt::DockWidgetArea >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_corner_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Corner", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.corner", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_createPopupMenu(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // createPopupMenu()
            QMenu * cppResult = cppSelf->QMainWindow::createPopupMenu();
            pyResult = Shiboken::Converter<QMenu * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_dockOptions(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dockOptions()const
            QFlags<QMainWindow::DockOption> cppResult = cppSelf->QMainWindow::dockOptions();
            pyResult = Shiboken::Converter<QFlags<QMainWindow::DockOption> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_dockWidgetArea(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: dockWidgetArea(QDockWidget*)const
    if (Shiboken::Converter<QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // dockWidgetArea(QDockWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_dockWidgetArea_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDockWidget* cpp_arg0 = Shiboken::Converter<QDockWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dockWidgetArea(QDockWidget*)const
            Qt::DockWidgetArea cppResult = cppSelf->QMainWindow::dockWidgetArea(cpp_arg0);
            pyResult = Shiboken::Converter<Qt::DockWidgetArea >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_dockWidgetArea_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.dockWidgetArea", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_documentMode(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentMode()const
            bool cppResult = cppSelf->QMainWindow::documentMode();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_event(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QMainWindow::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.event", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_iconSize(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // iconSize()const
            QSize cppResult = cppSelf->QMainWindow::iconSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_insertToolBar(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertToolBar", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertToolBar(QToolBar*,QToolBar*)
    if (numArgs == 2 && Shiboken::Converter<QToolBar * >::isConvertible(pyargs[0]) && Shiboken::Converter<QToolBar * >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertToolBar(QToolBar*,QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_insertToolBar_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QToolBar* cpp_arg0 = Shiboken::Converter<QToolBar* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QToolBar* cpp_arg1 = Shiboken::Converter<QToolBar* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insertToolBar(QToolBar*,QToolBar*)
            cppSelf->QMainWindow::insertToolBar(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_insertToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar, PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.insertToolBar", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_insertToolBarBreak(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertToolBarBreak(QToolBar*)
    if (Shiboken::Converter<QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // insertToolBarBreak(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_insertToolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QToolBar* cpp_arg0 = Shiboken::Converter<QToolBar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // insertToolBarBreak(QToolBar*)
            cppSelf->QMainWindow::insertToolBarBreak(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_insertToolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.insertToolBarBreak", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_isAnimated(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAnimated()const
            bool cppResult = cppSelf->QMainWindow::isAnimated();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_isDockNestingEnabled(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDockNestingEnabled()const
            bool cppResult = cppSelf->QMainWindow::isDockNestingEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_isSeparator(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSeparator(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // isSeparator(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_isSeparator_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isSeparator(QPoint)const
            bool cppResult = cppSelf->QMainWindow::isSeparator(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_isSeparator_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.isSeparator", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_menuBar(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // menuBar()const
            QMenuBar * cppResult = cppSelf->QMainWindow::menuBar();
            pyResult = Shiboken::Converter<QMenuBar * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_menuWidget(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // menuWidget()const
            QWidget * cppResult = cppSelf->QMainWindow::menuWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_removeDockWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeDockWidget(QDockWidget*)
    if (Shiboken::Converter<QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // removeDockWidget(QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_removeDockWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDockWidget* cpp_arg0 = Shiboken::Converter<QDockWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeDockWidget(QDockWidget*)
            cppSelf->QMainWindow::removeDockWidget(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_removeDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.removeDockWidget", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_removeToolBar(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeToolBar(QToolBar*)
    if (Shiboken::Converter<QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // removeToolBar(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_removeToolBar_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QToolBar* cpp_arg0 = Shiboken::Converter<QToolBar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeToolBar(QToolBar*)
            cppSelf->QMainWindow::removeToolBar(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_removeToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.removeToolBar", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_removeToolBarBreak(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeToolBarBreak(QToolBar*)
    if (Shiboken::Converter<QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // removeToolBarBreak(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_removeToolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QToolBar* cpp_arg0 = Shiboken::Converter<QToolBar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeToolBarBreak(QToolBar*)
            cppSelf->QMainWindow::removeToolBarBreak(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_removeToolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.removeToolBarBreak", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_restoreDockWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreDockWidget(QDockWidget*)
    if (Shiboken::Converter<QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // restoreDockWidget(QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_restoreDockWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDockWidget* cpp_arg0 = Shiboken::Converter<QDockWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // restoreDockWidget(QDockWidget*)
            bool cppResult = cppSelf->QMainWindow::restoreDockWidget(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_restoreDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.restoreDockWidget", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_restoreState(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "version" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.restoreState(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.restoreState(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.restoreState(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:restoreState", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: restoreState(QByteArray,int)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // restoreState(QByteArray,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // restoreState(QByteArray,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_restoreState_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "version");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "version";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.restoreState(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // restoreState(QByteArray,int)
            bool cppResult = cppSelf->QMainWindow::restoreState(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_restoreState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.restoreState", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_saveState(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "version" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.saveState(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.saveState(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:saveState", &arg))
        return 0;


    // Overloaded function decisor
    // 0: saveState(int)const
    if (numArgs == 0) {
        overloadId = 0; // saveState(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // saveState(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_saveState_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "version");
                if (value) {
                    if (arg)
                        errorArgName = "version";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.saveState(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // saveState(int)const
            QByteArray cppResult = cppSelf->QMainWindow::saveState(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_saveState_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.saveState", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setAnimated(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnimated(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAnimated(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setAnimated_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAnimated(bool)
            cppSelf->QMainWindow::setAnimated(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setAnimated_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setAnimated", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setCentralWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCentralWidget(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setCentralWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setCentralWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCentralWidget(QWidget*)
            // Begin code injection
            
            // TEMPLATE - replace_child - START
            QWidget* oldChild = cppSelf->centralWidget();
            if (oldChild) {
               Shiboken::AutoDecRef pyChild(Shiboken::Converter<QWidget* >::toPython(oldChild));
               Shiboken::setParent(NULL, pyChild);
            }
            Shiboken::setParent(self, arg);
            // TEMPLATE - replace_child - END
            
            // End of code injection

            cppSelf->QMainWindow::setCentralWidget(cpp_arg0);

            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setCentralWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setCentralWidget", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setCorner(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCorner", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCorner(Qt::Corner,Qt::DockWidgetArea)
    if (numArgs == 2 && Shiboken::Converter<Qt::Corner >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::DockWidgetArea >::isConvertible(pyargs[1])) {
        overloadId = 0; // setCorner(Qt::Corner,Qt::DockWidgetArea)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setCorner_TypeError;

    // Call function/method
    {
        {
            Qt::Corner cpp_arg0 = Shiboken::Converter<Qt::Corner >::toCpp(pyargs[0]);
            Qt::DockWidgetArea cpp_arg1 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setCorner(Qt::Corner,Qt::DockWidgetArea)
            cppSelf->QMainWindow::setCorner(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setCorner_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Corner, PySide.QtCore.Qt.DockWidgetArea", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.setCorner", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setDockNestingEnabled(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDockNestingEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDockNestingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setDockNestingEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDockNestingEnabled(bool)
            cppSelf->QMainWindow::setDockNestingEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setDockNestingEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setDockNestingEnabled", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setDockOptions(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDockOptions(QFlags<QMainWindow::DockOption>)
    if (Shiboken::Converter<QFlags<QMainWindow::DockOption> >::isConvertible(arg)) {
        overloadId = 0; // setDockOptions(QFlags<QMainWindow::DockOption>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setDockOptions_TypeError;

    // Call function/method
    {
        {
            QFlags<QMainWindow::DockOption> cpp_arg0 = Shiboken::Converter<QFlags<QMainWindow::DockOption> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDockOptions(QFlags<QMainWindow::DockOption>)
            cppSelf->QMainWindow::setDockOptions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setDockOptions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMainWindow.DockOptions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setDockOptions", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setDocumentMode(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentMode(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDocumentMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setDocumentMode_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDocumentMode(bool)
            cppSelf->QMainWindow::setDocumentMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setDocumentMode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setDocumentMode", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setIconSize(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconSize(QSize)
    if (Shiboken::Converter<const QSize & >::isConvertible(arg)) {
        overloadId = 0; // setIconSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setIconSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIconSize(QSize)
            cppSelf->QMainWindow::setIconSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setIconSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setIconSize", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setMenuBar(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMenuBar(QMenuBar*)
    if (Shiboken::Converter<QMenuBar * >::isConvertible(arg)) {
        overloadId = 0; // setMenuBar(QMenuBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setMenuBar_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMenuBar* cpp_arg0 = Shiboken::Converter<QMenuBar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMenuBar(QMenuBar*)
            // Begin code injection
            
            // TEMPLATE - replace_child - START
            QMenuBar* oldChild = cppSelf->menuBar();
            if (oldChild) {
               Shiboken::AutoDecRef pyChild(Shiboken::Converter<QMenuBar* >::toPython(oldChild));
               Shiboken::setParent(NULL, pyChild);
            }
            Shiboken::setParent(self, arg);
            // TEMPLATE - replace_child - END
            
            // End of code injection

            cppSelf->QMainWindow::setMenuBar(cpp_arg0);

            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setMenuBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMenuBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setMenuBar", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setMenuWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMenuWidget(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setMenuWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setMenuWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMenuWidget(QWidget*)
            // Begin code injection
            
            // TEMPLATE - replace_child - START
            QWidget* oldChild = cppSelf->menuWidget();
            if (oldChild) {
               Shiboken::AutoDecRef pyChild(Shiboken::Converter<QWidget* >::toPython(oldChild));
               Shiboken::setParent(NULL, pyChild);
            }
            Shiboken::setParent(self, arg);
            // TEMPLATE - replace_child - END
            
            // End of code injection

            cppSelf->QMainWindow::setMenuWidget(cpp_arg0);

            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setMenuWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setMenuWidget", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setStatusBar(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatusBar(QStatusBar*)
    if (Shiboken::Converter<QStatusBar * >::isConvertible(arg)) {
        overloadId = 0; // setStatusBar(QStatusBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setStatusBar_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QStatusBar* cpp_arg0 = Shiboken::Converter<QStatusBar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStatusBar(QStatusBar*)
            // Begin code injection
            
            // TEMPLATE - replace_child - START
            QStatusBar* oldChild = cppSelf->statusBar();
            if (oldChild) {
               Shiboken::AutoDecRef pyChild(Shiboken::Converter<QStatusBar* >::toPython(oldChild));
               Shiboken::setParent(NULL, pyChild);
            }
            Shiboken::setParent(self, arg);
            // TEMPLATE - replace_child - END
            
            // End of code injection

            cppSelf->QMainWindow::setStatusBar(cpp_arg0);

            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setStatusBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStatusBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setStatusBar", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setTabPosition(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setTabPosition", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
    if (numArgs == 2 && Shiboken::Converter<QFlags<Qt::DockWidgetArea> >::isConvertible(pyargs[0]) && Shiboken::Converter<QTabWidget::TabPosition >::isConvertible(pyargs[1])) {
        overloadId = 0; // setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setTabPosition_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::DockWidgetArea> cpp_arg0 = Shiboken::Converter<QFlags<Qt::DockWidgetArea> >::toCpp(pyargs[0]);
            QTabWidget::TabPosition cpp_arg1 = Shiboken::Converter<QTabWidget::TabPosition >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
            cppSelf->QMainWindow::setTabPosition(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setTabPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DockWidgetAreas, PySide.QtGui.QTabWidget.TabPosition", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.setTabPosition", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setTabShape(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabShape(QTabWidget::TabShape)
    if (Shiboken::Converter<QTabWidget::TabShape >::isConvertible(arg)) {
        overloadId = 0; // setTabShape(QTabWidget::TabShape)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setTabShape_TypeError;

    // Call function/method
    {
        {
            QTabWidget::TabShape cpp_arg0 = Shiboken::Converter<QTabWidget::TabShape >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTabShape(QTabWidget::TabShape)
            cppSelf->QMainWindow::setTabShape(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setTabShape_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTabWidget.TabShape", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setTabShape", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setToolButtonStyle(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolButtonStyle(Qt::ToolButtonStyle)
    if (Shiboken::Converter<Qt::ToolButtonStyle >::isConvertible(arg)) {
        overloadId = 0; // setToolButtonStyle(Qt::ToolButtonStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setToolButtonStyle_TypeError;

    // Call function/method
    {
        {
            Qt::ToolButtonStyle cpp_arg0 = Shiboken::Converter<Qt::ToolButtonStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setToolButtonStyle(Qt::ToolButtonStyle)
            cppSelf->QMainWindow::setToolButtonStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setToolButtonStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ToolButtonStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setToolButtonStyle", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_setUnifiedTitleAndToolBarOnMac(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUnifiedTitleAndToolBarOnMac(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUnifiedTitleAndToolBarOnMac(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_setUnifiedTitleAndToolBarOnMac_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUnifiedTitleAndToolBarOnMac(bool)
            cppSelf->QMainWindow::setUnifiedTitleAndToolBarOnMac(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_setUnifiedTitleAndToolBarOnMac_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setUnifiedTitleAndToolBarOnMac", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_splitDockWidget(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "splitDockWidget", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
    if (numArgs == 3 && Shiboken::Converter<QDockWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QDockWidget * >::isConvertible(pyargs[1]) && Shiboken::Converter<Qt::Orientation >::isConvertible(pyargs[2])) {
        overloadId = 0; // splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_splitDockWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QDockWidget* cpp_arg0 = Shiboken::Converter<QDockWidget* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDockWidget* cpp_arg1 = Shiboken::Converter<QDockWidget* >::toCpp(pyargs[1]);
            Qt::Orientation cpp_arg2 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
            cppSelf->QMainWindow::splitDockWidget(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_splitDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget, PySide.QtGui.QDockWidget, PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.splitDockWidget", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_statusBar(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // statusBar()const
            QStatusBar * cppResult = cppSelf->QMainWindow::statusBar();
            pyResult = Shiboken::Converter<QStatusBar * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_tabPosition(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tabPosition(Qt::DockWidgetArea)const
    if (Shiboken::Converter<Qt::DockWidgetArea >::isConvertible(arg)) {
        overloadId = 0; // tabPosition(Qt::DockWidgetArea)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_tabPosition_TypeError;

    // Call function/method
    {
        {
            Qt::DockWidgetArea cpp_arg0 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // tabPosition(Qt::DockWidgetArea)const
            QTabWidget::TabPosition cppResult = cppSelf->QMainWindow::tabPosition(cpp_arg0);
            pyResult = Shiboken::Converter<QTabWidget::TabPosition >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_tabPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DockWidgetArea", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.tabPosition", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_tabShape(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tabShape()const
            QTabWidget::TabShape cppResult = cppSelf->QMainWindow::tabShape();
            pyResult = Shiboken::Converter<QTabWidget::TabShape >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_tabifiedDockWidgets(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tabifiedDockWidgets(QDockWidget*)const
    if (Shiboken::Converter<QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // tabifiedDockWidgets(QDockWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_tabifiedDockWidgets_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDockWidget* cpp_arg0 = Shiboken::Converter<QDockWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // tabifiedDockWidgets(QDockWidget*)const
            QList<QDockWidget * > cppResult = cppSelf->QMainWindow::tabifiedDockWidgets(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QDockWidget * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_tabifiedDockWidgets_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.tabifiedDockWidgets", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_tabifyDockWidget(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "tabifyDockWidget", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: tabifyDockWidget(QDockWidget*,QDockWidget*)
    if (numArgs == 2 && Shiboken::Converter<QDockWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QDockWidget * >::isConvertible(pyargs[1])) {
        overloadId = 0; // tabifyDockWidget(QDockWidget*,QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_tabifyDockWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QDockWidget* cpp_arg0 = Shiboken::Converter<QDockWidget* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDockWidget* cpp_arg1 = Shiboken::Converter<QDockWidget* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // tabifyDockWidget(QDockWidget*,QDockWidget*)
            cppSelf->QMainWindow::tabifyDockWidget(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMainWindowFunc_tabifyDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget, PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.tabifyDockWidget", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_toolBarArea(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toolBarArea(QToolBar*)const
    if (Shiboken::Converter<QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // toolBarArea(QToolBar*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_toolBarArea_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QToolBar* cpp_arg0 = Shiboken::Converter<QToolBar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toolBarArea(QToolBar*)const
            Qt::ToolBarArea cppResult = cppSelf->QMainWindow::toolBarArea(cpp_arg0);
            pyResult = Shiboken::Converter<Qt::ToolBarArea >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_toolBarArea_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.toolBarArea", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_toolBarBreak(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toolBarBreak(QToolBar*)const
    if (Shiboken::Converter<QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // toolBarBreak(QToolBar*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMainWindowFunc_toolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QToolBar* cpp_arg0 = Shiboken::Converter<QToolBar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toolBarBreak(QToolBar*)const
            bool cppResult = cppSelf->QMainWindow::toolBarBreak(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMainWindowFunc_toolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.toolBarBreak", overloads);
        return 0;
}

static PyObject* SbkQMainWindowFunc_toolButtonStyle(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toolButtonStyle()const
            Qt::ToolButtonStyle cppResult = cppSelf->QMainWindow::toolButtonStyle();
            pyResult = Shiboken::Converter<Qt::ToolButtonStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMainWindowFunc_unifiedTitleAndToolBarOnMac(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unifiedTitleAndToolBarOnMac()const
            bool cppResult = cppSelf->QMainWindow::unifiedTitleAndToolBarOnMac();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQMainWindow_methods[] = {
    {"addDockWidget", (PyCFunction)SbkQMainWindowFunc_addDockWidget, METH_VARARGS},
    {"addToolBar", (PyCFunction)SbkQMainWindowFunc_addToolBar, METH_VARARGS},
    {"addToolBarBreak", (PyCFunction)SbkQMainWindowFunc_addToolBarBreak, METH_VARARGS|METH_KEYWORDS},
    {"centralWidget", (PyCFunction)SbkQMainWindowFunc_centralWidget, METH_NOARGS},
    {"contextMenuEvent", (PyCFunction)SbkQMainWindowFunc_contextMenuEvent, METH_O},
    {"corner", (PyCFunction)SbkQMainWindowFunc_corner, METH_O},
    {"createPopupMenu", (PyCFunction)SbkQMainWindowFunc_createPopupMenu, METH_NOARGS},
    {"dockOptions", (PyCFunction)SbkQMainWindowFunc_dockOptions, METH_NOARGS},
    {"dockWidgetArea", (PyCFunction)SbkQMainWindowFunc_dockWidgetArea, METH_O},
    {"documentMode", (PyCFunction)SbkQMainWindowFunc_documentMode, METH_NOARGS},
    {"event", (PyCFunction)SbkQMainWindowFunc_event, METH_O},
    {"iconSize", (PyCFunction)SbkQMainWindowFunc_iconSize, METH_NOARGS},
    {"insertToolBar", (PyCFunction)SbkQMainWindowFunc_insertToolBar, METH_VARARGS},
    {"insertToolBarBreak", (PyCFunction)SbkQMainWindowFunc_insertToolBarBreak, METH_O},
    {"isAnimated", (PyCFunction)SbkQMainWindowFunc_isAnimated, METH_NOARGS},
    {"isDockNestingEnabled", (PyCFunction)SbkQMainWindowFunc_isDockNestingEnabled, METH_NOARGS},
    {"isSeparator", (PyCFunction)SbkQMainWindowFunc_isSeparator, METH_O},
    {"menuBar", (PyCFunction)SbkQMainWindowFunc_menuBar, METH_NOARGS},
    {"menuWidget", (PyCFunction)SbkQMainWindowFunc_menuWidget, METH_NOARGS},
    {"removeDockWidget", (PyCFunction)SbkQMainWindowFunc_removeDockWidget, METH_O},
    {"removeToolBar", (PyCFunction)SbkQMainWindowFunc_removeToolBar, METH_O},
    {"removeToolBarBreak", (PyCFunction)SbkQMainWindowFunc_removeToolBarBreak, METH_O},
    {"restoreDockWidget", (PyCFunction)SbkQMainWindowFunc_restoreDockWidget, METH_O},
    {"restoreState", (PyCFunction)SbkQMainWindowFunc_restoreState, METH_VARARGS|METH_KEYWORDS},
    {"saveState", (PyCFunction)SbkQMainWindowFunc_saveState, METH_VARARGS|METH_KEYWORDS},
    {"setAnimated", (PyCFunction)SbkQMainWindowFunc_setAnimated, METH_O},
    {"setCentralWidget", (PyCFunction)SbkQMainWindowFunc_setCentralWidget, METH_O},
    {"setCorner", (PyCFunction)SbkQMainWindowFunc_setCorner, METH_VARARGS},
    {"setDockNestingEnabled", (PyCFunction)SbkQMainWindowFunc_setDockNestingEnabled, METH_O},
    {"setDockOptions", (PyCFunction)SbkQMainWindowFunc_setDockOptions, METH_O},
    {"setDocumentMode", (PyCFunction)SbkQMainWindowFunc_setDocumentMode, METH_O},
    {"setIconSize", (PyCFunction)SbkQMainWindowFunc_setIconSize, METH_O},
    {"setMenuBar", (PyCFunction)SbkQMainWindowFunc_setMenuBar, METH_O},
    {"setMenuWidget", (PyCFunction)SbkQMainWindowFunc_setMenuWidget, METH_O},
    {"setStatusBar", (PyCFunction)SbkQMainWindowFunc_setStatusBar, METH_O},
    {"setTabPosition", (PyCFunction)SbkQMainWindowFunc_setTabPosition, METH_VARARGS},
    {"setTabShape", (PyCFunction)SbkQMainWindowFunc_setTabShape, METH_O},
    {"setToolButtonStyle", (PyCFunction)SbkQMainWindowFunc_setToolButtonStyle, METH_O},
    {"setUnifiedTitleAndToolBarOnMac", (PyCFunction)SbkQMainWindowFunc_setUnifiedTitleAndToolBarOnMac, METH_O},
    {"splitDockWidget", (PyCFunction)SbkQMainWindowFunc_splitDockWidget, METH_VARARGS},
    {"statusBar", (PyCFunction)SbkQMainWindowFunc_statusBar, METH_NOARGS},
    {"tabPosition", (PyCFunction)SbkQMainWindowFunc_tabPosition, METH_O},
    {"tabShape", (PyCFunction)SbkQMainWindowFunc_tabShape, METH_NOARGS},
    {"tabifiedDockWidgets", (PyCFunction)SbkQMainWindowFunc_tabifiedDockWidgets, METH_O},
    {"tabifyDockWidget", (PyCFunction)SbkQMainWindowFunc_tabifyDockWidget, METH_VARARGS},
    {"toolBarArea", (PyCFunction)SbkQMainWindowFunc_toolBarArea, METH_O},
    {"toolBarBreak", (PyCFunction)SbkQMainWindowFunc_toolBarBreak, METH_O},
    {"toolButtonStyle", (PyCFunction)SbkQMainWindowFunc_toolButtonStyle, METH_NOARGS},
    {"unifiedTitleAndToolBarOnMac", (PyCFunction)SbkQMainWindowFunc_unifiedTitleAndToolBarOnMac, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQMainWindowSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QMainWindow* me = reinterpret_cast<QMainWindow*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMainWindow_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMainWindow",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMainWindow_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMainWindow_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQMainWindowSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMainWindow >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMainWindow*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQMainWindow_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QMainWindow*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQMainWindow_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QMainWindow*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQMainWindow_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QMainWindow::DockOptions >::checkType(self) && Shiboken::Converter<QMainWindow::DockOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        Shiboken::Converter<QMainWindow::DockOptions>::toCpp(self)
        & Shiboken::Converter< QMainWindow::DockOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QMainWindow::DockOptions >::checkType(self) && Shiboken::Converter<QMainWindow::DockOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        Shiboken::Converter<QMainWindow::DockOptions>::toCpp(self)
        | Shiboken::Converter< QMainWindow::DockOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QMainWindow::DockOptions >::checkType(self) && Shiboken::Converter<QMainWindow::DockOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        Shiboken::Converter<QMainWindow::DockOptions>::toCpp(self)
        ^ Shiboken::Converter< QMainWindow::DockOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        ~Shiboken::Converter<QMainWindow::DockOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QMainWindow_DockOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QMainWindow_DockOption_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QMainWindow_DockOption_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QMainWindow_DockOption_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DockOption",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QMainWindow_DockOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QMainWindow_DockOption_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QMainWindow_DockOption_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QMainWindow_DockOption_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QMainWindow_DockOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DockOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QMainWindow_DockOption_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QMainWindow(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMAINWINDOW_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMainWindow_Type);

    SbkQMainWindow_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX];
    SbkQMainWindow_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX])->mi_init;

    // Fill type discovery information
    SbkQMainWindow_Type.type_discovery = &SbkQMainWindow_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]), &SbkQMainWindow_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMainWindow_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMainWindow_Type));
    PyModule_AddObject(module, "QMainWindow",
        ((PyObject*)&SbkQMainWindow_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: DockOption
    SbkPySide_QtGuiTypes[SBK_QMAINWINDOW_DOCKOPTION_IDX] = &SbkPySide_QtGui_QMainWindow_DockOption_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMainWindow_DockOption_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMainWindow_DockOption_Type);
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict,
            "DockOption",((PyObject*)&SbkPySide_QtGui_QMainWindow_DockOption_Type));

    // init flags class: QFlags<QMainWindow::DockOption>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QMAINWINDOW_DOCKOPTION__IDX] = &SbkPySide_QtGui_QMainWindow_DockOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMainWindow_DockOptions_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMainWindow_DockOptions_Type);
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict,
            "DockOptions",((PyObject*)&SbkPySide_QtGui_QMainWindow_DockOptions_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMainWindow_DockOption_Type,
        (long) QMainWindow::AnimatedDocks, "AnimatedDocks");
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict,
        "AnimatedDocks", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption_Type.tp_dict,
        "AnimatedDocks", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMainWindow_DockOption_Type,
        (long) QMainWindow::AllowNestedDocks, "AllowNestedDocks");
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict,
        "AllowNestedDocks", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption_Type.tp_dict,
        "AllowNestedDocks", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMainWindow_DockOption_Type,
        (long) QMainWindow::AllowTabbedDocks, "AllowTabbedDocks");
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict,
        "AllowTabbedDocks", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption_Type.tp_dict,
        "AllowTabbedDocks", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMainWindow_DockOption_Type,
        (long) QMainWindow::ForceTabbedDocks, "ForceTabbedDocks");
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict,
        "ForceTabbedDocks", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption_Type.tp_dict,
        "ForceTabbedDocks", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMainWindow_DockOption_Type,
        (long) QMainWindow::VerticalTabs, "VerticalTabs");
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict,
        "VerticalTabs", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption_Type.tp_dict,
        "VerticalTabs", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMainWindow::DockOption");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("iconSizeChanged", "const QSize&", NULL);
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict, "iconSizeChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("toolButtonStyleChanged", "Qt::ToolButtonStyle", NULL);
    PyDict_SetItemString(SbkQMainWindow_Type.super.ht_type.tp_dict, "toolButtonStyleChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QMainWindow >("QMainWindow*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMainWindow >(typeid(QMainWindow).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QMainWindow >(typeid(QMainWindowWrapper).name());
    PySide::initQtMetaType<QMainWindow* >();
}

