/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qmatrix4x3_wrapper.h"

// Extra includes

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMatrix4x3_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMatrix4x3 >()))
        return -1;

    QMatrix4x3* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QMatrix4x3", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QMatrix4x3()
    // 1: QMatrix4x3(QMatrix4x3)
    if (numArgs == 0) {
        overloadId = 0; // QMatrix4x3()
    } else if (numArgs == 1 && Shiboken::Converter<const QMatrix4x3 & >::isConvertible(arg)) {
        overloadId = 1; // QMatrix4x3(QMatrix4x3)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x3_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMatrix4x3()
            {

                if(!PyErr_Occurred()) {
                // QMatrix4x3()
                cptr = new QMatrix4x3();
                }
                break;
            }
            case 1: // QMatrix4x3(QMatrix4x3)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QMatrix4x3* cpp_arg0 = Shiboken::Converter<QMatrix4x3* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QMatrix4x3(QMatrix4x3)
                cptr = new QMatrix4x3(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMatrix4x3 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMatrix4x3_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQMatrix4x3_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QMatrix4x3", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x3", overloads);
        return -1;
}

static PyMethodDef SbkQMatrix4x3_methods[] = {
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMatrix4x3_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMatrix4x3",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMatrix4x3_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMatrix4x3_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMatrix4x3 >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMatrix4x3",
    /*user_data*/           0
};
} //extern


void init_QMatrix4x3(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMATRIX4X3_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMatrix4x3_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMatrix4x3_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMatrix4x3_Type));
    PyModule_AddObject(module, "QMatrix4x3",
        ((PyObject*)&SbkQMatrix4x3_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QMatrix4x3 >("QMatrix4x3");
    Shiboken::TypeResolver::createObjectTypeResolver<QMatrix4x3 >("QMatrix4x3*");
    Shiboken::TypeResolver::createValueTypeResolver<QMatrix4x3 >(typeid(QMatrix4x3).name());
    PySide::initQtMetaType<QMatrix4x3 >();
}

