/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qmatrix4x4_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qgenericmatrix.h>
#include <qmatrix.h>
#include <qmatrix4x4.h>
#include <qpoint.h>
#include <qquaternion.h>
#include <qrect.h>
#include <qtransform.h>
#include <qvector3d.h>
#include <qvector4d.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMatrix4x4_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMatrix4x4 >()))
        return -1;

    QMatrix4x4* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8 || numArgs == 9 || numArgs == 10 || numArgs == 11 || numArgs == 12 || numArgs == 13 || numArgs == 14 || numArgs == 15)
        goto SbkQMatrix4x4_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QMatrix4x4", 0, 16, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9]), &(pyargs[10]), &(pyargs[11]), &(pyargs[12]), &(pyargs[13]), &(pyargs[14]), &(pyargs[15])))
        return -1;

    // Overloaded function decisor
    // 0: QMatrix4x4(QMatrix4x4)
    // 1: QMatrix4x4()
    // 2: QMatrix4x4(QMatrix)
    // 3: QMatrix4x4(QTransform)
    // 4: QMatrix4x4(const qreal*)
    // 5: QMatrix4x4(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 1; // QMatrix4x4()
    } else if (numArgs == 16 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5]) && SbkNumber_Check(pyargs[6]) && SbkNumber_Check(pyargs[7]) && SbkNumber_Check(pyargs[8]) && SbkNumber_Check(pyargs[9]) && SbkNumber_Check(pyargs[10]) && SbkNumber_Check(pyargs[11]) && SbkNumber_Check(pyargs[12]) && SbkNumber_Check(pyargs[13]) && SbkNumber_Check(pyargs[14]) && SbkNumber_Check(pyargs[15])) {
        overloadId = 5; // QMatrix4x4(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && PySequence_Check(pyargs[0])) {
        overloadId = 4; // QMatrix4x4(const qreal*)
    } else if (numArgs == 1 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QMatrix4x4(QTransform)
    } else if (numArgs == 1 && Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QMatrix4x4(QMatrix)
    } else if (numArgs == 1 && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QMatrix4x4(QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMatrix4x4(QMatrix4x4)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
                QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QMatrix4x4(QMatrix4x4)
                cptr = new QMatrix4x4(*cpp_arg0);
                }
                break;
            }
            case 1: // QMatrix4x4()
            {

                if(!PyErr_Occurred()) {
                // QMatrix4x4()
                cptr = new QMatrix4x4();
                }
                break;
            }
            case 2: // QMatrix4x4(QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QMatrix4x4(QMatrix)
                cptr = new QMatrix4x4(*cpp_arg0);
                }
                break;
            }
            case 3: // QMatrix4x4(QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QMatrix4x4(QTransform)
                cptr = new QMatrix4x4(*cpp_arg0);
                }
                break;
            }
            case 4: // QMatrix4x4(const qreal*)
            {

                if(!PyErr_Occurred()) {
                // QMatrix4x4(const qreal*)
                // Begin code injection
                
                if (PySequence_Size(pyargs[0]) == 16) {
                    qreal values[16];
                    for(int i=0; i < 16; i++) {
                        PyObject *pv = PySequence_Fast_GET_ITEM(pyargs[0], i);
                        values[i] = PyFloat_AsDouble(pv);
                    }
                
                    cptr = new QMatrix4x4(values[0], values[1], values[2], values[3],
                                   values[4], values[5], values[6], values[7],
                                   values[8], values[9], values[10], values[11],
                                   values[12], values[13], values[14], values[15]);
                }
                
                // End of code injection

                }
                break;
            }
            case 5: // QMatrix4x4(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);
                qreal cpp_arg6 = Shiboken::Converter<qreal >::toCpp(pyargs[6]);
                qreal cpp_arg7 = Shiboken::Converter<qreal >::toCpp(pyargs[7]);
                qreal cpp_arg8 = Shiboken::Converter<qreal >::toCpp(pyargs[8]);
                qreal cpp_arg9 = Shiboken::Converter<qreal >::toCpp(pyargs[9]);
                qreal cpp_arg10 = Shiboken::Converter<qreal >::toCpp(pyargs[10]);
                qreal cpp_arg11 = Shiboken::Converter<qreal >::toCpp(pyargs[11]);
                qreal cpp_arg12 = Shiboken::Converter<qreal >::toCpp(pyargs[12]);
                qreal cpp_arg13 = Shiboken::Converter<qreal >::toCpp(pyargs[13]);
                qreal cpp_arg14 = Shiboken::Converter<qreal >::toCpp(pyargs[14]);
                qreal cpp_arg15 = Shiboken::Converter<qreal >::toCpp(pyargs[15]);

                if(!PyErr_Occurred()) {
                // QMatrix4x4(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
                cptr = new QMatrix4x4(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6, cpp_arg7, cpp_arg8, cpp_arg9, cpp_arg10, cpp_arg11, cpp_arg12, cpp_arg13, cpp_arg14, cpp_arg15);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMatrix4x4 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMatrix4x4_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQMatrix4x4_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", "", "PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", "qreal", "float, float, float, float, float, float, float, float, float, float, float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4", overloads);
        return -1;
}

static PyObject* SbkQMatrix4x4Func_column(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: column(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // column(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_column_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // column(int)const
            QVector4D cppResult = cppSelf->QMatrix4x4::column(cpp_arg0);
            pyResult = Shiboken::Converter<QVector4D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func_column_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.column", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_copyDataTo(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // copyDataTo(qreal*)const
            // Begin code injection
            
            qreal values[16];
            cppSelf->copyDataTo(values);
            pyResult = PyTuple_New(16);
            for(int i=0; i < 16; i++) {
              PyObject *v = PyFloat_FromDouble(values[i]);
              PyTuple_SET_ITEM(pyResult, i, v);
            }
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrix4x4Func_data(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // constData()const
            // Begin code injection
            
            const qreal* values = cppSelf->constData();
            pyResult = PyTuple_New(16);
            for(int i=0; i < 16; i++) {
              PyObject *v = PyFloat_FromDouble(values[i]);
              PyTuple_SET_ITEM(pyResult, i, v);
            }
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrix4x4Func_determinant(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // determinant()const
            qreal cppResult = cppSelf->QMatrix4x4::determinant();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrix4x4Func_fill(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: fill(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fill(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_fill_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fill(qreal)
            cppSelf->QMatrix4x4::fill(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_fill_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.fill", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_flipCoordinates(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flipCoordinates()
            cppSelf->QMatrix4x4::flipCoordinates();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQMatrix4x4Func_frustum(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "frustum", 6, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: frustum(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 0; // frustum(qreal,qreal,qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_frustum_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
            qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

            if(!PyErr_Occurred()) {
            // frustum(qreal,qreal,qreal,qreal,qreal,qreal)
            cppSelf->QMatrix4x4::frustum(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_frustum_TypeError:
        const char* overloads[] = {"float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.frustum", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_inverted(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "invertible" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMatrix4x4.inverted(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMatrix4x4.inverted(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:inverted", &arg))
        return 0;


    // Overloaded function decisor
    // 0: inverted(bool*)const
    if (numArgs == 0) {
        overloadId = 0; // inverted(bool*)const
    } else if (PyBool_Check(arg)) {
        overloadId = 0; // inverted(bool*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_inverted_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "invertible");
                if (value) {
                    if (arg)
                        errorArgName = "invertible";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMatrix4x4.inverted(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool * cpp_arg0 = arg ? Shiboken::Converter<bool * >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // inverted(bool*)const
            QMatrix4x4 cppResult = cppSelf->QMatrix4x4::inverted(cpp_arg0);
            pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func_inverted_TypeError:
        const char* overloads[] = {"bool = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.inverted", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_isIdentity(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isIdentity()const
            bool cppResult = cppSelf->QMatrix4x4::isIdentity();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrix4x4Func_lookAt(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "lookAt", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: lookAt(QVector3D,QVector3D,QVector3D)
    if (numArgs == 3 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[1]) && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[2])) {
        overloadId = 0; // lookAt(QVector3D,QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_lookAt_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
            QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QVector3D >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
            QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QVector3D > cpp_arg2_auto_ptr;
            QVector3D* cpp_arg2 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[2]);
            if (!Shiboken::Converter<QVector3D >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg2);

            if(!PyErr_Occurred()) {
            // lookAt(QVector3D,QVector3D,QVector3D)
            cppSelf->QMatrix4x4::lookAt(*cpp_arg0, *cpp_arg1, *cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_lookAt_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.lookAt", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_map(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: map(QPoint)const
    // 1: map(QPointF)const
    // 2: map(QVector3D)const
    // 3: map(QVector4D)const
    if (Shiboken::Converter<const QVector3D & >::isConvertible(arg)) {
        overloadId = 2; // map(QVector3D)const
    } else if (Shiboken::Converter<const QVector4D & >::isConvertible(arg)) {
        overloadId = 3; // map(QVector4D)const
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // map(QPoint)const
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 1; // map(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_map_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // map(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // map(QPoint)const
                QPoint cppResult = cppSelf->QMatrix4x4::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 1: // map(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QPointF)const
                QPointF cppResult = cppSelf->QMatrix4x4::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // map(QVector3D)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
                QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(arg);
                if (!Shiboken::Converter<QVector3D >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QVector3D)const
                QVector3D cppResult = cppSelf->QMatrix4x4::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QVector3D >::toPython(cppResult);
                }
                break;
            }
            case 3: // map(QVector4D)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg0_auto_ptr;
                QVector4D* cpp_arg0 = Shiboken::Converter<QVector4D* >::toCpp(arg);
                if (!Shiboken::Converter<QVector4D >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QVector4D)const
                QVector4D cppResult = cppSelf->QMatrix4x4::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QVector4D >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func_map_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QVector3D", "PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.map", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_mapRect(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapRect(QRect)const
    // 1: mapRect(QRectF)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // mapRect(QRect)const
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 1; // mapRect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_mapRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRect(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // mapRect(QRect)const
                QRect cppResult = cppSelf->QMatrix4x4::mapRect(*cpp_arg0);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRect(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapRect(QRectF)const
                QRectF cppResult = cppSelf->QMatrix4x4::mapRect(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func_mapRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.mapRect", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_mapVector(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapVector(QVector3D)const
    if (Shiboken::Converter<const QVector3D & >::isConvertible(arg)) {
        overloadId = 0; // mapVector(QVector3D)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_mapVector_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
            QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(arg);
            if (!Shiboken::Converter<QVector3D >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // mapVector(QVector3D)const
            QVector3D cppResult = cppSelf->QMatrix4x4::mapVector(*cpp_arg0);
            pyResult = Shiboken::Converter<QVector3D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func_mapVector_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.mapVector", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_normalMatrix(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalMatrix()const
            QMatrix3x3 cppResult = cppSelf->QMatrix4x4::normalMatrix();
            pyResult = Shiboken::Converter<QMatrix3x3 >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrix4x4Func_optimize(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // optimize()
            cppSelf->QMatrix4x4::optimize();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQMatrix4x4Func_ortho(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5)
        goto SbkQMatrix4x4Func_ortho_TypeError;

    if (!PyArg_UnpackTuple(args, "ortho", 1, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: ortho(QRect)
    // 1: ortho(QRectF)
    // 2: ortho(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // ortho(qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // ortho(QRect)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // ortho(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_ortho_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // ortho(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // ortho(QRect)
                cppSelf->QMatrix4x4::ortho(*cpp_arg0);
                }
                break;
            }
            case 1: // ortho(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // ortho(QRectF)
                cppSelf->QMatrix4x4::ortho(*cpp_arg0);
                }
                break;
            }
            case 2: // ortho(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // ortho(qreal,qreal,qreal,qreal,qreal,qreal)
                cppSelf->QMatrix4x4::ortho(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_ortho_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.ortho", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_perspective(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "perspective", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: perspective(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // perspective(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_perspective_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // perspective(qreal,qreal,qreal,qreal)
            cppSelf->QMatrix4x4::perspective(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_perspective_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.perspective", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_rotate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "z" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMatrix4x4.rotate(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMatrix4x4.rotate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMatrix4x4.rotate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:rotate", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: rotate(QQuaternion)
    // 1: rotate(qreal,QVector3D)
    // 2: rotate(qreal,qreal,qreal,qreal)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs >= 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // rotate(qreal,qreal,qreal,qreal)
            } else if (SbkNumber_Check(pyargs[3])) {
                overloadId = 2; // rotate(qreal,qreal,qreal,qreal)
            }
        } else if (numArgs == 2 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[1])) {
            overloadId = 1; // rotate(qreal,QVector3D)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QQuaternion & >::isConvertible(pyargs[0])) {
        overloadId = 0; // rotate(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_rotate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // rotate(QQuaternion)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // rotate(QQuaternion)
                cppSelf->QMatrix4x4::rotate(*cpp_arg0);
                }
                break;
            }
            case 1: // rotate(qreal,QVector3D)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // rotate(qreal,QVector3D)
                cppSelf->QMatrix4x4::rotate(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // rotate(qreal,qreal,qreal,qreal)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "z");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "z";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMatrix4x4.rotate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 0.0f;

                if(!PyErr_Occurred()) {
                // rotate(qreal,qreal,qreal,qreal)
                cppSelf->QMatrix4x4::rotate(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_rotate_TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", "float, PySide.QtGui.QVector3D", "float, float, float, float = 0.0f", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.rotate", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_row(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: row(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // row(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_row_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // row(int)const
            QVector4D cppResult = cppSelf->QMatrix4x4::row(cpp_arg0);
            pyResult = Shiboken::Converter<QVector4D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func_row_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.row", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_scale(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: scale(QVector3D)
    // 1: scale(qreal)
    // 2: scale(qreal,qreal)
    // 3: scale(qreal,qreal,qreal)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // scale(qreal)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // scale(qreal,qreal)
            } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
                overloadId = 3; // scale(qreal,qreal,qreal)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[0])) {
        overloadId = 0; // scale(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_scale_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scale(QVector3D)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
                QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // scale(QVector3D)
                cppSelf->QMatrix4x4::scale(*cpp_arg0);
                }
                break;
            }
            case 1: // scale(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // scale(qreal)
                cppSelf->QMatrix4x4::scale(cpp_arg0);
                }
                break;
            }
            case 2: // scale(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // scale(qreal,qreal)
                cppSelf->QMatrix4x4::scale(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // scale(qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // scale(qreal,qreal,qreal)
                cppSelf->QMatrix4x4::scale(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_scale_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", "float", "float, float", "float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.scale", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_setColumn(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColumn", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setColumn(int,QVector4D)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setColumn(int,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_setColumn_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
            QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setColumn(int,QVector4D)
            cppSelf->QMatrix4x4::setColumn(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_setColumn_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.setColumn", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_setRow(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRow", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRow(int,QVector4D)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setRow(int,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_setRow_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
            QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setRow(int,QVector4D)
            cppSelf->QMatrix4x4::setRow(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_setRow_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.setRow", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_setToIdentity(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // setToIdentity()
            cppSelf->QMatrix4x4::setToIdentity();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQMatrix4x4Func_toAffine(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toAffine()const
            QMatrix cppResult = cppSelf->QMatrix4x4::toAffine();
            pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrix4x4Func_toTransform(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: toTransform()const
    // 1: toTransform(qreal)const
    if (numArgs == 0) {
        overloadId = 0; // toTransform()const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 1; // toTransform(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_toTransform_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toTransform()const
            {

                if(!PyErr_Occurred()) {
                // toTransform()const
                QTransform cppResult = cppSelf->QMatrix4x4::toTransform();
                pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
                }
                break;
            }
            case 1: // toTransform(qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // toTransform(qreal)const
                QTransform cppResult = cppSelf->QMatrix4x4::toTransform(cpp_arg0);
                pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func_toTransform_TypeError:
        const char* overloads[] = {"", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.toTransform", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_translate(PyObject* self, PyObject* args)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QVector3D)
    // 1: translate(qreal,qreal)
    // 2: translate(qreal,qreal,qreal)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // translate(qreal,qreal)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 2; // translate(qreal,qreal,qreal)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QVector3D)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
                QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translate(QVector3D)
                cppSelf->QMatrix4x4::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                cppSelf->QMatrix4x4::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // translate(qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // translate(qreal,qreal,qreal)
                cppSelf->QMatrix4x4::translate(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrix4x4Func_translate_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", "float, float", "float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix4x4.translate", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func_transposed(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transposed()const
            QMatrix4x4 cppResult = cppSelf->QMatrix4x4::transposed();
            pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQMatrix4x4_methods[] = {
    {"column", (PyCFunction)SbkQMatrix4x4Func_column, METH_O},
    {"copyDataTo", (PyCFunction)SbkQMatrix4x4Func_copyDataTo, METH_NOARGS},
    {"data", (PyCFunction)SbkQMatrix4x4Func_data, METH_NOARGS},
    {"determinant", (PyCFunction)SbkQMatrix4x4Func_determinant, METH_NOARGS},
    {"fill", (PyCFunction)SbkQMatrix4x4Func_fill, METH_O},
    {"flipCoordinates", (PyCFunction)SbkQMatrix4x4Func_flipCoordinates, METH_NOARGS},
    {"frustum", (PyCFunction)SbkQMatrix4x4Func_frustum, METH_VARARGS},
    {"inverted", (PyCFunction)SbkQMatrix4x4Func_inverted, METH_VARARGS|METH_KEYWORDS},
    {"isIdentity", (PyCFunction)SbkQMatrix4x4Func_isIdentity, METH_NOARGS},
    {"lookAt", (PyCFunction)SbkQMatrix4x4Func_lookAt, METH_VARARGS},
    {"map", (PyCFunction)SbkQMatrix4x4Func_map, METH_O},
    {"mapRect", (PyCFunction)SbkQMatrix4x4Func_mapRect, METH_O},
    {"mapVector", (PyCFunction)SbkQMatrix4x4Func_mapVector, METH_O},
    {"normalMatrix", (PyCFunction)SbkQMatrix4x4Func_normalMatrix, METH_NOARGS},
    {"optimize", (PyCFunction)SbkQMatrix4x4Func_optimize, METH_NOARGS},
    {"ortho", (PyCFunction)SbkQMatrix4x4Func_ortho, METH_VARARGS},
    {"perspective", (PyCFunction)SbkQMatrix4x4Func_perspective, METH_VARARGS},
    {"rotate", (PyCFunction)SbkQMatrix4x4Func_rotate, METH_VARARGS|METH_KEYWORDS},
    {"row", (PyCFunction)SbkQMatrix4x4Func_row, METH_O},
    {"scale", (PyCFunction)SbkQMatrix4x4Func_scale, METH_VARARGS},
    {"setColumn", (PyCFunction)SbkQMatrix4x4Func_setColumn, METH_VARARGS},
    {"setRow", (PyCFunction)SbkQMatrix4x4Func_setRow, METH_VARARGS},
    {"setToIdentity", (PyCFunction)SbkQMatrix4x4Func_setToIdentity, METH_NOARGS},
    {"toAffine", (PyCFunction)SbkQMatrix4x4Func_toAffine, METH_NOARGS},
    {"toTransform", (PyCFunction)SbkQMatrix4x4Func_toTransform, METH_NOARGS|METH_O},
    {"translate", (PyCFunction)SbkQMatrix4x4Func_translate, METH_VARARGS},
    {"transposed", (PyCFunction)SbkQMatrix4x4Func_transposed, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQMatrix4x4Func___mul__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QMatrix4x4,QMatrix4x4)
    // 1: operator*(QPoint,QMatrix4x4)
    // 2: operator*(QPointF,QMatrix4x4)
    // 3: operator*(qreal,QMatrix4x4)
    // 4: operator*(QMatrix4x4,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 4; // operator*(QMatrix4x4,qreal)
    } else if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 3; // operator*(qreal,QMatrix4x4)
    } else if (isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 1; // operator*(QPoint,QMatrix4x4)
    } else if (isReverse && Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 2; // operator*(QPointF,QMatrix4x4)
    } else if (!isReverse && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QMatrix4x4,QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QMatrix4x4,QMatrix4x4)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
                QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(arg);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator*(QMatrix4x4,QMatrix4x4)
                QMatrix4x4 cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QPoint,QMatrix4x4)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPoint,QMatrix4x4) [reverse operator]
                QPoint cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(QPointF,QMatrix4x4)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator*(QPointF,QMatrix4x4) [reverse operator]
                QPointF cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 3: // operator*(qreal,QMatrix4x4)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(qreal,QMatrix4x4) [reverse operator]
                QMatrix4x4 cppResult = cpp_arg0 * (*cppSelf);
                pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
                }
                break;
            }
            case 4: // operator*(QMatrix4x4,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QMatrix4x4,qreal)
                QMatrix4x4 cppResult = (*cppSelf) * cpp_arg0;
                pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__mul__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___imul__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QMatrix4x4)
    // 1: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___imul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*=(QMatrix4x4)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
                QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(arg);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator*=(QMatrix4x4)
                (*cppSelf) *= (*cpp_arg0);
                }
                break;
            }
            case 1: // operator*=(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*=(qreal)
                (*cppSelf) *= cpp_arg0;
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQMatrix4x4Func___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__imul__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___add__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QMatrix4x4,QMatrix4x4)
    if (!isReverse && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(arg)) {
        overloadId = 0; // operator+(QMatrix4x4,QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___add___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
            QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(arg);
            if (!Shiboken::Converter<QMatrix4x4 >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator+(QMatrix4x4,QMatrix4x4)
            QMatrix4x4 cppResult = (*cppSelf) + (*cpp_arg0);
            pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__add__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___iadd__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QMatrix4x4)
    if (!isReverse && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___iadd___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
            QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(arg);
            if (!Shiboken::Converter<QMatrix4x4 >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator+=(QMatrix4x4)
            (*cppSelf) += (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQMatrix4x4Func___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__iadd__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___neg__(PyObject* self)
{
    QMatrix4x4* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // operator-(QMatrix4x4)
            QMatrix4x4 cppResult = - (*cppSelf);
            pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrix4x4Func___sub__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QMatrix4x4,QMatrix4x4)
    if (!isReverse && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(arg)) {
        overloadId = 0; // operator-(QMatrix4x4,QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___sub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
            QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(arg);
            if (!Shiboken::Converter<QMatrix4x4 >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator-(QMatrix4x4,QMatrix4x4)
            QMatrix4x4 cppResult = (*cppSelf) - (*cpp_arg0);
            pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__sub__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___isub__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QMatrix4x4)
    if (!isReverse && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___isub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QMatrix4x4 > cpp_arg0_auto_ptr;
            QMatrix4x4* cpp_arg0 = Shiboken::Converter<QMatrix4x4* >::toCpp(arg);
            if (!Shiboken::Converter<QMatrix4x4 >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator-=(QMatrix4x4)
            (*cppSelf) -= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQMatrix4x4Func___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__isub__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___div__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QMatrix4x4,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QMatrix4x4,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___div___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/(QMatrix4x4,qreal)
            QMatrix4x4 cppResult = (*cppSelf) / cpp_arg0;
            pyResult = Shiboken::Converter<QMatrix4x4 >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__div__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___idiv__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/=(qreal)
            (*cppSelf) /= cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQMatrix4x4Func___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__idiv__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___lshift__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QMatrix4x4)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QMatrix4x4) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQMatrix4x4Func___rshift__(PyObject* self, PyObject* arg)
{
    QMatrix4x4* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix4x4 >::checkType(arg) && !Shiboken::Converter<QMatrix4x4 >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QMatrix4x4&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QMatrix4x4&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix4x4Func___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QMatrix4x4&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrix4x4Func___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix4x4.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQMatrix4x4_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQMatrix4x4Func___add__,
    /*nb_subtract*/             (binaryfunc)SbkQMatrix4x4Func___sub__,
    /*nb_multiply*/             (binaryfunc)SbkQMatrix4x4Func___mul__,
    /*nb_divide*/               (binaryfunc)SbkQMatrix4x4Func___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)SbkQMatrix4x4Func___neg__,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQMatrix4x4Func___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQMatrix4x4Func___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQMatrix4x4Func___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)SbkQMatrix4x4Func___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)SbkQMatrix4x4Func___imul__,
    /*nb_inplace_divide*/       (binaryfunc)SbkQMatrix4x4Func___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQMatrix4x4_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QMatrix4x4& cpp_self = *Shiboken::Converter<QMatrix4x4* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QMatrix4x4 & >::isConvertible(other)) {
                // operator!=(const QMatrix4x4 & other) const
                QMatrix4x4* cpp_other = Shiboken::Converter<QMatrix4x4* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QMatrix4x4  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QMatrix4x4 >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_other_auto_ptr;
                QMatrix4x4* cpp_other = Shiboken::Converter<QMatrix4x4* >::toCpp(other);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQMatrix4x4_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QMatrix4x4 & >::isConvertible(other)) {
                // operator==(const QMatrix4x4 & other) const
                QMatrix4x4* cpp_other = Shiboken::Converter<QMatrix4x4* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QMatrix4x4  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QMatrix4x4 >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_other_auto_ptr;
                QMatrix4x4* cpp_other = Shiboken::Converter<QMatrix4x4* >::toCpp(other);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQMatrix4x4_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQMatrix4x4_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMatrix4x4_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMatrix4x4",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQMatrix4x4_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQMatrix4x4_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMatrix4x4_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMatrix4x4_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMatrix4x4 >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMatrix4x4",
    /*user_data*/           0
};
} //extern


void init_QMatrix4x4(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMATRIX4X4_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMatrix4x4_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMatrix4x4_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMatrix4x4_Type));
    PyModule_AddObject(module, "QMatrix4x4",
        ((PyObject*)&SbkQMatrix4x4_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QMatrix4x4 >("QMatrix4x4");
    Shiboken::TypeResolver::createObjectTypeResolver<QMatrix4x4 >("QMatrix4x4*");
    Shiboken::TypeResolver::createValueTypeResolver<QMatrix4x4 >(typeid(QMatrix4x4).name());
    PySide::initQtMetaType<QMatrix4x4 >();
}

