/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qmatrix_wrapper.h"

// Extra includes
#include <QPainterPath>
#include <qdatastream.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMatrix_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMatrix >()))
        return -1;

    QMatrix* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5)
        goto SbkQMatrix_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QMatrix", 0, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QMatrix()
    // 1: QMatrix(QMatrix)
    // 2: QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QMatrix()
    } else if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QMatrix(QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrix_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMatrix()
            {

                if(!PyErr_Occurred()) {
                // QMatrix()
                cptr = new QMatrix();
                }
                break;
            }
            case 1: // QMatrix(QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QMatrix(QMatrix)
                cptr = new QMatrix(*cpp_arg0);
                }
                break;
            }
            case 2: // QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
                cptr = new QMatrix(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMatrix >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMatrix_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQMatrix_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QMatrix", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix", overloads);
        return -1;
}

static PyObject* SbkQMatrixFunc_det(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // det()const
            qreal cppResult = cppSelf->QMatrix::det();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_determinant(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // determinant()const
            qreal cppResult = cppSelf->QMatrix::determinant();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_dx(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dx()const
            qreal cppResult = cppSelf->QMatrix::dx();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_dy(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dy()const
            qreal cppResult = cppSelf->QMatrix::dy();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_inverted(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // inverted(bool*)const
            // Begin code injection
            
            // TEMPLATE - fix_bool* - START
            bool ok_;
            QMatrix retval_ = cppSelf->inverted(&ok_);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_isIdentity(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isIdentity()const
            bool cppResult = cppSelf->QMatrix::isIdentity();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_isInvertible(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isInvertible()const
            bool cppResult = cppSelf->QMatrix::isInvertible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_m11(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m11()const
            qreal cppResult = cppSelf->QMatrix::m11();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_m12(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m12()const
            qreal cppResult = cppSelf->QMatrix::m12();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_m21(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m21()const
            qreal cppResult = cppSelf->QMatrix::m21();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_m22(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // m22()const
            qreal cppResult = cppSelf->QMatrix::m22();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMatrixFunc_map(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: map(QLine)const
    // 1: map(QLineF)const
    // 2: map(QPainterPath)const
    // 3: map(QPoint)const
    // 4: map(QPointF)const
    // 5: map(QPolygon)const
    // 6: map(QPolygonF)const
    // 7: map(QRegion)const
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 5; // map(QPolygon)const
    } else if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 7; // map(QRegion)const
    } else if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 6; // map(QPolygonF)const
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 3; // map(QPoint)const
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 4; // map(QPointF)const
    } else if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 2; // map(QPainterPath)const
    } else if (Shiboken::Converter<const QLine & >::isConvertible(arg)) {
        overloadId = 0; // map(QLine)const
    } else if (Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 1; // map(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_map_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // map(QLine)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // map(QLine)const
                QLine cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QLine >::toPython(cppResult);
                }
                break;
            }
            case 1: // map(QLineF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
                if (!Shiboken::Converter<QLineF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QLineF)const
                QLineF cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
                }
                break;
            }
            case 2: // map(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // map(QPainterPath)const
                QPainterPath cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 3: // map(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // map(QPoint)const
                QPoint cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 4: // map(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QPointF)const
                QPointF cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // map(QPolygon)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygon >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QPolygon)const
                QPolygon cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 6: // map(QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QPolygonF)const
                QPolygonF cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 7: // map(QRegion)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // map(QRegion)const
                QRegion cppResult = cppSelf->QMatrix::map(*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtGui.QPainterPath", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.map", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc_mapRect(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapRect(QRect)const
    // 1: mapRect(QRectF)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // mapRect(QRect)const
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 1; // mapRect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_mapRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRect(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // mapRect(QRect)const
                QRect cppResult = cppSelf->QMatrix::mapRect(*cpp_arg0);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRect(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapRect(QRectF)const
                QRectF cppResult = cppSelf->QMatrix::mapRect(*cpp_arg0);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc_mapRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.mapRect", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc_mapToPolygon(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToPolygon(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // mapToPolygon(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_mapToPolygon_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mapToPolygon(QRect)const
            QPolygon cppResult = cppSelf->QMatrix::mapToPolygon(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc_mapToPolygon_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.mapToPolygon", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc_reset(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QMatrix::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQMatrixFunc_rotate(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_rotate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rotate(qreal)
            QMatrix & cppResult = cppSelf->QMatrix::rotate(cpp_arg0);
            pyResult = Shiboken::Converter<QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc_rotate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.rotate", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc_scale(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_scale_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scale(qreal,qreal)
            QMatrix & cppResult = cppSelf->QMatrix::scale(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.scale", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc_setMatrix(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMatrix", 6, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: setMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 0; // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_setMatrix_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
            qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

            if(!PyErr_Occurred()) {
            // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
            cppSelf->QMatrix::setMatrix(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMatrixFunc_setMatrix_TypeError:
        const char* overloads[] = {"float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.setMatrix", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc_shear(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // shear(qreal,qreal)
            QMatrix & cppResult = cppSelf->QMatrix::shear(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.shear", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc_translate(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc_translate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // translate(qreal,qreal)
            QMatrix & cppResult = cppSelf->QMatrix::translate(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc_translate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.translate", overloads);
        return 0;
}

static PyMethodDef SbkQMatrix_methods[] = {
    {"det", (PyCFunction)SbkQMatrixFunc_det, METH_NOARGS},
    {"determinant", (PyCFunction)SbkQMatrixFunc_determinant, METH_NOARGS},
    {"dx", (PyCFunction)SbkQMatrixFunc_dx, METH_NOARGS},
    {"dy", (PyCFunction)SbkQMatrixFunc_dy, METH_NOARGS},
    {"inverted", (PyCFunction)SbkQMatrixFunc_inverted, METH_NOARGS},
    {"isIdentity", (PyCFunction)SbkQMatrixFunc_isIdentity, METH_NOARGS},
    {"isInvertible", (PyCFunction)SbkQMatrixFunc_isInvertible, METH_NOARGS},
    {"m11", (PyCFunction)SbkQMatrixFunc_m11, METH_NOARGS},
    {"m12", (PyCFunction)SbkQMatrixFunc_m12, METH_NOARGS},
    {"m21", (PyCFunction)SbkQMatrixFunc_m21, METH_NOARGS},
    {"m22", (PyCFunction)SbkQMatrixFunc_m22, METH_NOARGS},
    {"map", (PyCFunction)SbkQMatrixFunc_map, METH_O},
    {"mapRect", (PyCFunction)SbkQMatrixFunc_mapRect, METH_O},
    {"mapToPolygon", (PyCFunction)SbkQMatrixFunc_mapToPolygon, METH_O},
    {"reset", (PyCFunction)SbkQMatrixFunc_reset, METH_NOARGS},
    {"rotate", (PyCFunction)SbkQMatrixFunc_rotate, METH_O},
    {"scale", (PyCFunction)SbkQMatrixFunc_scale, METH_VARARGS},
    {"setMatrix", (PyCFunction)SbkQMatrixFunc_setMatrix, METH_VARARGS},
    {"shear", (PyCFunction)SbkQMatrixFunc_shear, METH_VARARGS},
    {"translate", (PyCFunction)SbkQMatrixFunc_translate, METH_VARARGS},
    {0} // Sentinel
};

static PyObject* SbkQMatrixFunc___mul__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix >::checkType(arg) && !Shiboken::Converter<QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QLine,QMatrix)
    // 1: operator*(QLineF,QMatrix)
    // 2: operator*(QMatrix)const
    // 3: operator*(QPoint,QMatrix)
    // 4: operator*(QPointF,QMatrix)
    if (isReverse && Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 3; // operator*(QPoint,QMatrix)
    } else if (isReverse && Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 4; // operator*(QPointF,QMatrix)
    } else if (!isReverse && Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 2; // operator*(QMatrix)const
    } else if (isReverse && Shiboken::Converter<const QLine & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QLine,QMatrix)
    } else if (isReverse && Shiboken::Converter<const QLineF & >::isConvertible(arg)) {
        overloadId = 1; // operator*(QLineF,QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QLine,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QLine,QMatrix) [reverse operator]
                QLine cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QLine >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QLineF,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(arg);
                if (!Shiboken::Converter<QLineF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator*(QLineF,QMatrix) [reverse operator]
                QLineF cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QLineF >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(QMatrix)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QMatrix)const
                QMatrix cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
                }
                break;
            }
            case 3: // operator*(QPoint,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPoint,QMatrix) [reverse operator]
                QPoint cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 4: // operator*(QPointF,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator*(QPointF,QMatrix) [reverse operator]
                QPointF cppResult = (*cpp_arg0) * (*cppSelf);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtGui.QMatrix", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__mul__", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc___imul__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix >::checkType(arg) && !Shiboken::Converter<QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QMatrix)
    if (!isReverse && Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc___imul___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator*=(QMatrix)
            (*cppSelf) *= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQMatrixFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__imul__", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc___lshift__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix >::checkType(arg) && !Shiboken::Converter<QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QMatrix)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QMatrix) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQMatrixFunc___rshift__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QMatrix >::checkType(arg) && !Shiboken::Converter<QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QMatrix&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QMatrix&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMatrixFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QMatrix&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMatrixFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQMatrix_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)SbkQMatrixFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQMatrixFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQMatrixFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)SbkQMatrixFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQMatrix_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QMatrix& cpp_self = *Shiboken::Converter<QMatrix* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QMatrix & >::isConvertible(other)) {
                // operator!=(const QMatrix & arg__1) const
                QMatrix* cpp_other = Shiboken::Converter<QMatrix* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QMatrix  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQMatrix_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QMatrix & >::isConvertible(other)) {
                // operator==(const QMatrix & arg__1) const
                QMatrix* cpp_other = Shiboken::Converter<QMatrix* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QMatrix  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQMatrix_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQMatrix_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMatrix_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMatrix",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQMatrix_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQMatrix_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMatrix_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMatrix_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMatrix >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMatrix",
    /*user_data*/           0
};
} //extern


void init_QMatrix(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMATRIX_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMatrix_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMatrix_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMatrix_Type));
    PyModule_AddObject(module, "QMatrix",
        ((PyObject*)&SbkQMatrix_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QMatrix >("QMatrix");
    Shiboken::TypeResolver::createObjectTypeResolver<QMatrix >("QMatrix*");
    Shiboken::TypeResolver::createValueTypeResolver<QMatrix >(typeid(QMatrix).name());
    PySide::initQtMetaType<QMatrix >();
}

