/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qmessagebox_wrapper.h"

// Extra includes
#include <QList>
#include <QPixmap>
#include <qabstractbutton.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmessagebox.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qpushbutton.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QMessageBoxWrapper::QMessageBoxWrapper(QMessageBox::Icon icon, const QString & title, const QString & text, QFlags<QMessageBox::StandardButton> buttons, QWidget * parent, QFlags<Qt::WindowType> flags) : QMessageBox(icon, title, text, buttons, parent, flags), m_metaObject(0) {
    // ... middle
}

QMessageBoxWrapper::QMessageBoxWrapper(QWidget * parent) : QMessageBox(parent), m_metaObject(0) {
    // ... middle
}

void QMessageBoxWrapper::accept()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "accept"));
    if (py_override.isNull()) {
        return this->QDialog::accept();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::changeEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QMessageBox::changeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QMessageBox::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QDialog::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QMessageBoxWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QMessageBoxWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::done(int arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "done"));
    if (py_override.isNull()) {
        return this->QDialog::done(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::dragEnterEvent(QDragEnterEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragEnterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::dragLeaveEvent(QDragLeaveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragLeaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::dragMoveEvent(QDragMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::dropEvent(QDropEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dropEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QMessageBoxWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QMessageBox::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QMessageBoxWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QDialog::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QMessageBoxWrapper::focusInEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusInEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QMessageBoxWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QMessageBoxWrapper::focusOutEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusOutEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QMessageBoxWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QMessageBoxWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QMessageBoxWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QMessageBoxWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QMessageBox::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::keyReleaseEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QMessageBoxWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QMessageBoxWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QDialog::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QMessageBoxWrapper::mouseDoubleClickEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseDoubleClickEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::mouseMoveEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::mousePressEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mousePressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::mouseReleaseEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QMessageBoxWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QMessageBox.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QMessageBoxWrapper::paintEvent(QPaintEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QWidget::paintEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::reject()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reject"));
    if (py_override.isNull()) {
        return this->QDialog::reject();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QMessageBox::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QDialog::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QMessageBox::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QMessageBoxWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QMessageBox::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMessageBox.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QMessageBoxWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMessageBoxWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMessageBoxWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QWidget::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QMessageBoxWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QMessageBox::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QMessageBoxWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QMessageBox::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QMessageBoxWrapper::~QMessageBoxWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMessageBox_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMessageBox >()))
        return -1;

    QMessageBoxWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "buttons", "flags", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQMessageBox_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOO:QMessageBox", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QMessageBox(QMessageBox::Icon,QString,QString,QFlags<QMessageBox::StandardButton>,QWidget*,QFlags<Qt::WindowType>)
    // 1: QMessageBox(QWidget*)
    if (numArgs == 0) {
        overloadId = 1; // QMessageBox(QWidget*)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QMessageBox(QWidget*)
    } else if (numArgs >= 3 && Shiboken::Converter<QMessageBox::Icon >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // QMessageBox(QMessageBox::Icon,QString,QString,QFlags<QMessageBox::StandardButton>,QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // QMessageBox(QMessageBox::Icon,QString,QString,QFlags<QMessageBox::StandardButton>,QWidget*,QFlags<Qt::WindowType>)
            } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 0; // QMessageBox(QMessageBox::Icon,QString,QString,QFlags<QMessageBox::StandardButton>,QWidget*,QFlags<Qt::WindowType>)
                } else if (Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(pyargs[5])) {
                    overloadId = 0; // QMessageBox(QMessageBox::Icon,QString,QString,QFlags<QMessageBox::StandardButton>,QWidget*,QFlags<Qt::WindowType>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBox_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMessageBox(QMessageBox::Icon,QString,QString,QFlags<QMessageBox::StandardButton>,QWidget*,QFlags<Qt::WindowType>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "buttons");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "buttons";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "parent";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "flags";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QMessageBox::Icon cpp_arg0 = Shiboken::Converter<QMessageBox::Icon >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QFlags<QMessageBox::StandardButton> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::toCpp(pyargs[3]) : QMessageBox::NoButton;
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return -1;
                QWidget* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[4]) : 0;
                QFlags<Qt::WindowType> cpp_arg5 = pyargs[5] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[5]) : Qt::Dialog | Qt::MSWindowsFixedSizeDialogHint;

                if(!PyErr_Occurred()) {
                // QMessageBox(QMessageBox::Icon,QString,QString,QFlags<QMessageBox::StandardButton>,QWidget*,QFlags<Qt::WindowType>)
                cptr = new QMessageBoxWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                Shiboken::setParent(pyargs[4], self);
                }
                break;
            }
            case 1: // QMessageBox(QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QMessageBox(QWidget*)
                cptr = new QMessageBoxWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMessageBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMessageBox_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQMessageBox_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMessageBox.Icon, QString, QString, PySide.QtGui.QMessageBox.StandardButtons = QMessageBox.NoButton, PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = Qt.Dialog | Qt.MSWindowsFixedSizeDialogHint", "PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox", overloads);
        return -1;
}

static PyObject* SbkQMessageBoxFunc_about(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "about", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: about(QWidget*,QString,QString)
    if (numArgs == 3 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // about(QWidget*,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_about_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // about(QWidget*,QString,QString)
            QMessageBox::about(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_about_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.about", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_aboutQt(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "title" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.aboutQt(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.aboutQt(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.aboutQt(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:aboutQt", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: aboutQt(QWidget*,QString)
    if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // aboutQt(QWidget*,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // aboutQt(QWidget*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_aboutQt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "title");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "title";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.aboutQt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // aboutQt(QWidget*,QString)
            QMessageBox::aboutQt(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_aboutQt_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.aboutQt", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_addButton(PyObject* self, PyObject* args)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addButton", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addButton(QAbstractButton*,QMessageBox::ButtonRole)
    // 1: addButton(QMessageBox::StandardButton)
    // 2: addButton(QString,QMessageBox::ButtonRole)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QMessageBox::ButtonRole >::isConvertible(pyargs[1])) {
        overloadId = 2; // addButton(QString,QMessageBox::ButtonRole)
    } else if (numArgs == 1 && Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[0])) {
        overloadId = 1; // addButton(QMessageBox::StandardButton)
    } else if (numArgs == 2 && Shiboken::Converter<QAbstractButton * >::isConvertible(pyargs[0]) && Shiboken::Converter<QMessageBox::ButtonRole >::isConvertible(pyargs[1])) {
        overloadId = 0; // addButton(QAbstractButton*,QMessageBox::ButtonRole)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_addButton_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addButton(QAbstractButton*,QMessageBox::ButtonRole)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(pyargs[0]);
                QMessageBox::ButtonRole cpp_arg1 = Shiboken::Converter<QMessageBox::ButtonRole >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addButton(QAbstractButton*,QMessageBox::ButtonRole)
                cppSelf->QMessageBox::addButton(cpp_arg0, cpp_arg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // addButton(QMessageBox::StandardButton)
            {
                QMessageBox::StandardButton cpp_arg0 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // addButton(QMessageBox::StandardButton)
                QPushButton * cppResult = cppSelf->QMessageBox::addButton(cpp_arg0);
                pyResult = Shiboken::Converter<QPushButton * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 2: // addButton(QString,QMessageBox::ButtonRole)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QMessageBox::ButtonRole cpp_arg1 = Shiboken::Converter<QMessageBox::ButtonRole >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addButton(QString,QMessageBox::ButtonRole)
                QPushButton * cppResult = cppSelf->QMessageBox::addButton(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPushButton * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_addButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton, PySide.QtGui.QMessageBox.ButtonRole", "PySide.QtGui.QMessageBox.StandardButton", "QString, PySide.QtGui.QMessageBox.ButtonRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.addButton", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_button(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: button(QMessageBox::StandardButton)const
    if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(arg)) {
        overloadId = 0; // button(QMessageBox::StandardButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_button_TypeError;

    // Call function/method
    {
        {
            QMessageBox::StandardButton cpp_arg0 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // button(QMessageBox::StandardButton)const
            QAbstractButton * cppResult = cppSelf->QMessageBox::button(cpp_arg0);
            pyResult = Shiboken::Converter<QAbstractButton * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_button_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMessageBox.StandardButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.button", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_buttonRole(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: buttonRole(QAbstractButton*)const
    if (Shiboken::Converter<QAbstractButton * >::isConvertible(arg)) {
        overloadId = 0; // buttonRole(QAbstractButton*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_buttonRole_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // buttonRole(QAbstractButton*)const
            QMessageBox::ButtonRole cppResult = cppSelf->QMessageBox::buttonRole(cpp_arg0);
            pyResult = Shiboken::Converter<QMessageBox::ButtonRole >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_buttonRole_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.buttonRole", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_buttons(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // buttons()const
            QList<QAbstractButton * > cppResult = cppSelf->QMessageBox::buttons();
            pyResult = Shiboken::Converter<QList<QAbstractButton * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_changeEvent(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_changeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // changeEvent(QEvent*)
            cppSelf->QMessageBox::changeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_changeEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.changeEvent", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_clickedButton(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clickedButton()const
            QAbstractButton * cppResult = cppSelf->QMessageBox::clickedButton();
            pyResult = Shiboken::Converter<QAbstractButton * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_closeEvent(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: closeEvent(QCloseEvent*)
    if (Shiboken::Converter<QCloseEvent * >::isConvertible(arg)) {
        overloadId = 0; // closeEvent(QCloseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_closeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QCloseEvent* cpp_arg0 = Shiboken::Converter<QCloseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // closeEvent(QCloseEvent*)
            cppSelf->QMessageBox::closeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_closeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCloseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.closeEvent", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_critical(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "buttons", "defaultButton" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.critical(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.critical(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.critical(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:critical", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: critical(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
    // 1: critical(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
    if (numArgs >= 3 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // critical(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
        } else if (numArgs == 5 && Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[3]) && Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
            overloadId = 1; // critical(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
        } else if (Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // critical(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            } else if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
                overloadId = 0; // critical(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_critical_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // critical(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "buttons");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "buttons";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "defaultButton");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "defaultButton";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.critical(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QFlags<QMessageBox::StandardButton> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::toCpp(pyargs[3]) : QMessageBox::Ok;
                QMessageBox::StandardButton cpp_arg4 = pyargs[4] ? Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]) : QMessageBox::NoButton;

                if(!PyErr_Occurred()) {
                // critical(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
                threadStateSaver.save();
                QMessageBox::StandardButton cppResult = QMessageBox::critical(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QMessageBox::StandardButton >::toPython(cppResult);
                }
                break;
            }
            case 1: // critical(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QMessageBox::StandardButton cpp_arg3 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[3]);
                QMessageBox::StandardButton cpp_arg4 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // critical(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
                int cppResult = QMessageBox::critical(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_critical_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButtons = QMessageBox.Ok, PySide.QtGui.QMessageBox.StandardButton = NoButton", "PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButton, PySide.QtGui.QMessageBox.StandardButton", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.critical", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_defaultButton(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultButton()const
            QPushButton * cppResult = cppSelf->QMessageBox::defaultButton();
            pyResult = Shiboken::Converter<QPushButton * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_detailedText(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // detailedText()const
            QString cppResult = cppSelf->QMessageBox::detailedText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_escapeButton(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // escapeButton()const
            QAbstractButton * cppResult = cppSelf->QMessageBox::escapeButton();
            pyResult = Shiboken::Converter<QAbstractButton * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_event(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QMessageBox::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.event", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_exec_(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // exec()
            threadStateSaver.save();
            int cppResult = cppSelf->QMessageBox::exec();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_icon(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // icon()const
            QMessageBox::Icon cppResult = cppSelf->QMessageBox::icon();
            pyResult = Shiboken::Converter<QMessageBox::Icon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_iconPixmap(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // iconPixmap()const
            QPixmap cppResult = cppSelf->QMessageBox::iconPixmap();
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_information(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "button1", "buttons", "defaultButton" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.information(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.information(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.information(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:information", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: information(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
    // 1: information(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
    if (numArgs >= 3 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // information(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
        } else if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 1; // information(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
            } else if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
                overloadId = 1; // information(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
            }
        } else if (Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // information(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            } else if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
                overloadId = 0; // information(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_information_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // information(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "buttons");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "buttons";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "defaultButton");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "defaultButton";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.information(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QFlags<QMessageBox::StandardButton> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::toCpp(pyargs[3]) : QMessageBox::Ok;
                QMessageBox::StandardButton cpp_arg4 = pyargs[4] ? Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]) : QMessageBox::NoButton;

                if(!PyErr_Occurred()) {
                // information(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
                threadStateSaver.save();
                QMessageBox::StandardButton cppResult = QMessageBox::information(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QMessageBox::StandardButton >::toPython(cppResult);
                }
                break;
            }
            case 1: // information(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "button1");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "button1";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.information(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QMessageBox::StandardButton cpp_arg3 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[3]);
                QMessageBox::StandardButton cpp_arg4 = pyargs[4] ? Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]) : QMessageBox::NoButton;

                if(!PyErr_Occurred()) {
                // information(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
                QMessageBox::StandardButton cppResult = QMessageBox::information(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QMessageBox::StandardButton >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_information_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButtons = QMessageBox.Ok, PySide.QtGui.QMessageBox.StandardButton = NoButton", "PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButton, PySide.QtGui.QMessageBox.StandardButton = NoButton", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.information", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_informativeText(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // informativeText()const
            QString cppResult = cppSelf->QMessageBox::informativeText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QMessageBox::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_open(PyObject* self, PyObject* args)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto SbkQMessageBoxFunc_open_TypeError;

    if (!PyArg_UnpackTuple(args, "open", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: open()
    // 1: open(QObject*,const char*)
    if (numArgs == 0) {
        overloadId = 0; // open()
    } else if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
        overloadId = 1; // open(QObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_open_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // open()
            {

                if(!PyErr_Occurred()) {
                // open()
                cppSelf->QMessageBox::open();
                }
                break;
            }
            case 1: // open(QObject*,const char*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // open(QObject*,const char*)
                cppSelf->QMessageBox::open(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_open_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.open", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_question(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "buttons", "defaultButton" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.question(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.question(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.question(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:question", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: question(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
    // 1: question(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
    if (numArgs >= 3 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // question(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
        } else if (numArgs == 5 && Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[3]) && Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
            overloadId = 1; // question(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
        } else if (Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // question(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            } else if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
                overloadId = 0; // question(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_question_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // question(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "buttons");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "buttons";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "defaultButton");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "defaultButton";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.question(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QFlags<QMessageBox::StandardButton> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::toCpp(pyargs[3]) : QMessageBox::Ok;
                QMessageBox::StandardButton cpp_arg4 = pyargs[4] ? Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]) : QMessageBox::NoButton;

                if(!PyErr_Occurred()) {
                // question(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
                threadStateSaver.save();
                QMessageBox::StandardButton cppResult = QMessageBox::question(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QMessageBox::StandardButton >::toPython(cppResult);
                }
                break;
            }
            case 1: // question(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QMessageBox::StandardButton cpp_arg3 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[3]);
                QMessageBox::StandardButton cpp_arg4 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // question(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
                int cppResult = QMessageBox::question(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_question_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButtons = QMessageBox.Ok, PySide.QtGui.QMessageBox.StandardButton = NoButton", "PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButton, PySide.QtGui.QMessageBox.StandardButton", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.question", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_removeButton(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeButton(QAbstractButton*)
    if (Shiboken::Converter<QAbstractButton * >::isConvertible(arg)) {
        overloadId = 0; // removeButton(QAbstractButton*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_removeButton_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeButton(QAbstractButton*)
            cppSelf->QMessageBox::removeButton(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_removeButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.removeButton", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter<QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QResizeEvent* cpp_arg0 = Shiboken::Converter<QResizeEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resizeEvent(QResizeEvent*)
            cppSelf->QMessageBox::resizeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.resizeEvent", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setDefaultButton(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultButton(QMessageBox::StandardButton)
    // 1: setDefaultButton(QPushButton*)
    if (Shiboken::Converter<QPushButton * >::isConvertible(arg)) {
        overloadId = 1; // setDefaultButton(QPushButton*)
    } else if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(arg)) {
        overloadId = 0; // setDefaultButton(QMessageBox::StandardButton)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setDefaultButton_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setDefaultButton(QMessageBox::StandardButton)
            {
                QMessageBox::StandardButton cpp_arg0 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setDefaultButton(QMessageBox::StandardButton)
                cppSelf->QMessageBox::setDefaultButton(cpp_arg0);
                }
                break;
            }
            case 1: // setDefaultButton(QPushButton*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPushButton* cpp_arg0 = Shiboken::Converter<QPushButton* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setDefaultButton(QPushButton*)
                cppSelf->QMessageBox::setDefaultButton(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setDefaultButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMessageBox.StandardButton", "PySide.QtGui.QPushButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setDefaultButton", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setDetailedText(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDetailedText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDetailedText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setDetailedText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDetailedText(QString)
            cppSelf->QMessageBox::setDetailedText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setDetailedText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setDetailedText", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setEscapeButton(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEscapeButton(QAbstractButton*)
    // 1: setEscapeButton(QMessageBox::StandardButton)
    if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(arg)) {
        overloadId = 1; // setEscapeButton(QMessageBox::StandardButton)
    } else if (Shiboken::Converter<QAbstractButton * >::isConvertible(arg)) {
        overloadId = 0; // setEscapeButton(QAbstractButton*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setEscapeButton_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setEscapeButton(QAbstractButton*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setEscapeButton(QAbstractButton*)
                cppSelf->QMessageBox::setEscapeButton(cpp_arg0);
                }
                break;
            }
            case 1: // setEscapeButton(QMessageBox::StandardButton)
            {
                QMessageBox::StandardButton cpp_arg0 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setEscapeButton(QMessageBox::StandardButton)
                cppSelf->QMessageBox::setEscapeButton(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setEscapeButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton", "PySide.QtGui.QMessageBox.StandardButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setEscapeButton", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setIcon(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIcon(QMessageBox::Icon)
    if (Shiboken::Converter<QMessageBox::Icon >::isConvertible(arg)) {
        overloadId = 0; // setIcon(QMessageBox::Icon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setIcon_TypeError;

    // Call function/method
    {
        {
            QMessageBox::Icon cpp_arg0 = Shiboken::Converter<QMessageBox::Icon >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIcon(QMessageBox::Icon)
            cppSelf->QMessageBox::setIcon(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMessageBox.Icon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setIcon", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setIconPixmap(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconPixmap(QPixmap)
    if (Shiboken::Converter<const QPixmap & >::isConvertible(arg)) {
        overloadId = 0; // setIconPixmap(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setIconPixmap_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
            QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(arg);
            if (!Shiboken::Converter<QPixmap >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setIconPixmap(QPixmap)
            cppSelf->QMessageBox::setIconPixmap(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setIconPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setIconPixmap", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setInformativeText(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInformativeText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setInformativeText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setInformativeText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInformativeText(QString)
            cppSelf->QMessageBox::setInformativeText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setInformativeText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setInformativeText", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setStandardButtons(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStandardButtons(QFlags<QMessageBox::StandardButton>)
    if (Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::isConvertible(arg)) {
        overloadId = 0; // setStandardButtons(QFlags<QMessageBox::StandardButton>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setStandardButtons_TypeError;

    // Call function/method
    {
        {
            QFlags<QMessageBox::StandardButton> cpp_arg0 = Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStandardButtons(QFlags<QMessageBox::StandardButton>)
            cppSelf->QMessageBox::setStandardButtons(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setStandardButtons_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMessageBox.StandardButtons", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setStandardButtons", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setText(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setText(QString)
            cppSelf->QMessageBox::setText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setText", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_setTextFormat(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextFormat(Qt::TextFormat)
    if (Shiboken::Converter<Qt::TextFormat >::isConvertible(arg)) {
        overloadId = 0; // setTextFormat(Qt::TextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_setTextFormat_TypeError;

    // Call function/method
    {
        {
            Qt::TextFormat cpp_arg0 = Shiboken::Converter<Qt::TextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextFormat(Qt::TextFormat)
            cppSelf->QMessageBox::setTextFormat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_setTextFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.setTextFormat", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_showEvent(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: showEvent(QShowEvent*)
    if (Shiboken::Converter<QShowEvent * >::isConvertible(arg)) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_showEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QShowEvent* cpp_arg0 = Shiboken::Converter<QShowEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // showEvent(QShowEvent*)
            cppSelf->QMessageBox::showEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMessageBoxFunc_showEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QShowEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.showEvent", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_sizeHint(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizeHint()const
            QSize cppResult = cppSelf->QMessageBox::sizeHint();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_standardButton(PyObject* self, PyObject* arg)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: standardButton(QAbstractButton*)const
    if (Shiboken::Converter<QAbstractButton * >::isConvertible(arg)) {
        overloadId = 0; // standardButton(QAbstractButton*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_standardButton_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractButton* cpp_arg0 = Shiboken::Converter<QAbstractButton* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // standardButton(QAbstractButton*)const
            QMessageBox::StandardButton cppResult = cppSelf->QMessageBox::standardButton(cpp_arg0);
            pyResult = Shiboken::Converter<QMessageBox::StandardButton >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_standardButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMessageBox.standardButton", overloads);
        return 0;
}

static PyObject* SbkQMessageBoxFunc_standardButtons(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // standardButtons()const
            QFlags<QMessageBox::StandardButton> cppResult = cppSelf->QMessageBox::standardButtons();
            pyResult = Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_text(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QString cppResult = cppSelf->QMessageBox::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_textFormat(PyObject* self)
{
    QMessageBox* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMessageBox* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textFormat()const
            Qt::TextFormat cppResult = cppSelf->QMessageBox::textFormat();
            pyResult = Shiboken::Converter<Qt::TextFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMessageBoxFunc_warning(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "buttons", "defaultButton" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.warning(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.warning(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMessageBox.warning(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:warning", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: warning(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
    // 1: warning(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
    if (numArgs >= 3 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // warning(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
        } else if (numArgs == 5 && Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[3]) && Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
            overloadId = 1; // warning(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
        } else if (Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // warning(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            } else if (Shiboken::Converter<QMessageBox::StandardButton >::isConvertible(pyargs[4])) {
                overloadId = 0; // warning(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMessageBoxFunc_warning_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // warning(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "buttons");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "buttons";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "defaultButton");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "defaultButton";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMessageBox.warning(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QFlags<QMessageBox::StandardButton> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QMessageBox::StandardButton> >::toCpp(pyargs[3]) : QMessageBox::Ok;
                QMessageBox::StandardButton cpp_arg4 = pyargs[4] ? Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]) : QMessageBox::NoButton;

                if(!PyErr_Occurred()) {
                // warning(QWidget*,QString,QString,QFlags<QMessageBox::StandardButton>,QMessageBox::StandardButton)
                threadStateSaver.save();
                QMessageBox::StandardButton cppResult = QMessageBox::warning(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QMessageBox::StandardButton >::toPython(cppResult);
                }
                break;
            }
            case 1: // warning(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QMessageBox::StandardButton cpp_arg3 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[3]);
                QMessageBox::StandardButton cpp_arg4 = Shiboken::Converter<QMessageBox::StandardButton >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // warning(QWidget*,QString,QString,QMessageBox::StandardButton,QMessageBox::StandardButton)
                int cppResult = QMessageBox::warning(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMessageBoxFunc_warning_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButtons = QMessageBox.Ok, PySide.QtGui.QMessageBox.StandardButton = NoButton", "PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QMessageBox.StandardButton, PySide.QtGui.QMessageBox.StandardButton", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMessageBox.warning", overloads);
        return 0;
}

static PyMethodDef SbkQMessageBox_methods[] = {
    {"about", (PyCFunction)SbkQMessageBoxFunc_about, METH_VARARGS|METH_STATIC},
    {"aboutQt", (PyCFunction)SbkQMessageBoxFunc_aboutQt, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"addButton", (PyCFunction)SbkQMessageBoxFunc_addButton, METH_VARARGS},
    {"button", (PyCFunction)SbkQMessageBoxFunc_button, METH_O},
    {"buttonRole", (PyCFunction)SbkQMessageBoxFunc_buttonRole, METH_O},
    {"buttons", (PyCFunction)SbkQMessageBoxFunc_buttons, METH_NOARGS},
    {"changeEvent", (PyCFunction)SbkQMessageBoxFunc_changeEvent, METH_O},
    {"clickedButton", (PyCFunction)SbkQMessageBoxFunc_clickedButton, METH_NOARGS},
    {"closeEvent", (PyCFunction)SbkQMessageBoxFunc_closeEvent, METH_O},
    {"critical", (PyCFunction)SbkQMessageBoxFunc_critical, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"defaultButton", (PyCFunction)SbkQMessageBoxFunc_defaultButton, METH_NOARGS},
    {"detailedText", (PyCFunction)SbkQMessageBoxFunc_detailedText, METH_NOARGS},
    {"escapeButton", (PyCFunction)SbkQMessageBoxFunc_escapeButton, METH_NOARGS},
    {"event", (PyCFunction)SbkQMessageBoxFunc_event, METH_O},
    {"exec_", (PyCFunction)SbkQMessageBoxFunc_exec_, METH_NOARGS},
    {"icon", (PyCFunction)SbkQMessageBoxFunc_icon, METH_NOARGS},
    {"iconPixmap", (PyCFunction)SbkQMessageBoxFunc_iconPixmap, METH_NOARGS},
    {"information", (PyCFunction)SbkQMessageBoxFunc_information, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"informativeText", (PyCFunction)SbkQMessageBoxFunc_informativeText, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)SbkQMessageBoxFunc_keyPressEvent, METH_O},
    {"open", (PyCFunction)SbkQMessageBoxFunc_open, METH_VARARGS},
    {"question", (PyCFunction)SbkQMessageBoxFunc_question, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"removeButton", (PyCFunction)SbkQMessageBoxFunc_removeButton, METH_O},
    {"resizeEvent", (PyCFunction)SbkQMessageBoxFunc_resizeEvent, METH_O},
    {"setDefaultButton", (PyCFunction)SbkQMessageBoxFunc_setDefaultButton, METH_O},
    {"setDetailedText", (PyCFunction)SbkQMessageBoxFunc_setDetailedText, METH_O},
    {"setEscapeButton", (PyCFunction)SbkQMessageBoxFunc_setEscapeButton, METH_O},
    {"setIcon", (PyCFunction)SbkQMessageBoxFunc_setIcon, METH_O},
    {"setIconPixmap", (PyCFunction)SbkQMessageBoxFunc_setIconPixmap, METH_O},
    {"setInformativeText", (PyCFunction)SbkQMessageBoxFunc_setInformativeText, METH_O},
    {"setStandardButtons", (PyCFunction)SbkQMessageBoxFunc_setStandardButtons, METH_O},
    {"setText", (PyCFunction)SbkQMessageBoxFunc_setText, METH_O},
    {"setTextFormat", (PyCFunction)SbkQMessageBoxFunc_setTextFormat, METH_O},
    {"showEvent", (PyCFunction)SbkQMessageBoxFunc_showEvent, METH_O},
    {"sizeHint", (PyCFunction)SbkQMessageBoxFunc_sizeHint, METH_NOARGS},
    {"standardButton", (PyCFunction)SbkQMessageBoxFunc_standardButton, METH_O},
    {"standardButtons", (PyCFunction)SbkQMessageBoxFunc_standardButtons, METH_NOARGS},
    {"text", (PyCFunction)SbkQMessageBoxFunc_text, METH_NOARGS},
    {"textFormat", (PyCFunction)SbkQMessageBoxFunc_textFormat, METH_NOARGS},
    {"warning", (PyCFunction)SbkQMessageBoxFunc_warning, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQMessageBoxSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QMessageBox* me = reinterpret_cast<QMessageBox*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]))
        return static_cast<QDialog*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMessageBox_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMessageBox",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMessageBox_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMessageBox_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQMessageBoxSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMessageBox >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMessageBox*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQMessageBox_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QMessageBox*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQMessageBox_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QMessageBox*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQMessageBox_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QMessageBox_ButtonRole_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QMessageBox_ButtonRole_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QMessageBox_ButtonRole_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ButtonRole",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QMessageBox_ButtonRole_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QMessageBox_ButtonRole_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QMessageBox_ButtonRole_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QMessageBox_StandardButton___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QMessageBox::StandardButtons >::checkType(self) && Shiboken::Converter<QMessageBox::StandardButtons >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QMessageBox::StandardButtons >::toPython(
        Shiboken::Converter<QMessageBox::StandardButtons>::toCpp(self)
        & Shiboken::Converter< QMessageBox::StandardButtons >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMessageBox_StandardButton___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QMessageBox::StandardButtons >::checkType(self) && Shiboken::Converter<QMessageBox::StandardButtons >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QMessageBox::StandardButtons >::toPython(
        Shiboken::Converter<QMessageBox::StandardButtons>::toCpp(self)
        | Shiboken::Converter< QMessageBox::StandardButtons >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMessageBox_StandardButton___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QMessageBox::StandardButtons >::checkType(self) && Shiboken::Converter<QMessageBox::StandardButtons >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QMessageBox::StandardButtons >::toPython(
        Shiboken::Converter<QMessageBox::StandardButtons>::toCpp(self)
        ^ Shiboken::Converter< QMessageBox::StandardButtons >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMessageBox_StandardButton___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QMessageBox::StandardButtons >::toPython(
        ~Shiboken::Converter<QMessageBox::StandardButtons >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QMessageBox_StandardButton_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QMessageBox_StandardButton___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QMessageBox_StandardButton___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QMessageBox_StandardButton___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QMessageBox_StandardButton___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QMessageBox_StandardButton_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QMessageBox_StandardButton_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QMessageBox_StandardButton_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StandardButton",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QMessageBox_StandardButton_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QMessageBox_StandardButton_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QMessageBox_StandardButton_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QMessageBox_StandardButton_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QMessageBox_StandardButtons_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StandardButtons",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QMessageBox_Icon_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QMessageBox_Icon_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QMessageBox_Icon_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Icon",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QMessageBox_Icon_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QMessageBox_Icon_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QMessageBox_Icon_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QMessageBox(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMESSAGEBOX_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMessageBox_Type);

    SbkQMessageBox_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX];
    SbkQMessageBox_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX])->mi_init;

    // Fill type discovery information
    SbkQMessageBox_Type.type_discovery = &SbkQMessageBox_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]), &SbkQMessageBox_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMessageBox_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMessageBox_Type));
    PyModule_AddObject(module, "QMessageBox",
        ((PyObject*)&SbkQMessageBox_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ButtonRole
    SbkPySide_QtGuiTypes[SBK_QMESSAGEBOX_BUTTONROLE_IDX] = &SbkPySide_QtGui_QMessageBox_ButtonRole_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMessageBox_ButtonRole_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type);
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
            "ButtonRole",((PyObject*)&SbkPySide_QtGui_QMessageBox_ButtonRole_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::InvalidRole, "InvalidRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "InvalidRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "InvalidRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::AcceptRole, "AcceptRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "AcceptRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "AcceptRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::RejectRole, "RejectRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "RejectRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "RejectRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::DestructiveRole, "DestructiveRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "DestructiveRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "DestructiveRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::ActionRole, "ActionRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "ActionRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "ActionRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::HelpRole, "HelpRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "HelpRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "HelpRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::YesRole, "YesRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "YesRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "YesRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::NoRole, "NoRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "NoRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "NoRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::ResetRole, "ResetRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "ResetRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "ResetRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::ApplyRole, "ApplyRole");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "ApplyRole", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "ApplyRole", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_ButtonRole_Type,
        (long) QMessageBox::NRoles, "NRoles");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "NRoles", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_ButtonRole_Type.tp_dict,
        "NRoles", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMessageBox::ButtonRole");

    // init enum class: StandardButton
    SbkPySide_QtGuiTypes[SBK_QMESSAGEBOX_STANDARDBUTTON_IDX] = &SbkPySide_QtGui_QMessageBox_StandardButton_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMessageBox_StandardButton_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMessageBox_StandardButton_Type);
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
            "StandardButton",((PyObject*)&SbkPySide_QtGui_QMessageBox_StandardButton_Type));

    // init flags class: QFlags<QMessageBox::StandardButton>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QMESSAGEBOX_STANDARDBUTTON__IDX] = &SbkPySide_QtGui_QMessageBox_StandardButtons_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMessageBox_StandardButtons_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMessageBox_StandardButtons_Type);
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
            "StandardButtons",((PyObject*)&SbkPySide_QtGui_QMessageBox_StandardButtons_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::NoButton, "NoButton");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "NoButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "NoButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Ok, "Ok");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Ok", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Ok", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Save, "Save");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Save", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Save", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::SaveAll, "SaveAll");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "SaveAll", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "SaveAll", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Open, "Open");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Open", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Open", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Yes, "Yes");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Yes", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Yes", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::YesToAll, "YesToAll");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "YesToAll", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "YesToAll", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::No, "No");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "No", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "No", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::NoToAll, "NoToAll");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "NoToAll", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "NoToAll", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Abort, "Abort");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Abort", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Abort", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Retry, "Retry");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Retry", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Retry", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Ignore, "Ignore");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Ignore", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Ignore", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Close, "Close");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Close", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Close", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Cancel, "Cancel");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Cancel", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Cancel", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Discard, "Discard");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Discard", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Discard", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Help, "Help");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Help", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Help", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Apply, "Apply");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Apply", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Apply", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Reset, "Reset");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Reset", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Reset", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::RestoreDefaults, "RestoreDefaults");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "RestoreDefaults", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "RestoreDefaults", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::FirstButton, "FirstButton");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "FirstButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "FirstButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::LastButton, "LastButton");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "LastButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "LastButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::YesAll, "YesAll");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "YesAll", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "YesAll", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::NoAll, "NoAll");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "NoAll", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "NoAll", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Default, "Default");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Default", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Default", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::Escape, "Escape");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Escape", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "Escape", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::FlagMask, "FlagMask");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "FlagMask", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "FlagMask", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_StandardButton_Type,
        (long) QMessageBox::ButtonMask, "ButtonMask");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "ButtonMask", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_StandardButton_Type.tp_dict,
        "ButtonMask", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMessageBox::StandardButton");

    // init enum class: Icon
    SbkPySide_QtGuiTypes[SBK_QMESSAGEBOX_ICON_IDX] = &SbkPySide_QtGui_QMessageBox_Icon_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMessageBox_Icon_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMessageBox_Icon_Type);
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
            "Icon",((PyObject*)&SbkPySide_QtGui_QMessageBox_Icon_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_Icon_Type,
        (long) QMessageBox::NoIcon, "NoIcon");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "NoIcon", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_Icon_Type.tp_dict,
        "NoIcon", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_Icon_Type,
        (long) QMessageBox::Information, "Information");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Information", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_Icon_Type.tp_dict,
        "Information", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_Icon_Type,
        (long) QMessageBox::Warning, "Warning");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Warning", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_Icon_Type.tp_dict,
        "Warning", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_Icon_Type,
        (long) QMessageBox::Critical, "Critical");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Critical", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_Icon_Type.tp_dict,
        "Critical", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMessageBox_Icon_Type,
        (long) QMessageBox::Question, "Question");
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict,
        "Question", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMessageBox_Icon_Type.tp_dict,
        "Question", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMessageBox::Icon");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("buttonClicked", "QAbstractButton*", NULL);
    PyDict_SetItemString(SbkQMessageBox_Type.super.ht_type.tp_dict, "buttonClicked", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QMessageBox >("QMessageBox*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMessageBox >(typeid(QMessageBox).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QMessageBox >(typeid(QMessageBoxWrapper).name());
    PySide::initQtMetaType<QMessageBox* >();
}

