/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qmouseeventtransition_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractanimation.h>
#include <qabstractstate.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmouseeventtransition.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainterpath.h>
#include <qstate.h>
#include <qstatemachine.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QMouseEventTransitionWrapper::QMouseEventTransitionWrapper(QObject * object, QEvent::Type type, Qt::MouseButton button, QState * sourceState) : QMouseEventTransition(object, type, button, sourceState), m_metaObject(0) {
    // ... middle
}

QMouseEventTransitionWrapper::QMouseEventTransitionWrapper(QState * sourceState) : QMouseEventTransition(sourceState), m_metaObject(0) {
    // ... middle
}

void QMouseEventTransitionWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMouseEventTransitionWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMouseEventTransitionWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMouseEventTransitionWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QMouseEventTransitionWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QEventTransition::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMouseEventTransition.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QMouseEventTransitionWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMouseEventTransition.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QMouseEventTransitionWrapper::eventTest(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventTest"));
    if (py_override.isNull()) {
        return this->QMouseEventTransition::eventTest(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMouseEventTransition.eventTest", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QMouseEventTransitionWrapper::onTransition(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "onTransition"));
    if (py_override.isNull()) {
        return this->QMouseEventTransition::onTransition(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMouseEventTransitionWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QMouseEventTransitionWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QMouseEventTransition::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QMouseEventTransitionWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QMouseEventTransition::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QMouseEventTransitionWrapper::~QMouseEventTransitionWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMouseEventTransition_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMouseEventTransition >()))
        return -1;

    QMouseEventTransitionWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "sourceState" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQMouseEventTransition_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:QMouseEventTransition", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QMouseEventTransition(QObject*,QEvent::Type,Qt::MouseButton,QState*)
    // 1: QMouseEventTransition(QState*)
    if (numArgs == 0) {
        overloadId = 1; // QMouseEventTransition(QState*)
    } else if (Shiboken::Converter<QState * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QMouseEventTransition(QState*)
    } else if (numArgs >= 3 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent::Type >::isConvertible(pyargs[1]) && Shiboken::Converter<Qt::MouseButton >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // QMouseEventTransition(QObject*,QEvent::Type,Qt::MouseButton,QState*)
        } else if (Shiboken::Converter<QState * >::isConvertible(pyargs[3])) {
            overloadId = 0; // QMouseEventTransition(QObject*,QEvent::Type,Qt::MouseButton,QState*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMouseEventTransition_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMouseEventTransition(QObject*,QEvent::Type,Qt::MouseButton,QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sourceState");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "sourceState";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMouseEventTransition(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QEvent::Type cpp_arg1 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[1]);
                Qt::MouseButton cpp_arg2 = Shiboken::Converter<Qt::MouseButton >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return -1;
                QState* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QState* >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // QMouseEventTransition(QObject*,QEvent::Type,Qt::MouseButton,QState*)
                cptr = new QMouseEventTransitionWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 1: // QMouseEventTransition(QState*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sourceState");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "sourceState";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMouseEventTransition(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QState* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QState* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QMouseEventTransition(QState*)
                cptr = new QMouseEventTransitionWrapper(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMouseEventTransition >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMouseEventTransition_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQMouseEventTransition_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent.Type, PySide.QtCore.Qt.MouseButton, PySide.QtCore.QState = None", "PySide.QtCore.QState = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMouseEventTransition", overloads);
        return -1;
}

static PyObject* SbkQMouseEventTransitionFunc_button(PyObject* self)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // button()const
            Qt::MouseButton cppResult = cppSelf->QMouseEventTransition::button();
            pyResult = Shiboken::Converter<Qt::MouseButton >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMouseEventTransitionFunc_eventTest(PyObject* self, PyObject* arg)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: eventTest(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // eventTest(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMouseEventTransitionFunc_eventTest_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // eventTest(QEvent*)
            bool cppResult = cppSelf->QMouseEventTransition::eventTest(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMouseEventTransitionFunc_eventTest_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMouseEventTransition.eventTest", overloads);
        return 0;
}

static PyObject* SbkQMouseEventTransitionFunc_hitTestPath(PyObject* self)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hitTestPath()const
            QPainterPath cppResult = cppSelf->QMouseEventTransition::hitTestPath();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMouseEventTransitionFunc_modifierMask(PyObject* self)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // modifierMask()const
            QFlags<Qt::KeyboardModifier> cppResult = cppSelf->QMouseEventTransition::modifierMask();
            pyResult = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMouseEventTransitionFunc_onTransition(PyObject* self, PyObject* arg)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: onTransition(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // onTransition(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMouseEventTransitionFunc_onTransition_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // onTransition(QEvent*)
            cppSelf->QMouseEventTransition::onTransition(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMouseEventTransitionFunc_onTransition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMouseEventTransition.onTransition", overloads);
        return 0;
}

static PyObject* SbkQMouseEventTransitionFunc_setButton(PyObject* self, PyObject* arg)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setButton(Qt::MouseButton)
    if (Shiboken::Converter<Qt::MouseButton >::isConvertible(arg)) {
        overloadId = 0; // setButton(Qt::MouseButton)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMouseEventTransitionFunc_setButton_TypeError;

    // Call function/method
    {
        {
            Qt::MouseButton cpp_arg0 = Shiboken::Converter<Qt::MouseButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setButton(Qt::MouseButton)
            cppSelf->QMouseEventTransition::setButton(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMouseEventTransitionFunc_setButton_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMouseEventTransition.setButton", overloads);
        return 0;
}

static PyObject* SbkQMouseEventTransitionFunc_setHitTestPath(PyObject* self, PyObject* arg)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHitTestPath(QPainterPath)
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // setHitTestPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMouseEventTransitionFunc_setHitTestPath_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHitTestPath(QPainterPath)
            cppSelf->QMouseEventTransition::setHitTestPath(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMouseEventTransitionFunc_setHitTestPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMouseEventTransition.setHitTestPath", overloads);
        return 0;
}

static PyObject* SbkQMouseEventTransitionFunc_setModifierMask(PyObject* self, PyObject* arg)
{
    QMouseEventTransition* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMouseEventTransition* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModifierMask(QFlags<Qt::KeyboardModifier>)
    if (Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::isConvertible(arg)) {
        overloadId = 0; // setModifierMask(QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMouseEventTransitionFunc_setModifierMask_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::KeyboardModifier> cpp_arg0 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setModifierMask(QFlags<Qt::KeyboardModifier>)
            cppSelf->QMouseEventTransition::setModifierMask(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMouseEventTransitionFunc_setModifierMask_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMouseEventTransition.setModifierMask", overloads);
        return 0;
}

static PyMethodDef SbkQMouseEventTransition_methods[] = {
    {"button", (PyCFunction)SbkQMouseEventTransitionFunc_button, METH_NOARGS},
    {"eventTest", (PyCFunction)SbkQMouseEventTransitionFunc_eventTest, METH_O},
    {"hitTestPath", (PyCFunction)SbkQMouseEventTransitionFunc_hitTestPath, METH_NOARGS},
    {"modifierMask", (PyCFunction)SbkQMouseEventTransitionFunc_modifierMask, METH_NOARGS},
    {"onTransition", (PyCFunction)SbkQMouseEventTransitionFunc_onTransition, METH_O},
    {"setButton", (PyCFunction)SbkQMouseEventTransitionFunc_setButton, METH_O},
    {"setHitTestPath", (PyCFunction)SbkQMouseEventTransitionFunc_setHitTestPath, METH_O},
    {"setModifierMask", (PyCFunction)SbkQMouseEventTransitionFunc_setModifierMask, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMouseEventTransition_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMouseEventTransition",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMouseEventTransition_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMouseEventTransition_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMouseEventTransition >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMouseEventTransition*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQMouseEventTransition_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QMouseEventTransition*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQMouseEventTransition_Type;
    return 0;
}


void init_QMouseEventTransition(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMOUSEEVENTTRANSITION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMouseEventTransition_Type);

    SbkQMouseEventTransition_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENTTRANSITION_IDX];
    // Fill type discovery information
    SbkQMouseEventTransition_Type.type_discovery = &SbkQMouseEventTransition_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QEVENTTRANSITION_IDX]), &SbkQMouseEventTransition_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMouseEventTransition_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMouseEventTransition_Type));
    PyModule_AddObject(module, "QMouseEventTransition",
        ((PyObject*)&SbkQMouseEventTransition_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QMouseEventTransition >("QMouseEventTransition*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMouseEventTransition >(typeid(QMouseEventTransition).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QMouseEventTransition >(typeid(QMouseEventTransitionWrapper).name());
    PySide::initQtMetaType<QMouseEventTransition* >();
}

