/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qmovie_wrapper.h"

// Extra includes
#include <QColor>
#include <QImage>
#include <QList>
#include <QPixmap>
#include <QRect>
#include <QSize>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qimage.h>
#include <qiodevice.h>
#include <qmovie.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpixmap.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QMovieWrapper::QMovieWrapper(QIODevice * device, const QByteArray & format, QObject * parent) : QMovie(device, format, parent), m_metaObject(0) {
    // ... middle
}

QMovieWrapper::QMovieWrapper(QObject * parent) : QMovie(parent), m_metaObject(0) {
    // ... middle
}

QMovieWrapper::QMovieWrapper(const QString & fileName, const QByteArray & format, QObject * parent) : QMovie(fileName, format, parent), m_metaObject(0) {
    // ... middle
}

void QMovieWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMovieWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QMovieWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QMovieWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QMovieWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMovie.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QMovieWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMovie.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QMovieWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QMovieWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QMovie::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QMovieWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QMovie::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QMovieWrapper::~QMovieWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQMovie_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QMovie >()))
        return -1;

    QMovieWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOO:QMovie", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QMovie(QIODevice*,QByteArray,QObject*)
    // 1: QMovie(QObject*)
    // 2: QMovie(QString,QByteArray,QObject*)
    if (numArgs == 0) {
        overloadId = 1; // QMovie(QObject*)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QMovie(QString,QByteArray,QObject*)
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QMovie(QString,QByteArray,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 2; // QMovie(QString,QByteArray,QObject*)
            }
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QMovie(QObject*)
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QMovie(QIODevice*,QByteArray,QObject*)
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QMovie(QIODevice*,QByteArray,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 0; // QMovie(QIODevice*,QByteArray,QObject*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovie_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMovie(QIODevice*,QByteArray,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMovie(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray cpp_arg1_tmp = QByteArray();
                QByteArray* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QMovie(QIODevice*,QByteArray,QObject*)
                cptr = new QMovieWrapper(cpp_arg0, *cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
            case 1: // QMovie(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMovie(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QMovie(QObject*)
                cptr = new QMovieWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 2: // QMovie(QString,QByteArray,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMovie(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray cpp_arg1_tmp = QByteArray();
                QByteArray* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QMovie(QString,QByteArray,QObject*)
                cptr = new QMovieWrapper(cpp_arg0, *cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QMovie >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQMovie_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQMovie_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, PySide.QtCore.QByteArray = QByteArray(), PySide.QtCore.QObject = None", "PySide.QtCore.QObject = None", "QString, PySide.QtCore.QByteArray = QByteArray(), PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMovie", overloads);
        return -1;
}

static PyObject* SbkQMovieFunc_backgroundColor(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundColor()const
            QColor cppResult = cppSelf->QMovie::backgroundColor();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_cacheMode(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cacheMode()const
            QMovie::CacheMode cppResult = cppSelf->QMovie::cacheMode();
            pyResult = Shiboken::Converter<QMovie::CacheMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_currentFrameNumber(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentFrameNumber()const
            int cppResult = cppSelf->QMovie::currentFrameNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_currentImage(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentImage()const
            QImage cppResult = cppSelf->QMovie::currentImage();
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_currentPixmap(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentPixmap()const
            QPixmap cppResult = cppSelf->QMovie::currentPixmap();
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_device(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QIODevice * cppResult = cppSelf->QMovie::device();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_fileName(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QMovie::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_format(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QByteArray cppResult = cppSelf->QMovie::format();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_frameCount(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // frameCount()const
            int cppResult = cppSelf->QMovie::frameCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_frameRect(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // frameRect()const
            QRect cppResult = cppSelf->QMovie::frameRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_isValid(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QMovie::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_jumpToFrame(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: jumpToFrame(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // jumpToFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_jumpToFrame_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // jumpToFrame(int)
            bool cppResult = cppSelf->QMovie::jumpToFrame(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQMovieFunc_jumpToFrame_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.jumpToFrame", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_jumpToNextFrame(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // jumpToNextFrame()
            bool cppResult = cppSelf->QMovie::jumpToNextFrame();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_loopCount(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // loopCount()const
            int cppResult = cppSelf->QMovie::loopCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_nextFrameDelay(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextFrameDelay()const
            int cppResult = cppSelf->QMovie::nextFrameDelay();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_scaledSize(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scaledSize()
            QSize cppResult = cppSelf->QMovie::scaledSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_setBackgroundColor(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundColor(QColor)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setBackgroundColor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBackgroundColor(QColor)
            cppSelf->QMovie::setBackgroundColor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setBackgroundColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setBackgroundColor", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_setCacheMode(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCacheMode(QMovie::CacheMode)
    if (Shiboken::Converter<QMovie::CacheMode >::isConvertible(arg)) {
        overloadId = 0; // setCacheMode(QMovie::CacheMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setCacheMode_TypeError;

    // Call function/method
    {
        {
            QMovie::CacheMode cpp_arg0 = Shiboken::Converter<QMovie::CacheMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCacheMode(QMovie::CacheMode)
            cppSelf->QMovie::setCacheMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setCacheMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMovie.CacheMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setCacheMode", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_setDevice(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDevice(QIODevice*)
            cppSelf->QMovie::setDevice(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setDevice", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_setFileName(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFileName(QString)
            cppSelf->QMovie::setFileName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setFileName", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_setFormat(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormat(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setFormat(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFormat(QByteArray)
            cppSelf->QMovie::setFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setFormat", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_setPaused(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPaused(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPaused(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setPaused_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPaused(bool)
            cppSelf->QMovie::setPaused(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setPaused_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setPaused", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_setScaledSize(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaledSize(QSize)
    if (Shiboken::Converter<const QSize & >::isConvertible(arg)) {
        overloadId = 0; // setScaledSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setScaledSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScaledSize(QSize)
            cppSelf->QMovie::setScaledSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setScaledSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setScaledSize", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_setSpeed(PyObject* self, PyObject* arg)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpeed(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSpeed(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQMovieFunc_setSpeed_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSpeed(int)
            cppSelf->QMovie::setSpeed(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQMovieFunc_setSpeed_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMovie.setSpeed", overloads);
        return 0;
}

static PyObject* SbkQMovieFunc_speed(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // speed()const
            int cppResult = cppSelf->QMovie::speed();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_start(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // start()
            cppSelf->QMovie::start();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQMovieFunc_state(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QMovie::MovieState cppResult = cppSelf->QMovie::state();
            pyResult = Shiboken::Converter<QMovie::MovieState >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQMovieFunc_stop(PyObject* self)
{
    QMovie* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QMovie* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stop()
            cppSelf->QMovie::stop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQMovieFunc_supportedFormats(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedFormats()
            QList<QByteArray > cppResult = QMovie::supportedFormats();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQMovie_methods[] = {
    {"backgroundColor", (PyCFunction)SbkQMovieFunc_backgroundColor, METH_NOARGS},
    {"cacheMode", (PyCFunction)SbkQMovieFunc_cacheMode, METH_NOARGS},
    {"currentFrameNumber", (PyCFunction)SbkQMovieFunc_currentFrameNumber, METH_NOARGS},
    {"currentImage", (PyCFunction)SbkQMovieFunc_currentImage, METH_NOARGS},
    {"currentPixmap", (PyCFunction)SbkQMovieFunc_currentPixmap, METH_NOARGS},
    {"device", (PyCFunction)SbkQMovieFunc_device, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQMovieFunc_fileName, METH_NOARGS},
    {"format", (PyCFunction)SbkQMovieFunc_format, METH_NOARGS},
    {"frameCount", (PyCFunction)SbkQMovieFunc_frameCount, METH_NOARGS},
    {"frameRect", (PyCFunction)SbkQMovieFunc_frameRect, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQMovieFunc_isValid, METH_NOARGS},
    {"jumpToFrame", (PyCFunction)SbkQMovieFunc_jumpToFrame, METH_O},
    {"jumpToNextFrame", (PyCFunction)SbkQMovieFunc_jumpToNextFrame, METH_NOARGS},
    {"loopCount", (PyCFunction)SbkQMovieFunc_loopCount, METH_NOARGS},
    {"nextFrameDelay", (PyCFunction)SbkQMovieFunc_nextFrameDelay, METH_NOARGS},
    {"scaledSize", (PyCFunction)SbkQMovieFunc_scaledSize, METH_NOARGS},
    {"setBackgroundColor", (PyCFunction)SbkQMovieFunc_setBackgroundColor, METH_O},
    {"setCacheMode", (PyCFunction)SbkQMovieFunc_setCacheMode, METH_O},
    {"setDevice", (PyCFunction)SbkQMovieFunc_setDevice, METH_O},
    {"setFileName", (PyCFunction)SbkQMovieFunc_setFileName, METH_O},
    {"setFormat", (PyCFunction)SbkQMovieFunc_setFormat, METH_O},
    {"setPaused", (PyCFunction)SbkQMovieFunc_setPaused, METH_O},
    {"setScaledSize", (PyCFunction)SbkQMovieFunc_setScaledSize, METH_O},
    {"setSpeed", (PyCFunction)SbkQMovieFunc_setSpeed, METH_O},
    {"speed", (PyCFunction)SbkQMovieFunc_speed, METH_NOARGS},
    {"start", (PyCFunction)SbkQMovieFunc_start, METH_NOARGS},
    {"state", (PyCFunction)SbkQMovieFunc_state, METH_NOARGS},
    {"stop", (PyCFunction)SbkQMovieFunc_stop, METH_NOARGS},
    {"supportedFormats", (PyCFunction)SbkQMovieFunc_supportedFormats, METH_NOARGS|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQMovie_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMovie",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQMovie_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQMovie_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QMovie >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QMovie*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQMovie_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QMovie*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQMovie_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QMovie_CacheMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QMovie_CacheMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QMovie_CacheMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CacheMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QMovie_CacheMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QMovie_CacheMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QMovie_CacheMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QMovie_MovieState_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QMovie_MovieState_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QMovie_MovieState_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MovieState",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QMovie_MovieState_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QMovie_MovieState_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QMovie_MovieState_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QMovie(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMOVIE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQMovie_Type);

    SbkQMovie_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQMovie_Type.type_discovery = &SbkQMovie_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQMovie_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQMovie_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQMovie_Type));
    PyModule_AddObject(module, "QMovie",
        ((PyObject*)&SbkQMovie_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: CacheMode
    SbkPySide_QtGuiTypes[SBK_QMOVIE_CACHEMODE_IDX] = &SbkPySide_QtGui_QMovie_CacheMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMovie_CacheMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMovie_CacheMode_Type);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict,
            "CacheMode",((PyObject*)&SbkPySide_QtGui_QMovie_CacheMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMovie_CacheMode_Type,
        (long) QMovie::CacheNone, "CacheNone");
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict,
        "CacheNone", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMovie_CacheMode_Type.tp_dict,
        "CacheNone", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMovie_CacheMode_Type,
        (long) QMovie::CacheAll, "CacheAll");
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict,
        "CacheAll", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMovie_CacheMode_Type.tp_dict,
        "CacheAll", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMovie::CacheMode");

    // init enum class: MovieState
    SbkPySide_QtGuiTypes[SBK_QMOVIE_MOVIESTATE_IDX] = &SbkPySide_QtGui_QMovie_MovieState_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMovie_MovieState_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QMovie_MovieState_Type);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict,
            "MovieState",((PyObject*)&SbkPySide_QtGui_QMovie_MovieState_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMovie_MovieState_Type,
        (long) QMovie::NotRunning, "NotRunning");
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict,
        "NotRunning", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMovie_MovieState_Type.tp_dict,
        "NotRunning", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMovie_MovieState_Type,
        (long) QMovie::Paused, "Paused");
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict,
        "Paused", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMovie_MovieState_Type.tp_dict,
        "Paused", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QMovie_MovieState_Type,
        (long) QMovie::Running, "Running");
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict,
        "Running", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QMovie_MovieState_Type.tp_dict,
        "Running", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMovie::MovieState");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("updated", "const QRect&", NULL);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict, "updated", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("error", "QImageReader::ImageReaderError", NULL);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict, "error", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("resized", "const QSize&", NULL);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict, "resized", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("started", "void", NULL);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict, "started", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("finished", "void", NULL);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict, "finished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("frameChanged", "int", NULL);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict, "frameChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "QMovie::MovieState", NULL);
    PyDict_SetItemString(SbkQMovie_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QMovie >("QMovie*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMovie >(typeid(QMovie).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QMovie >(typeid(QMovieWrapper).name());
    PySide::initQtMetaType<QMovie* >();
}

