/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpaintenginestate_wrapper.h"

// Extra includes
#include <QPainterPath>
#include <qbrush.h>
#include <qfont.h>
#include <qmatrix.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpen.h>
#include <qpoint.h>
#include <qregion.h>
#include <qtransform.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPaintEngineState_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPaintEngineState >()))
        return -1;

    QPaintEngineState* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QPaintEngineState()
            cptr = new QPaintEngineState();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPaintEngineState >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQPaintEngineStateFunc_backgroundBrush(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundBrush()const
            QBrush cppResult = cppSelf->QPaintEngineState::backgroundBrush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_backgroundMode(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundMode()const
            Qt::BGMode cppResult = cppSelf->QPaintEngineState::backgroundMode();
            pyResult = Shiboken::Converter<Qt::BGMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_brush(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // brush()const
            QBrush cppResult = cppSelf->QPaintEngineState::brush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_brushNeedsResolving(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // brushNeedsResolving()const
            bool cppResult = cppSelf->QPaintEngineState::brushNeedsResolving();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_brushOrigin(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // brushOrigin()const
            QPointF cppResult = cppSelf->QPaintEngineState::brushOrigin();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_clipOperation(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipOperation()const
            Qt::ClipOperation cppResult = cppSelf->QPaintEngineState::clipOperation();
            pyResult = Shiboken::Converter<Qt::ClipOperation >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_clipPath(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipPath()const
            QPainterPath cppResult = cppSelf->QPaintEngineState::clipPath();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_clipRegion(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipRegion()const
            QRegion cppResult = cppSelf->QPaintEngineState::clipRegion();
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_compositionMode(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // compositionMode()const
            QPainter::CompositionMode cppResult = cppSelf->QPaintEngineState::compositionMode();
            pyResult = Shiboken::Converter<QPainter::CompositionMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_font(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // font()const
            QFont cppResult = cppSelf->QPaintEngineState::font();
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_isClipEnabled(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isClipEnabled()const
            bool cppResult = cppSelf->QPaintEngineState::isClipEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_matrix(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // matrix()const
            QMatrix cppResult = cppSelf->QPaintEngineState::matrix();
            pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_opacity(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // opacity()const
            qreal cppResult = cppSelf->QPaintEngineState::opacity();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_painter(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // painter()const
            QPainter * cppResult = cppSelf->QPaintEngineState::painter();
            pyResult = Shiboken::Converter<QPainter * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_pen(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pen()const
            QPen cppResult = cppSelf->QPaintEngineState::pen();
            pyResult = Shiboken::Converter<QPen >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_penNeedsResolving(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // penNeedsResolving()const
            bool cppResult = cppSelf->QPaintEngineState::penNeedsResolving();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_renderHints(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // renderHints()const
            QFlags<QPainter::RenderHint> cppResult = cppSelf->QPaintEngineState::renderHints();
            pyResult = Shiboken::Converter<QFlags<QPainter::RenderHint> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_state(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QFlags<QPaintEngine::DirtyFlag> cppResult = cppSelf->QPaintEngineState::state();
            pyResult = Shiboken::Converter<QFlags<QPaintEngine::DirtyFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPaintEngineStateFunc_transform(PyObject* self)
{
    QPaintEngineState* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPaintEngineState* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transform()const
            QTransform cppResult = cppSelf->QPaintEngineState::transform();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPaintEngineState_methods[] = {
    {"backgroundBrush", (PyCFunction)SbkQPaintEngineStateFunc_backgroundBrush, METH_NOARGS},
    {"backgroundMode", (PyCFunction)SbkQPaintEngineStateFunc_backgroundMode, METH_NOARGS},
    {"brush", (PyCFunction)SbkQPaintEngineStateFunc_brush, METH_NOARGS},
    {"brushNeedsResolving", (PyCFunction)SbkQPaintEngineStateFunc_brushNeedsResolving, METH_NOARGS},
    {"brushOrigin", (PyCFunction)SbkQPaintEngineStateFunc_brushOrigin, METH_NOARGS},
    {"clipOperation", (PyCFunction)SbkQPaintEngineStateFunc_clipOperation, METH_NOARGS},
    {"clipPath", (PyCFunction)SbkQPaintEngineStateFunc_clipPath, METH_NOARGS},
    {"clipRegion", (PyCFunction)SbkQPaintEngineStateFunc_clipRegion, METH_NOARGS},
    {"compositionMode", (PyCFunction)SbkQPaintEngineStateFunc_compositionMode, METH_NOARGS},
    {"font", (PyCFunction)SbkQPaintEngineStateFunc_font, METH_NOARGS},
    {"isClipEnabled", (PyCFunction)SbkQPaintEngineStateFunc_isClipEnabled, METH_NOARGS},
    {"matrix", (PyCFunction)SbkQPaintEngineStateFunc_matrix, METH_NOARGS},
    {"opacity", (PyCFunction)SbkQPaintEngineStateFunc_opacity, METH_NOARGS},
    {"painter", (PyCFunction)SbkQPaintEngineStateFunc_painter, METH_NOARGS},
    {"pen", (PyCFunction)SbkQPaintEngineStateFunc_pen, METH_NOARGS},
    {"penNeedsResolving", (PyCFunction)SbkQPaintEngineStateFunc_penNeedsResolving, METH_NOARGS},
    {"renderHints", (PyCFunction)SbkQPaintEngineStateFunc_renderHints, METH_NOARGS},
    {"state", (PyCFunction)SbkQPaintEngineStateFunc_state, METH_NOARGS},
    {"transform", (PyCFunction)SbkQPaintEngineStateFunc_transform, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQPaintEngineState_get_dirtyFlags(PyObject* self, void*)
{
    return Shiboken::Converter<QFlags<QPaintEngine::DirtyFlag> >::toPython(Shiboken::Converter<QPaintEngineState* >::toCpp(self)->dirtyFlags);
}
static int SbkQPaintEngineState_set_dirtyFlags(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'dirtyFlags' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QFlags<QPaintEngine::DirtyFlag> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'dirtyFlags', 'DirtyFlags' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QPaintEngineState* >::toCpp(self)->dirtyFlags = Shiboken::Converter<QFlags<QPaintEngine::DirtyFlag> >::toCpp(value);

    return 0;
}

// Getters and Setters for QPaintEngineState
static PyGetSetDef SbkQPaintEngineState_getsetlist[] = {
    {const_cast<char*>("dirtyFlags"), SbkQPaintEngineState_get_dirtyFlags, SbkQPaintEngineState_set_dirtyFlags},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPaintEngineState_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPaintEngineState",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPaintEngineState_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQPaintEngineState_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPaintEngineState_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPaintEngineState >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPaintEngineState*",
    /*user_data*/           0
};
} //extern


void init_QPaintEngineState(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTENGINESTATE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPaintEngineState_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPaintEngineState_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPaintEngineState_Type));
    PyModule_AddObject(module, "QPaintEngineState",
        ((PyObject*)&SbkQPaintEngineState_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QPaintEngineState >("QPaintEngineState*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPaintEngineState >(typeid(QPaintEngineState).name());
    PySide::initQtMetaType<QPaintEngineState* >();
}

