/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpainterpath_wrapper.h"
#include "qpainterpath_element_wrapper.h"

// Extra includes
#include <QList>
#include <QPainterPath>
#include <qdatastream.h>
#include <qfont.h>
#include <qmatrix.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qtransform.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPainterPath_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPainterPath >()))
        return -1;

    QPainterPath* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPainterPath", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QPainterPath()
    // 1: QPainterPath(QPainterPath)
    // 2: QPainterPath(QPointF)
    if (numArgs == 0) {
        overloadId = 0; // QPainterPath()
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 2; // QPainterPath(QPointF)
    } else if (numArgs == 1 && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 1; // QPainterPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPath_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPainterPath()
            {

                if(!PyErr_Occurred()) {
                // QPainterPath()
                cptr = new QPainterPath();
                }
                break;
            }
            case 1: // QPainterPath(QPainterPath)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QPainterPath(QPainterPath)
                cptr = new QPainterPath(*cpp_arg0);
                }
                break;
            }
            case 2: // QPainterPath(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPainterPath(QPointF)
                cptr = new QPainterPath(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPainterPath >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPainterPath_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPainterPath_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath", overloads);
        return -1;
}

static PyObject* SbkQPainterPathFunc_addEllipse(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQPainterPathFunc_addEllipse_TypeError;

    if (!PyArg_UnpackTuple(args, "addEllipse", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addEllipse(QPointF,qreal,qreal)
    // 1: addEllipse(QRectF)
    // 2: addEllipse(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // addEllipse(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // addEllipse(QRectF)
    } else if (numArgs == 3 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // addEllipse(QPointF,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addEllipse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addEllipse(QPointF,qreal,qreal)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // addEllipse(QPointF,qreal,qreal)
                cppSelf->QPainterPath::addEllipse(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // addEllipse(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // addEllipse(QRectF)
                cppSelf->QPainterPath::addEllipse(*cpp_arg0);
                }
                break;
            }
            case 2: // addEllipse(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // addEllipse(qreal,qreal,qreal,qreal)
                cppSelf->QPainterPath::addEllipse(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addEllipse_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, float, float", "PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addEllipse", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_addPath(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPath(QPainterPath)
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // addPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addPath_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addPath(QPainterPath)
            cppSelf->QPainterPath::addPath(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.addPath", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_addPolygon(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPolygon(QPolygonF)
    if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 0; // addPolygon(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addPolygon_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
            if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // addPolygon(QPolygonF)
            cppSelf->QPainterPath::addPolygon(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.addPolygon", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_addRect(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQPainterPathFunc_addRect_TypeError;

    if (!PyArg_UnpackTuple(args, "addRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addRect(QRectF)
    // 1: addRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // addRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // addRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRect(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // addRect(QRectF)
                cppSelf->QPainterPath::addRect(*cpp_arg0);
                }
                break;
            }
            case 1: // addRect(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // addRect(qreal,qreal,qreal,qreal)
                cppSelf->QPainterPath::addRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addRect", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_addRegion(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addRegion(QRegion)
    if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // addRegion(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addRegion_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // addRegion(QRegion)
            cppSelf->QPainterPath::addRegion(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addRegion_TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.addRegion", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_addRoundRect(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4)
        goto SbkQPainterPathFunc_addRoundRect_TypeError;

    if (!PyArg_UnpackTuple(args, "addRoundRect", 2, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addRoundRect(QRectF,int)
    // 1: addRoundRect(QRectF,int,int)
    // 2: addRoundRect(qreal,qreal,qreal,qreal,int)
    // 3: addRoundRect(qreal,qreal,qreal,qreal,int,int)
    if (numArgs >= 5 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
        if (numArgs == 5) {
            overloadId = 2; // addRoundRect(qreal,qreal,qreal,qreal,int)
        } else if (numArgs == 6 && SbkNumber_Check(pyargs[5])) {
            overloadId = 3; // addRoundRect(qreal,qreal,qreal,qreal,int,int)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // addRoundRect(QRectF,int)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // addRoundRect(QRectF,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addRoundRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRoundRect(QRectF,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addRoundRect(QRectF,int)
                cppSelf->QPainterPath::addRoundRect(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // addRoundRect(QRectF,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // addRoundRect(QRectF,int,int)
                cppSelf->QPainterPath::addRoundRect(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // addRoundRect(qreal,qreal,qreal,qreal,int)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // addRoundRect(qreal,qreal,qreal,qreal,int)
                cppSelf->QPainterPath::addRoundRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 3: // addRoundRect(qreal,qreal,qreal,qreal,int,int)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cpp_arg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // addRoundRect(qreal,qreal,qreal,qreal,int,int)
                cppSelf->QPainterPath::addRoundRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addRoundRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, int", "PySide.QtCore.QRectF, int, int", "float, float, float, float, int", "float, float, float, float, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addRoundRect", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_addRoundedRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): not enough arguments");
        return 0;
    } else if (numArgs == 5)
        goto SbkQPainterPathFunc_addRoundedRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOO:addRoundedRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
    // 1: addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
    if (numArgs >= 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 1; // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter<Qt::SizeMode >::isConvertible(pyargs[6])) {
            overloadId = 1; // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter<Qt::SizeMode >::isConvertible(pyargs[3])) {
            overloadId = 0; // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addRoundedRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                Qt::SizeMode cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[3]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                // addRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
                cppSelf->QPainterPath::addRoundedRect(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 1: // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "mode";
                        else
                            pyargs[6] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.addRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);
                Qt::SizeMode cpp_arg6 = pyargs[6] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[6]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                // addRoundedRect(qreal,qreal,qreal,qreal,qreal,qreal,Qt::SizeMode)
                cppSelf->QPainterPath::addRoundedRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addRoundedRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", "float, float, float, float, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addRoundedRect", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_addText(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addText", 3, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addText(QPointF,QFont,QString)
    // 1: addText(qreal,qreal,QFont,QString)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QFont & >::isConvertible(pyargs[2]) && Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
        overloadId = 1; // addText(qreal,qreal,QFont,QString)
    } else if (numArgs == 3 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QFont & >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // addText(QPointF,QFont,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_addText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addText(QPointF,QFont,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QFont > cpp_arg1_auto_ptr;
                QFont* cpp_arg1 = Shiboken::Converter<QFont* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QFont >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QFont >(cpp_arg1);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // addText(QPointF,QFont,QString)
                cppSelf->QPainterPath::addText(*cpp_arg0, *cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // addText(qreal,qreal,QFont,QString)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QFont > cpp_arg2_auto_ptr;
                QFont* cpp_arg2 = Shiboken::Converter<QFont* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QFont >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QFont >(cpp_arg2);
                QString cpp_arg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // addText(qreal,qreal,QFont,QString)
                cppSelf->QPainterPath::addText(cpp_arg0, cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_addText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtGui.QFont, QString", "float, float, PySide.QtGui.QFont, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.addText", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_angleAtPercent(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: angleAtPercent(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // angleAtPercent(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_angleAtPercent_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // angleAtPercent(qreal)const
            qreal cppResult = cppSelf->QPainterPath::angleAtPercent(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_angleAtPercent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.angleAtPercent", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_arcMoveTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4)
        goto SbkQPainterPathFunc_arcMoveTo_TypeError;

    if (!PyArg_UnpackTuple(args, "arcMoveTo", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: arcMoveTo(QRectF,qreal)
    // 1: arcMoveTo(qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 5 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
        overloadId = 1; // arcMoveTo(qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // arcMoveTo(QRectF,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_arcMoveTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // arcMoveTo(QRectF,qreal)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // arcMoveTo(QRectF,qreal)
                cppSelf->QPainterPath::arcMoveTo(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // arcMoveTo(qreal,qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // arcMoveTo(qreal,qreal,qreal,qreal,qreal)
                cppSelf->QPainterPath::arcMoveTo(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_arcMoveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, float", "float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.arcMoveTo", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_arcTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto SbkQPainterPathFunc_arcTo_TypeError;

    if (!PyArg_UnpackTuple(args, "arcTo", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: arcTo(QRectF,qreal,qreal)
    // 1: arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 1; // arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // arcTo(QRectF,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_arcTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // arcTo(QRectF,qreal,qreal)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // arcTo(QRectF,qreal,qreal)
                cppSelf->QPainterPath::arcTo(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // arcTo(qreal,qreal,qreal,qreal,qreal,qreal)
                cppSelf->QPainterPath::arcTo(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_arcTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, float, float", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.arcTo", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_boundingRect(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect()const
            QRectF cppResult = cppSelf->QPainterPath::boundingRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_closeSubpath(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // closeSubpath()
            cppSelf->QPainterPath::closeSubpath();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPainterPathFunc_connectPath(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: connectPath(QPainterPath)
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // connectPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_connectPath_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // connectPath(QPainterPath)
            cppSelf->QPainterPath::connectPath(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_connectPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.connectPath", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_contains(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPainterPath)const
    // 1: contains(QPointF)const
    // 2: contains(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 2; // contains(QRectF)const
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 1; // contains(QPointF)const
    } else if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // contains(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_contains_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // contains(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // contains(QPainterPath)const
                bool cppResult = cppSelf->QPainterPath::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // contains(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // contains(QPointF)const
                bool cppResult = cppSelf->QPainterPath::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // contains(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // contains(QRectF)const
                bool cppResult = cppSelf->QPainterPath::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.contains", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_controlPointRect(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // controlPointRect()const
            QRectF cppResult = cppSelf->QPainterPath::controlPointRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_cubicTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto SbkQPainterPathFunc_cubicTo_TypeError;

    if (!PyArg_UnpackTuple(args, "cubicTo", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: cubicTo(QPointF,QPointF,QPointF)
    // 1: cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 1; // cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 3 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[2])) {
        overloadId = 0; // cubicTo(QPointF,QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_cubicTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // cubicTo(QPointF,QPointF,QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg2_auto_ptr;
                QPointF* cpp_arg2 = Shiboken::Converter<QPointF* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QPointF >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // cubicTo(QPointF,QPointF,QPointF)
                cppSelf->QPainterPath::cubicTo(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 1: // cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // cubicTo(qreal,qreal,qreal,qreal,qreal,qreal)
                cppSelf->QPainterPath::cubicTo(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_cubicTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.QPointF, PySide.QtCore.QPointF", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.cubicTo", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_currentPosition(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentPosition()const
            QPointF cppResult = cppSelf->QPainterPath::currentPosition();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_elementAt(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // elementAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_elementAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // elementAt(int)const
            const QPainterPath::Element & cppResult = cppSelf->QPainterPath::elementAt(cpp_arg0);
            pyResult = Shiboken::Converter<const QPainterPath::Element & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_elementAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.elementAt", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_elementCount(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // elementCount()const
            int cppResult = cppSelf->QPainterPath::elementCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_fillRule(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fillRule()const
            Qt::FillRule cppResult = cppSelf->QPainterPath::fillRule();
            pyResult = Shiboken::Converter<Qt::FillRule >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_intersected(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QPainterPath)const
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // intersected(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // intersected(QPainterPath)const
            QPainterPath cppResult = cppSelf->QPainterPath::intersected(*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.intersected", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_intersects(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QPainterPath)const
    // 1: intersects(QRectF)const
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 1; // intersects(QRectF)const
    } else if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // intersects(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_intersects_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // intersects(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // intersects(QPainterPath)const
                bool cppResult = cppSelf->QPainterPath::intersects(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // intersects(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // intersects(QRectF)const
                bool cppResult = cppSelf->QPainterPath::intersects(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.intersects", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_isEmpty(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QPainterPath::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_length(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            qreal cppResult = cppSelf->QPainterPath::length();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_lineTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "lineTo", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lineTo(QPointF)
    // 1: lineTo(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // lineTo(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // lineTo(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_lineTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // lineTo(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // lineTo(QPointF)
                cppSelf->QPainterPath::lineTo(*cpp_arg0);
                }
                break;
            }
            case 1: // lineTo(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // lineTo(qreal,qreal)
                cppSelf->QPainterPath::lineTo(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_lineTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.lineTo", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_moveTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveTo", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveTo(QPointF)
    // 1: moveTo(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // moveTo(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // moveTo(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_moveTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // moveTo(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // moveTo(QPointF)
                cppSelf->QPainterPath::moveTo(*cpp_arg0);
                }
                break;
            }
            case 1: // moveTo(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // moveTo(qreal,qreal)
                cppSelf->QPainterPath::moveTo(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_moveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.moveTo", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_percentAtLength(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: percentAtLength(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // percentAtLength(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_percentAtLength_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // percentAtLength(qreal)const
            qreal cppResult = cppSelf->QPainterPath::percentAtLength(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_percentAtLength_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.percentAtLength", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_pointAtPercent(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pointAtPercent(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // pointAtPercent(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_pointAtPercent_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // pointAtPercent(qreal)const
            QPointF cppResult = cppSelf->QPainterPath::pointAtPercent(cpp_arg0);
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_pointAtPercent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.pointAtPercent", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_quadTo(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQPainterPathFunc_quadTo_TypeError;

    if (!PyArg_UnpackTuple(args, "quadTo", 2, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: quadTo(QPointF,QPointF)
    // 1: quadTo(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // quadTo(qreal,qreal,qreal,qreal)
    } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // quadTo(QPointF,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_quadTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // quadTo(QPointF,QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // quadTo(QPointF,QPointF)
                cppSelf->QPainterPath::quadTo(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // quadTo(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // quadTo(qreal,qreal,qreal,qreal)
                cppSelf->QPainterPath::quadTo(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_quadTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.QPointF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.quadTo", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_setElementPositionAt(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setElementPositionAt", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setElementPositionAt(int,qreal,qreal)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setElementPositionAt(int,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_setElementPositionAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setElementPositionAt(int,qreal,qreal)
            cppSelf->QPainterPath::setElementPositionAt(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_setElementPositionAt_TypeError:
        const char* overloads[] = {"int, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.setElementPositionAt", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_setFillRule(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFillRule(Qt::FillRule)
    if (Shiboken::Converter<Qt::FillRule >::isConvertible(arg)) {
        overloadId = 0; // setFillRule(Qt::FillRule)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_setFillRule_TypeError;

    // Call function/method
    {
        {
            Qt::FillRule cpp_arg0 = Shiboken::Converter<Qt::FillRule >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFillRule(Qt::FillRule)
            cppSelf->QPainterPath::setFillRule(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_setFillRule_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.FillRule", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.setFillRule", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_simplified(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // simplified()const
            QPainterPath cppResult = cppSelf->QPainterPath::simplified();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_slopeAtPercent(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: slopeAtPercent(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // slopeAtPercent(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_slopeAtPercent_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // slopeAtPercent(qreal)const
            qreal cppResult = cppSelf->QPainterPath::slopeAtPercent(cpp_arg0);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_slopeAtPercent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.slopeAtPercent", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_subtracted(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtracted(QPainterPath)const
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // subtracted(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_subtracted_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // subtracted(QPainterPath)const
            QPainterPath cppResult = cppSelf->QPainterPath::subtracted(*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_subtracted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.subtracted", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_subtractedInverted(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtractedInverted(QPainterPath)const
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // subtractedInverted(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_subtractedInverted_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // subtractedInverted(QPainterPath)const
            QPainterPath cppResult = cppSelf->QPainterPath::subtractedInverted(*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_subtractedInverted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.subtractedInverted", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_toFillPolygon(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "matrix" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygon(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygon(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toFillPolygon", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toFillPolygon(QMatrix)const
    // 1: toFillPolygon(QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // toFillPolygon(QMatrix)const
    } else if (numArgs == 1 && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 1; // toFillPolygon(QTransform)const
    } else if (Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // toFillPolygon(QMatrix)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_toFillPolygon_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toFillPolygon(QMatrix)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "matrix");
                    if (value) {
                        if (arg)
                            errorArgName = "matrix";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix cpp_arg0_tmp = QMatrix();
                QMatrix* cpp_arg0 = arg ? Shiboken::Converter<QMatrix* >::toCpp(arg) : &cpp_arg0_tmp;

                if(!PyErr_Occurred()) {
                // toFillPolygon(QMatrix)const
                QPolygonF cppResult = cppSelf->QPainterPath::toFillPolygon(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 1: // toFillPolygon(QTransform)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // toFillPolygon(QTransform)const
                QPolygonF cppResult = cppSelf->QPainterPath::toFillPolygon(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_toFillPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix = QMatrix()", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.toFillPolygon", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_toFillPolygons(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "matrix" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygons(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygons(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toFillPolygons", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toFillPolygons(QMatrix)const
    // 1: toFillPolygons(QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // toFillPolygons(QMatrix)const
    } else if (numArgs == 1 && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 1; // toFillPolygons(QTransform)const
    } else if (Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // toFillPolygons(QMatrix)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_toFillPolygons_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toFillPolygons(QMatrix)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "matrix");
                    if (value) {
                        if (arg)
                            errorArgName = "matrix";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toFillPolygons(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix cpp_arg0_tmp = QMatrix();
                QMatrix* cpp_arg0 = arg ? Shiboken::Converter<QMatrix* >::toCpp(arg) : &cpp_arg0_tmp;

                if(!PyErr_Occurred()) {
                // toFillPolygons(QMatrix)const
                QList<QPolygonF > cppResult = cppSelf->QPainterPath::toFillPolygons(*cpp_arg0);
                pyResult = Shiboken::Converter<QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
            case 1: // toFillPolygons(QTransform)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // toFillPolygons(QTransform)const
                QList<QPolygonF > cppResult = cppSelf->QPainterPath::toFillPolygons(*cpp_arg0);
                pyResult = Shiboken::Converter<QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_toFillPolygons_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix = QMatrix()", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.toFillPolygons", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_toReversed(PyObject* self)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toReversed()const
            QPainterPath cppResult = cppSelf->QPainterPath::toReversed();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathFunc_toSubpathPolygons(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "matrix" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toSubpathPolygons(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainterPath.toSubpathPolygons(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toSubpathPolygons", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toSubpathPolygons(QMatrix)const
    // 1: toSubpathPolygons(QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // toSubpathPolygons(QMatrix)const
    } else if (numArgs == 1 && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 1; // toSubpathPolygons(QTransform)const
    } else if (Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // toSubpathPolygons(QMatrix)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_toSubpathPolygons_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toSubpathPolygons(QMatrix)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "matrix");
                    if (value) {
                        if (arg)
                            errorArgName = "matrix";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainterPath.toSubpathPolygons(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix cpp_arg0_tmp = QMatrix();
                QMatrix* cpp_arg0 = arg ? Shiboken::Converter<QMatrix* >::toCpp(arg) : &cpp_arg0_tmp;

                if(!PyErr_Occurred()) {
                // toSubpathPolygons(QMatrix)const
                QList<QPolygonF > cppResult = cppSelf->QPainterPath::toSubpathPolygons(*cpp_arg0);
                pyResult = Shiboken::Converter<QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
            case 1: // toSubpathPolygons(QTransform)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // toSubpathPolygons(QTransform)const
                QList<QPolygonF > cppResult = cppSelf->QPainterPath::toSubpathPolygons(*cpp_arg0);
                pyResult = Shiboken::Converter<QList<QPolygonF > >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_toSubpathPolygons_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix = QMatrix()", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.toSubpathPolygons", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_translate(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPointF)
    // 1: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translate(QPointF)
                cppSelf->QPainterPath::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                cppSelf->QPainterPath::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.translate", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_translated(PyObject* self, PyObject* args)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPointF)const
    // 1: translated(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translated(QPointF)const
                QPainterPath cppResult = cppSelf->QPainterPath::translated(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translated(qreal,qreal)const
                QPainterPath cppResult = cppSelf->QPainterPath::translated(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainterPath.translated", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc_united(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QPainterPath)const
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // united(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc_united_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // united(QPainterPath)const
            QPainterPath cppResult = cppSelf->QPainterPath::united(*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.united", overloads);
        return 0;
}

static PyMethodDef SbkQPainterPath_methods[] = {
    {"addEllipse", (PyCFunction)SbkQPainterPathFunc_addEllipse, METH_VARARGS},
    {"addPath", (PyCFunction)SbkQPainterPathFunc_addPath, METH_O},
    {"addPolygon", (PyCFunction)SbkQPainterPathFunc_addPolygon, METH_O},
    {"addRect", (PyCFunction)SbkQPainterPathFunc_addRect, METH_VARARGS},
    {"addRegion", (PyCFunction)SbkQPainterPathFunc_addRegion, METH_O},
    {"addRoundRect", (PyCFunction)SbkQPainterPathFunc_addRoundRect, METH_VARARGS},
    {"addRoundedRect", (PyCFunction)SbkQPainterPathFunc_addRoundedRect, METH_VARARGS|METH_KEYWORDS},
    {"addText", (PyCFunction)SbkQPainterPathFunc_addText, METH_VARARGS},
    {"angleAtPercent", (PyCFunction)SbkQPainterPathFunc_angleAtPercent, METH_O},
    {"arcMoveTo", (PyCFunction)SbkQPainterPathFunc_arcMoveTo, METH_VARARGS},
    {"arcTo", (PyCFunction)SbkQPainterPathFunc_arcTo, METH_VARARGS},
    {"boundingRect", (PyCFunction)SbkQPainterPathFunc_boundingRect, METH_NOARGS},
    {"closeSubpath", (PyCFunction)SbkQPainterPathFunc_closeSubpath, METH_NOARGS},
    {"connectPath", (PyCFunction)SbkQPainterPathFunc_connectPath, METH_O},
    {"contains", (PyCFunction)SbkQPainterPathFunc_contains, METH_O},
    {"controlPointRect", (PyCFunction)SbkQPainterPathFunc_controlPointRect, METH_NOARGS},
    {"cubicTo", (PyCFunction)SbkQPainterPathFunc_cubicTo, METH_VARARGS},
    {"currentPosition", (PyCFunction)SbkQPainterPathFunc_currentPosition, METH_NOARGS},
    {"elementAt", (PyCFunction)SbkQPainterPathFunc_elementAt, METH_O},
    {"elementCount", (PyCFunction)SbkQPainterPathFunc_elementCount, METH_NOARGS},
    {"fillRule", (PyCFunction)SbkQPainterPathFunc_fillRule, METH_NOARGS},
    {"intersected", (PyCFunction)SbkQPainterPathFunc_intersected, METH_O},
    {"intersects", (PyCFunction)SbkQPainterPathFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)SbkQPainterPathFunc_isEmpty, METH_NOARGS},
    {"length", (PyCFunction)SbkQPainterPathFunc_length, METH_NOARGS},
    {"lineTo", (PyCFunction)SbkQPainterPathFunc_lineTo, METH_VARARGS},
    {"moveTo", (PyCFunction)SbkQPainterPathFunc_moveTo, METH_VARARGS},
    {"percentAtLength", (PyCFunction)SbkQPainterPathFunc_percentAtLength, METH_O},
    {"pointAtPercent", (PyCFunction)SbkQPainterPathFunc_pointAtPercent, METH_O},
    {"quadTo", (PyCFunction)SbkQPainterPathFunc_quadTo, METH_VARARGS},
    {"setElementPositionAt", (PyCFunction)SbkQPainterPathFunc_setElementPositionAt, METH_VARARGS},
    {"setFillRule", (PyCFunction)SbkQPainterPathFunc_setFillRule, METH_O},
    {"simplified", (PyCFunction)SbkQPainterPathFunc_simplified, METH_NOARGS},
    {"slopeAtPercent", (PyCFunction)SbkQPainterPathFunc_slopeAtPercent, METH_O},
    {"subtracted", (PyCFunction)SbkQPainterPathFunc_subtracted, METH_O},
    {"subtractedInverted", (PyCFunction)SbkQPainterPathFunc_subtractedInverted, METH_O},
    {"toFillPolygon", (PyCFunction)SbkQPainterPathFunc_toFillPolygon, METH_VARARGS|METH_KEYWORDS},
    {"toFillPolygons", (PyCFunction)SbkQPainterPathFunc_toFillPolygons, METH_VARARGS|METH_KEYWORDS},
    {"toReversed", (PyCFunction)SbkQPainterPathFunc_toReversed, METH_NOARGS},
    {"toSubpathPolygons", (PyCFunction)SbkQPainterPathFunc_toSubpathPolygons, METH_VARARGS|METH_KEYWORDS},
    {"translate", (PyCFunction)SbkQPainterPathFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)SbkQPainterPathFunc_translated, METH_VARARGS},
    {"united", (PyCFunction)SbkQPainterPathFunc_united, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQPainterPathFunc___and__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QPainterPath)const
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator&(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___and___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator&(QPainterPath)const
            QPainterPath cppResult = (*cppSelf) & (*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__and__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___iand__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QPainterPath)
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator&=(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___iand___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator&=(QPainterPath)
            (*cppSelf) &= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPainterPathFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__iand__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___mul__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QPainterPath,QMatrix)
    // 1: operator*(QPainterPath,QTransform)
    if (!isReverse && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 1; // operator*(QPainterPath,QTransform)
    } else if (!isReverse && Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QPainterPath,QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QPainterPath,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPainterPath,QMatrix)
                QPainterPath cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QPainterPath,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPainterPath,QTransform)
                QPainterPath cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__mul__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___add__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QPainterPath)const
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator+(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___add___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+(QPainterPath)const
            QPainterPath cppResult = (*cppSelf) + (*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__add__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___iadd__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QPainterPath)
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+=(QPainterPath)
            (*cppSelf) += (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPainterPathFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__iadd__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___sub__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QPainterPath)const
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator-(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-(QPainterPath)const
            QPainterPath cppResult = (*cppSelf) - (*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__sub__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___isub__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QPainterPath)
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-=(QPainterPath)
            (*cppSelf) -= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPainterPathFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__isub__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPainterPath)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QPainterPath) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPainterPath&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPainterPath&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QPainterPath&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__rshift__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___or__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QPainterPath)const
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator|(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___or___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator|(QPainterPath)const
            QPainterPath cppResult = (*cppSelf) | (*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__or__", overloads);
        return 0;
}

static PyObject* SbkQPainterPathFunc___ior__(PyObject* self, PyObject* arg)
{
    QPainterPath* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPainterPath >::checkType(arg) && !Shiboken::Converter<QPainterPath >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPath* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QPainterPath)
    if (!isReverse && Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // operator|=(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathFunc___ior___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator|=(QPainterPath)
            (*cppSelf) |= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQPainterPathFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPath.__ior__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQPainterPath_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQPainterPathFunc___add__,
    /*nb_subtract*/             (binaryfunc)SbkQPainterPathFunc___sub__,
    /*nb_multiply*/             (binaryfunc)SbkQPainterPathFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQPainterPathFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQPainterPathFunc___rshift__,
    /*nb_and*/                  (binaryfunc)SbkQPainterPathFunc___and__,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)SbkQPainterPathFunc___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQPainterPathFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)SbkQPainterPathFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)SbkQPainterPathFunc___iand__,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)SbkQPainterPathFunc___ior__,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQPainterPath_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QPainterPath& cpp_self = *Shiboken::Converter<QPainterPath* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QPainterPath & >::isConvertible(other)) {
                // operator!=(const QPainterPath & other) const
                QPainterPath* cpp_other = Shiboken::Converter<QPainterPath* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPainterPath  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQPainterPath_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QPainterPath & >::isConvertible(other)) {
                // operator==(const QPainterPath & other) const
                QPainterPath* cpp_other = Shiboken::Converter<QPainterPath* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPainterPath  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQPainterPath_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQPainterPath_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPainterPath_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPainterPath",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQPainterPath_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQPainterPath_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPainterPath_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPainterPath_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPainterPath >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPainterPath",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QPainterPath_ElementType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QPainterPath_ElementType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QPainterPath_ElementType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ElementType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QPainterPath_ElementType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QPainterPath_ElementType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QPainterPath_ElementType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QPainterPath(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTERPATH_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPainterPath_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPainterPath_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPainterPath_Type));
    PyModule_AddObject(module, "QPainterPath",
        ((PyObject*)&SbkQPainterPath_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ElementType
    SbkPySide_QtGuiTypes[SBK_QPAINTERPATH_ELEMENTTYPE_IDX] = &SbkPySide_QtGui_QPainterPath_ElementType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainterPath_ElementType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPainterPath_ElementType_Type);
    PyDict_SetItemString(SbkQPainterPath_Type.super.ht_type.tp_dict,
            "ElementType",((PyObject*)&SbkPySide_QtGui_QPainterPath_ElementType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainterPath_ElementType_Type,
        (long) QPainterPath::MoveToElement, "MoveToElement");
    PyDict_SetItemString(SbkQPainterPath_Type.super.ht_type.tp_dict,
        "MoveToElement", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType_Type.tp_dict,
        "MoveToElement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainterPath_ElementType_Type,
        (long) QPainterPath::LineToElement, "LineToElement");
    PyDict_SetItemString(SbkQPainterPath_Type.super.ht_type.tp_dict,
        "LineToElement", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType_Type.tp_dict,
        "LineToElement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainterPath_ElementType_Type,
        (long) QPainterPath::CurveToElement, "CurveToElement");
    PyDict_SetItemString(SbkQPainterPath_Type.super.ht_type.tp_dict,
        "CurveToElement", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType_Type.tp_dict,
        "CurveToElement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainterPath_ElementType_Type,
        (long) QPainterPath::CurveToDataElement, "CurveToDataElement");
    PyDict_SetItemString(SbkQPainterPath_Type.super.ht_type.tp_dict,
        "CurveToDataElement", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainterPath_ElementType_Type.tp_dict,
        "CurveToDataElement", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainterPath::ElementType");


    Shiboken::TypeResolver::createValueTypeResolver<QPainterPath >("QPainterPath");
    Shiboken::TypeResolver::createObjectTypeResolver<QPainterPath >("QPainterPath*");
    Shiboken::TypeResolver::createValueTypeResolver<QPainterPath >(typeid(QPainterPath).name());
    PySide::initQtMetaType<QPainterPath >();
}

