/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpainterpathstroker_wrapper.h"

// Extra includes
#include <QVector>
#include <qpainterpath.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPainterPathStroker_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPainterPathStroker >()))
        return -1;

    QPainterPathStroker* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QPainterPathStroker()
            cptr = new QPainterPathStroker();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPainterPathStroker >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQPainterPathStrokerFunc_capStyle(PyObject* self)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // capStyle()const
            Qt::PenCapStyle cppResult = cppSelf->QPainterPathStroker::capStyle();
            pyResult = Shiboken::Converter<Qt::PenCapStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathStrokerFunc_createStroke(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createStroke(QPainterPath)const
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // createStroke(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_createStroke_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createStroke(QPainterPath)const
            QPainterPath cppResult = cppSelf->QPainterPathStroker::createStroke(*cpp_arg0);
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterPathStrokerFunc_createStroke_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.createStroke", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_curveThreshold(PyObject* self)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // curveThreshold()const
            qreal cppResult = cppSelf->QPainterPathStroker::curveThreshold();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathStrokerFunc_dashOffset(PyObject* self)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dashOffset()const
            qreal cppResult = cppSelf->QPainterPathStroker::dashOffset();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathStrokerFunc_dashPattern(PyObject* self)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dashPattern()const
            QVector<qreal > cppResult = cppSelf->QPainterPathStroker::dashPattern();
            pyResult = Shiboken::Converter<QVector<qreal > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathStrokerFunc_joinStyle(PyObject* self)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // joinStyle()const
            Qt::PenJoinStyle cppResult = cppSelf->QPainterPathStroker::joinStyle();
            pyResult = Shiboken::Converter<Qt::PenJoinStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathStrokerFunc_miterLimit(PyObject* self)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // miterLimit()const
            qreal cppResult = cppSelf->QPainterPathStroker::miterLimit();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterPathStrokerFunc_setCapStyle(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCapStyle(Qt::PenCapStyle)
    if (Shiboken::Converter<Qt::PenCapStyle >::isConvertible(arg)) {
        overloadId = 0; // setCapStyle(Qt::PenCapStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_setCapStyle_TypeError;

    // Call function/method
    {
        {
            Qt::PenCapStyle cpp_arg0 = Shiboken::Converter<Qt::PenCapStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCapStyle(Qt::PenCapStyle)
            cppSelf->QPainterPathStroker::setCapStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathStrokerFunc_setCapStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenCapStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.setCapStyle", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_setCurveThreshold(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurveThreshold(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurveThreshold(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_setCurveThreshold_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurveThreshold(qreal)
            cppSelf->QPainterPathStroker::setCurveThreshold(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathStrokerFunc_setCurveThreshold_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.setCurveThreshold", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_setDashOffset(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDashOffset(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDashOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_setDashOffset_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDashOffset(qreal)
            cppSelf->QPainterPathStroker::setDashOffset(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathStrokerFunc_setDashOffset_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.setDashOffset", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_setDashPattern(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDashPattern(Qt::PenStyle)
    // 1: setDashPattern(QVector<qreal>)
    if (Shiboken::Converter< QVector<qreal >  >::isConvertible(arg)) {
        overloadId = 1; // setDashPattern(QVector<qreal>)
    } else if (Shiboken::Converter<Qt::PenStyle >::isConvertible(arg)) {
        overloadId = 0; // setDashPattern(Qt::PenStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_setDashPattern_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setDashPattern(Qt::PenStyle)
            {
                Qt::PenStyle cpp_arg0 = Shiboken::Converter<Qt::PenStyle >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setDashPattern(Qt::PenStyle)
                cppSelf->QPainterPathStroker::setDashPattern(cpp_arg0);
                }
                break;
            }
            case 1: // setDashPattern(QVector<qreal>)
            {
                QVector<qreal > cpp_arg0 = Shiboken::Converter<QVector<qreal > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setDashPattern(QVector<qreal>)
                cppSelf->QPainterPathStroker::setDashPattern(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathStrokerFunc_setDashPattern_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenStyle", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.setDashPattern", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_setJoinStyle(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setJoinStyle(Qt::PenJoinStyle)
    if (Shiboken::Converter<Qt::PenJoinStyle >::isConvertible(arg)) {
        overloadId = 0; // setJoinStyle(Qt::PenJoinStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_setJoinStyle_TypeError;

    // Call function/method
    {
        {
            Qt::PenJoinStyle cpp_arg0 = Shiboken::Converter<Qt::PenJoinStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setJoinStyle(Qt::PenJoinStyle)
            cppSelf->QPainterPathStroker::setJoinStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathStrokerFunc_setJoinStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenJoinStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.setJoinStyle", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_setMiterLimit(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMiterLimit(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMiterLimit(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_setMiterLimit_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMiterLimit(qreal)
            cppSelf->QPainterPathStroker::setMiterLimit(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathStrokerFunc_setMiterLimit_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.setMiterLimit", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_setWidth(PyObject* self, PyObject* arg)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterPathStrokerFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidth(qreal)
            cppSelf->QPainterPathStroker::setWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterPathStrokerFunc_setWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainterPathStroker.setWidth", overloads);
        return 0;
}

static PyObject* SbkQPainterPathStrokerFunc_width(PyObject* self)
{
    QPainterPathStroker* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainterPathStroker* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            qreal cppResult = cppSelf->QPainterPathStroker::width();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPainterPathStroker_methods[] = {
    {"capStyle", (PyCFunction)SbkQPainterPathStrokerFunc_capStyle, METH_NOARGS},
    {"createStroke", (PyCFunction)SbkQPainterPathStrokerFunc_createStroke, METH_O},
    {"curveThreshold", (PyCFunction)SbkQPainterPathStrokerFunc_curveThreshold, METH_NOARGS},
    {"dashOffset", (PyCFunction)SbkQPainterPathStrokerFunc_dashOffset, METH_NOARGS},
    {"dashPattern", (PyCFunction)SbkQPainterPathStrokerFunc_dashPattern, METH_NOARGS},
    {"joinStyle", (PyCFunction)SbkQPainterPathStrokerFunc_joinStyle, METH_NOARGS},
    {"miterLimit", (PyCFunction)SbkQPainterPathStrokerFunc_miterLimit, METH_NOARGS},
    {"setCapStyle", (PyCFunction)SbkQPainterPathStrokerFunc_setCapStyle, METH_O},
    {"setCurveThreshold", (PyCFunction)SbkQPainterPathStrokerFunc_setCurveThreshold, METH_O},
    {"setDashOffset", (PyCFunction)SbkQPainterPathStrokerFunc_setDashOffset, METH_O},
    {"setDashPattern", (PyCFunction)SbkQPainterPathStrokerFunc_setDashPattern, METH_O},
    {"setJoinStyle", (PyCFunction)SbkQPainterPathStrokerFunc_setJoinStyle, METH_O},
    {"setMiterLimit", (PyCFunction)SbkQPainterPathStrokerFunc_setMiterLimit, METH_O},
    {"setWidth", (PyCFunction)SbkQPainterPathStrokerFunc_setWidth, METH_O},
    {"width", (PyCFunction)SbkQPainterPathStrokerFunc_width, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPainterPathStroker_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPainterPathStroker",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPainterPathStroker_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPainterPathStroker_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPainterPathStroker >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPainterPathStroker*",
    /*user_data*/           0
};
} //extern


void init_QPainterPathStroker(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTERPATHSTROKER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPainterPathStroker_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPainterPathStroker_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPainterPathStroker_Type));
    PyModule_AddObject(module, "QPainterPathStroker",
        ((PyObject*)&SbkQPainterPathStroker_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QPainterPathStroker >("QPainterPathStroker*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPainterPathStroker >(typeid(QPainterPathStroker).name());
    PySide::initQtMetaType<QPainterPathStroker* >();
}

