/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpen_wrapper.h"

// Extra includes
#include <QBrush>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qdatastream.h>
#include <qpen.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPen_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPen >()))
        return -1;

    QPen* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "c", "j", "s" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPen(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPen(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QPen", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QPen()
    // 1: QPen(Qt::PenStyle)
    // 2: QPen(QBrush,qreal,Qt::PenStyle,Qt::PenCapStyle,Qt::PenJoinStyle)
    // 3: QPen(QColor)
    // 4: QPen(QPen)
    if (numArgs == 0) {
        overloadId = 0; // QPen()
    } else if (numArgs == 1 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QPen(QColor)
    } else if (numArgs >= 2 && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QPen(QBrush,qreal,Qt::PenStyle,Qt::PenCapStyle,Qt::PenJoinStyle)
        } else if (Shiboken::Converter<Qt::PenStyle >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QPen(QBrush,qreal,Qt::PenStyle,Qt::PenCapStyle,Qt::PenJoinStyle)
            } else if (Shiboken::Converter<Qt::PenCapStyle >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // QPen(QBrush,qreal,Qt::PenStyle,Qt::PenCapStyle,Qt::PenJoinStyle)
                } else if (Shiboken::Converter<Qt::PenJoinStyle >::isConvertible(pyargs[4])) {
                    overloadId = 2; // QPen(QBrush,qreal,Qt::PenStyle,Qt::PenCapStyle,Qt::PenJoinStyle)
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<Qt::PenStyle >::isConvertible(pyargs[0])) {
        overloadId = 1; // QPen(Qt::PenStyle)
    } else if (numArgs == 1 && Shiboken::Converter<const QPen & >::isConvertible(pyargs[0])) {
        overloadId = 4; // QPen(QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPen_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPen()
            {

                if(!PyErr_Occurred()) {
                // QPen()
                cptr = new QPen();
                }
                break;
            }
            case 1: // QPen(Qt::PenStyle)
            {
                Qt::PenStyle cpp_arg0 = Shiboken::Converter<Qt::PenStyle >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QPen(Qt::PenStyle)
                cptr = new QPen(cpp_arg0);
                }
                break;
            }
            case 2: // QPen(QBrush,qreal,Qt::PenStyle,Qt::PenCapStyle,Qt::PenJoinStyle)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "s");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "s";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "c");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "c";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "j");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "j";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPen(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
                QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QBrush >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                Qt::PenStyle cpp_arg2 = pyargs[2] ? Shiboken::Converter<Qt::PenStyle >::toCpp(pyargs[2]) : Qt::SolidLine;
                Qt::PenCapStyle cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::PenCapStyle >::toCpp(pyargs[3]) : Qt::SquareCap;
                Qt::PenJoinStyle cpp_arg4 = pyargs[4] ? Shiboken::Converter<Qt::PenJoinStyle >::toCpp(pyargs[4]) : Qt::BevelJoin;

                if(!PyErr_Occurred()) {
                // QPen(QBrush,qreal,Qt::PenStyle,Qt::PenCapStyle,Qt::PenJoinStyle)
                cptr = new QPen(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 3: // QPen(QColor)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPen(QColor)
                cptr = new QPen(*cpp_arg0);
                }
                break;
            }
            case 4: // QPen(QPen)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPen > cpp_arg0_auto_ptr;
                QPen* cpp_arg0 = Shiboken::Converter<QPen* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPen >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPen >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPen(QPen)
                cptr = new QPen(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPen >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPen_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPen_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.PenStyle", "PySide.QtGui.QBrush, float, PySide.QtCore.Qt.PenStyle = Qt.SolidLine, PySide.QtCore.Qt.PenCapStyle = Qt.SquareCap, PySide.QtCore.Qt.PenJoinStyle = Qt.BevelJoin", "PySide.QtGui.QColor", "PySide.QtGui.QPen", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPen", overloads);
        return -1;
}

static PyObject* SbkQPenFunc_brush(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // brush()const
            QBrush cppResult = cppSelf->QPen::brush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_capStyle(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // capStyle()const
            Qt::PenCapStyle cppResult = cppSelf->QPen::capStyle();
            pyResult = Shiboken::Converter<Qt::PenCapStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_color(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // color()const
            QColor cppResult = cppSelf->QPen::color();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_dashOffset(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dashOffset()const
            qreal cppResult = cppSelf->QPen::dashOffset();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_dashPattern(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dashPattern()const
            QVector<qreal > cppResult = cppSelf->QPen::dashPattern();
            pyResult = Shiboken::Converter<QVector<qreal > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_isCosmetic(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCosmetic()const
            bool cppResult = cppSelf->QPen::isCosmetic();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_isSolid(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSolid()const
            bool cppResult = cppSelf->QPen::isSolid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_joinStyle(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // joinStyle()const
            Qt::PenJoinStyle cppResult = cppSelf->QPen::joinStyle();
            pyResult = Shiboken::Converter<Qt::PenJoinStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_miterLimit(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // miterLimit()const
            qreal cppResult = cppSelf->QPen::miterLimit();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_setBrush(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBrush(QBrush)
    if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 0; // setBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setBrush_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
            QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
            if (!Shiboken::Converter<QBrush >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBrush(QBrush)
            cppSelf->QPen::setBrush(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setBrush", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setCapStyle(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCapStyle(Qt::PenCapStyle)
    if (Shiboken::Converter<Qt::PenCapStyle >::isConvertible(arg)) {
        overloadId = 0; // setCapStyle(Qt::PenCapStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setCapStyle_TypeError;

    // Call function/method
    {
        {
            Qt::PenCapStyle cpp_arg0 = Shiboken::Converter<Qt::PenCapStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCapStyle(Qt::PenCapStyle)
            cppSelf->QPen::setCapStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setCapStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenCapStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setCapStyle", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setColor(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColor(QColor)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // setColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setColor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setColor(QColor)
            cppSelf->QPen::setColor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setColor", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setCosmetic(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCosmetic(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCosmetic(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setCosmetic_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCosmetic(bool)
            cppSelf->QPen::setCosmetic(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setCosmetic_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setCosmetic", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setDashOffset(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDashOffset(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDashOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setDashOffset_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDashOffset(qreal)
            cppSelf->QPen::setDashOffset(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setDashOffset_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setDashOffset", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setDashPattern(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDashPattern(QVector<qreal>)
    if (Shiboken::Converter< QVector<qreal >  >::isConvertible(arg)) {
        overloadId = 0; // setDashPattern(QVector<qreal>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setDashPattern_TypeError;

    // Call function/method
    {
        {
            QVector<qreal > cpp_arg0 = Shiboken::Converter<QVector<qreal > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDashPattern(QVector<qreal>)
            cppSelf->QPen::setDashPattern(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setDashPattern_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setDashPattern", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setJoinStyle(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setJoinStyle(Qt::PenJoinStyle)
    if (Shiboken::Converter<Qt::PenJoinStyle >::isConvertible(arg)) {
        overloadId = 0; // setJoinStyle(Qt::PenJoinStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setJoinStyle_TypeError;

    // Call function/method
    {
        {
            Qt::PenJoinStyle cpp_arg0 = Shiboken::Converter<Qt::PenJoinStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setJoinStyle(Qt::PenJoinStyle)
            cppSelf->QPen::setJoinStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setJoinStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenJoinStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setJoinStyle", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setMiterLimit(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMiterLimit(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMiterLimit(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setMiterLimit_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMiterLimit(qreal)
            cppSelf->QPen::setMiterLimit(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setMiterLimit_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setMiterLimit", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setStyle(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(Qt::PenStyle)
    if (Shiboken::Converter<Qt::PenStyle >::isConvertible(arg)) {
        overloadId = 0; // setStyle(Qt::PenStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            Qt::PenStyle cpp_arg0 = Shiboken::Converter<Qt::PenStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStyle(Qt::PenStyle)
            cppSelf->QPen::setStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setStyle", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setWidth(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidth(int)
            cppSelf->QPen::setWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setWidth", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_setWidthF(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidthF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidthF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc_setWidthF_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidthF(qreal)
            cppSelf->QPen::setWidthF(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPenFunc_setWidthF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.setWidthF", overloads);
        return 0;
}

static PyObject* SbkQPenFunc_style(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()const
            Qt::PenStyle cppResult = cppSelf->QPen::style();
            pyResult = Shiboken::Converter<Qt::PenStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_width(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            int cppResult = cppSelf->QPen::width();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPenFunc_widthF(PyObject* self)
{
    QPen* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // widthF()const
            qreal cppResult = cppSelf->QPen::widthF();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPen_methods[] = {
    {"brush", (PyCFunction)SbkQPenFunc_brush, METH_NOARGS},
    {"capStyle", (PyCFunction)SbkQPenFunc_capStyle, METH_NOARGS},
    {"color", (PyCFunction)SbkQPenFunc_color, METH_NOARGS},
    {"dashOffset", (PyCFunction)SbkQPenFunc_dashOffset, METH_NOARGS},
    {"dashPattern", (PyCFunction)SbkQPenFunc_dashPattern, METH_NOARGS},
    {"isCosmetic", (PyCFunction)SbkQPenFunc_isCosmetic, METH_NOARGS},
    {"isSolid", (PyCFunction)SbkQPenFunc_isSolid, METH_NOARGS},
    {"joinStyle", (PyCFunction)SbkQPenFunc_joinStyle, METH_NOARGS},
    {"miterLimit", (PyCFunction)SbkQPenFunc_miterLimit, METH_NOARGS},
    {"setBrush", (PyCFunction)SbkQPenFunc_setBrush, METH_O},
    {"setCapStyle", (PyCFunction)SbkQPenFunc_setCapStyle, METH_O},
    {"setColor", (PyCFunction)SbkQPenFunc_setColor, METH_O},
    {"setCosmetic", (PyCFunction)SbkQPenFunc_setCosmetic, METH_O},
    {"setDashOffset", (PyCFunction)SbkQPenFunc_setDashOffset, METH_O},
    {"setDashPattern", (PyCFunction)SbkQPenFunc_setDashPattern, METH_O},
    {"setJoinStyle", (PyCFunction)SbkQPenFunc_setJoinStyle, METH_O},
    {"setMiterLimit", (PyCFunction)SbkQPenFunc_setMiterLimit, METH_O},
    {"setStyle", (PyCFunction)SbkQPenFunc_setStyle, METH_O},
    {"setWidth", (PyCFunction)SbkQPenFunc_setWidth, METH_O},
    {"setWidthF", (PyCFunction)SbkQPenFunc_setWidthF, METH_O},
    {"style", (PyCFunction)SbkQPenFunc_style, METH_NOARGS},
    {"width", (PyCFunction)SbkQPenFunc_width, METH_NOARGS},
    {"widthF", (PyCFunction)SbkQPenFunc_widthF, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQPenFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPen >::checkType(arg) && !Shiboken::Converter<QPen >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPen)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QPen) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPenFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQPenFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPen* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPen >::checkType(arg) && !Shiboken::Converter<QPen >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPen* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPen&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPen&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPenFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QPen&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPenFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPen.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQPen_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQPenFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQPenFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQPen_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QPen& cpp_self = *Shiboken::Converter<QPen* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QPen & >::isConvertible(other)) {
                // operator!=(const QPen & p) const
                QPen* cpp_other = Shiboken::Converter<QPen* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPen  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QPen >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QPen > cpp_other_auto_ptr;
                QPen* cpp_other = Shiboken::Converter<QPen* >::toCpp(other);
                if (!Shiboken::Converter<QPen >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QPen >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQPen_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QPen & >::isConvertible(other)) {
                // operator==(const QPen & p) const
                QPen* cpp_other = Shiboken::Converter<QPen* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QPen  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QPen >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QPen > cpp_other_auto_ptr;
                QPen* cpp_other = Shiboken::Converter<QPen* >::toCpp(other);
                if (!Shiboken::Converter<QPen >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QPen >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQPen_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQPen_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPen_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPen",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQPen_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQPen_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPen_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPen_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPen >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPen",
    /*user_data*/           0
};
} //extern


void init_QPen(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPEN_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPen_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPen_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPen_Type));
    PyModule_AddObject(module, "QPen",
        ((PyObject*)&SbkQPen_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QPen >("QPen");
    Shiboken::TypeResolver::createObjectTypeResolver<QPen >("QPen*");
    Shiboken::TypeResolver::createValueTypeResolver<QPen >(typeid(QPen).name());
    PySide::initQtMetaType<QPen >();
}

