/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpictureio_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qpicture.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPictureIO_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPictureIO >()))
        return -1;

    QPictureIO* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QPictureIO()
            cptr = new QPictureIO();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPictureIO >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQPictureIOFunc_description(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // description()const
            QString cppResult = cppSelf->QPictureIO::description();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_fileName(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QPictureIO::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_gamma(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // gamma()const
            float cppResult = cppSelf->QPictureIO::gamma();
            pyResult = Shiboken::Converter<float >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_inputFormats(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // inputFormats()
            QList<QByteArray > cppResult = QPictureIO::inputFormats();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_ioDevice(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ioDevice()const
            QIODevice * cppResult = cppSelf->QPictureIO::ioDevice();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_outputFormats(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // outputFormats()
            QList<QByteArray > cppResult = QPictureIO::outputFormats();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_picture(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // picture()const
            const QPicture & cppResult = cppSelf->QPictureIO::picture();
            pyResult = Shiboken::Converter<const QPicture & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_pictureFormat(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pictureFormat(QIODevice*)
    // 1: pictureFormat(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // pictureFormat(QString)
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // pictureFormat(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_pictureFormat_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pictureFormat(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // pictureFormat(QIODevice*)
                QByteArray cppResult = QPictureIO::pictureFormat(cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 1: // pictureFormat(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // pictureFormat(QString)
                QByteArray cppResult = QPictureIO::pictureFormat(cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPictureIOFunc_pictureFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.pictureFormat", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_quality(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // quality()const
            int cppResult = cppSelf->QPictureIO::quality();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_read(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // read()
            bool cppResult = cppSelf->QPictureIO::read();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_setDescription(PyObject* self, PyObject* arg)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDescription(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_setDescription_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDescription(QString)
            cppSelf->QPictureIO::setDescription(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPictureIOFunc_setDescription_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.setDescription", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_setFileName(PyObject* self, PyObject* arg)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFileName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_setFileName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFileName(QString)
            cppSelf->QPictureIO::setFileName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPictureIOFunc_setFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.setFileName", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_setGamma(PyObject* self, PyObject* arg)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGamma(float)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGamma(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_setGamma_TypeError;

    // Call function/method
    {
        {
            float cpp_arg0 = Shiboken::Converter<float >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGamma(float)
            cppSelf->QPictureIO::setGamma(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPictureIOFunc_setGamma_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.setGamma", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_setIODevice(PyObject* self, PyObject* arg)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIODevice(QIODevice*)
    if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setIODevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_setIODevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIODevice(QIODevice*)
            cppSelf->QPictureIO::setIODevice(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPictureIOFunc_setIODevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.setIODevice", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_setPicture(PyObject* self, PyObject* arg)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPicture(QPicture)
    if (Shiboken::Converter<const QPicture & >::isConvertible(arg)) {
        overloadId = 0; // setPicture(QPicture)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_setPicture_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPicture* cpp_arg0 = Shiboken::Converter<QPicture* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPicture(QPicture)
            cppSelf->QPictureIO::setPicture(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPictureIOFunc_setPicture_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPicture", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.setPicture", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_setQuality(PyObject* self, PyObject* arg)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQuality(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setQuality(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_setQuality_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setQuality(int)
            cppSelf->QPictureIO::setQuality(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPictureIOFunc_setQuality_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.setQuality", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_setStatus(PyObject* self, PyObject* arg)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatus(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStatus(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPictureIOFunc_setStatus_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStatus(int)
            cppSelf->QPictureIO::setStatus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPictureIOFunc_setStatus_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPictureIO.setStatus", overloads);
        return 0;
}

static PyObject* SbkQPictureIOFunc_status(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // status()const
            int cppResult = cppSelf->QPictureIO::status();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPictureIOFunc_write(PyObject* self)
{
    QPictureIO* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPictureIO* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // write()
            bool cppResult = cppSelf->QPictureIO::write();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPictureIO_methods[] = {
    {"description", (PyCFunction)SbkQPictureIOFunc_description, METH_NOARGS},
    {"fileName", (PyCFunction)SbkQPictureIOFunc_fileName, METH_NOARGS},
    {"gamma", (PyCFunction)SbkQPictureIOFunc_gamma, METH_NOARGS},
    {"inputFormats", (PyCFunction)SbkQPictureIOFunc_inputFormats, METH_NOARGS|METH_STATIC},
    {"ioDevice", (PyCFunction)SbkQPictureIOFunc_ioDevice, METH_NOARGS},
    {"outputFormats", (PyCFunction)SbkQPictureIOFunc_outputFormats, METH_NOARGS|METH_STATIC},
    {"picture", (PyCFunction)SbkQPictureIOFunc_picture, METH_NOARGS},
    {"pictureFormat", (PyCFunction)SbkQPictureIOFunc_pictureFormat, METH_O|METH_STATIC},
    {"quality", (PyCFunction)SbkQPictureIOFunc_quality, METH_NOARGS},
    {"read", (PyCFunction)SbkQPictureIOFunc_read, METH_NOARGS},
    {"setDescription", (PyCFunction)SbkQPictureIOFunc_setDescription, METH_O},
    {"setFileName", (PyCFunction)SbkQPictureIOFunc_setFileName, METH_O},
    {"setGamma", (PyCFunction)SbkQPictureIOFunc_setGamma, METH_O},
    {"setIODevice", (PyCFunction)SbkQPictureIOFunc_setIODevice, METH_O},
    {"setPicture", (PyCFunction)SbkQPictureIOFunc_setPicture, METH_O},
    {"setQuality", (PyCFunction)SbkQPictureIOFunc_setQuality, METH_O},
    {"setStatus", (PyCFunction)SbkQPictureIOFunc_setStatus, METH_O},
    {"status", (PyCFunction)SbkQPictureIOFunc_status, METH_NOARGS},
    {"write", (PyCFunction)SbkQPictureIOFunc_write, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPictureIO_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPictureIO",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPictureIO_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPictureIO_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPictureIO >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPictureIO*",
    /*user_data*/           0
};
} //extern


void init_QPictureIO(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPICTUREIO_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPictureIO_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPictureIO_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPictureIO_Type));
    PyModule_AddObject(module, "QPictureIO",
        ((PyObject*)&SbkQPictureIO_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QPictureIO >("QPictureIO*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPictureIO >(typeid(QPictureIO).name());
    PySide::initQtMetaType<QPictureIO* >();
}

