/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qpinchgesture_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QPinchGestureWrapper::QPinchGestureWrapper(QObject * parent) : QPinchGesture(parent), m_metaObject(0) {
    // ... middle
}

void QPinchGestureWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QPinchGestureWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QPinchGestureWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QPinchGestureWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QPinchGestureWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPinchGesture.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QPinchGestureWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPinchGesture.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QPinchGestureWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QPinchGestureWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QPinchGesture::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QPinchGestureWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QPinchGesture::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QPinchGestureWrapper::~QPinchGestureWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPinchGesture_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPinchGesture >()))
        return -1;

    QPinchGestureWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QPinchGesture", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QPinchGesture(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QPinchGesture(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QPinchGesture(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGesture_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPinchGesture(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QPinchGesture(QObject*)
            cptr = new QPinchGestureWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPinchGesture >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPinchGesture_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQPinchGesture_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPinchGesture", overloads);
        return -1;
}

static PyObject* SbkQPinchGestureFunc_centerPoint(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // centerPoint()const
            QPointF cppResult = cppSelf->QPinchGesture::centerPoint();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_changeFlags(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // changeFlags()const
            QFlags<QPinchGesture::ChangeFlag> cppResult = cppSelf->QPinchGesture::changeFlags();
            pyResult = Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_lastCenterPoint(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastCenterPoint()const
            QPointF cppResult = cppSelf->QPinchGesture::lastCenterPoint();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_lastRotationAngle(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastRotationAngle()const
            qreal cppResult = cppSelf->QPinchGesture::lastRotationAngle();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_lastScaleFactor(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastScaleFactor()const
            qreal cppResult = cppSelf->QPinchGesture::lastScaleFactor();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_rotationAngle(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rotationAngle()const
            qreal cppResult = cppSelf->QPinchGesture::rotationAngle();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_scaleFactor(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scaleFactor()const
            qreal cppResult = cppSelf->QPinchGesture::scaleFactor();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_setCenterPoint(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCenterPoint(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setCenterPoint_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setCenterPoint(QPointF)
            cppSelf->QPinchGesture::setCenterPoint(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setCenterPoint", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setChangeFlags(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    if (Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::isConvertible(arg)) {
        overloadId = 0; // setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setChangeFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QPinchGesture::ChangeFlag> cpp_arg0 = Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
            cppSelf->QPinchGesture::setChangeFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setChangeFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPinchGesture.ChangeFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setChangeFlags", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setLastCenterPoint(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastCenterPoint(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setLastCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setLastCenterPoint_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setLastCenterPoint(QPointF)
            cppSelf->QPinchGesture::setLastCenterPoint(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setLastCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setLastCenterPoint", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setLastRotationAngle(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastRotationAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLastRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setLastRotationAngle_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLastRotationAngle(qreal)
            cppSelf->QPinchGesture::setLastRotationAngle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setLastRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setLastRotationAngle", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setLastScaleFactor(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastScaleFactor(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLastScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setLastScaleFactor_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLastScaleFactor(qreal)
            cppSelf->QPinchGesture::setLastScaleFactor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setLastScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setLastScaleFactor", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setRotationAngle(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRotationAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setRotationAngle_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRotationAngle(qreal)
            cppSelf->QPinchGesture::setRotationAngle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setRotationAngle", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setScaleFactor(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScaleFactor(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setScaleFactor_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScaleFactor(qreal)
            cppSelf->QPinchGesture::setScaleFactor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setScaleFactor", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setStartCenterPoint(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartCenterPoint(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // setStartCenterPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setStartCenterPoint_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setStartCenterPoint(QPointF)
            cppSelf->QPinchGesture::setStartCenterPoint(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setStartCenterPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setStartCenterPoint", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setTotalChangeFlags(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    if (Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::isConvertible(arg)) {
        overloadId = 0; // setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setTotalChangeFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QPinchGesture::ChangeFlag> cpp_arg0 = Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTotalChangeFlags(QFlags<QPinchGesture::ChangeFlag>)
            cppSelf->QPinchGesture::setTotalChangeFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setTotalChangeFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPinchGesture.ChangeFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setTotalChangeFlags", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setTotalRotationAngle(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalRotationAngle(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTotalRotationAngle(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setTotalRotationAngle_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTotalRotationAngle(qreal)
            cppSelf->QPinchGesture::setTotalRotationAngle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setTotalRotationAngle_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setTotalRotationAngle", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_setTotalScaleFactor(PyObject* self, PyObject* arg)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTotalScaleFactor(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTotalScaleFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPinchGestureFunc_setTotalScaleFactor_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTotalScaleFactor(qreal)
            cppSelf->QPinchGesture::setTotalScaleFactor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPinchGestureFunc_setTotalScaleFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPinchGesture.setTotalScaleFactor", overloads);
        return 0;
}

static PyObject* SbkQPinchGestureFunc_startCenterPoint(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startCenterPoint()const
            QPointF cppResult = cppSelf->QPinchGesture::startCenterPoint();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_totalChangeFlags(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // totalChangeFlags()const
            QFlags<QPinchGesture::ChangeFlag> cppResult = cppSelf->QPinchGesture::totalChangeFlags();
            pyResult = Shiboken::Converter<QFlags<QPinchGesture::ChangeFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_totalRotationAngle(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // totalRotationAngle()const
            qreal cppResult = cppSelf->QPinchGesture::totalRotationAngle();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPinchGestureFunc_totalScaleFactor(PyObject* self)
{
    QPinchGesture* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPinchGesture* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // totalScaleFactor()const
            qreal cppResult = cppSelf->QPinchGesture::totalScaleFactor();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPinchGesture_methods[] = {
    {"centerPoint", (PyCFunction)SbkQPinchGestureFunc_centerPoint, METH_NOARGS},
    {"changeFlags", (PyCFunction)SbkQPinchGestureFunc_changeFlags, METH_NOARGS},
    {"lastCenterPoint", (PyCFunction)SbkQPinchGestureFunc_lastCenterPoint, METH_NOARGS},
    {"lastRotationAngle", (PyCFunction)SbkQPinchGestureFunc_lastRotationAngle, METH_NOARGS},
    {"lastScaleFactor", (PyCFunction)SbkQPinchGestureFunc_lastScaleFactor, METH_NOARGS},
    {"rotationAngle", (PyCFunction)SbkQPinchGestureFunc_rotationAngle, METH_NOARGS},
    {"scaleFactor", (PyCFunction)SbkQPinchGestureFunc_scaleFactor, METH_NOARGS},
    {"setCenterPoint", (PyCFunction)SbkQPinchGestureFunc_setCenterPoint, METH_O},
    {"setChangeFlags", (PyCFunction)SbkQPinchGestureFunc_setChangeFlags, METH_O},
    {"setLastCenterPoint", (PyCFunction)SbkQPinchGestureFunc_setLastCenterPoint, METH_O},
    {"setLastRotationAngle", (PyCFunction)SbkQPinchGestureFunc_setLastRotationAngle, METH_O},
    {"setLastScaleFactor", (PyCFunction)SbkQPinchGestureFunc_setLastScaleFactor, METH_O},
    {"setRotationAngle", (PyCFunction)SbkQPinchGestureFunc_setRotationAngle, METH_O},
    {"setScaleFactor", (PyCFunction)SbkQPinchGestureFunc_setScaleFactor, METH_O},
    {"setStartCenterPoint", (PyCFunction)SbkQPinchGestureFunc_setStartCenterPoint, METH_O},
    {"setTotalChangeFlags", (PyCFunction)SbkQPinchGestureFunc_setTotalChangeFlags, METH_O},
    {"setTotalRotationAngle", (PyCFunction)SbkQPinchGestureFunc_setTotalRotationAngle, METH_O},
    {"setTotalScaleFactor", (PyCFunction)SbkQPinchGestureFunc_setTotalScaleFactor, METH_O},
    {"startCenterPoint", (PyCFunction)SbkQPinchGestureFunc_startCenterPoint, METH_NOARGS},
    {"totalChangeFlags", (PyCFunction)SbkQPinchGestureFunc_totalChangeFlags, METH_NOARGS},
    {"totalRotationAngle", (PyCFunction)SbkQPinchGestureFunc_totalRotationAngle, METH_NOARGS},
    {"totalScaleFactor", (PyCFunction)SbkQPinchGestureFunc_totalScaleFactor, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPinchGesture_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPinchGesture",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPinchGesture_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPinchGesture_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPinchGesture >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPinchGesture*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQPinchGesture_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QPinchGesture*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQPinchGesture_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPinchGesture::ChangeFlags >::checkType(self) && Shiboken::Converter<QPinchGesture::ChangeFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter<QPinchGesture::ChangeFlags>::toCpp(self)
        & Shiboken::Converter< QPinchGesture::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPinchGesture::ChangeFlags >::checkType(self) && Shiboken::Converter<QPinchGesture::ChangeFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter<QPinchGesture::ChangeFlags>::toCpp(self)
        | Shiboken::Converter< QPinchGesture::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPinchGesture::ChangeFlags >::checkType(self) && Shiboken::Converter<QPinchGesture::ChangeFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        Shiboken::Converter<QPinchGesture::ChangeFlags>::toCpp(self)
        ^ Shiboken::Converter< QPinchGesture::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPinchGesture::ChangeFlags >::toPython(
        ~Shiboken::Converter<QPinchGesture::ChangeFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QPinchGesture_ChangeFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QPinchGesture_ChangeFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QPinchGesture_ChangeFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ChangeFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QPinchGesture_ChangeFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QPinchGesture_ChangeFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QPinchGesture_ChangeFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QPinchGesture_ChangeFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ChangeFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QPinchGesture(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPinchGesture_Type);

    SbkQPinchGesture_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGESTURE_IDX];
    // Fill type discovery information
    SbkQPinchGesture_Type.type_discovery = &SbkQPinchGesture_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QGESTURE_IDX]), &SbkQPinchGesture_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPinchGesture_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPinchGesture_Type));
    PyModule_AddObject(module, "QPinchGesture",
        ((PyObject*)&SbkQPinchGesture_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ChangeFlag
    SbkPySide_QtGuiTypes[SBK_QPINCHGESTURE_CHANGEFLAG_IDX] = &SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type);
    PyDict_SetItemString(SbkQPinchGesture_Type.super.ht_type.tp_dict,
            "ChangeFlag",((PyObject*)&SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type));

    // init flags class: QFlags<QPinchGesture::ChangeFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QPINCHGESTURE_CHANGEFLAG__IDX] = &SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type);
    PyDict_SetItemString(SbkQPinchGesture_Type.super.ht_type.tp_dict,
            "ChangeFlags",((PyObject*)&SbkPySide_QtGui_QPinchGesture_ChangeFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type,
        (long) QPinchGesture::ScaleFactorChanged, "ScaleFactorChanged");
    PyDict_SetItemString(SbkQPinchGesture_Type.super.ht_type.tp_dict,
        "ScaleFactorChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type.tp_dict,
        "ScaleFactorChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type,
        (long) QPinchGesture::RotationAngleChanged, "RotationAngleChanged");
    PyDict_SetItemString(SbkQPinchGesture_Type.super.ht_type.tp_dict,
        "RotationAngleChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type.tp_dict,
        "RotationAngleChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type,
        (long) QPinchGesture::CenterPointChanged, "CenterPointChanged");
    PyDict_SetItemString(SbkQPinchGesture_Type.super.ht_type.tp_dict,
        "CenterPointChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPinchGesture_ChangeFlag_Type.tp_dict,
        "CenterPointChanged", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPinchGesture::ChangeFlag");


    Shiboken::TypeResolver::createObjectTypeResolver<QPinchGesture >("QPinchGesture*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPinchGesture >(typeid(QPinchGesture).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QPinchGesture >(typeid(QPinchGestureWrapper).name());
    PySide::initQtMetaType<QPinchGesture* >();
}

