/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpixmap_wrapper.h"

// Extra includes
#include <QVariant>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcolor.h>
#include <qdatastream.h>
#include <qimage.h>
#include <qimagereader.h>
#include <qimagewriter.h>
#include <qiodevice.h>
#include <qmatrix.h>
#include <qpaintengine.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qtransform.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QPixmapWrapper::QPixmapWrapper() : QPixmap() {
    // ... middle
}

QPixmapWrapper::QPixmapWrapper(const QSize & arg__1) : QPixmap(arg__1) {
    // ... middle
}

QPixmapWrapper::QPixmapWrapper(const QString & fileName, const char * format, QFlags<Qt::ImageConversionFlag> flags) : QPixmap(fileName, format, flags) {
    // ... middle
}

QPixmapWrapper::QPixmapWrapper(int w, int h) : QPixmap(w, h) {
    // ... middle
}

int QPixmapWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QPixmap::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPixmap.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QPixmapWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QPixmap::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPixmap.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QPixmapWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QPixmap::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPixmap.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QPixmap.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QPixmapWrapper::~QPixmapWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPixmap_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPixmap >()))
        return -1;

    QPixmapWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags", "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QPixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QPixmap()
    // 1: QPixmap(QVariant)
    // 2: QPixmap(QPixmap)
    // 3: QPixmap(QSize)
    // 4: QPixmap(QString,const char*,QFlags<Qt::ImageConversionFlag>)
    // 5: QPixmap(int,int)
    if (numArgs == 0) {
        overloadId = 0; // QPixmap()
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 5; // QPixmap(int,int)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // QPixmap(QString,const char*,QFlags<Qt::ImageConversionFlag>)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // QPixmap(QString,const char*,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[2])) {
                overloadId = 4; // QPixmap(QString,const char*,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QPixmap(QSize)
    } else if (numArgs == 1 && Shiboken::Converter<QVariant >::isConvertible(pyargs[0])) {
        overloadId = 1; // QPixmap(QVariant)
    } else if (numArgs == 1 && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QPixmap(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmap_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPixmap()
            {

                if(!PyErr_Occurred()) {
                // QPixmap()
                cptr = new QPixmapWrapper();
                }
                break;
            }
            case 1: // QPixmap(QVariant)
            {
                QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QPixmap(QVariant)
                // Begin code injection
                
                if (cpp_arg0.type() == QVariant::Pixmap)
                    cptr = new QPixmapWrapper(cpp_arg0.value<QPixmap>());
                else if (cpp_arg0.type() == QVariant::Image)
                    cptr = new QPixmapWrapper(QPixmap::fromImage(cpp_arg0.value<QImage>()));
                else
                    PyErr_SetString(PyExc_TypeError, "QVariant must be holding a QPixmap");
                
                // End of code injection

                }
                break;
            }
            case 2: // QPixmap(QPixmap)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
                QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPixmap(QPixmap)
                cptr = new QPixmapWrapper(*reinterpret_cast<QPixmapWrapper*>(cpp_arg0));
                }
                break;
            }
            case 3: // QPixmap(QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QPixmap(QSize)
                cptr = new QPixmapWrapper(*cpp_arg0);
                }
                break;
            }
            case 4: // QPixmap(QString,const char*,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                QFlags<Qt::ImageConversionFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[2]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // QPixmap(QString,const char*,QFlags<Qt::ImageConversionFlag>)
                cptr = new QPixmapWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 5: // QPixmap(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QPixmap(int,int)
                cptr = new QPixmapWrapper(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPixmap >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPixmap_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPixmap_Init_TypeError:
        const char* overloads[] = {"", "QVariant", "PySide.QtGui.QPixmap", "PySide.QtCore.QSize", "QString, str = None, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap", overloads);
        return -1;
}

static PyObject* SbkQPixmapFunc_alphaChannel(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alphaChannel()const
            QPixmap cppResult = cppSelf->QPixmap::alphaChannel();
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_cacheKey(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cacheKey()const
            qint64 cppResult = cppSelf->QPixmap::cacheKey();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_convertFromImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.convertFromImage(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.convertFromImage(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.convertFromImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:convertFromImage", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: convertFromImage(QImage,QFlags<Qt::ImageConversionFlag>)
    if (Shiboken::Converter<const QImage & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // convertFromImage(QImage,QFlags<Qt::ImageConversionFlag>)
        } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // convertFromImage(QImage,QFlags<Qt::ImageConversionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_convertFromImage_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.convertFromImage(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);
            QFlags<Qt::ImageConversionFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[1]) : Qt::AutoColor;

            if(!PyErr_Occurred()) {
            // convertFromImage(QImage,QFlags<Qt::ImageConversionFlag>)
            bool cppResult = cppSelf->QPixmap::convertFromImage(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_convertFromImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.convertFromImage", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_copy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.copy(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.copy(): too many arguments");
        return 0;
    } else if (numArgs == 2 || numArgs == 3)
        goto SbkQPixmapFunc_copy_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:copy", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: copy(QRect)const
    // 1: copy(int,int,int,int)const
    if (numArgs == 0) {
        overloadId = 0; // copy(QRect)const
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // copy(int,int,int,int)const
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // copy(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_copy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // copy(QRect)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.copy(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect cpp_arg0_tmp = QRect();
                QRect* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QRect* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;

                if(!PyErr_Occurred()) {
                // copy(QRect)const
                QPixmap cppResult = cppSelf->QPixmap::copy(*cpp_arg0);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 1: // copy(int,int,int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // copy(int,int,int,int)const
                QPixmap cppResult = cppSelf->QPixmap::copy(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_copy_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect = QRect()", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.copy", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_createHeuristicMask(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "clipTight" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.createHeuristicMask(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.createHeuristicMask(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createHeuristicMask", &arg))
        return 0;


    // Overloaded function decisor
    // 0: createHeuristicMask(bool)const
    if (numArgs == 0) {
        overloadId = 0; // createHeuristicMask(bool)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // createHeuristicMask(bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_createHeuristicMask_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "clipTight");
                if (value) {
                    if (arg)
                        errorArgName = "clipTight";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.createHeuristicMask(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cpp_arg0 = arg ? Shiboken::Converter<bool >::toCpp(arg) : true;

            if(!PyErr_Occurred()) {
            // createHeuristicMask(bool)const
            QBitmap cppResult = cppSelf->QPixmap::createHeuristicMask(cpp_arg0);
            pyResult = Shiboken::Converter<QBitmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_createHeuristicMask_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.createHeuristicMask", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_createMaskFromColor(PyObject* self, PyObject* args)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createMaskFromColor", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createMaskFromColor(QColor)const
    // 1: createMaskFromColor(QColor,Qt::MaskMode)const
    if (Shiboken::Converter<const QColor & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createMaskFromColor(QColor)const
        } else if (numArgs == 2 && Shiboken::Converter<Qt::MaskMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // createMaskFromColor(QColor,Qt::MaskMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_createMaskFromColor_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // createMaskFromColor(QColor)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // createMaskFromColor(QColor)const
                QBitmap cppResult = cppSelf->QPixmap::createMaskFromColor(*cpp_arg0);
                pyResult = Shiboken::Converter<QBitmap >::toPython(cppResult);
                }
                break;
            }
            case 1: // createMaskFromColor(QColor,Qt::MaskMode)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);
                Qt::MaskMode cpp_arg1 = Shiboken::Converter<Qt::MaskMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // createMaskFromColor(QColor,Qt::MaskMode)const
                QBitmap cppResult = cppSelf->QPixmap::createMaskFromColor(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QBitmap >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_createMaskFromColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", "PySide.QtGui.QColor, PySide.QtCore.Qt.MaskMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.createMaskFromColor", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_defaultDepth(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultDepth()
            int cppResult = QPixmap::defaultDepth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_depth(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // depth()const
            int cppResult = cppSelf->QPixmap::depth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_devType(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // devType()const
            int cppResult = cppSelf->QPixmap::devType();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_fill(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fillColor" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fill(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.fill(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:fill", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: fill(QColor)
    // 1: fill(const QWidget*,QPoint)
    // 2: fill(const QWidget*,int,int)
    if (numArgs == 0) {
        overloadId = 0; // fill(QColor)
    } else if (Shiboken::Converter<const QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 2; // fill(const QWidget*,int,int)
        } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
            overloadId = 1; // fill(const QWidget*,QPoint)
        }
    } else if (Shiboken::Converter<const QColor & >::isConvertible(pyargs[0])) {
        overloadId = 0; // fill(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_fill_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fill(QColor)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fillColor");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "fillColor";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fill(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor cpp_arg0_tmp = Qt::white;
                QColor* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QColor* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
                if (pyargs[0] && !Shiboken::Converter<QColor >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // fill(QColor)
                cppSelf->QPixmap::fill(*cpp_arg0);
                }
                break;
            }
            case 1: // fill(const QWidget*,QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fill(const QWidget*,QPoint)
                cppSelf->QPixmap::fill(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // fill(const QWidget*,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // fill(const QWidget*,int,int)
                cppSelf->QPixmap::fill(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPixmapFunc_fill_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor = Qt.white", "PySide.QtGui.QWidget, PySide.QtCore.QPoint", "PySide.QtGui.QWidget, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.fill", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_fromImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImage(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImage(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromImage", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromImage(QImage,QFlags<Qt::ImageConversionFlag>)
    if (Shiboken::Converter<const QImage & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromImage(QImage,QFlags<Qt::ImageConversionFlag>)
        } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromImage(QImage,QFlags<Qt::ImageConversionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_fromImage_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImage(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);
            QFlags<Qt::ImageConversionFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[1]) : Qt::AutoColor;

            if(!PyErr_Occurred()) {
            // fromImage(QImage,QFlags<Qt::ImageConversionFlag>)
            QPixmap cppResult = QPixmap::fromImage(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_fromImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.fromImage", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_fromImageReader(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImageReader(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImageReader(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImageReader(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromImageReader", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromImageReader(QImageReader*,QFlags<Qt::ImageConversionFlag>)
    if (Shiboken::Converter<QImageReader * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromImageReader(QImageReader*,QFlags<Qt::ImageConversionFlag>)
        } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromImageReader(QImageReader*,QFlags<Qt::ImageConversionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_fromImageReader_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fromImageReader(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QImageReader* cpp_arg0 = Shiboken::Converter<QImageReader* >::toCpp(pyargs[0]);
            QFlags<Qt::ImageConversionFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[1]) : Qt::AutoColor;

            if(!PyErr_Occurred()) {
            // fromImageReader(QImageReader*,QFlags<Qt::ImageConversionFlag>)
            QPixmap cppResult = QPixmap::fromImageReader(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_fromImageReader_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImageReader, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.fromImageReader", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_fromX11Pixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fromX11Pixmap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.fromX11Pixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.fromX11Pixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromX11Pixmap", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromX11Pixmap(Qt::HANDLE,QPixmap::ShareMode)
    if (PyLong_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromX11Pixmap(Qt::HANDLE,QPixmap::ShareMode)
        } else if (Shiboken::Converter<QPixmap::ShareMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromX11Pixmap(Qt::HANDLE,QPixmap::ShareMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_fromX11Pixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.fromX11Pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::HANDLE cpp_arg0 = Shiboken::Converter<Qt::HANDLE >::toCpp(pyargs[0]);
            QPixmap::ShareMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QPixmap::ShareMode >::toCpp(pyargs[1]) : QPixmap::ImplicitlyShared;

            if(!PyErr_Occurred()) {
            // fromX11Pixmap(Qt::HANDLE,QPixmap::ShareMode)
            QPixmap cppResult = QPixmap::fromX11Pixmap(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_fromX11Pixmap_TypeError:
        const char* overloads[] = {"Qt::HANDLE, PySide.QtGui.QPixmap.ShareMode = ImplicitlyShared", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.fromX11Pixmap", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_grabWidget(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "h", "w", "x", "y" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWidget(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWidget(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWidget(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:grabWidget", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: grabWidget(QWidget*,QRect)
    // 1: grabWidget(QWidget*,int,int,int,int)
    if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // grabWidget(QWidget*,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // grabWidget(QWidget*,int,int,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // grabWidget(QWidget*,int,int,int,int)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 1; // grabWidget(QWidget*,int,int,int,int)
                    } else if (SbkNumber_Check(pyargs[4])) {
                        overloadId = 1; // grabWidget(QWidget*,int,int,int,int)
                    }
                }
            }
        } else if (numArgs == 2 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[1])) {
            overloadId = 0; // grabWidget(QWidget*,QRect)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_grabWidget_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // grabWidget(QWidget*,QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QRect* cpp_arg1 = Shiboken::Converter<QRect* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // grabWidget(QWidget*,QRect)
                QPixmap cppResult = QPixmap::grabWidget(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 1: // grabWidget(QWidget*,int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "x");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "x";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "y");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "y";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "w");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "w";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "h");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "h";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWidget(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : -1;
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : -1;

                if(!PyErr_Occurred()) {
                // grabWidget(QWidget*,int,int,int,int)
                QPixmap cppResult = QPixmap::grabWidget(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_grabWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.QRect", "PySide.QtGui.QWidget, int = 0, int = 0, int = -1, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.grabWidget", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_grabWindow(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "h", "w", "x", "y" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWindow(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWindow(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWindow(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:grabWindow", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: grabWindow(ulong,int,int,int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // grabWindow(ulong,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // grabWindow(ulong,int,int,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // grabWindow(ulong,int,int,int,int)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // grabWindow(ulong,int,int,int,int)
                    } else if (SbkNumber_Check(pyargs[4])) {
                        overloadId = 0; // grabWindow(ulong,int,int,int,int)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_grabWindow_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "x");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "x";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "y");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "y";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "w");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "w";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "h");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "h";
                    else
                        pyargs[4] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.grabWindow(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;
            int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : -1;
            int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : -1;

            if(!PyErr_Occurred()) {
            // grabWindow(ulong,int,int,int,int)
            QPixmap cppResult = QPixmap::grabWindow(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_grabWindow_TypeError:
        const char* overloads[] = {"unsigned long, int = 0, int = 0, int = -1, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.grabWindow", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_handle(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // handle()const
            Qt::HANDLE cppResult = cppSelf->QPixmap::handle();
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_hasAlpha(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasAlpha()const
            bool cppResult = cppSelf->QPixmap::hasAlpha();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_hasAlphaChannel(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasAlphaChannel()const
            bool cppResult = cppSelf->QPixmap::hasAlphaChannel();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_height(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            int cppResult = cppSelf->QPixmap::height();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_isNull(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QPixmap::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_isQBitmap(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isQBitmap()const
            bool cppResult = cppSelf->QPixmap::isQBitmap();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_load(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags", "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.load(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.load(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.load(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:load", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: load(QString,const char*,QFlags<Qt::ImageConversionFlag>)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // load(QString,const char*,QFlags<Qt::ImageConversionFlag>)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // load(QString,const char*,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[2])) {
                overloadId = 0; // load(QString,const char*,QFlags<Qt::ImageConversionFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_load_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "flags";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.load(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
            QFlags<Qt::ImageConversionFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[2]) : Qt::AutoColor;

            if(!PyErr_Occurred()) {
            // load(QString,const char*,QFlags<Qt::ImageConversionFlag>)
            bool cppResult = cppSelf->QPixmap::load(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_load_TypeError:
        const char* overloads[] = {"QString, str = None, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.load", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_loadFromData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags", "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.loadFromData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.loadFromData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.loadFromData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:loadFromData", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: loadFromData(QByteArray,const char*,QFlags<Qt::ImageConversionFlag>)
    // 1: loadFromData(const uchar*,uint,const char*,QFlags<Qt::ImageConversionFlag>)
    if (Shiboken::Converter<const char * >::checkType(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // loadFromData(const uchar*,uint,const char*,QFlags<Qt::ImageConversionFlag>)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // loadFromData(const uchar*,uint,const char*,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // loadFromData(const uchar*,uint,const char*,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // loadFromData(QByteArray,const char*,QFlags<Qt::ImageConversionFlag>)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // loadFromData(QByteArray,const char*,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[2])) {
                overloadId = 0; // loadFromData(QByteArray,const char*,QFlags<Qt::ImageConversionFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_loadFromData_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // loadFromData(QByteArray,const char*,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.loadFromData(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                QFlags<Qt::ImageConversionFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[2]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // loadFromData(QByteArray,const char*,QFlags<Qt::ImageConversionFlag>)
                bool cppResult = cppSelf->QPixmap::loadFromData(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // loadFromData(const uchar*,uint,const char*,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.loadFromData(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                QFlags<Qt::ImageConversionFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[2]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // loadFromData(const uchar*,uint,const char*,QFlags<Qt::ImageConversionFlag>)
                // Begin code injection
                
                const uchar* buf_out = reinterpret_cast<const uchar*>(PyString_AS_STRING(pyargs[1-1]));
                
                // End of code injection
                // Begin code injection
                
                uint len_out = static_cast<uint>(PyString_GET_SIZE(pyargs[1-1]));
                
                // End of code injection
                bool cppResult = cppSelf->QPixmap::loadFromData(buf_out, len_out, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_loadFromData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, str = None, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "uchar, unsigned int, str = None, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.loadFromData", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_mask(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mask()const
            QBitmap cppResult = cppSelf->QPixmap::mask();
            pyResult = Shiboken::Converter<QBitmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_metric(PyObject* self, PyObject* arg)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cpp_arg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = cppSelf->QPixmap::metric(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.metric", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_paintEngine(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // paintEngine()const
            QPaintEngine * cppResult = cppSelf->QPixmap::paintEngine();
            pyResult = Shiboken::Converter<QPaintEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_rect(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rect()const
            QRect cppResult = cppSelf->QPixmap::rect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_save(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format", "quality" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.save(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.save(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.save(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:save", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: save(QIODevice*,const char*,int)const
    // 1: save(QString,const char*,int)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // save(QString,const char*,int)const
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // save(QString,const char*,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // save(QString,const char*,int)const
            }
        }
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // save(QIODevice*,const char*,int)const
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // save(QIODevice*,const char*,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // save(QIODevice*,const char*,int)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_save_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // save(QIODevice*,const char*,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "quality");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "quality";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.save(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

                if(!PyErr_Occurred()) {
                // save(QIODevice*,const char*,int)const
                bool cppResult = cppSelf->QPixmap::save(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // save(QString,const char*,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "quality");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "quality";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.save(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cpp_arg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

                if(!PyErr_Occurred()) {
                // save(QString,const char*,int)const
                bool cppResult = cppSelf->QPixmap::save(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_save_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, str = None, int = -1", "QString, str = None, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.save", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_scaled(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "aspectMode", "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scaled(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scaled(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scaled(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:scaled", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
    // 1: scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[3])) {
                overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            }
        }
    } else if (Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_scaled_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aspectMode";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scaled(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
                Qt::AspectRatioMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]) : Qt::IgnoreAspectRatio;
                Qt::TransformationMode cpp_arg2 = pyargs[2] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[2]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
                QPixmap cppResult = cppSelf->QPixmap::scaled(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 1: // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectMode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "aspectMode";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scaled(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                Qt::AspectRatioMode cpp_arg2 = pyargs[2] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[2]) : Qt::IgnoreAspectRatio;
                Qt::TransformationMode cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[3]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
                QPixmap cppResult = cppSelf->QPixmap::scaled(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_scaled_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", "int, int, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.scaled", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_scaledToHeight(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToHeight(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToHeight(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToHeight(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scaledToHeight", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scaledToHeight(int,Qt::TransformationMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaledToHeight(int,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // scaledToHeight(int,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_scaledToHeight_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToHeight(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

            if(!PyErr_Occurred()) {
            // scaledToHeight(int,Qt::TransformationMode)const
            QPixmap cppResult = cppSelf->QPixmap::scaledToHeight(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_scaledToHeight_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.scaledToHeight", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_scaledToWidth(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToWidth(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToWidth(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToWidth(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scaledToWidth", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scaledToWidth(int,Qt::TransformationMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaledToWidth(int,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // scaledToWidth(int,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_scaledToWidth_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scaledToWidth(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

            if(!PyErr_Occurred()) {
            // scaledToWidth(int,Qt::TransformationMode)const
            QPixmap cppResult = cppSelf->QPixmap::scaledToWidth(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_scaledToWidth_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.scaledToWidth", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_scroll(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "exposed" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scroll(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scroll(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.scroll(): not enough arguments");
        return 0;
    } else if (numArgs == 5)
        goto SbkQPixmapFunc_scroll_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOO:scroll", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: scroll(int,int,QRect,QRegion*)
    // 1: scroll(int,int,int,int,int,int,QRegion*)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs >= 6 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
            if (numArgs == 6) {
                overloadId = 1; // scroll(int,int,int,int,int,int,QRegion*)
            } else if (Shiboken::Converter<QRegion * >::isConvertible(pyargs[6])) {
                overloadId = 1; // scroll(int,int,int,int,int,int,QRegion*)
            }
        } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // scroll(int,int,QRect,QRegion*)
            } else if (Shiboken::Converter<QRegion * >::isConvertible(pyargs[3])) {
                overloadId = 0; // scroll(int,int,QRect,QRegion*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_scroll_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scroll(int,int,QRect,QRegion*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "exposed");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "exposed";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scroll(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QRect* cpp_arg2 = Shiboken::Converter<QRect* >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg3_auto_ptr;
                QRegion* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QRegion* >::toCpp(pyargs[3]) : 0;
                if (pyargs[3] && !Shiboken::Converter<QRegion >::checkType(pyargs[3]))
                    cpp_arg3_auto_ptr = std::auto_ptr<QRegion >(cpp_arg3);

                if(!PyErr_Occurred()) {
                // scroll(int,int,QRect,QRegion*)
                cppSelf->QPixmap::scroll(cpp_arg0, cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 1: // scroll(int,int,int,int,int,int,QRegion*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "exposed");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "exposed";
                        else
                            pyargs[6] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.scroll(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cpp_arg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg6_auto_ptr;
                QRegion* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QRegion* >::toCpp(pyargs[6]) : 0;
                if (pyargs[6] && !Shiboken::Converter<QRegion >::checkType(pyargs[6]))
                    cpp_arg6_auto_ptr = std::auto_ptr<QRegion >(cpp_arg6);

                if(!PyErr_Occurred()) {
                // scroll(int,int,int,int,int,int,QRegion*)
                cppSelf->QPixmap::scroll(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPixmapFunc_scroll_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QRect, PySide.QtGui.QRegion = None", "int, int, int, int, int, int, PySide.QtGui.QRegion = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.scroll", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_setAlphaChannel(PyObject* self, PyObject* arg)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlphaChannel(QPixmap)
    if (Shiboken::Converter<const QPixmap & >::isConvertible(arg)) {
        overloadId = 0; // setAlphaChannel(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_setAlphaChannel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
            QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(arg);
            if (!Shiboken::Converter<QPixmap >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setAlphaChannel(QPixmap)
            cppSelf->QPixmap::setAlphaChannel(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPixmapFunc_setAlphaChannel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.setAlphaChannel", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_setMask(PyObject* self, PyObject* arg)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMask(QBitmap)
    if (Shiboken::Converter<const QBitmap & >::isConvertible(arg)) {
        overloadId = 0; // setMask(QBitmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_setMask_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBitmap > cpp_arg0_auto_ptr;
            QBitmap* cpp_arg0 = Shiboken::Converter<QBitmap* >::toCpp(arg);
            if (!Shiboken::Converter<QBitmap >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBitmap >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setMask(QBitmap)
            cppSelf->QPixmap::setMask(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPixmapFunc_setMask_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBitmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.setMask", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_size(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSize cppResult = cppSelf->QPixmap::size();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_toImage(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toImage()const
            QImage cppResult = cppSelf->QPixmap::toImage();
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_transformed(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.transformed(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.transformed(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPixmap.transformed(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:transformed", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: transformed(QMatrix,Qt::TransformationMode)const
    // 1: transformed(QTransform,Qt::TransformationMode)const
    if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // transformed(QTransform,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // transformed(QTransform,Qt::TransformationMode)const
        }
    } else if (Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // transformed(QMatrix,Qt::TransformationMode)const
        } else if (Shiboken::Converter<Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // transformed(QMatrix,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_transformed_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // transformed(QMatrix,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.transformed(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);
                Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // transformed(QMatrix,Qt::TransformationMode)const
                QPixmap cppResult = cppSelf->QPixmap::transformed(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 1: // transformed(QTransform,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPixmap.transformed(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
                Qt::TransformationMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                // transformed(QTransform,Qt::TransformationMode)const
                QPixmap cppResult = cppSelf->QPixmap::transformed(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_transformed_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", "PySide.QtGui.QTransform, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.transformed", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_trueMatrix(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "trueMatrix", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: trueMatrix(QMatrix,int,int)
    // 1: trueMatrix(QTransform,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // trueMatrix(QTransform,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // trueMatrix(QMatrix,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_trueMatrix_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // trueMatrix(QMatrix,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // trueMatrix(QMatrix,int,int)
                QMatrix cppResult = QPixmap::trueMatrix(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
                }
                break;
            }
            case 1: // trueMatrix(QTransform,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // trueMatrix(QTransform,int,int)
                QTransform cppResult = QPixmap::trueMatrix(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_trueMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, int, int", "PySide.QtGui.QTransform, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmap.trueMatrix", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_width(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            int cppResult = cppSelf->QPixmap::width();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_x11Info(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x11Info()const
            const QX11Info & cppResult = cppSelf->QPixmap::x11Info();
            pyResult = Shiboken::Converter<const QX11Info & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_x11PictureHandle(PyObject* self)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x11PictureHandle()const
            Qt::HANDLE cppResult = cppSelf->QPixmap::x11PictureHandle();
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPixmapFunc_x11SetDefaultScreen(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: x11SetDefaultScreen(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // x11SetDefaultScreen(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_x11SetDefaultScreen_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // x11SetDefaultScreen(int)
            int cppResult = QPixmap::x11SetDefaultScreen(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc_x11SetDefaultScreen_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.x11SetDefaultScreen", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc_x11SetScreen(PyObject* self, PyObject* arg)
{
    QPixmap* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: x11SetScreen(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // x11SetScreen(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc_x11SetScreen_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // x11SetScreen(int)
            cppSelf->QPixmap::x11SetScreen(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPixmapFunc_x11SetScreen_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.x11SetScreen", overloads);
        return 0;
}

static PyMethodDef SbkQPixmap_methods[] = {
    {"alphaChannel", (PyCFunction)SbkQPixmapFunc_alphaChannel, METH_NOARGS},
    {"cacheKey", (PyCFunction)SbkQPixmapFunc_cacheKey, METH_NOARGS},
    {"convertFromImage", (PyCFunction)SbkQPixmapFunc_convertFromImage, METH_VARARGS|METH_KEYWORDS},
    {"copy", (PyCFunction)SbkQPixmapFunc_copy, METH_VARARGS|METH_KEYWORDS},
    {"createHeuristicMask", (PyCFunction)SbkQPixmapFunc_createHeuristicMask, METH_VARARGS|METH_KEYWORDS},
    {"createMaskFromColor", (PyCFunction)SbkQPixmapFunc_createMaskFromColor, METH_VARARGS},
    {"defaultDepth", (PyCFunction)SbkQPixmapFunc_defaultDepth, METH_NOARGS|METH_STATIC},
    {"depth", (PyCFunction)SbkQPixmapFunc_depth, METH_NOARGS},
    {"devType", (PyCFunction)SbkQPixmapFunc_devType, METH_NOARGS},
    {"fill", (PyCFunction)SbkQPixmapFunc_fill, METH_VARARGS|METH_KEYWORDS},
    {"fromImage", (PyCFunction)SbkQPixmapFunc_fromImage, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromImageReader", (PyCFunction)SbkQPixmapFunc_fromImageReader, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromX11Pixmap", (PyCFunction)SbkQPixmapFunc_fromX11Pixmap, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"grabWidget", (PyCFunction)SbkQPixmapFunc_grabWidget, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"grabWindow", (PyCFunction)SbkQPixmapFunc_grabWindow, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"handle", (PyCFunction)SbkQPixmapFunc_handle, METH_NOARGS},
    {"hasAlpha", (PyCFunction)SbkQPixmapFunc_hasAlpha, METH_NOARGS},
    {"hasAlphaChannel", (PyCFunction)SbkQPixmapFunc_hasAlphaChannel, METH_NOARGS},
    {"height", (PyCFunction)SbkQPixmapFunc_height, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQPixmapFunc_isNull, METH_NOARGS},
    {"isQBitmap", (PyCFunction)SbkQPixmapFunc_isQBitmap, METH_NOARGS},
    {"load", (PyCFunction)SbkQPixmapFunc_load, METH_VARARGS|METH_KEYWORDS},
    {"loadFromData", (PyCFunction)SbkQPixmapFunc_loadFromData, METH_VARARGS|METH_KEYWORDS},
    {"mask", (PyCFunction)SbkQPixmapFunc_mask, METH_NOARGS},
    {"metric", (PyCFunction)SbkQPixmapFunc_metric, METH_O},
    {"paintEngine", (PyCFunction)SbkQPixmapFunc_paintEngine, METH_NOARGS},
    {"rect", (PyCFunction)SbkQPixmapFunc_rect, METH_NOARGS},
    {"save", (PyCFunction)SbkQPixmapFunc_save, METH_VARARGS|METH_KEYWORDS},
    {"scaled", (PyCFunction)SbkQPixmapFunc_scaled, METH_VARARGS|METH_KEYWORDS},
    {"scaledToHeight", (PyCFunction)SbkQPixmapFunc_scaledToHeight, METH_VARARGS|METH_KEYWORDS},
    {"scaledToWidth", (PyCFunction)SbkQPixmapFunc_scaledToWidth, METH_VARARGS|METH_KEYWORDS},
    {"scroll", (PyCFunction)SbkQPixmapFunc_scroll, METH_VARARGS|METH_KEYWORDS},
    {"setAlphaChannel", (PyCFunction)SbkQPixmapFunc_setAlphaChannel, METH_O},
    {"setMask", (PyCFunction)SbkQPixmapFunc_setMask, METH_O},
    {"size", (PyCFunction)SbkQPixmapFunc_size, METH_NOARGS},
    {"toImage", (PyCFunction)SbkQPixmapFunc_toImage, METH_NOARGS},
    {"transformed", (PyCFunction)SbkQPixmapFunc_transformed, METH_VARARGS|METH_KEYWORDS},
    {"trueMatrix", (PyCFunction)SbkQPixmapFunc_trueMatrix, METH_VARARGS|METH_STATIC},
    {"width", (PyCFunction)SbkQPixmapFunc_width, METH_NOARGS},
    {"x11Info", (PyCFunction)SbkQPixmapFunc_x11Info, METH_NOARGS},
    {"x11PictureHandle", (PyCFunction)SbkQPixmapFunc_x11PictureHandle, METH_NOARGS},
    {"x11SetDefaultScreen", (PyCFunction)SbkQPixmapFunc_x11SetDefaultScreen, METH_O|METH_STATIC},
    {"x11SetScreen", (PyCFunction)SbkQPixmapFunc_x11SetScreen, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQPixmapFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPixmap* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPixmap >::checkType(arg) && !Shiboken::Converter<QPixmap >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPixmap)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QPixmap) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQPixmapFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPixmap* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPixmap >::checkType(arg) && !Shiboken::Converter<QPixmap >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPixmap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPixmap&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPixmap&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPixmapFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QPixmap&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPixmapFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmap.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQPixmap_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQPixmapFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQPixmapFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

static void* SbkQPixmap_ObjCopierFunc(const void* ptr){
    return new QPixmapWrapper(*reinterpret_cast<const QPixmap*>(ptr));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPixmap_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPixmap",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQPixmap_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPixmap_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPixmap_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          &SbkQPixmap_ObjCopierFunc,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPixmap >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPixmap",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQPixmap_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QPixmap*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQPixmap_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QPixmap_ShareMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QPixmap_ShareMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QPixmap_ShareMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ShareMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QPixmap_ShareMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QPixmap_ShareMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QPixmap_ShareMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QPixmap(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPIXMAP_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPixmap_Type);

    SbkQPixmap_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    // Fill type discovery information
    SbkQPixmap_Type.type_discovery = &SbkQPixmap_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &SbkQPixmap_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPixmap_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPixmap_Type));
    PyModule_AddObject(module, "QPixmap",
        ((PyObject*)&SbkQPixmap_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ShareMode
    SbkPySide_QtGuiTypes[SBK_QPIXMAP_SHAREMODE_IDX] = &SbkPySide_QtGui_QPixmap_ShareMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPixmap_ShareMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPixmap_ShareMode_Type);
    PyDict_SetItemString(SbkQPixmap_Type.super.ht_type.tp_dict,
            "ShareMode",((PyObject*)&SbkPySide_QtGui_QPixmap_ShareMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPixmap_ShareMode_Type,
        (long) QPixmap::ImplicitlyShared, "ImplicitlyShared");
    PyDict_SetItemString(SbkQPixmap_Type.super.ht_type.tp_dict,
        "ImplicitlyShared", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPixmap_ShareMode_Type.tp_dict,
        "ImplicitlyShared", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPixmap_ShareMode_Type,
        (long) QPixmap::ExplicitlyShared, "ExplicitlyShared");
    PyDict_SetItemString(SbkQPixmap_Type.super.ht_type.tp_dict,
        "ExplicitlyShared", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPixmap_ShareMode_Type.tp_dict,
        "ExplicitlyShared", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPixmap::ShareMode");


    Shiboken::TypeResolver::createValueTypeResolver<QPixmap >("QPixmap");
    Shiboken::TypeResolver::createObjectTypeResolver<QPixmap >("QPixmap*");
    Shiboken::TypeResolver::createValueTypeResolver<QPixmap >(typeid(QPixmap).name());
    Shiboken::TypeResolver::createValueTypeResolver<QPixmap >(typeid(QPixmapWrapper).name());
    PySide::initQtMetaType<QPixmap >();
}

