/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpolygon_wrapper.h"

// Extra includes
#include <QList>
#include <QMatrix>
#include <QTransform>
#include <QVector>
#include <qdatastream.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPolygon_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPolygon >()))
        return -1;

    QPolygon* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "closed" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QPolygon", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QPolygon()
    // 1: QPolygon(QPolygon)
    // 2: QPolygon(QRect,bool)
    // 3: QPolygon(QVector<QPoint>)
    // 4: QPolygon(int)
    if (numArgs == 0) {
        overloadId = 0; // QPolygon()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 4; // QPolygon(int)
    } else if (numArgs == 1 && Shiboken::Converter< QVector<QPoint >  >::isConvertible(pyargs[0])) {
        overloadId = 3; // QPolygon(QVector<QPoint>)
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QPolygon(QRect,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // QPolygon(QRect,bool)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygon & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QPolygon(QPolygon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygon_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPolygon()
            {

                if(!PyErr_Occurred()) {
                // QPolygon()
                cptr = new QPolygon();
                }
                break;
            }
            case 1: // QPolygon(QPolygon)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygon >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPolygon(QPolygon)
                cptr = new QPolygon(*cpp_arg0);
                }
                break;
            }
            case 2: // QPolygon(QRect,bool)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "closed");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "closed";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

                if(!PyErr_Occurred()) {
                // QPolygon(QRect,bool)
                cptr = new QPolygon(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QPolygon(QVector<QPoint>)
            {
                QVector<QPoint > cpp_arg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QPolygon(QVector<QPoint>)
                cptr = new QPolygon(cpp_arg0);
                }
                break;
            }
            case 4: // QPolygon(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QPolygon(int)
                cptr = new QPolygon(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPolygon >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPolygon_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPolygon_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPolygon", "PySide.QtCore.QRect, bool = false", "list", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon", overloads);
        return -1;
}

static PyObject* SbkQPolygonFunc_append(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // append(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_append_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // append(QPoint)
            cppSelf->QPolygon::append(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.append", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_at(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_at_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // at(int)const
            const QPoint & cppResult = cppSelf->QPolygon::at(cpp_arg0);
            pyResult = Shiboken::Converter<const QPoint & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.at", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_boundingRect(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect()const
            QRect cppResult = cppSelf->QPolygon::boundingRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFunc_capacity(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // capacity()const
            int cppResult = cppSelf->QPolygon::capacity();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFunc_clear(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QPolygon::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFunc_contains(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // contains(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_contains_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contains(QPoint)const
            bool cppResult = cppSelf->QPolygon::contains(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.contains", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_containsPoint(PyObject* self, PyObject* args)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "containsPoint", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: containsPoint(QPoint,Qt::FillRule)const
    if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::FillRule >::isConvertible(pyargs[1])) {
        overloadId = 0; // containsPoint(QPoint,Qt::FillRule)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_containsPoint_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
            Qt::FillRule cpp_arg1 = Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // containsPoint(QPoint,Qt::FillRule)const
            bool cppResult = cppSelf->QPolygon::containsPoint(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_containsPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtCore.Qt.FillRule", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.containsPoint", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_count(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: count()const
    // 1: count(QPoint)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 1; // count(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                // count()const
                int cppResult = cppSelf->QPolygon::count();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // count(QPoint)const
                int cppResult = cppSelf->QPolygon::count(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_count_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.count", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_empty(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // empty()const
            bool cppResult = cppSelf->QPolygon::empty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFunc_endsWith(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // endsWith(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_endsWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // endsWith(QPoint)const
            bool cppResult = cppSelf->QPolygon::endsWith(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_endsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.endsWith", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_fill(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "size" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.fill(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.fill(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.fill(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fill", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fill(QPoint,int)
    if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fill(QPoint,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // fill(QPoint,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_fill_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "size";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.fill(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // fill(QPoint,int)
            QVector<QPoint > & cppResult = cppSelf->QPolygon::fill(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVector<QPoint >  >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_fill_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.fill", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_fromList(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromList(QList<QPoint>)
    if (Shiboken::Converter< QList<QPoint >  >::isConvertible(arg)) {
        overloadId = 0; // fromList(QList<QPoint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_fromList_TypeError;

    // Call function/method
    {
        {
            QList<QPoint > cpp_arg0 = Shiboken::Converter<QList<QPoint > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromList(QList<QPoint>)
            QVector<QPoint > cppResult = QPolygon::fromList(cpp_arg0);
            pyResult = Shiboken::Converter<QVector<QPoint > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_fromList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.fromList", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.indexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QPoint,int)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QPoint,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(QPoint,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // indexOf(QPoint,int)const
            int cppResult = cppSelf->QPolygon::indexOf(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.indexOf", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_intersected(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QPolygon)const
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 0; // intersected(QPolygon)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
            QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
            if (!Shiboken::Converter<QPolygon >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // intersected(QPolygon)const
            QPolygon cppResult = cppSelf->QPolygon::intersected(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.intersected", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_isEmpty(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QPolygon::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFunc_isSharedWith(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSharedWith(QVector<QPoint>)const
    if (Shiboken::Converter< QVector<QPoint >  >::isConvertible(arg)) {
        overloadId = 0; // isSharedWith(QVector<QPoint>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_isSharedWith_TypeError;

    // Call function/method
    {
        {
            QVector<QPoint > cpp_arg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isSharedWith(QVector<QPoint>)const
            bool cppResult = cppSelf->QPolygon::isSharedWith(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_isSharedWith_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.isSharedWith", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.lastIndexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QPoint,int)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QPoint,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(QPoint,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // lastIndexOf(QPoint,int)const
            int cppResult = cppSelf->QPolygon::lastIndexOf(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.lastIndexOf", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_mid(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "length" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.mid(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.mid(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.mid(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mid", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mid(int,int)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mid(int,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // mid(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_mid_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "length");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "length";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.mid(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // mid(int,int)const
            QVector<QPoint > cppResult = cppSelf->QPolygon::mid(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVector<QPoint > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_mid_TypeError:
        const char* overloads[] = {"int, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.mid", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_pop_back(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pop_back()
            cppSelf->QPolygon::pop_back();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFunc_pop_front(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pop_front()
            cppSelf->QPolygon::pop_front();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFunc_prepend(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // prepend(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_prepend_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // prepend(QPoint)
            cppSelf->QPolygon::prepend(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.prepend", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_push_back(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_back(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // push_back(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_push_back_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // push_back(QPoint)
            cppSelf->QPolygon::push_back(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_push_back_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.push_back", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_push_front(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_front(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // push_front(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_push_front_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // push_front(QPoint)
            cppSelf->QPolygon::push_front(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_push_front_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.push_front", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_remove(PyObject* self, PyObject* args)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "remove", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: remove(int)
    // 1: remove(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // remove(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // remove(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_remove_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // remove(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // remove(int)
                cppSelf->QPolygon::remove(cpp_arg0);
                }
                break;
            }
            case 1: // remove(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // remove(int,int)
                cppSelf->QPolygon::remove(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_remove_TypeError:
        const char* overloads[] = {"int", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.remove", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_replace(PyObject* self, PyObject* args)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QPoint)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(int,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_replace_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // replace(int,QPoint)
            cppSelf->QPolygon::replace(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.replace", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_reserve(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reserve(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // reserve(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_reserve_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // reserve(int)
            cppSelf->QPolygon::reserve(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_reserve_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.reserve", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_resize(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_resize_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resize(int)
            cppSelf->QPolygon::resize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.resize", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_setSharable(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSharable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSharable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_setSharable_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSharable(bool)
            cppSelf->QPolygon::setSharable(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_setSharable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.setSharable", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_size(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            int cppResult = cppSelf->QPolygon::size();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFunc_squeeze(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // squeeze()
            cppSelf->QPolygon::squeeze();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFunc_startsWith(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // startsWith(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_startsWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // startsWith(QPoint)const
            bool cppResult = cppSelf->QPolygon::startsWith(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_startsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.startsWith", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_subtracted(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtracted(QPolygon)const
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 0; // subtracted(QPolygon)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_subtracted_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
            QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
            if (!Shiboken::Converter<QPolygon >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // subtracted(QPolygon)const
            QPolygon cppResult = cppSelf->QPolygon::subtracted(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_subtracted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.subtracted", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_toList(PyObject* self)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toList()const
            QList<QPoint > cppResult = cppSelf->QPolygon::toList();
            pyResult = Shiboken::Converter<QList<QPoint > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFunc_translate(PyObject* self, PyObject* args)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPoint)
    // 1: translate(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // translate(QPoint)
                cppSelf->QPolygon::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(int,int)
                cppSelf->QPolygon::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.translate", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_translated(PyObject* self, PyObject* args)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPoint)const
    // 1: translated(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // translated(QPoint)const
                QPolygon cppResult = cppSelf->QPolygon::translated(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translated(int,int)const
                QPolygon cppResult = cppSelf->QPolygon::translated(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.translated", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_united(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QPolygon)const
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 0; // united(QPolygon)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_united_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
            QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
            if (!Shiboken::Converter<QPolygon >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // united(QPolygon)const
            QPolygon cppResult = cppSelf->QPolygon::united(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.united", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc_value(PyObject* self, PyObject* args)
{
    QPolygon* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(int)const
    // 1: value(int,QPoint)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // value(int)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
            overloadId = 1; // value(int,QPoint)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // value(int)const
                QPoint cppResult = cppSelf->QPolygon::value(cpp_arg0);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(int,QPoint)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // value(int,QPoint)const
                QPoint cppResult = cppSelf->QPolygon::value(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc_value_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.value", overloads);
        return 0;
}

static PyMethodDef SbkQPolygon_methods[] = {
    {"append", (PyCFunction)SbkQPolygonFunc_append, METH_O},
    {"at", (PyCFunction)SbkQPolygonFunc_at, METH_O},
    {"boundingRect", (PyCFunction)SbkQPolygonFunc_boundingRect, METH_NOARGS},
    {"capacity", (PyCFunction)SbkQPolygonFunc_capacity, METH_NOARGS},
    {"clear", (PyCFunction)SbkQPolygonFunc_clear, METH_NOARGS},
    {"contains", (PyCFunction)SbkQPolygonFunc_contains, METH_O},
    {"containsPoint", (PyCFunction)SbkQPolygonFunc_containsPoint, METH_VARARGS},
    {"count", (PyCFunction)SbkQPolygonFunc_count, METH_NOARGS|METH_O},
    {"empty", (PyCFunction)SbkQPolygonFunc_empty, METH_NOARGS},
    {"endsWith", (PyCFunction)SbkQPolygonFunc_endsWith, METH_O},
    {"fill", (PyCFunction)SbkQPolygonFunc_fill, METH_VARARGS|METH_KEYWORDS},
    {"fromList", (PyCFunction)SbkQPolygonFunc_fromList, METH_O|METH_STATIC},
    {"indexOf", (PyCFunction)SbkQPolygonFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"intersected", (PyCFunction)SbkQPolygonFunc_intersected, METH_O},
    {"isEmpty", (PyCFunction)SbkQPolygonFunc_isEmpty, METH_NOARGS},
    {"isSharedWith", (PyCFunction)SbkQPolygonFunc_isSharedWith, METH_O},
    {"lastIndexOf", (PyCFunction)SbkQPolygonFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"mid", (PyCFunction)SbkQPolygonFunc_mid, METH_VARARGS|METH_KEYWORDS},
    {"pop_back", (PyCFunction)SbkQPolygonFunc_pop_back, METH_NOARGS},
    {"pop_front", (PyCFunction)SbkQPolygonFunc_pop_front, METH_NOARGS},
    {"prepend", (PyCFunction)SbkQPolygonFunc_prepend, METH_O},
    {"push_back", (PyCFunction)SbkQPolygonFunc_push_back, METH_O},
    {"push_front", (PyCFunction)SbkQPolygonFunc_push_front, METH_O},
    {"remove", (PyCFunction)SbkQPolygonFunc_remove, METH_VARARGS},
    {"replace", (PyCFunction)SbkQPolygonFunc_replace, METH_VARARGS},
    {"reserve", (PyCFunction)SbkQPolygonFunc_reserve, METH_O},
    {"resize", (PyCFunction)SbkQPolygonFunc_resize, METH_O},
    {"setSharable", (PyCFunction)SbkQPolygonFunc_setSharable, METH_O},
    {"size", (PyCFunction)SbkQPolygonFunc_size, METH_NOARGS},
    {"squeeze", (PyCFunction)SbkQPolygonFunc_squeeze, METH_NOARGS},
    {"startsWith", (PyCFunction)SbkQPolygonFunc_startsWith, METH_O},
    {"subtracted", (PyCFunction)SbkQPolygonFunc_subtracted, METH_O},
    {"toList", (PyCFunction)SbkQPolygonFunc_toList, METH_NOARGS},
    {"translate", (PyCFunction)SbkQPolygonFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)SbkQPolygonFunc_translated, METH_VARARGS},
    {"united", (PyCFunction)SbkQPolygonFunc_united, METH_O},
    {"value", (PyCFunction)SbkQPolygonFunc_value, METH_VARARGS},
    {0} // Sentinel
};

static PyObject* SbkQPolygonFunc___mul__(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPolygon >::checkType(arg) && !Shiboken::Converter<QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QPolygon,QMatrix)
    // 1: operator*(QPolygon,QTransform)
    if (!isReverse && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 1; // operator*(QPolygon,QTransform)
    } else if (!isReverse && Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QPolygon,QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QPolygon,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPolygon,QMatrix)
                QPolygon cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QPolygon,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPolygon,QTransform)
                QPolygon cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.__mul__", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPolygon >::checkType(arg) && !Shiboken::Converter<QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPolygon)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPolygon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QPolygon) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQPolygonFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPolygon* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPolygon >::checkType(arg) && !Shiboken::Converter<QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPolygon&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPolygon&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QPolygon&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygon.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQPolygon_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)SbkQPolygonFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQPolygonFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQPolygonFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQPolygon_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QPolygon& cpp_self = *Shiboken::Converter<QPolygon* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< QVector<QPoint >  >::isConvertible(other)) {
                // operator!=(const QVector<QPoint > & v) const
                const QVector<QPoint > & cpp_other = Shiboken::Converter< QVector<QPoint >  >::toCpp(other);
                result = (cpp_self != cpp_other);
            } else goto SbkQPolygon_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< QVector<QPoint >  >::isConvertible(other)) {
                // operator==(const QVector<QPoint > & v) const
                const QVector<QPoint > & cpp_other = Shiboken::Converter< QVector<QPoint >  >::toCpp(other);
                result = (cpp_self == cpp_other);
            } else goto SbkQPolygon_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQPolygon_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPolygon_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPolygon",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQPolygon_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQPolygon_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPolygon_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPolygon_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPolygon >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPolygon",
    /*user_data*/           0
};
} //extern


void init_QPolygon(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPOLYGON_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPolygon_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPolygon_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPolygon_Type));
    PyModule_AddObject(module, "QPolygon",
        ((PyObject*)&SbkQPolygon_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QPolygon >("QPolygon");
    Shiboken::TypeResolver::createObjectTypeResolver<QPolygon >("QPolygon*");
    Shiboken::TypeResolver::createValueTypeResolver<QPolygon >(typeid(QPolygon).name());
    PySide::initQtMetaType<QPolygon >();
}

