/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpolygonf_wrapper.h"

// Extra includes
#include <QList>
#include <QMatrix>
#include <QTransform>
#include <QVector>
#include <qdatastream.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPolygonF_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPolygonF >()))
        return -1;

    QPolygonF* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPolygonF", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QPolygonF()
    // 1: QPolygonF(QPolygon)
    // 2: QPolygonF(QPolygonF)
    // 3: QPolygonF(QRectF)
    // 4: QPolygonF(QVector<QPointF>)
    // 5: QPolygonF(int)
    if (numArgs == 0) {
        overloadId = 0; // QPolygonF()
    } else if (numArgs == 1 && SbkNumber_Check(arg)) {
        overloadId = 5; // QPolygonF(int)
    } else if (numArgs == 1 && Shiboken::Converter< QVector<QPointF >  >::isConvertible(arg)) {
        overloadId = 4; // QPolygonF(QVector<QPointF>)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 3; // QPolygonF(QRectF)
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 1; // QPolygonF(QPolygon)
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 2; // QPolygonF(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonF_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPolygonF()
            {

                if(!PyErr_Occurred()) {
                // QPolygonF()
                cptr = new QPolygonF();
                }
                break;
            }
            case 1: // QPolygonF(QPolygon)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygon >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPolygonF(QPolygon)
                cptr = new QPolygonF(*cpp_arg0);
                }
                break;
            }
            case 2: // QPolygonF(QPolygonF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPolygonF(QPolygonF)
                cptr = new QPolygonF(*cpp_arg0);
                }
                break;
            }
            case 3: // QPolygonF(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPolygonF(QRectF)
                cptr = new QPolygonF(*cpp_arg0);
                }
                break;
            }
            case 4: // QPolygonF(QVector<QPointF>)
            {
                QVector<QPointF > cpp_arg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QPolygonF(QVector<QPointF>)
                cptr = new QPolygonF(cpp_arg0);
                }
                break;
            }
            case 5: // QPolygonF(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QPolygonF(int)
                cptr = new QPolygonF(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPolygonF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPolygonF_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPolygonF_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "list", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF", overloads);
        return -1;
}

static PyObject* SbkQPolygonFFunc_append(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // append(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_append_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // append(QPointF)
            cppSelf->QPolygonF::append(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.append", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_at(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_at_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // at(int)const
            const QPointF & cppResult = cppSelf->QPolygonF::at(cpp_arg0);
            pyResult = Shiboken::Converter<const QPointF & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.at", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_boundingRect(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect()const
            QRectF cppResult = cppSelf->QPolygonF::boundingRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_capacity(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // capacity()const
            int cppResult = cppSelf->QPolygonF::capacity();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_clear(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QPolygonF::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFFunc_contains(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPointF)const
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // contains(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_contains_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // contains(QPointF)const
            bool cppResult = cppSelf->QPolygonF::contains(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.contains", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_containsPoint(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "containsPoint", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: containsPoint(QPointF,Qt::FillRule)const
    if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::FillRule >::isConvertible(pyargs[1])) {
        overloadId = 0; // containsPoint(QPointF,Qt::FillRule)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_containsPoint_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
            Qt::FillRule cpp_arg1 = Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // containsPoint(QPointF,Qt::FillRule)const
            bool cppResult = cppSelf->QPolygonF::containsPoint(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_containsPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.Qt.FillRule", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.containsPoint", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_count(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: count()const
    // 1: count(QPointF)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 1; // count(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                // count()const
                int cppResult = cppSelf->QPolygonF::count();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
                if (!Shiboken::Converter<QPointF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // count(QPointF)const
                int cppResult = cppSelf->QPolygonF::count(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_count_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.count", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_empty(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // empty()const
            bool cppResult = cppSelf->QPolygonF::empty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_endsWith(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(QPointF)const
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // endsWith(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_endsWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // endsWith(QPointF)const
            bool cppResult = cppSelf->QPolygonF::endsWith(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_endsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.endsWith", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_fill(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "size" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.fill(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.fill(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.fill(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fill", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fill(QPointF,int)
    if (Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fill(QPointF,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // fill(QPointF,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_fill_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "size";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.fill(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // fill(QPointF,int)
            QVector<QPointF > & cppResult = cppSelf->QPolygonF::fill(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVector<QPointF >  >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_fill_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.fill", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_fromList(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromList(QList<QPointF>)
    if (Shiboken::Converter< QList<QPointF >  >::isConvertible(arg)) {
        overloadId = 0; // fromList(QList<QPointF>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_fromList_TypeError;

    // Call function/method
    {
        {
            QList<QPointF > cpp_arg0 = Shiboken::Converter<QList<QPointF > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fromList(QList<QPointF>)
            QVector<QPointF > cppResult = QPolygonF::fromList(cpp_arg0);
            pyResult = Shiboken::Converter<QVector<QPointF > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_fromList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.fromList", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.indexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QPointF,int)const
    if (Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QPointF,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(QPointF,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // indexOf(QPointF,int)const
            int cppResult = cppSelf->QPolygonF::indexOf(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.indexOf", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_intersected(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QPolygonF)const
    if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 0; // intersected(QPolygonF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
            if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // intersected(QPolygonF)const
            QPolygonF cppResult = cppSelf->QPolygonF::intersected(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.intersected", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_isClosed(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isClosed()const
            bool cppResult = cppSelf->QPolygonF::isClosed();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_isEmpty(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QPolygonF::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_isSharedWith(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSharedWith(QVector<QPointF>)const
    if (Shiboken::Converter< QVector<QPointF >  >::isConvertible(arg)) {
        overloadId = 0; // isSharedWith(QVector<QPointF>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_isSharedWith_TypeError;

    // Call function/method
    {
        {
            QVector<QPointF > cpp_arg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isSharedWith(QVector<QPointF>)const
            bool cppResult = cppSelf->QPolygonF::isSharedWith(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_isSharedWith_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.isSharedWith", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.lastIndexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QPointF,int)const
    if (Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QPointF,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(QPointF,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // lastIndexOf(QPointF,int)const
            int cppResult = cppSelf->QPolygonF::lastIndexOf(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.lastIndexOf", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_mid(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "length" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.mid(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.mid(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.mid(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mid", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mid(int,int)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mid(int,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // mid(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_mid_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "length");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "length";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.mid(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // mid(int,int)const
            QVector<QPointF > cppResult = cppSelf->QPolygonF::mid(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVector<QPointF > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_mid_TypeError:
        const char* overloads[] = {"int, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.mid", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_pop_back(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pop_back()
            cppSelf->QPolygonF::pop_back();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFFunc_pop_front(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pop_front()
            cppSelf->QPolygonF::pop_front();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFFunc_prepend(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // prepend(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_prepend_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // prepend(QPointF)
            cppSelf->QPolygonF::prepend(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.prepend", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_push_back(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_back(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // push_back(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_push_back_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // push_back(QPointF)
            cppSelf->QPolygonF::push_back(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_push_back_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.push_back", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_push_front(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_front(QPointF)
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // push_front(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_push_front_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // push_front(QPointF)
            cppSelf->QPolygonF::push_front(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_push_front_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.push_front", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_remove(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "remove", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: remove(int)
    // 1: remove(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // remove(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // remove(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_remove_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // remove(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // remove(int)
                cppSelf->QPolygonF::remove(cpp_arg0);
                }
                break;
            }
            case 1: // remove(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // remove(int,int)
                cppSelf->QPolygonF::remove(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_remove_TypeError:
        const char* overloads[] = {"int", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.remove", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_replace(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QPointF)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(int,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_replace_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
            QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // replace(int,QPointF)
            cppSelf->QPolygonF::replace(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.replace", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_reserve(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reserve(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // reserve(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_reserve_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // reserve(int)
            cppSelf->QPolygonF::reserve(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_reserve_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.reserve", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_resize(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_resize_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resize(int)
            cppSelf->QPolygonF::resize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.resize", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_setSharable(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSharable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSharable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_setSharable_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSharable(bool)
            cppSelf->QPolygonF::setSharable(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_setSharable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.setSharable", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_size(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            int cppResult = cppSelf->QPolygonF::size();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_squeeze(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // squeeze()
            cppSelf->QPolygonF::squeeze();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPolygonFFunc_startsWith(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(QPointF)const
    if (Shiboken::Converter<const QPointF & >::isConvertible(arg)) {
        overloadId = 0; // startsWith(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_startsWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
            QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(arg);
            if (!Shiboken::Converter<QPointF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // startsWith(QPointF)const
            bool cppResult = cppSelf->QPolygonF::startsWith(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_startsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.startsWith", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_subtracted(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtracted(QPolygonF)const
    if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 0; // subtracted(QPolygonF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_subtracted_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
            if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // subtracted(QPolygonF)const
            QPolygonF cppResult = cppSelf->QPolygonF::subtracted(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_subtracted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.subtracted", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_toList(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toList()const
            QList<QPointF > cppResult = cppSelf->QPolygonF::toList();
            pyResult = Shiboken::Converter<QList<QPointF > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_toPolygon(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPolygon()const
            QPolygon cppResult = cppSelf->QPolygonF::toPolygon();
            pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPolygonFFunc_translate(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPointF)
    // 1: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translate(QPointF)
                cppSelf->QPolygonF::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                cppSelf->QPolygonF::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPolygonFFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.translate", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_translated(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPointF)const
    // 1: translated(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translated(QPointF)const
                QPolygonF cppResult = cppSelf->QPolygonF::translated(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translated(qreal,qreal)const
                QPolygonF cppResult = cppSelf->QPolygonF::translated(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.translated", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_united(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QPolygonF)const
    if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 0; // united(QPolygonF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_united_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
            if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // united(QPolygonF)const
            QPolygonF cppResult = cppSelf->QPolygonF::united(*cpp_arg0);
            pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.united", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc_value(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(int)const
    // 1: value(int,QPointF)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // value(int)const
        } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
            overloadId = 1; // value(int,QPointF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // value(int)const
                QPointF cppResult = cppSelf->QPolygonF::value(cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(int,QPointF)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // value(int,QPointF)const
                QPointF cppResult = cppSelf->QPolygonF::value(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc_value_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.value", overloads);
        return 0;
}

static PyMethodDef SbkQPolygonF_methods[] = {
    {"append", (PyCFunction)SbkQPolygonFFunc_append, METH_O},
    {"at", (PyCFunction)SbkQPolygonFFunc_at, METH_O},
    {"boundingRect", (PyCFunction)SbkQPolygonFFunc_boundingRect, METH_NOARGS},
    {"capacity", (PyCFunction)SbkQPolygonFFunc_capacity, METH_NOARGS},
    {"clear", (PyCFunction)SbkQPolygonFFunc_clear, METH_NOARGS},
    {"contains", (PyCFunction)SbkQPolygonFFunc_contains, METH_O},
    {"containsPoint", (PyCFunction)SbkQPolygonFFunc_containsPoint, METH_VARARGS},
    {"count", (PyCFunction)SbkQPolygonFFunc_count, METH_NOARGS|METH_O},
    {"empty", (PyCFunction)SbkQPolygonFFunc_empty, METH_NOARGS},
    {"endsWith", (PyCFunction)SbkQPolygonFFunc_endsWith, METH_O},
    {"fill", (PyCFunction)SbkQPolygonFFunc_fill, METH_VARARGS|METH_KEYWORDS},
    {"fromList", (PyCFunction)SbkQPolygonFFunc_fromList, METH_O|METH_STATIC},
    {"indexOf", (PyCFunction)SbkQPolygonFFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"intersected", (PyCFunction)SbkQPolygonFFunc_intersected, METH_O},
    {"isClosed", (PyCFunction)SbkQPolygonFFunc_isClosed, METH_NOARGS},
    {"isEmpty", (PyCFunction)SbkQPolygonFFunc_isEmpty, METH_NOARGS},
    {"isSharedWith", (PyCFunction)SbkQPolygonFFunc_isSharedWith, METH_O},
    {"lastIndexOf", (PyCFunction)SbkQPolygonFFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"mid", (PyCFunction)SbkQPolygonFFunc_mid, METH_VARARGS|METH_KEYWORDS},
    {"pop_back", (PyCFunction)SbkQPolygonFFunc_pop_back, METH_NOARGS},
    {"pop_front", (PyCFunction)SbkQPolygonFFunc_pop_front, METH_NOARGS},
    {"prepend", (PyCFunction)SbkQPolygonFFunc_prepend, METH_O},
    {"push_back", (PyCFunction)SbkQPolygonFFunc_push_back, METH_O},
    {"push_front", (PyCFunction)SbkQPolygonFFunc_push_front, METH_O},
    {"remove", (PyCFunction)SbkQPolygonFFunc_remove, METH_VARARGS},
    {"replace", (PyCFunction)SbkQPolygonFFunc_replace, METH_VARARGS},
    {"reserve", (PyCFunction)SbkQPolygonFFunc_reserve, METH_O},
    {"resize", (PyCFunction)SbkQPolygonFFunc_resize, METH_O},
    {"setSharable", (PyCFunction)SbkQPolygonFFunc_setSharable, METH_O},
    {"size", (PyCFunction)SbkQPolygonFFunc_size, METH_NOARGS},
    {"squeeze", (PyCFunction)SbkQPolygonFFunc_squeeze, METH_NOARGS},
    {"startsWith", (PyCFunction)SbkQPolygonFFunc_startsWith, METH_O},
    {"subtracted", (PyCFunction)SbkQPolygonFFunc_subtracted, METH_O},
    {"toList", (PyCFunction)SbkQPolygonFFunc_toList, METH_NOARGS},
    {"toPolygon", (PyCFunction)SbkQPolygonFFunc_toPolygon, METH_NOARGS},
    {"translate", (PyCFunction)SbkQPolygonFFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)SbkQPolygonFFunc_translated, METH_VARARGS},
    {"united", (PyCFunction)SbkQPolygonFFunc_united, METH_O},
    {"value", (PyCFunction)SbkQPolygonFFunc_value, METH_VARARGS},
    {0} // Sentinel
};

static PyObject* SbkQPolygonFFunc___mul__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPolygonF >::checkType(arg) && !Shiboken::Converter<QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QPolygonF,QMatrix)
    // 1: operator*(QPolygonF,QTransform)
    if (!isReverse && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 1; // operator*(QPolygonF,QTransform)
    } else if (!isReverse && Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QPolygonF,QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QPolygonF,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPolygonF,QMatrix)
                QPolygonF cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QPolygonF,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QPolygonF,QTransform)
                QPolygonF cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__mul__", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPolygonF >::checkType(arg) && !Shiboken::Converter<QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPolygonF)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QPolygonF) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQPolygonFFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QPolygonF >::checkType(arg) && !Shiboken::Converter<QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPolygonF&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPolygonF&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPolygonFFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QPolygonF&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPolygonFFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQPolygonF_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)SbkQPolygonFFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQPolygonFFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQPolygonFFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQPolygonF_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QPolygonF& cpp_self = *Shiboken::Converter<QPolygonF* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< QVector<QPointF >  >::isConvertible(other)) {
                // operator!=(const QVector<QPointF > & v) const
                const QVector<QPointF > & cpp_other = Shiboken::Converter< QVector<QPointF >  >::toCpp(other);
                result = (cpp_self != cpp_other);
            } else goto SbkQPolygonF_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< QVector<QPointF >  >::isConvertible(other)) {
                // operator==(const QVector<QPointF > & v) const
                const QVector<QPointF > & cpp_other = Shiboken::Converter< QVector<QPointF >  >::toCpp(other);
                result = (cpp_self == cpp_other);
            } else goto SbkQPolygonF_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQPolygonF_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPolygonF_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPolygonF",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQPolygonF_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQPolygonF_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPolygonF_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPolygonF_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPolygonF >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPolygonF",
    /*user_data*/           0
};
} //extern


void init_QPolygonF(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPOLYGONF_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPolygonF_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPolygonF_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPolygonF_Type));
    PyModule_AddObject(module, "QPolygonF",
        ((PyObject*)&SbkQPolygonF_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QPolygonF >("QPolygonF");
    Shiboken::TypeResolver::createObjectTypeResolver<QPolygonF >("QPolygonF*");
    Shiboken::TypeResolver::createValueTypeResolver<QPolygonF >(typeid(QPolygonF).name());
    PySide::initQtMetaType<QPolygonF >();
}

