/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qprinterinfo_wrapper.h"

// Extra includes
#include <QList>
#include <qprinter.h>
#include <qprinterinfo.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPrinterInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPrinterInfo >()))
        return -1;

    QPrinterInfo* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPrinterInfo", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QPrinterInfo()
    // 1: QPrinterInfo(QPrinter)
    // 2: QPrinterInfo(QPrinterInfo)
    if (numArgs == 0) {
        overloadId = 0; // QPrinterInfo()
    } else if (numArgs == 1 && Shiboken::Converter< QPrinter & >::isConvertible(arg)) {
        overloadId = 1; // QPrinterInfo(QPrinter)
    } else if (numArgs == 1 && Shiboken::Converter<const QPrinterInfo & >::isConvertible(arg)) {
        overloadId = 2; // QPrinterInfo(QPrinterInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPrinterInfo_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPrinterInfo()
            {

                if(!PyErr_Occurred()) {
                // QPrinterInfo()
                cptr = new QPrinterInfo();
                }
                break;
            }
            case 1: // QPrinterInfo(QPrinter)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QPrinter* cpp_arg0 = Shiboken::Converter<QPrinter* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QPrinterInfo(QPrinter)
                cptr = new QPrinterInfo(*cpp_arg0);
                }
                break;
            }
            case 2: // QPrinterInfo(QPrinterInfo)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QPrinterInfo > cpp_arg0_auto_ptr;
                QPrinterInfo* cpp_arg0 = Shiboken::Converter<QPrinterInfo* >::toCpp(arg);
                if (!Shiboken::Converter<QPrinterInfo >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPrinterInfo >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QPrinterInfo(QPrinterInfo)
                cptr = new QPrinterInfo(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPrinterInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPrinterInfo_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPrinterInfo_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPrinter", "PySide.QtGui.QPrinterInfo", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrinterInfo", overloads);
        return -1;
}

static PyObject* SbkQPrinterInfoFunc_availablePrinters(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // availablePrinters()
            QList<QPrinterInfo > cppResult = QPrinterInfo::availablePrinters();
            pyResult = Shiboken::Converter<QList<QPrinterInfo > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPrinterInfoFunc_defaultPrinter(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultPrinter()
            QPrinterInfo cppResult = QPrinterInfo::defaultPrinter();
            pyResult = Shiboken::Converter<QPrinterInfo >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPrinterInfoFunc_isDefault(PyObject* self)
{
    QPrinterInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPrinterInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDefault()const
            bool cppResult = cppSelf->QPrinterInfo::isDefault();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPrinterInfoFunc_isNull(PyObject* self)
{
    QPrinterInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPrinterInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QPrinterInfo::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPrinterInfoFunc_printerName(PyObject* self)
{
    QPrinterInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPrinterInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // printerName()const
            QString cppResult = cppSelf->QPrinterInfo::printerName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPrinterInfoFunc_supportedPaperSizes(PyObject* self)
{
    QPrinterInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPrinterInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedPaperSizes()const
            QList<QPrinter::PageSize > cppResult = cppSelf->QPrinterInfo::supportedPaperSizes();
            pyResult = Shiboken::Converter<QList<QPrinter::PageSize > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPrinterInfo_methods[] = {
    {"availablePrinters", (PyCFunction)SbkQPrinterInfoFunc_availablePrinters, METH_NOARGS|METH_STATIC},
    {"defaultPrinter", (PyCFunction)SbkQPrinterInfoFunc_defaultPrinter, METH_NOARGS|METH_STATIC},
    {"isDefault", (PyCFunction)SbkQPrinterInfoFunc_isDefault, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQPrinterInfoFunc_isNull, METH_NOARGS},
    {"printerName", (PyCFunction)SbkQPrinterInfoFunc_printerName, METH_NOARGS},
    {"supportedPaperSizes", (PyCFunction)SbkQPrinterInfoFunc_supportedPaperSizes, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPrinterInfo_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPrinterInfo",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPrinterInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPrinterInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPrinterInfo >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPrinterInfo",
    /*user_data*/           0
};
} //extern


void init_QPrinterInfo(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPRINTERINFO_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPrinterInfo_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPrinterInfo_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPrinterInfo_Type));
    PyModule_AddObject(module, "QPrinterInfo",
        ((PyObject*)&SbkQPrinterInfo_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QPrinterInfo >("QPrinterInfo");
    Shiboken::TypeResolver::createObjectTypeResolver<QPrinterInfo >("QPrinterInfo*");
    Shiboken::TypeResolver::createValueTypeResolver<QPrinterInfo >(typeid(QPrinterInfo).name());
    PySide::initQtMetaType<QPrinterInfo >();
}

