/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qquaternion_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qquaternion.h>
#include <qvector3d.h>
#include <qvector4d.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQQuaternion_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QQuaternion >()))
        return -1;

    QQuaternion* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQQuaternion_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QQuaternion", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QQuaternion(QQuaternion)
    // 1: QQuaternion()
    // 2: QQuaternion(QVector4D)
    // 3: QQuaternion(qreal,QVector3D)
    // 4: QQuaternion(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 1; // QQuaternion()
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 4 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 4; // QQuaternion(qreal,qreal,qreal,qreal)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[1])) {
            overloadId = 3; // QQuaternion(qreal,QVector3D)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QQuaternion(QVector4D)
    } else if (numArgs == 1 && Shiboken::Converter<const QQuaternion & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QQuaternion(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternion_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QQuaternion(QQuaternion)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QQuaternion(QQuaternion)
                cptr = new QQuaternion(*cpp_arg0);
                }
                break;
            }
            case 1: // QQuaternion()
            {

                if(!PyErr_Occurred()) {
                // QQuaternion()
                cptr = new QQuaternion();
                }
                break;
            }
            case 2: // QQuaternion(QVector4D)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QVector4D > cpp_arg0_auto_ptr;
                QVector4D* cpp_arg0 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QQuaternion(QVector4D)
                cptr = new QQuaternion(*cpp_arg0);
                }
                break;
            }
            case 3: // QQuaternion(qreal,QVector3D)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // QQuaternion(qreal,QVector3D)
                cptr = new QQuaternion(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // QQuaternion(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // QQuaternion(qreal,qreal,qreal,qreal)
                cptr = new QQuaternion(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QQuaternion >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQQuaternion_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQQuaternion_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", "", "PySide.QtGui.QVector4D", "float, PySide.QtGui.QVector3D", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion", overloads);
        return -1;
}

static PyObject* SbkQQuaternionFunc_conjugate(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // conjugate()const
            QQuaternion cppResult = cppSelf->QQuaternion::conjugate();
            pyResult = Shiboken::Converter<QQuaternion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_fromAxisAndAngle(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQQuaternionFunc_fromAxisAndAngle_TypeError;

    if (!PyArg_UnpackTuple(args, "fromAxisAndAngle", 2, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromAxisAndAngle(QVector3D,qreal)
    // 1: fromAxisAndAngle(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // fromAxisAndAngle(qreal,qreal,qreal,qreal)
    } else if (numArgs == 2 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // fromAxisAndAngle(QVector3D,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_fromAxisAndAngle_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromAxisAndAngle(QVector3D,qreal)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
                QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fromAxisAndAngle(QVector3D,qreal)
                QQuaternion cppResult = QQuaternion::fromAxisAndAngle(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QQuaternion >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromAxisAndAngle(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // fromAxisAndAngle(qreal,qreal,qreal,qreal)
                QQuaternion cppResult = QQuaternion::fromAxisAndAngle(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QQuaternion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc_fromAxisAndAngle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.fromAxisAndAngle", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_isIdentity(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isIdentity()const
            bool cppResult = cppSelf->QQuaternion::isIdentity();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_isNull(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QQuaternion::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_length(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            qreal cppResult = cppSelf->QQuaternion::length();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_lengthSquared(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lengthSquared()const
            qreal cppResult = cppSelf->QQuaternion::lengthSquared();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_nlerp(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "nlerp", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: nlerp(QQuaternion,QQuaternion,qreal)
    if (numArgs == 3 && Shiboken::Converter<const QQuaternion & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QQuaternion & >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // nlerp(QQuaternion,QQuaternion,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_nlerp_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QQuaternion* cpp_arg1 = Shiboken::Converter<QQuaternion* >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // nlerp(QQuaternion,QQuaternion,qreal)
            QQuaternion cppResult = QQuaternion::nlerp(*cpp_arg0, *cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QQuaternion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc_nlerp_TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion, PySide.QtGui.QQuaternion, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.nlerp", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_normalize(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalize()
            cppSelf->QQuaternion::normalize();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQQuaternionFunc_normalized(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalized()const
            QQuaternion cppResult = cppSelf->QQuaternion::normalized();
            pyResult = Shiboken::Converter<QQuaternion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_rotatedVector(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotatedVector(QVector3D)const
    if (Shiboken::Converter<const QVector3D & >::isConvertible(arg)) {
        overloadId = 0; // rotatedVector(QVector3D)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_rotatedVector_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
            QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(arg);
            if (!Shiboken::Converter<QVector3D >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // rotatedVector(QVector3D)const
            QVector3D cppResult = cppSelf->QQuaternion::rotatedVector(*cpp_arg0);
            pyResult = Shiboken::Converter<QVector3D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc_rotatedVector_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.rotatedVector", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_scalar(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scalar()const
            qreal cppResult = cppSelf->QQuaternion::scalar();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_setScalar(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScalar(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setScalar(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_setScalar_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScalar(qreal)
            cppSelf->QQuaternion::setScalar(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQQuaternionFunc_setScalar_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setScalar", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_setVector(PyObject* self, PyObject* args)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQQuaternionFunc_setVector_TypeError;

    if (!PyArg_UnpackTuple(args, "setVector", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setVector(QVector3D)
    // 1: setVector(qreal,qreal,qreal)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // setVector(qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setVector(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_setVector_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setVector(QVector3D)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
                QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setVector(QVector3D)
                cppSelf->QQuaternion::setVector(*cpp_arg0);
                }
                break;
            }
            case 1: // setVector(qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setVector(qreal,qreal,qreal)
                cppSelf->QQuaternion::setVector(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQQuaternionFunc_setVector_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", "float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.setVector", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_setX(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_setX_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setX(qreal)
            cppSelf->QQuaternion::setX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQQuaternionFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setX", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_setY(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_setY_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setY(qreal)
            cppSelf->QQuaternion::setY(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQQuaternionFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setY", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_setZ(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setZ(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setZ(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_setZ_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setZ(qreal)
            cppSelf->QQuaternion::setZ(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQQuaternionFunc_setZ_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.setZ", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_slerp(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "slerp", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: slerp(QQuaternion,QQuaternion,qreal)
    if (numArgs == 3 && Shiboken::Converter<const QQuaternion & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QQuaternion & >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // slerp(QQuaternion,QQuaternion,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc_slerp_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QQuaternion* cpp_arg1 = Shiboken::Converter<QQuaternion* >::toCpp(pyargs[1]);
            qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // slerp(QQuaternion,QQuaternion,qreal)
            QQuaternion cppResult = QQuaternion::slerp(*cpp_arg0, *cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QQuaternion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc_slerp_TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion, PySide.QtGui.QQuaternion, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QQuaternion.slerp", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc_toVector4D(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toVector4D()const
            QVector4D cppResult = cppSelf->QQuaternion::toVector4D();
            pyResult = Shiboken::Converter<QVector4D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_vector(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // vector()const
            QVector3D cppResult = cppSelf->QQuaternion::vector();
            pyResult = Shiboken::Converter<QVector3D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_x(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x()const
            qreal cppResult = cppSelf->QQuaternion::x();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_y(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y()const
            qreal cppResult = cppSelf->QQuaternion::y();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc_z(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // z()const
            qreal cppResult = cppSelf->QQuaternion::z();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQQuaternion_methods[] = {
    {"conjugate", (PyCFunction)SbkQQuaternionFunc_conjugate, METH_NOARGS},
    {"fromAxisAndAngle", (PyCFunction)SbkQQuaternionFunc_fromAxisAndAngle, METH_VARARGS|METH_STATIC},
    {"isIdentity", (PyCFunction)SbkQQuaternionFunc_isIdentity, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQQuaternionFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)SbkQQuaternionFunc_length, METH_NOARGS},
    {"lengthSquared", (PyCFunction)SbkQQuaternionFunc_lengthSquared, METH_NOARGS},
    {"nlerp", (PyCFunction)SbkQQuaternionFunc_nlerp, METH_VARARGS|METH_STATIC},
    {"normalize", (PyCFunction)SbkQQuaternionFunc_normalize, METH_NOARGS},
    {"normalized", (PyCFunction)SbkQQuaternionFunc_normalized, METH_NOARGS},
    {"rotatedVector", (PyCFunction)SbkQQuaternionFunc_rotatedVector, METH_O},
    {"scalar", (PyCFunction)SbkQQuaternionFunc_scalar, METH_NOARGS},
    {"setScalar", (PyCFunction)SbkQQuaternionFunc_setScalar, METH_O},
    {"setVector", (PyCFunction)SbkQQuaternionFunc_setVector, METH_VARARGS},
    {"setX", (PyCFunction)SbkQQuaternionFunc_setX, METH_O},
    {"setY", (PyCFunction)SbkQQuaternionFunc_setY, METH_O},
    {"setZ", (PyCFunction)SbkQQuaternionFunc_setZ, METH_O},
    {"slerp", (PyCFunction)SbkQQuaternionFunc_slerp, METH_VARARGS|METH_STATIC},
    {"toVector4D", (PyCFunction)SbkQQuaternionFunc_toVector4D, METH_NOARGS},
    {"vector", (PyCFunction)SbkQQuaternionFunc_vector, METH_NOARGS},
    {"x", (PyCFunction)SbkQQuaternionFunc_x, METH_NOARGS},
    {"y", (PyCFunction)SbkQQuaternionFunc_y, METH_NOARGS},
    {"z", (PyCFunction)SbkQQuaternionFunc_z, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQQuaternionFunc___mul__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QQuaternion,QQuaternion)
    // 1: operator*(QQuaternion,qreal)
    // 2: operator*(qreal,QQuaternion)
    if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 2; // operator*(qreal,QQuaternion)
    } else if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*(QQuaternion,qreal)
    } else if (!isReverse && Shiboken::Converter<const QQuaternion & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QQuaternion,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QQuaternion,QQuaternion)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QQuaternion,QQuaternion)
                const QQuaternion cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter< QQuaternion >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QQuaternion,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QQuaternion,qreal)
                const QQuaternion cppResult = (*cppSelf) * cpp_arg0;
                pyResult = Shiboken::Converter< QQuaternion >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(qreal,QQuaternion)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(qreal,QQuaternion) [reverse operator]
                const QQuaternion cppResult = cpp_arg0 * (*cppSelf);
                pyResult = Shiboken::Converter< QQuaternion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", "float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__mul__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___imul__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QQuaternion)
    // 1: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse && Shiboken::Converter<const QQuaternion & >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___imul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*=(QQuaternion)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*=(QQuaternion)
                (*cppSelf) *= (*cpp_arg0);
                }
                break;
            }
            case 1: // operator*=(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*=(qreal)
                (*cppSelf) *= cpp_arg0;
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQQuaternionFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__imul__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___add__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QQuaternion,QQuaternion)
    if (!isReverse && Shiboken::Converter<const QQuaternion & >::isConvertible(arg)) {
        overloadId = 0; // operator+(QQuaternion,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___add___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+(QQuaternion,QQuaternion)
            const QQuaternion cppResult = (*cppSelf) + (*cpp_arg0);
            pyResult = Shiboken::Converter< QQuaternion >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__add__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___iadd__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QQuaternion)
    if (!isReverse && Shiboken::Converter<const QQuaternion & >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+=(QQuaternion)
            (*cppSelf) += (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQQuaternionFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__iadd__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___neg__(PyObject* self)
{
    QQuaternion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // operator-(QQuaternion)
            const QQuaternion cppResult = - (*cppSelf);
            pyResult = Shiboken::Converter< QQuaternion >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQQuaternionFunc___sub__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QQuaternion,QQuaternion)
    if (!isReverse && Shiboken::Converter<const QQuaternion & >::isConvertible(arg)) {
        overloadId = 0; // operator-(QQuaternion,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-(QQuaternion,QQuaternion)
            const QQuaternion cppResult = (*cppSelf) - (*cpp_arg0);
            pyResult = Shiboken::Converter< QQuaternion >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__sub__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___isub__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QQuaternion)
    if (!isReverse && Shiboken::Converter<const QQuaternion & >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QQuaternion* cpp_arg0 = Shiboken::Converter<QQuaternion* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-=(QQuaternion)
            (*cppSelf) -= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQQuaternionFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QQuaternion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__isub__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___div__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QQuaternion,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QQuaternion,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/(QQuaternion,qreal)
            const QQuaternion cppResult = (*cppSelf) / cpp_arg0;
            pyResult = Shiboken::Converter< QQuaternion >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__div__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___idiv__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/=(qreal)
            (*cppSelf) /= cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQQuaternionFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__idiv__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___lshift__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QQuaternion)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QQuaternion) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQQuaternionFunc___rshift__(PyObject* self, PyObject* arg)
{
    QQuaternion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QQuaternion >::checkType(arg) && !Shiboken::Converter<QQuaternion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QQuaternion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QQuaternion&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QQuaternion&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQQuaternionFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QQuaternion&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQQuaternionFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QQuaternion.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQQuaternion_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQQuaternionFunc___add__,
    /*nb_subtract*/             (binaryfunc)SbkQQuaternionFunc___sub__,
    /*nb_multiply*/             (binaryfunc)SbkQQuaternionFunc___mul__,
    /*nb_divide*/               (binaryfunc)SbkQQuaternionFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)SbkQQuaternionFunc___neg__,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQQuaternionFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQQuaternionFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQQuaternionFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)SbkQQuaternionFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)SbkQQuaternionFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)SbkQQuaternionFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQQuaternion_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QQuaternion& cpp_self = *Shiboken::Converter<QQuaternion* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QQuaternion & >::isConvertible(other)) {
                // operator!=(const QQuaternion & q2)
                QQuaternion* cpp_other = Shiboken::Converter<QQuaternion* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QQuaternion  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQQuaternion_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QQuaternion & >::isConvertible(other)) {
                // operator==(const QQuaternion & q2)
                QQuaternion* cpp_other = Shiboken::Converter<QQuaternion* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QQuaternion  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQQuaternion_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQQuaternion_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQQuaternion_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QQuaternion",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQQuaternion_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQQuaternion_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQQuaternion_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQQuaternion_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QQuaternion >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QQuaternion",
    /*user_data*/           0
};
} //extern


void init_QQuaternion(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QQUATERNION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQQuaternion_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQQuaternion_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQQuaternion_Type));
    PyModule_AddObject(module, "QQuaternion",
        ((PyObject*)&SbkQQuaternion_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QQuaternion >("QQuaternion");
    Shiboken::TypeResolver::createObjectTypeResolver<QQuaternion >("QQuaternion*");
    Shiboken::TypeResolver::createValueTypeResolver<QQuaternion >(typeid(QQuaternion).name());
    PySide::initQtMetaType<QQuaternion >();
}

