/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qregion_wrapper.h"

// Extra includes
#include <QVector>
#include <qbitmap.h>
#include <qdatastream.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQRegion_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QRegion >()))
        return -1;

    QRegion* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fillRule", "t" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QRegion(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QRegion(): too many arguments");
        return -1;
    } else if (numArgs == 3)
        goto SbkQRegion_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:QRegion", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QRegion()
    // 1: QRegion(QBitmap)
    // 2: QRegion(QPolygon,Qt::FillRule)
    // 3: QRegion(QRect,QRegion::RegionType)
    // 4: QRegion(QRegion)
    // 5: QRegion(int,int,int,int,QRegion::RegionType)
    if (numArgs == 0) {
        overloadId = 0; // QRegion()
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 5; // QRegion(int,int,int,int,QRegion::RegionType)
        } else if (Shiboken::Converter<QRegion::RegionType >::isConvertible(pyargs[4])) {
            overloadId = 5; // QRegion(int,int,int,int,QRegion::RegionType)
        }
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QRegion(QRect,QRegion::RegionType)
        } else if (Shiboken::Converter<QRegion::RegionType >::isConvertible(pyargs[1])) {
            overloadId = 3; // QRegion(QRect,QRegion::RegionType)
        }
    } else if (Shiboken::Converter<const QPolygon & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QRegion(QPolygon,Qt::FillRule)
        } else if (Shiboken::Converter<Qt::FillRule >::isConvertible(pyargs[1])) {
            overloadId = 2; // QRegion(QPolygon,Qt::FillRule)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QBitmap & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QRegion(QBitmap)
    } else if (numArgs == 1 && Shiboken::Converter<const QRegion & >::isConvertible(pyargs[0])) {
        overloadId = 4; // QRegion(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegion_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QRegion()
            {

                if(!PyErr_Occurred()) {
                // QRegion()
                cptr = new QRegion();
                }
                break;
            }
            case 1: // QRegion(QBitmap)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QBitmap > cpp_arg0_auto_ptr;
                QBitmap* cpp_arg0 = Shiboken::Converter<QBitmap* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QBitmap >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QBitmap >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QRegion(QBitmap)
                cptr = new QRegion(*cpp_arg0);
                }
                break;
            }
            case 2: // QRegion(QPolygon,Qt::FillRule)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fillRule");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fillRule";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QRegion(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygon >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);
                Qt::FillRule cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]) : Qt::OddEvenFill;

                if(!PyErr_Occurred()) {
                // QRegion(QPolygon,Qt::FillRule)
                cptr = new QRegion(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QRegion(QRect,QRegion::RegionType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "t");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "t";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QRegion(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                QRegion::RegionType cpp_arg1 = pyargs[1] ? Shiboken::Converter<QRegion::RegionType >::toCpp(pyargs[1]) : QRegion::Rectangle;

                if(!PyErr_Occurred()) {
                // QRegion(QRect,QRegion::RegionType)
                cptr = new QRegion(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 4: // QRegion(QRegion)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRegion >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QRegion(QRegion)
                cptr = new QRegion(*cpp_arg0);
                }
                break;
            }
            case 5: // QRegion(int,int,int,int,QRegion::RegionType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "t");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "t";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QRegion(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                QRegion::RegionType cpp_arg4 = pyargs[4] ? Shiboken::Converter<QRegion::RegionType >::toCpp(pyargs[4]) : QRegion::Rectangle;

                if(!PyErr_Occurred()) {
                // QRegion(int,int,int,int,QRegion::RegionType)
                cptr = new QRegion(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QRegion >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQRegion_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQRegion_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QBitmap", "PySide.QtGui.QPolygon, PySide.QtCore.Qt.FillRule = Qt.OddEvenFill", "PySide.QtCore.QRect, PySide.QtGui.QRegion.RegionType = Rectangle", "PySide.QtGui.QRegion", "int, int, int, int, PySide.QtGui.QRegion.RegionType = Rectangle", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QRegion", overloads);
        return -1;
}

static PyObject* SbkQRegionFunc_boundingRect(PyObject* self)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect()const
            QRect cppResult = cppSelf->QRegion::boundingRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegionFunc_contains(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPoint)const
    // 1: contains(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 1; // contains(QRect)const
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // contains(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_contains_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // contains(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // contains(QPoint)const
                bool cppResult = cppSelf->QRegion::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // contains(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // contains(QRect)const
                bool cppResult = cppSelf->QRegion::contains(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.contains", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_intersected(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QRect)const
    // 1: intersected(QRegion)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // intersected(QRect)const
    } else if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 1; // intersected(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_intersected_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // intersected(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // intersected(QRect)const
                QRegion cppResult = cppSelf->QRegion::intersected(*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
            case 1: // intersected(QRegion)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // intersected(QRegion)const
                QRegion cppResult = cppSelf->QRegion::intersected(*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.intersected", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_intersects(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QRect)const
    // 1: intersects(QRegion)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // intersects(QRect)const
    } else if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 1; // intersects(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_intersects_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // intersects(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // intersects(QRect)const
                bool cppResult = cppSelf->QRegion::intersects(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // intersects(QRegion)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // intersects(QRegion)const
                bool cppResult = cppSelf->QRegion::intersects(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.intersects", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_isEmpty(PyObject* self)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QRegion::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegionFunc_numRects(PyObject* self)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numRects()const
            int cppResult = cppSelf->QRegion::numRects();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegionFunc_rectCount(PyObject* self)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rectCount()const
            int cppResult = cppSelf->QRegion::rectCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegionFunc_rects(PyObject* self)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rects()const
            QVector<QRect > cppResult = cppSelf->QRegion::rects();
            pyResult = Shiboken::Converter<QVector<QRect > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQRegionFunc_setRects(PyObject* self, PyObject* args)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRects", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRects(const QRect*,int)
    if (numArgs == 2 && Shiboken::Converter<const QRect * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setRects(const QRect*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_setRects_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setRects(const QRect*,int)
            cppSelf->QRegion::setRects(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRegionFunc_setRects_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QRegion.setRects", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_subtracted(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtracted(QRegion)const
    if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // subtracted(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_subtracted_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // subtracted(QRegion)const
            QRegion cppResult = cppSelf->QRegion::subtracted(*cpp_arg0);
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_subtracted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.subtracted", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_translate(PyObject* self, PyObject* args)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPoint)
    // 1: translate(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // translate(QPoint)
                cppSelf->QRegion::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(int,int)
                cppSelf->QRegion::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQRegionFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QRegion.translate", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_translated(PyObject* self, PyObject* args)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPoint)const
    // 1: translated(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // translated(QPoint)const
                QRegion cppResult = cppSelf->QRegion::translated(*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translated(int,int)const
                QRegion cppResult = cppSelf->QRegion::translated(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QRegion.translated", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_unite(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unite(QRect)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // unite(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_unite_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // unite(QRect)const
            QRegion cppResult = cppSelf->QRegion::unite(*cpp_arg0);
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_unite_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.unite", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_united(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QRect)const
    // 1: united(QRegion)const
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // united(QRect)const
    } else if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 1; // united(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_united_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // united(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // united(QRect)const
                QRegion cppResult = cppSelf->QRegion::united(*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
            case 1: // united(QRegion)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // united(QRegion)const
                QRegion cppResult = cppSelf->QRegion::united(*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.united", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc_xored(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: xored(QRegion)const
    if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // xored(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc_xored_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // xored(QRegion)const
            QRegion cppResult = cppSelf->QRegion::xored(*cpp_arg0);
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc_xored_TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.xored", overloads);
        return 0;
}

static PyMethodDef SbkQRegion_methods[] = {
    {"boundingRect", (PyCFunction)SbkQRegionFunc_boundingRect, METH_NOARGS},
    {"contains", (PyCFunction)SbkQRegionFunc_contains, METH_O},
    {"intersected", (PyCFunction)SbkQRegionFunc_intersected, METH_O},
    {"intersects", (PyCFunction)SbkQRegionFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)SbkQRegionFunc_isEmpty, METH_NOARGS},
    {"numRects", (PyCFunction)SbkQRegionFunc_numRects, METH_NOARGS},
    {"rectCount", (PyCFunction)SbkQRegionFunc_rectCount, METH_NOARGS},
    {"rects", (PyCFunction)SbkQRegionFunc_rects, METH_NOARGS},
    {"setRects", (PyCFunction)SbkQRegionFunc_setRects, METH_VARARGS},
    {"subtracted", (PyCFunction)SbkQRegionFunc_subtracted, METH_O},
    {"translate", (PyCFunction)SbkQRegionFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)SbkQRegionFunc_translated, METH_VARARGS},
    {"unite", (PyCFunction)SbkQRegionFunc_unite, METH_O},
    {"united", (PyCFunction)SbkQRegionFunc_united, METH_O},
    {"xored", (PyCFunction)SbkQRegionFunc_xored, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQRegionFunc___and__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QRect)const
    // 1: operator&(QRegion)const
    if (!isReverse && Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // operator&(QRect)const
    } else if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 1; // operator&(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___and___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator&(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator&(QRect)const
                const QRegion cppResult = (*cppSelf) & (*cpp_arg0);
                pyResult = Shiboken::Converter< QRegion >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator&(QRegion)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator&(QRegion)const
                const QRegion cppResult = (*cppSelf) & (*cpp_arg0);
                pyResult = Shiboken::Converter< QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__and__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___mul__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QRegion,QMatrix)
    // 1: operator*(QRegion,QTransform)
    if (!isReverse && Shiboken::Converter<const QTransform & >::isConvertible(arg)) {
        overloadId = 1; // operator*(QRegion,QTransform)
    } else if (!isReverse && Shiboken::Converter<const QMatrix & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QRegion,QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QRegion,QMatrix)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QRegion,QMatrix)
                QRegion cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QRegion,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QRegion,QTransform)
                QRegion cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__mul__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___add__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QRect)const
    // 1: operator+(QRegion)const
    if (!isReverse && Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // operator+(QRect)const
    } else if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 1; // operator+(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___add___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator+(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+(QRect)const
                const QRegion cppResult = (*cppSelf) + (*cpp_arg0);
                pyResult = Shiboken::Converter< QRegion >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator+(QRegion)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator+(QRegion)const
                const QRegion cppResult = (*cppSelf) + (*cpp_arg0);
                pyResult = Shiboken::Converter< QRegion >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__add__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___iadd__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QRegion)
    if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator+=(QRegion)
            (*cppSelf) += (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRegionFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__iadd__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___sub__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QRegion)const
    if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // operator-(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator-(QRegion)const
            const QRegion cppResult = (*cppSelf) - (*cpp_arg0);
            pyResult = Shiboken::Converter< QRegion >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__sub__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___isub__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QRegion)
    if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator-=(QRegion)
            (*cppSelf) -= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRegionFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__isub__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___lshift__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QRegion)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QRegion) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___rshift__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QRegion&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QRegion&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QRegion&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__rshift__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___xor__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rxor__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rxor__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator^(QRegion)const
    if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // operator^(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___xor___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator^(QRegion)const
            const QRegion cppResult = (*cppSelf) ^ (*cpp_arg0);
            pyResult = Shiboken::Converter< QRegion >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___xor___TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__xor__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___ixor__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator^=(QRegion)
    if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // operator^=(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___ixor___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator^=(QRegion)
            (*cppSelf) ^= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRegionFunc___ixor___TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__ixor__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___or__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QRegion)const
    if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // operator|(QRegion)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___or___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator|(QRegion)const
            const QRegion cppResult = (*cppSelf) | (*cpp_arg0);
            pyResult = Shiboken::Converter< QRegion >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQRegionFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__or__", overloads);
        return 0;
}

static PyObject* SbkQRegionFunc___ior__(PyObject* self, PyObject* arg)
{
    QRegion* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QRegion >::checkType(arg) && !Shiboken::Converter<QRegion >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QRegion* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QRegion)
    if (!isReverse && Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // operator|=(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQRegionFunc___ior___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // operator|=(QRegion)
            (*cppSelf) |= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQRegionFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QRegion.__ior__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQRegion_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQRegionFunc___add__,
    /*nb_subtract*/             (binaryfunc)SbkQRegionFunc___sub__,
    /*nb_multiply*/             (binaryfunc)SbkQRegionFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQRegionFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQRegionFunc___rshift__,
    /*nb_and*/                  (binaryfunc)SbkQRegionFunc___and__,
    /*nb_xor*/                  (binaryfunc)SbkQRegionFunc___xor__,
    /*nb_or*/                   (binaryfunc)SbkQRegionFunc___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQRegionFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)SbkQRegionFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)SbkQRegionFunc___ixor__,
    /*nb_inplace_or*/           (binaryfunc)SbkQRegionFunc___ior__,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQRegion_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QRegion& cpp_self = *Shiboken::Converter<QRegion* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QRegion & >::isConvertible(other)) {
                // operator!=(const QRegion & r) const
                QRegion* cpp_other = Shiboken::Converter<QRegion* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRegion  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QRegion >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QRegion > cpp_other_auto_ptr;
                QRegion* cpp_other = Shiboken::Converter<QRegion* >::toCpp(other);
                if (!Shiboken::Converter<QRegion >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QRegion >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQRegion_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QRegion & >::isConvertible(other)) {
                // operator==(const QRegion & r) const
                QRegion* cpp_other = Shiboken::Converter<QRegion* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QRegion  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QRegion >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QRegion > cpp_other_auto_ptr;
                QRegion* cpp_other = Shiboken::Converter<QRegion* >::toCpp(other);
                if (!Shiboken::Converter<QRegion >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QRegion >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQRegion_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQRegion_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQRegion_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QRegion",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQRegion_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQRegion_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQRegion_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQRegion_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QRegion >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QRegion",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QRegion_RegionType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QRegion_RegionType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QRegion_RegionType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RegionType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QRegion_RegionType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QRegion_RegionType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QRegion_RegionType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QRegion(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QREGION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQRegion_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQRegion_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQRegion_Type));
    PyModule_AddObject(module, "QRegion",
        ((PyObject*)&SbkQRegion_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: RegionType
    SbkPySide_QtGuiTypes[SBK_QREGION_REGIONTYPE_IDX] = &SbkPySide_QtGui_QRegion_RegionType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QRegion_RegionType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QRegion_RegionType_Type);
    PyDict_SetItemString(SbkQRegion_Type.super.ht_type.tp_dict,
            "RegionType",((PyObject*)&SbkPySide_QtGui_QRegion_RegionType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QRegion_RegionType_Type,
        (long) QRegion::Rectangle, "Rectangle");
    PyDict_SetItemString(SbkQRegion_Type.super.ht_type.tp_dict,
        "Rectangle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QRegion_RegionType_Type.tp_dict,
        "Rectangle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QRegion_RegionType_Type,
        (long) QRegion::Ellipse, "Ellipse");
    PyDict_SetItemString(SbkQRegion_Type.super.ht_type.tp_dict,
        "Ellipse", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QRegion_RegionType_Type.tp_dict,
        "Ellipse", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QRegion::RegionType");


    Shiboken::TypeResolver::createValueTypeResolver<QRegion >("QRegion");
    Shiboken::TypeResolver::createObjectTypeResolver<QRegion >("QRegion*");
    Shiboken::TypeResolver::createValueTypeResolver<QRegion >(typeid(QRegion).name());
    PySide::initQtMetaType<QRegion >();
}

