/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qshortcut_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qkeysequence.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QShortcutWrapper::QShortcutWrapper(QWidget * parent) : QShortcut(parent), m_metaObject(0) {
    // ... middle
}

QShortcutWrapper::QShortcutWrapper(const QKeySequence & key, QWidget * parent, const char * member, const char * ambiguousMember, Qt::ShortcutContext context) : QShortcut(key, parent, member, ambiguousMember, context), m_metaObject(0) {
    // ... middle
}

void QShortcutWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QShortcutWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QShortcutWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QShortcutWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QShortcutWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QShortcut::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QShortcut.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QShortcutWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QShortcut.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QShortcutWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QShortcutWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QShortcut::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QShortcutWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QShortcut::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QShortcutWrapper::~QShortcutWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQShortcut_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QShortcut >()))
        return -1;

    QShortcutWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "ambiguousMember", "arg__4", "context", "member" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QShortcut(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QShortcut", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
    // 1: QShortcut(QWidget*)
    // 2: QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
    if (numArgs == 1 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QShortcut(QWidget*)
    } else if (numArgs >= 2 && Shiboken::Converter<QKeySequence >::isConvertible(pyargs[0]) && Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
        } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
            } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
                } else if (Shiboken::Converter<Qt::ShortcutContext >::isConvertible(pyargs[4])) {
                    overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
                }
            }
        } else if (PyCallable_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
            } else if (Shiboken::Converter<Qt::ShortcutContext >::isConvertible(pyargs[3])) {
                overloadId = 0; // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQShortcut_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "arg__4");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "arg__4";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QShortcut(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QKeySequence > cpp_arg0_auto_ptr;
                QKeySequence* cpp_arg0 = Shiboken::Converter<QKeySequence* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QKeySequence >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QKeySequence >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);
                Qt::ShortcutContext cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::ShortcutContext >::toCpp(pyargs[3]) : Qt::WindowShortcut;

                if(!PyErr_Occurred()) {
                // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
                overloadId = 0;
                // Begin code injection
                
                cptr = new QShortcutWrapper((*cpp_arg0), cpp_arg1);
                
                // End of code injection

                }
                break;
            }
            case 1: // QShortcut(QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QShortcut(QWidget*)
                cptr = new QShortcutWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 2: // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "member");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "member";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "ambiguousMember");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "ambiguousMember";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "context");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "context";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QShortcut(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QKeySequence > cpp_arg0_auto_ptr;
                QKeySequence* cpp_arg0 = Shiboken::Converter<QKeySequence* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QKeySequence >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QKeySequence >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);
                const char * cpp_arg2 = pyargs[2] ? Shiboken::Converter<const char * >::toCpp(pyargs[2]) : 0;
                const char * cpp_arg3 = pyargs[3] ? Shiboken::Converter<const char * >::toCpp(pyargs[3]) : 0;
                Qt::ShortcutContext cpp_arg4 = pyargs[4] ? Shiboken::Converter<Qt::ShortcutContext >::toCpp(pyargs[4]) : Qt::WindowShortcut;

                if(!PyErr_Occurred()) {
                // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
                cptr = new QShortcutWrapper(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QShortcut >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQShortcut_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }
    switch(overloadId) {
        case 0:
        {
            // Begin code injection
            
            Shiboken::AutoDecRef result(PyObject_CallMethod(self, "connect", "OsO", self, SIGNAL(activated()), pyargs[3-1]));
            if (!result.isNull())
                Shiboken::setParent(pyargs[2-1], self);
            
            // End of code injection
        }
}


    return 1;

    SbkQShortcut_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence, PySide.QtGui.QWidget, PyCallable, PySide.QtCore.Qt.ShortcutContext = Qt.WindowShortcut", "PySide.QtGui.QWidget", "PySide.QtGui.QKeySequence, PySide.QtGui.QWidget, str = None, str = None, PySide.QtCore.Qt.ShortcutContext = Qt.WindowShortcut", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QShortcut", overloads);
        return -1;
}

static PyObject* SbkQShortcutFunc_autoRepeat(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoRepeat()const
            bool cppResult = cppSelf->QShortcut::autoRepeat();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQShortcutFunc_context(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // context()
            Qt::ShortcutContext cppResult = cppSelf->QShortcut::context();
            pyResult = Shiboken::Converter<Qt::ShortcutContext >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQShortcutFunc_event(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQShortcutFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QShortcut::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQShortcutFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.event", overloads);
        return 0;
}

static PyObject* SbkQShortcutFunc_id(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // id()const
            int cppResult = cppSelf->QShortcut::id();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQShortcutFunc_isEnabled(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEnabled()const
            bool cppResult = cppSelf->QShortcut::isEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQShortcutFunc_key(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // key()const
            QKeySequence cppResult = cppSelf->QShortcut::key();
            pyResult = Shiboken::Converter<QKeySequence >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQShortcutFunc_parentWidget(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentWidget()const
            QWidget * cppResult = cppSelf->QShortcut::parentWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQShortcutFunc_setAutoRepeat(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoRepeat(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoRepeat(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQShortcutFunc_setAutoRepeat_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoRepeat(bool)
            cppSelf->QShortcut::setAutoRepeat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQShortcutFunc_setAutoRepeat_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setAutoRepeat", overloads);
        return 0;
}

static PyObject* SbkQShortcutFunc_setContext(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContext(Qt::ShortcutContext)
    if (Shiboken::Converter<Qt::ShortcutContext >::isConvertible(arg)) {
        overloadId = 0; // setContext(Qt::ShortcutContext)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQShortcutFunc_setContext_TypeError;

    // Call function/method
    {
        {
            Qt::ShortcutContext cpp_arg0 = Shiboken::Converter<Qt::ShortcutContext >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setContext(Qt::ShortcutContext)
            cppSelf->QShortcut::setContext(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQShortcutFunc_setContext_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ShortcutContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setContext", overloads);
        return 0;
}

static PyObject* SbkQShortcutFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQShortcutFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEnabled(bool)
            cppSelf->QShortcut::setEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQShortcutFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setEnabled", overloads);
        return 0;
}

static PyObject* SbkQShortcutFunc_setKey(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKey(QKeySequence)
    if (Shiboken::Converter<const QKeySequence & >::isConvertible(arg)) {
        overloadId = 0; // setKey(QKeySequence)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQShortcutFunc_setKey_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QKeySequence > cpp_arg0_auto_ptr;
            QKeySequence* cpp_arg0 = Shiboken::Converter<QKeySequence* >::toCpp(arg);
            if (!Shiboken::Converter<QKeySequence >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QKeySequence >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setKey(QKeySequence)
            cppSelf->QShortcut::setKey(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQShortcutFunc_setKey_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setKey", overloads);
        return 0;
}

static PyObject* SbkQShortcutFunc_setWhatsThis(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWhatsThis(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWhatsThis(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQShortcutFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWhatsThis(QString)
            cppSelf->QShortcut::setWhatsThis(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQShortcutFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setWhatsThis", overloads);
        return 0;
}

static PyObject* SbkQShortcutFunc_whatsThis(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // whatsThis()const
            QString cppResult = cppSelf->QShortcut::whatsThis();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQShortcut_methods[] = {
    {"autoRepeat", (PyCFunction)SbkQShortcutFunc_autoRepeat, METH_NOARGS},
    {"context", (PyCFunction)SbkQShortcutFunc_context, METH_NOARGS},
    {"event", (PyCFunction)SbkQShortcutFunc_event, METH_O},
    {"id", (PyCFunction)SbkQShortcutFunc_id, METH_NOARGS},
    {"isEnabled", (PyCFunction)SbkQShortcutFunc_isEnabled, METH_NOARGS},
    {"key", (PyCFunction)SbkQShortcutFunc_key, METH_NOARGS},
    {"parentWidget", (PyCFunction)SbkQShortcutFunc_parentWidget, METH_NOARGS},
    {"setAutoRepeat", (PyCFunction)SbkQShortcutFunc_setAutoRepeat, METH_O},
    {"setContext", (PyCFunction)SbkQShortcutFunc_setContext, METH_O},
    {"setEnabled", (PyCFunction)SbkQShortcutFunc_setEnabled, METH_O},
    {"setKey", (PyCFunction)SbkQShortcutFunc_setKey, METH_O},
    {"setWhatsThis", (PyCFunction)SbkQShortcutFunc_setWhatsThis, METH_O},
    {"whatsThis", (PyCFunction)SbkQShortcutFunc_whatsThis, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQShortcut_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QShortcut",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQShortcut_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQShortcut_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QShortcut >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QShortcut*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQShortcut_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QShortcut*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQShortcut_Type;
    return 0;
}


void init_QShortcut(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSHORTCUT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQShortcut_Type);

    SbkQShortcut_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQShortcut_Type.type_discovery = &SbkQShortcut_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQShortcut_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQShortcut_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQShortcut_Type));
    PyModule_AddObject(module, "QShortcut",
        ((PyObject*)&SbkQShortcut_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("activated", "void", NULL);
    PyDict_SetItemString(SbkQShortcut_Type.super.ht_type.tp_dict, "activated", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("activatedAmbiguously", "void", NULL);
    PyDict_SetItemString(SbkQShortcut_Type.super.ht_type.tp_dict, "activatedAmbiguously", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QShortcut >("QShortcut*");
    Shiboken::TypeResolver::createObjectTypeResolver<QShortcut >(typeid(QShortcut).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QShortcut >(typeid(QShortcutWrapper).name());
    PySide::initQtMetaType<QShortcut* >();
}

