/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiondockwidget_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQStyleOptionDockWidget_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionDockWidget >()))
        return -1;

    QStyleOptionDockWidget* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionDockWidget", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionDockWidget()
    // 1: QStyleOptionDockWidget(QStyleOptionDockWidget)
    // 2: QStyleOptionDockWidget(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionDockWidget()
    } else if (numArgs == 1 && SbkNumber_Check(arg)) {
        overloadId = 2; // QStyleOptionDockWidget(int)
    } else if (numArgs == 1 && Shiboken::Converter<const QStyleOptionDockWidget & >::isConvertible(arg)) {
        overloadId = 1; // QStyleOptionDockWidget(QStyleOptionDockWidget)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStyleOptionDockWidget_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionDockWidget()
            {

                if(!PyErr_Occurred()) {
                // QStyleOptionDockWidget()
                cptr = new QStyleOptionDockWidget();
                }
                break;
            }
            case 1: // QStyleOptionDockWidget(QStyleOptionDockWidget)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QStyleOptionDockWidget* cpp_arg0 = Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QStyleOptionDockWidget(QStyleOptionDockWidget)
                cptr = new QStyleOptionDockWidget(*cpp_arg0);
                }
                break;
            }
            case 2: // QStyleOptionDockWidget(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QStyleOptionDockWidget(int)
                cptr = new QStyleOptionDockWidget(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionDockWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQStyleOptionDockWidget_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQStyleOptionDockWidget_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionDockWidget", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionDockWidget", overloads);
        return -1;
}

static PyMethodDef SbkQStyleOptionDockWidget_methods[] = {
    {0} // Sentinel
};

static PyObject* SbkQStyleOptionDockWidget_get_title(PyObject* self, void*)
{
    return Shiboken::Converter<QString >::toPython(Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->title);
}
static int SbkQStyleOptionDockWidget_set_title(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'title' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'title', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->title = Shiboken::Converter<QString >::toCpp(value);

    return 0;
}

static PyObject* SbkQStyleOptionDockWidget_get_floatable(PyObject* self, void*)
{
    return Shiboken::Converter<bool >::toPython(Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->floatable);
}
static int SbkQStyleOptionDockWidget_set_floatable(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'floatable' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'floatable', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->floatable = Shiboken::Converter<bool >::toCpp(value);

    return 0;
}

static PyObject* SbkQStyleOptionDockWidget_get_closable(PyObject* self, void*)
{
    return Shiboken::Converter<bool >::toPython(Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->closable);
}
static int SbkQStyleOptionDockWidget_set_closable(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'closable' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'closable', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->closable = Shiboken::Converter<bool >::toCpp(value);

    return 0;
}

static PyObject* SbkQStyleOptionDockWidget_get_movable(PyObject* self, void*)
{
    return Shiboken::Converter<bool >::toPython(Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->movable);
}
static int SbkQStyleOptionDockWidget_set_movable(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'movable' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'movable', 'bool' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QStyleOptionDockWidget* >::toCpp(self)->movable = Shiboken::Converter<bool >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionDockWidget
static PyGetSetDef SbkQStyleOptionDockWidget_getsetlist[] = {
    {const_cast<char*>("title"), SbkQStyleOptionDockWidget_get_title, SbkQStyleOptionDockWidget_set_title},
    {const_cast<char*>("floatable"), SbkQStyleOptionDockWidget_get_floatable, SbkQStyleOptionDockWidget_set_floatable},
    {const_cast<char*>("closable"), SbkQStyleOptionDockWidget_get_closable, SbkQStyleOptionDockWidget_set_closable},
    {const_cast<char*>("movable"), SbkQStyleOptionDockWidget_get_movable, SbkQStyleOptionDockWidget_set_movable},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQStyleOptionDockWidget_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionDockWidget",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQStyleOptionDockWidget_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQStyleOptionDockWidget_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQStyleOptionDockWidget_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QStyleOptionDockWidget >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QStyleOptionDockWidget",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StyleOptionVersion",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StyleOptionType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QStyleOptionDockWidget(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGET_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQStyleOptionDockWidget_Type);

    SbkQStyleOptionDockWidget_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQStyleOptionDockWidget_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQStyleOptionDockWidget_Type));
    PyModule_AddObject(module, "QStyleOptionDockWidget",
        ((PyObject*)&SbkQStyleOptionDockWidget_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: StyleOptionVersion
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGET_STYLEOPTIONVERSION_IDX] = &SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_Type);
    PyDict_SetItemString(SbkQStyleOptionDockWidget_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_Type,
        (long) QStyleOptionDockWidget::Version, "Version");
    PyDict_SetItemString(SbkQStyleOptionDockWidget_Type.super.ht_type.tp_dict,
        "Version", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionVersion_Type.tp_dict,
        "Version", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionDockWidget::StyleOptionVersion");

    // init enum class: StyleOptionType
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONDOCKWIDGET_STYLEOPTIONTYPE_IDX] = &SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_Type);
    PyDict_SetItemString(SbkQStyleOptionDockWidget_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_Type,
        (long) QStyleOptionDockWidget::Type, "Type");
    PyDict_SetItemString(SbkQStyleOptionDockWidget_Type.super.ht_type.tp_dict,
        "Type", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionDockWidget_StyleOptionType_Type.tp_dict,
        "Type", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionDockWidget::StyleOptionType");


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionDockWidget >("QStyleOptionDockWidget");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionDockWidget >("QStyleOptionDockWidget*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionDockWidget >(typeid(QStyleOptionDockWidget).name());
    PySide::initQtMetaType<QStyleOptionDockWidget >();
}

