/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstylepainter_wrapper.h"

// Extra includes
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qfontmetrics.h>
#include <qimage.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainterpath.h>
#include <qpalette.h>
#include <qpen.h>
#include <qpicture.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qstylepainter.h>
#include <qtextoption.h>
#include <qtransform.h>
#include <qwidget.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQStylePainter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QStylePainter >()))
        return -1;

    QStylePainter* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStylePainter", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QStylePainter()
    // 1: QStylePainter(QPaintDevice*,QWidget*)
    // 2: QStylePainter(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QStylePainter()
    } else if (numArgs == 1 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QStylePainter(QWidget*)
    } else if (numArgs == 2 && Shiboken::Converter<QPaintDevice * >::isConvertible(pyargs[0]) && Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
        overloadId = 1; // QStylePainter(QPaintDevice*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStylePainter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStylePainter()
            {

                if(!PyErr_Occurred()) {
                // QStylePainter()
                cptr = new QStylePainter();
                }
                break;
            }
            case 1: // QStylePainter(QPaintDevice*,QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QStylePainter(QPaintDevice*,QWidget*)
                cptr = new QStylePainter(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QStylePainter(QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QStylePainter(QWidget*)
                cptr = new QStylePainter(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QStylePainter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQStylePainter_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQStylePainter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPaintDevice, PySide.QtGui.QWidget", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter", overloads);
        return -1;
}

static PyObject* SbkQStylePainterFunc_begin(PyObject* self, PyObject* args)
{
    QStylePainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStylePainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "begin", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: begin(QPaintDevice*,QWidget*)
    // 1: begin(QWidget*)
    if (numArgs == 1 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // begin(QWidget*)
    } else if (numArgs == 2 && Shiboken::Converter<QPaintDevice * >::isConvertible(pyargs[0]) && Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
        overloadId = 0; // begin(QPaintDevice*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStylePainterFunc_begin_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // begin(QPaintDevice*,QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // begin(QPaintDevice*,QWidget*)
                bool cppResult = cppSelf->QStylePainter::begin(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // begin(QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // begin(QWidget*)
                bool cppResult = cppSelf->QStylePainter::begin(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQStylePainterFunc_begin_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice, PySide.QtGui.QWidget", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.begin", overloads);
        return 0;
}

static PyObject* SbkQStylePainterFunc_drawComplexControl(PyObject* self, PyObject* args)
{
    QStylePainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStylePainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawComplexControl", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
    if (numArgs == 2 && Shiboken::Converter<QStyle::ComplexControl >::isConvertible(pyargs[0]) && Shiboken::Converter<const QStyleOptionComplex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStylePainterFunc_drawComplexControl_TypeError;

    // Call function/method
    {
        {
            QStyle::ComplexControl cpp_arg0 = Shiboken::Converter<QStyle::ComplexControl >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QStyleOptionComplex* cpp_arg1 = Shiboken::Converter<QStyleOptionComplex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // drawComplexControl(QStyle::ComplexControl,QStyleOptionComplex)
            cppSelf->QStylePainter::drawComplexControl(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStylePainterFunc_drawComplexControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawComplexControl", overloads);
        return 0;
}

static PyObject* SbkQStylePainterFunc_drawControl(PyObject* self, PyObject* args)
{
    QStylePainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStylePainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawControl", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawControl(QStyle::ControlElement,QStyleOption)
    if (numArgs == 2 && Shiboken::Converter<QStyle::ControlElement >::isConvertible(pyargs[0]) && Shiboken::Converter<const QStyleOption & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawControl(QStyle::ControlElement,QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStylePainterFunc_drawControl_TypeError;

    // Call function/method
    {
        {
            QStyle::ControlElement cpp_arg0 = Shiboken::Converter<QStyle::ControlElement >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QStyleOption* cpp_arg1 = Shiboken::Converter<QStyleOption* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // drawControl(QStyle::ControlElement,QStyleOption)
            cppSelf->QStylePainter::drawControl(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStylePainterFunc_drawControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ControlElement, PySide.QtGui.QStyleOption", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawControl", overloads);
        return 0;
}

static PyObject* SbkQStylePainterFunc_drawItemPixmap(PyObject* self, PyObject* args)
{
    QStylePainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStylePainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawItemPixmap", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemPixmap(QRect,int,QPixmap)
    if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[2])) {
        overloadId = 0; // drawItemPixmap(QRect,int,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStylePainterFunc_drawItemPixmap_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg2_auto_ptr;
            QPixmap* cpp_arg2 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[2]);
            if (!Shiboken::Converter<QPixmap >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg2);

            if(!PyErr_Occurred()) {
            // drawItemPixmap(QRect,int,QPixmap)
            cppSelf->QStylePainter::drawItemPixmap(*cpp_arg0, cpp_arg1, *cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStylePainterFunc_drawItemPixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawItemPixmap", overloads);
        return 0;
}

static PyObject* SbkQStylePainterFunc_drawItemText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QStylePainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStylePainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "textRole" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStylePainter.drawItemText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStylePainter.drawItemText(): too many arguments");
        return 0;
    } else if (numArgs < 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStylePainter.drawItemText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:drawItemText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
    if (numArgs >= 5 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QPalette & >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter<QString >::isConvertible(pyargs[4])) {
        if (numArgs == 5) {
            overloadId = 0; // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
        } else if (Shiboken::Converter<QPalette::ColorRole >::isConvertible(pyargs[5])) {
            overloadId = 0; // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStylePainterFunc_drawItemText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "textRole");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "textRole";
                    else
                        pyargs[5] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStylePainter.drawItemText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QPalette > cpp_arg2_auto_ptr;
            QPalette* cpp_arg2 = Shiboken::Converter<QPalette* >::toCpp(pyargs[2]);
            if (!Shiboken::Converter<QPalette >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QPalette >(cpp_arg2);
            bool cpp_arg3 = Shiboken::Converter<bool >::toCpp(pyargs[3]);
            QString cpp_arg4 = Shiboken::Converter<QString >::toCpp(pyargs[4]);
            QPalette::ColorRole cpp_arg5 = pyargs[5] ? Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[5]) : QPalette::NoRole;

            if(!PyErr_Occurred()) {
            // drawItemText(QRect,int,QPalette,bool,QString,QPalette::ColorRole)
            cppSelf->QStylePainter::drawItemText(*cpp_arg0, cpp_arg1, *cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStylePainterFunc_drawItemText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, PySide.QtGui.QPalette, bool, QString, PySide.QtGui.QPalette.ColorRole = QPalette.NoRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawItemText", overloads);
        return 0;
}

static PyObject* SbkQStylePainterFunc_drawPrimitive(PyObject* self, PyObject* args)
{
    QStylePainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStylePainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawPrimitive", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
    if (numArgs == 2 && Shiboken::Converter<QStyle::PrimitiveElement >::isConvertible(pyargs[0]) && Shiboken::Converter<const QStyleOption & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQStylePainterFunc_drawPrimitive_TypeError;

    // Call function/method
    {
        {
            QStyle::PrimitiveElement cpp_arg0 = Shiboken::Converter<QStyle::PrimitiveElement >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QStyleOption* cpp_arg1 = Shiboken::Converter<QStyleOption* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // drawPrimitive(QStyle::PrimitiveElement,QStyleOption)
            cppSelf->QStylePainter::drawPrimitive(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQStylePainterFunc_drawPrimitive_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.PrimitiveElement, PySide.QtGui.QStyleOption", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStylePainter.drawPrimitive", overloads);
        return 0;
}

static PyObject* SbkQStylePainterFunc_style(PyObject* self)
{
    QStylePainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QStylePainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()const
            QStyle * cppResult = cppSelf->QStylePainter::style();
            pyResult = Shiboken::Converter<QStyle * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQStylePainter_methods[] = {
    {"begin", (PyCFunction)SbkQStylePainterFunc_begin, METH_VARARGS},
    {"drawComplexControl", (PyCFunction)SbkQStylePainterFunc_drawComplexControl, METH_VARARGS},
    {"drawControl", (PyCFunction)SbkQStylePainterFunc_drawControl, METH_VARARGS},
    {"drawItemPixmap", (PyCFunction)SbkQStylePainterFunc_drawItemPixmap, METH_VARARGS},
    {"drawItemText", (PyCFunction)SbkQStylePainterFunc_drawItemText, METH_VARARGS|METH_KEYWORDS},
    {"drawPrimitive", (PyCFunction)SbkQStylePainterFunc_drawPrimitive, METH_VARARGS},
    {"style", (PyCFunction)SbkQStylePainterFunc_style, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQStylePainter_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStylePainter",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQStylePainter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQStylePainter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QStylePainter >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QStylePainter*",
    /*user_data*/           0
};
} //extern


void init_QStylePainter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEPAINTER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQStylePainter_Type);

    SbkQStylePainter_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTER_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQStylePainter_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQStylePainter_Type));
    PyModule_AddObject(module, "QStylePainter",
        ((PyObject*)&SbkQStylePainter_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QStylePainter >("QStylePainter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QStylePainter >(typeid(QStylePainter).name());
    PySide::initQtMetaType<QStylePainter* >();
}

