/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qsyntaxhighlighter_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qfont.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsyntaxhighlighter.h>
#include <qtextdocument.h>
#include <qtextedit.h>
#include <qtextformat.h>
#include <qtextobject.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QSyntaxHighlighterWrapper::QSyntaxHighlighterWrapper(QObject * parent) : QSyntaxHighlighter(parent), m_metaObject(0) {
    // ... middle
}

QSyntaxHighlighterWrapper::QSyntaxHighlighterWrapper(QTextDocument * parent) : QSyntaxHighlighter(parent), m_metaObject(0) {
    // ... middle
}

QSyntaxHighlighterWrapper::QSyntaxHighlighterWrapper(QTextEdit * parent) : QSyntaxHighlighter(parent), m_metaObject(0) {
    // ... middle
}

void QSyntaxHighlighterWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSyntaxHighlighterWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSyntaxHighlighterWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSyntaxHighlighterWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QSyntaxHighlighterWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSyntaxHighlighter.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QSyntaxHighlighterWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSyntaxHighlighter.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QSyntaxHighlighterWrapper::highlightBlock(const QString & text)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "highlightBlock"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSyntaxHighlighter.highlightBlock()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(text)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSyntaxHighlighterWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QSyntaxHighlighterWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QSyntaxHighlighter::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QSyntaxHighlighterWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QSyntaxHighlighter::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QSyntaxHighlighterWrapper::~QSyntaxHighlighterWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSyntaxHighlighter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSyntaxHighlighter >()))
        return -1;

    QSyntaxHighlighterWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QSYNTAXHIGHLIGHTER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QSyntaxHighlighter' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSyntaxHighlighter", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QSyntaxHighlighter(QObject*)
    // 1: QSyntaxHighlighter(QTextDocument*)
    // 2: QSyntaxHighlighter(QTextEdit*)
    if (numArgs == 1 && Shiboken::Converter<QTextEdit * >::isConvertible(arg)) {
        overloadId = 2; // QSyntaxHighlighter(QTextEdit*)
    } else if (numArgs == 1 && Shiboken::Converter<QTextDocument * >::isConvertible(arg)) {
        overloadId = 1; // QSyntaxHighlighter(QTextDocument*)
    } else if (numArgs == 1 && Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QSyntaxHighlighter(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSyntaxHighlighter(QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QSyntaxHighlighter(QObject*)
                cptr = new QSyntaxHighlighterWrapper(cpp_arg0);
                Shiboken::setParent(arg, self);
                }
                break;
            }
            case 1: // QSyntaxHighlighter(QTextDocument*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextDocument* cpp_arg0 = Shiboken::Converter<QTextDocument* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QSyntaxHighlighter(QTextDocument*)
                cptr = new QSyntaxHighlighterWrapper(cpp_arg0);
                Shiboken::setParent(arg, self);
                }
                break;
            }
            case 2: // QSyntaxHighlighter(QTextEdit*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextEdit* cpp_arg0 = Shiboken::Converter<QTextEdit* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QSyntaxHighlighter(QTextEdit*)
                cptr = new QSyntaxHighlighterWrapper(cpp_arg0);
                Shiboken::setParent(arg, self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSyntaxHighlighter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSyntaxHighlighter_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQSyntaxHighlighter_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", "PySide.QtGui.QTextDocument", "PySide.QtGui.QTextEdit", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QSyntaxHighlighter", overloads);
        return -1;
}

static PyObject* SbkQSyntaxHighlighterFunc_currentBlock(PyObject* self)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentBlock()const
            QTextBlock cppResult = cppSelf->QSyntaxHighlighter::currentBlock();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSyntaxHighlighterFunc_currentBlockState(PyObject* self)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentBlockState()const
            int cppResult = cppSelf->QSyntaxHighlighter::currentBlockState();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSyntaxHighlighterFunc_currentBlockUserData(PyObject* self)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentBlockUserData()const
            QTextBlockUserData * cppResult = cppSelf->QSyntaxHighlighter::currentBlockUserData();
            pyResult = Shiboken::Converter<QTextBlockUserData * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSyntaxHighlighterFunc_document(PyObject* self)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // document()const
            QTextDocument * cppResult = cppSelf->QSyntaxHighlighter::document();
            pyResult = Shiboken::Converter<QTextDocument * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSyntaxHighlighterFunc_format(PyObject* self, PyObject* arg)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: format(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // format(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighterFunc_format_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // format(int)const
            QTextCharFormat cppResult = cppSelf->QSyntaxHighlighter::format(cpp_arg0);
            pyResult = Shiboken::Converter<QTextCharFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSyntaxHighlighterFunc_format_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSyntaxHighlighter.format", overloads);
        return 0;
}

static PyObject* SbkQSyntaxHighlighterFunc_highlightBlock(PyObject* self, PyObject* arg)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: highlightBlock(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // highlightBlock(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighterFunc_highlightBlock_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // highlightBlock(QString)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSyntaxHighlighter.highlightBlock()' not implemented.");
                return 0;
            }
            cppSelf->highlightBlock(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSyntaxHighlighterFunc_highlightBlock_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSyntaxHighlighter.highlightBlock", overloads);
        return 0;
}

static PyObject* SbkQSyntaxHighlighterFunc_previousBlockState(PyObject* self)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // previousBlockState()const
            int cppResult = cppSelf->QSyntaxHighlighter::previousBlockState();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSyntaxHighlighterFunc_rehighlight(PyObject* self)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rehighlight()
            cppSelf->QSyntaxHighlighter::rehighlight();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSyntaxHighlighterFunc_rehighlightBlock(PyObject* self, PyObject* arg)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: rehighlightBlock(QTextBlock)
    if (Shiboken::Converter<const QTextBlock & >::isConvertible(arg)) {
        overloadId = 0; // rehighlightBlock(QTextBlock)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighterFunc_rehighlightBlock_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextBlock* cpp_arg0 = Shiboken::Converter<QTextBlock* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rehighlightBlock(QTextBlock)
            cppSelf->QSyntaxHighlighter::rehighlightBlock(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSyntaxHighlighterFunc_rehighlightBlock_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlock", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSyntaxHighlighter.rehighlightBlock", overloads);
        return 0;
}

static PyObject* SbkQSyntaxHighlighterFunc_setCurrentBlockState(PyObject* self, PyObject* arg)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentBlockState(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentBlockState(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighterFunc_setCurrentBlockState_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentBlockState(int)
            cppSelf->QSyntaxHighlighter::setCurrentBlockState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSyntaxHighlighterFunc_setCurrentBlockState_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSyntaxHighlighter.setCurrentBlockState", overloads);
        return 0;
}

static PyObject* SbkQSyntaxHighlighterFunc_setCurrentBlockUserData(PyObject* self, PyObject* arg)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentBlockUserData(QTextBlockUserData*)
    if (Shiboken::Converter<QTextBlockUserData * >::isConvertible(arg)) {
        overloadId = 0; // setCurrentBlockUserData(QTextBlockUserData*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighterFunc_setCurrentBlockUserData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextBlockUserData* cpp_arg0 = Shiboken::Converter<QTextBlockUserData* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentBlockUserData(QTextBlockUserData*)
            cppSelf->QSyntaxHighlighter::setCurrentBlockUserData(cpp_arg0);

            // Ownership transferences.
            BindingManager::instance().transferOwnershipToCpp(arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSyntaxHighlighterFunc_setCurrentBlockUserData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlockUserData", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSyntaxHighlighter.setCurrentBlockUserData", overloads);
        return 0;
}

static PyObject* SbkQSyntaxHighlighterFunc_setDocument(PyObject* self, PyObject* arg)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocument(QTextDocument*)
    if (Shiboken::Converter<QTextDocument * >::isConvertible(arg)) {
        overloadId = 0; // setDocument(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighterFunc_setDocument_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextDocument* cpp_arg0 = Shiboken::Converter<QTextDocument* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDocument(QTextDocument*)
            cppSelf->QSyntaxHighlighter::setDocument(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSyntaxHighlighterFunc_setDocument_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSyntaxHighlighter.setDocument", overloads);
        return 0;
}

static PyObject* SbkQSyntaxHighlighterFunc_setFormat(PyObject* self, PyObject* args)
{
    QSyntaxHighlighter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSyntaxHighlighter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFormat", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setFormat(int,int,QColor)
    // 1: setFormat(int,int,QFont)
    // 2: setFormat(int,int,QTextCharFormat)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 3 && Shiboken::Converter<const QTextCharFormat & >::isConvertible(pyargs[2])) {
            overloadId = 2; // setFormat(int,int,QTextCharFormat)
        } else if (numArgs == 3 && Shiboken::Converter<const QFont & >::isConvertible(pyargs[2])) {
            overloadId = 1; // setFormat(int,int,QFont)
        } else if (numArgs == 3 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[2])) {
            overloadId = 0; // setFormat(int,int,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSyntaxHighlighterFunc_setFormat_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFormat(int,int,QColor)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg2_auto_ptr;
                QColor* cpp_arg2 = Shiboken::Converter<QColor* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QColor >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // setFormat(int,int,QColor)
                cppSelf->QSyntaxHighlighter::setFormat(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 1: // setFormat(int,int,QFont)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QFont > cpp_arg2_auto_ptr;
                QFont* cpp_arg2 = Shiboken::Converter<QFont* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QFont >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QFont >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // setFormat(int,int,QFont)
                cppSelf->QSyntaxHighlighter::setFormat(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 2: // setFormat(int,int,QTextCharFormat)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QTextCharFormat* cpp_arg2 = Shiboken::Converter<QTextCharFormat* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setFormat(int,int,QTextCharFormat)
                cppSelf->QSyntaxHighlighter::setFormat(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSyntaxHighlighterFunc_setFormat_TypeError:
        const char* overloads[] = {"int, int, PySide.QtGui.QColor", "int, int, PySide.QtGui.QFont", "int, int, PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QSyntaxHighlighter.setFormat", overloads);
        return 0;
}

static PyMethodDef SbkQSyntaxHighlighter_methods[] = {
    {"currentBlock", (PyCFunction)SbkQSyntaxHighlighterFunc_currentBlock, METH_NOARGS},
    {"currentBlockState", (PyCFunction)SbkQSyntaxHighlighterFunc_currentBlockState, METH_NOARGS},
    {"currentBlockUserData", (PyCFunction)SbkQSyntaxHighlighterFunc_currentBlockUserData, METH_NOARGS},
    {"document", (PyCFunction)SbkQSyntaxHighlighterFunc_document, METH_NOARGS},
    {"format", (PyCFunction)SbkQSyntaxHighlighterFunc_format, METH_O},
    {"highlightBlock", (PyCFunction)SbkQSyntaxHighlighterFunc_highlightBlock, METH_O},
    {"previousBlockState", (PyCFunction)SbkQSyntaxHighlighterFunc_previousBlockState, METH_NOARGS},
    {"rehighlight", (PyCFunction)SbkQSyntaxHighlighterFunc_rehighlight, METH_NOARGS},
    {"rehighlightBlock", (PyCFunction)SbkQSyntaxHighlighterFunc_rehighlightBlock, METH_O},
    {"setCurrentBlockState", (PyCFunction)SbkQSyntaxHighlighterFunc_setCurrentBlockState, METH_O},
    {"setCurrentBlockUserData", (PyCFunction)SbkQSyntaxHighlighterFunc_setCurrentBlockUserData, METH_O},
    {"setDocument", (PyCFunction)SbkQSyntaxHighlighterFunc_setDocument, METH_O},
    {"setFormat", (PyCFunction)SbkQSyntaxHighlighterFunc_setFormat, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSyntaxHighlighter_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QSyntaxHighlighter",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSyntaxHighlighter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSyntaxHighlighter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSyntaxHighlighter >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSyntaxHighlighter*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQSyntaxHighlighter_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QSyntaxHighlighter*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQSyntaxHighlighter_Type;
    return 0;
}


void init_QSyntaxHighlighter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSYNTAXHIGHLIGHTER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSyntaxHighlighter_Type);

    SbkQSyntaxHighlighter_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQSyntaxHighlighter_Type.type_discovery = &SbkQSyntaxHighlighter_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQSyntaxHighlighter_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSyntaxHighlighter_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSyntaxHighlighter_Type));
    PyModule_AddObject(module, "QSyntaxHighlighter",
        ((PyObject*)&SbkQSyntaxHighlighter_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QSyntaxHighlighter >("QSyntaxHighlighter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSyntaxHighlighter >(typeid(QSyntaxHighlighter).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSyntaxHighlighter >(typeid(QSyntaxHighlighterWrapper).name());
    PySide::initQtMetaType<QSyntaxHighlighter* >();
}

