/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextblock_wrapper.h"
#include "qtextblock_iterator_wrapper.h"

// Extra includes
#include <QTextBlock>
#include <qtextdocument.h>
#include <qtextformat.h>
#include <qtextlayout.h>
#include <qtextlist.h>
#include <qtextobject.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextBlock_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextBlock >()))
        return -1;

    QTextBlock* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextBlock", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextBlock()
    // 1: QTextBlock(QTextBlock)
    if (numArgs == 0) {
        overloadId = 0; // QTextBlock()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextBlock & >::isConvertible(arg)) {
        overloadId = 1; // QTextBlock(QTextBlock)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextBlock_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextBlock()
            {

                if(!PyErr_Occurred()) {
                // QTextBlock()
                cptr = new QTextBlock();
                }
                break;
            }
            case 1: // QTextBlock(QTextBlock)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextBlock* cpp_arg0 = Shiboken::Converter<QTextBlock* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextBlock(QTextBlock)
                cptr = new QTextBlock(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextBlock >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextBlock_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextBlock_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextBlock", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextBlock", overloads);
        return -1;
}

static PyObject* SbkQTextBlockFunc_begin(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // begin()const
            QTextBlock::iterator cppResult = cppSelf->QTextBlock::begin();
            pyResult = Shiboken::Converter<QTextBlock::iterator >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_blockFormat(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blockFormat()const
            QTextBlockFormat cppResult = cppSelf->QTextBlock::blockFormat();
            pyResult = Shiboken::Converter<QTextBlockFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_blockFormatIndex(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blockFormatIndex()const
            int cppResult = cppSelf->QTextBlock::blockFormatIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_blockNumber(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blockNumber()const
            int cppResult = cppSelf->QTextBlock::blockNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_charFormat(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // charFormat()const
            QTextCharFormat cppResult = cppSelf->QTextBlock::charFormat();
            pyResult = Shiboken::Converter<QTextCharFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_charFormatIndex(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // charFormatIndex()const
            int cppResult = cppSelf->QTextBlock::charFormatIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_clearLayout(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearLayout()
            cppSelf->QTextBlock::clearLayout();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextBlockFunc_contains(PyObject* self, PyObject* arg)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // contains(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextBlockFunc_contains_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contains(int)const
            bool cppResult = cppSelf->QTextBlock::contains(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextBlockFunc_contains_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlock.contains", overloads);
        return 0;
}

static PyObject* SbkQTextBlockFunc_document(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // document()const
            const QTextDocument * cppResult = cppSelf->QTextBlock::document();
            pyResult = Shiboken::Converter<const QTextDocument * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_end(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // end()const
            QTextBlock::iterator cppResult = cppSelf->QTextBlock::end();
            pyResult = Shiboken::Converter<QTextBlock::iterator >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_firstLineNumber(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // firstLineNumber()const
            int cppResult = cppSelf->QTextBlock::firstLineNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_fragmentIndex(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fragmentIndex()const
            int cppResult = cppSelf->QTextBlock::fragmentIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_isValid(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QTextBlock::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_isVisible(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isVisible()const
            bool cppResult = cppSelf->QTextBlock::isVisible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_layout(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // layout()const
            QTextLayout * cppResult = cppSelf->QTextBlock::layout();
            pyResult = Shiboken::Converter<QTextLayout * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_length(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            int cppResult = cppSelf->QTextBlock::length();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_lineCount(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineCount()const
            int cppResult = cppSelf->QTextBlock::lineCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_next(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // next()const
            QTextBlock cppResult = cppSelf->QTextBlock::next();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_position(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // position()const
            int cppResult = cppSelf->QTextBlock::position();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_previous(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // previous()const
            QTextBlock cppResult = cppSelf->QTextBlock::previous();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_revision(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // revision()const
            int cppResult = cppSelf->QTextBlock::revision();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_setLineCount(PyObject* self, PyObject* arg)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLineCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLineCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextBlockFunc_setLineCount_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLineCount(int)
            cppSelf->QTextBlock::setLineCount(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextBlockFunc_setLineCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlock.setLineCount", overloads);
        return 0;
}

static PyObject* SbkQTextBlockFunc_setRevision(PyObject* self, PyObject* arg)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRevision(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRevision(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextBlockFunc_setRevision_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRevision(int)
            cppSelf->QTextBlock::setRevision(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextBlockFunc_setRevision_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlock.setRevision", overloads);
        return 0;
}

static PyObject* SbkQTextBlockFunc_setUserData(PyObject* self, PyObject* arg)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserData(QTextBlockUserData*)
    if (Shiboken::Converter<QTextBlockUserData * >::isConvertible(arg)) {
        overloadId = 0; // setUserData(QTextBlockUserData*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextBlockFunc_setUserData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextBlockUserData* cpp_arg0 = Shiboken::Converter<QTextBlockUserData* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUserData(QTextBlockUserData*)
            cppSelf->QTextBlock::setUserData(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextBlockFunc_setUserData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlockUserData", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlock.setUserData", overloads);
        return 0;
}

static PyObject* SbkQTextBlockFunc_setUserState(PyObject* self, PyObject* arg)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserState(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUserState(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextBlockFunc_setUserState_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUserState(int)
            cppSelf->QTextBlock::setUserState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextBlockFunc_setUserState_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlock.setUserState", overloads);
        return 0;
}

static PyObject* SbkQTextBlockFunc_setVisible(PyObject* self, PyObject* arg)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextBlockFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisible(bool)
            cppSelf->QTextBlock::setVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextBlockFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlock.setVisible", overloads);
        return 0;
}

static PyObject* SbkQTextBlockFunc_text(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QString cppResult = cppSelf->QTextBlock::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_textDirection(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textDirection()const
            Qt::LayoutDirection cppResult = cppSelf->QTextBlock::textDirection();
            pyResult = Shiboken::Converter<Qt::LayoutDirection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_textList(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textList()const
            QTextList * cppResult = cppSelf->QTextBlock::textList();
            pyResult = Shiboken::Converter<QTextList * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_userData(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userData()const
            QTextBlockUserData * cppResult = cppSelf->QTextBlock::userData();
            pyResult = Shiboken::Converter<QTextBlockUserData * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextBlockFunc_userState(PyObject* self)
{
    QTextBlock* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextBlock* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userState()const
            int cppResult = cppSelf->QTextBlock::userState();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextBlock_methods[] = {
    {"begin", (PyCFunction)SbkQTextBlockFunc_begin, METH_NOARGS},
    {"blockFormat", (PyCFunction)SbkQTextBlockFunc_blockFormat, METH_NOARGS},
    {"blockFormatIndex", (PyCFunction)SbkQTextBlockFunc_blockFormatIndex, METH_NOARGS},
    {"blockNumber", (PyCFunction)SbkQTextBlockFunc_blockNumber, METH_NOARGS},
    {"charFormat", (PyCFunction)SbkQTextBlockFunc_charFormat, METH_NOARGS},
    {"charFormatIndex", (PyCFunction)SbkQTextBlockFunc_charFormatIndex, METH_NOARGS},
    {"clearLayout", (PyCFunction)SbkQTextBlockFunc_clearLayout, METH_NOARGS},
    {"contains", (PyCFunction)SbkQTextBlockFunc_contains, METH_O},
    {"document", (PyCFunction)SbkQTextBlockFunc_document, METH_NOARGS},
    {"end", (PyCFunction)SbkQTextBlockFunc_end, METH_NOARGS},
    {"firstLineNumber", (PyCFunction)SbkQTextBlockFunc_firstLineNumber, METH_NOARGS},
    {"fragmentIndex", (PyCFunction)SbkQTextBlockFunc_fragmentIndex, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQTextBlockFunc_isValid, METH_NOARGS},
    {"isVisible", (PyCFunction)SbkQTextBlockFunc_isVisible, METH_NOARGS},
    {"layout", (PyCFunction)SbkQTextBlockFunc_layout, METH_NOARGS},
    {"length", (PyCFunction)SbkQTextBlockFunc_length, METH_NOARGS},
    {"lineCount", (PyCFunction)SbkQTextBlockFunc_lineCount, METH_NOARGS},
    {"next", (PyCFunction)SbkQTextBlockFunc_next, METH_NOARGS},
    {"position", (PyCFunction)SbkQTextBlockFunc_position, METH_NOARGS},
    {"previous", (PyCFunction)SbkQTextBlockFunc_previous, METH_NOARGS},
    {"revision", (PyCFunction)SbkQTextBlockFunc_revision, METH_NOARGS},
    {"setLineCount", (PyCFunction)SbkQTextBlockFunc_setLineCount, METH_O},
    {"setRevision", (PyCFunction)SbkQTextBlockFunc_setRevision, METH_O},
    {"setUserData", (PyCFunction)SbkQTextBlockFunc_setUserData, METH_O},
    {"setUserState", (PyCFunction)SbkQTextBlockFunc_setUserState, METH_O},
    {"setVisible", (PyCFunction)SbkQTextBlockFunc_setVisible, METH_O},
    {"text", (PyCFunction)SbkQTextBlockFunc_text, METH_NOARGS},
    {"textDirection", (PyCFunction)SbkQTextBlockFunc_textDirection, METH_NOARGS},
    {"textList", (PyCFunction)SbkQTextBlockFunc_textList, METH_NOARGS},
    {"userData", (PyCFunction)SbkQTextBlockFunc_userData, METH_NOARGS},
    {"userState", (PyCFunction)SbkQTextBlockFunc_userState, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQTextBlock_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QTextBlock& cpp_self = *Shiboken::Converter<QTextBlock* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QTextBlock & >::isConvertible(other)) {
                // operator!=(const QTextBlock & o) const
                QTextBlock* cpp_other = Shiboken::Converter<QTextBlock* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextBlock  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQTextBlock_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QTextBlock & >::isConvertible(other)) {
                // operator<(const QTextBlock & o) const
                QTextBlock* cpp_other = Shiboken::Converter<QTextBlock* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextBlock  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else goto SbkQTextBlock_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QTextBlock & >::isConvertible(other)) {
                // operator==(const QTextBlock & o) const
                QTextBlock* cpp_other = Shiboken::Converter<QTextBlock* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextBlock  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQTextBlock_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQTextBlock_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextBlock_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextBlock",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQTextBlock_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextBlock_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextBlock_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextBlock >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextBlock",
    /*user_data*/           0
};
} //extern


void init_QTextBlock(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTBLOCK_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextBlock_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextBlock_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextBlock_Type));
    PyModule_AddObject(module, "QTextBlock",
        ((PyObject*)&SbkQTextBlock_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextBlock >("QTextBlock");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextBlock >("QTextBlock*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextBlock >(typeid(QTextBlock).name());
    PySide::initQtMetaType<QTextBlock >();
}

