/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextcharformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QStringList>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qpen.h>
#include <qtextformat.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextCharFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextCharFormat >()))
        return -1;

    QTextCharFormat* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextCharFormat", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextCharFormat(QTextCharFormat)
    // 1: QTextCharFormat()
    // 2: QTextCharFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 1; // QTextCharFormat()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextFormat & >::isConvertible(arg)) {
        overloadId = 2; // QTextCharFormat(QTextFormat)
    } else if (numArgs == 1 && Shiboken::Converter<const QTextCharFormat & >::isConvertible(arg)) {
        overloadId = 0; // QTextCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextCharFormat(QTextCharFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextCharFormat* cpp_arg0 = Shiboken::Converter<QTextCharFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextCharFormat(QTextCharFormat)
                cptr = new QTextCharFormat(*cpp_arg0);
                }
                break;
            }
            case 1: // QTextCharFormat()
            {

                if(!PyErr_Occurred()) {
                // QTextCharFormat()
                cptr = new QTextCharFormat();
                }
                break;
            }
            case 2: // QTextCharFormat(QTextFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextFormat* cpp_arg0 = Shiboken::Converter<QTextFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextCharFormat(QTextFormat)
                cptr = new QTextCharFormat(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextCharFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextCharFormat_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextCharFormat_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", "", "PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCharFormat", overloads);
        return -1;
}

static PyObject* SbkQTextCharFormatFunc_anchorHref(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // anchorHref()const
            QString cppResult = cppSelf->QTextCharFormat::anchorHref();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_anchorNames(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // anchorNames()const
            QStringList cppResult = cppSelf->QTextCharFormat::anchorNames();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_font(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // font()const
            QFont cppResult = cppSelf->QTextCharFormat::font();
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontCapitalization(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontCapitalization()const
            QFont::Capitalization cppResult = cppSelf->QTextCharFormat::fontCapitalization();
            pyResult = Shiboken::Converter<QFont::Capitalization >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontFamily(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontFamily()const
            QString cppResult = cppSelf->QTextCharFormat::fontFamily();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontFixedPitch(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontFixedPitch()const
            bool cppResult = cppSelf->QTextCharFormat::fontFixedPitch();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontItalic(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontItalic()const
            bool cppResult = cppSelf->QTextCharFormat::fontItalic();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontKerning(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontKerning()const
            bool cppResult = cppSelf->QTextCharFormat::fontKerning();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontLetterSpacing(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontLetterSpacing()const
            qreal cppResult = cppSelf->QTextCharFormat::fontLetterSpacing();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontOverline(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontOverline()const
            bool cppResult = cppSelf->QTextCharFormat::fontOverline();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontPointSize(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontPointSize()const
            qreal cppResult = cppSelf->QTextCharFormat::fontPointSize();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontStrikeOut(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontStrikeOut()const
            bool cppResult = cppSelf->QTextCharFormat::fontStrikeOut();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontStyleHint(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontStyleHint()const
            QFont::StyleHint cppResult = cppSelf->QTextCharFormat::fontStyleHint();
            pyResult = Shiboken::Converter<QFont::StyleHint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontStyleStrategy(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontStyleStrategy()const
            QFont::StyleStrategy cppResult = cppSelf->QTextCharFormat::fontStyleStrategy();
            pyResult = Shiboken::Converter<QFont::StyleStrategy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontUnderline(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontUnderline()const
            bool cppResult = cppSelf->QTextCharFormat::fontUnderline();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontWeight(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontWeight()const
            int cppResult = cppSelf->QTextCharFormat::fontWeight();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_fontWordSpacing(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontWordSpacing()const
            qreal cppResult = cppSelf->QTextCharFormat::fontWordSpacing();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_isAnchor(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAnchor()const
            bool cppResult = cppSelf->QTextCharFormat::isAnchor();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_isValid(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QTextCharFormat::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_setAnchor(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnchor(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAnchor(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setAnchor_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAnchor(bool)
            cppSelf->QTextCharFormat::setAnchor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setAnchor_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setAnchor", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setAnchorHref(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnchorHref(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setAnchorHref(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setAnchorHref_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAnchorHref(QString)
            cppSelf->QTextCharFormat::setAnchorHref(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setAnchorHref_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setAnchorHref", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setAnchorNames(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnchorNames(QStringList)
    if (Shiboken::Converter< QStringList  >::isConvertible(arg)) {
        overloadId = 0; // setAnchorNames(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setAnchorNames_TypeError;

    // Call function/method
    {
        {
            QStringList cpp_arg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAnchorNames(QStringList)
            cppSelf->QTextCharFormat::setAnchorNames(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setAnchorNames_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setAnchorNames", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFont(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFont(QFont)
            cppSelf->QTextCharFormat::setFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFont", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontCapitalization(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontCapitalization(QFont::Capitalization)
    if (Shiboken::Converter<QFont::Capitalization >::isConvertible(arg)) {
        overloadId = 0; // setFontCapitalization(QFont::Capitalization)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontCapitalization_TypeError;

    // Call function/method
    {
        {
            QFont::Capitalization cpp_arg0 = Shiboken::Converter<QFont::Capitalization >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontCapitalization(QFont::Capitalization)
            cppSelf->QTextCharFormat::setFontCapitalization(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontCapitalization_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.Capitalization", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontCapitalization", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontFamily(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontFamily(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFontFamily(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontFamily_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontFamily(QString)
            cppSelf->QTextCharFormat::setFontFamily(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontFamily_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontFamily", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontFixedPitch(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontFixedPitch(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontFixedPitch(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontFixedPitch_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontFixedPitch(bool)
            cppSelf->QTextCharFormat::setFontFixedPitch(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontFixedPitch_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontFixedPitch", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontItalic(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontItalic(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontItalic(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontItalic_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontItalic(bool)
            cppSelf->QTextCharFormat::setFontItalic(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontItalic_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontItalic", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontKerning(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontKerning(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontKerning(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontKerning_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontKerning(bool)
            cppSelf->QTextCharFormat::setFontKerning(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontKerning_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontKerning", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontLetterSpacing(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontLetterSpacing(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontLetterSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontLetterSpacing_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontLetterSpacing(qreal)
            cppSelf->QTextCharFormat::setFontLetterSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontLetterSpacing_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontLetterSpacing", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontOverline(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontOverline(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontOverline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontOverline_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontOverline(bool)
            cppSelf->QTextCharFormat::setFontOverline(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontOverline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontOverline", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontPointSize(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontPointSize(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontPointSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontPointSize_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontPointSize(qreal)
            cppSelf->QTextCharFormat::setFontPointSize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontPointSize_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontPointSize", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontStrikeOut(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontStrikeOut(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontStrikeOut(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontStrikeOut_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontStrikeOut(bool)
            cppSelf->QTextCharFormat::setFontStrikeOut(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontStrikeOut_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontStrikeOut", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontStyleHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "strategy" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCharFormat.setFontStyleHint(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCharFormat.setFontStyleHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCharFormat.setFontStyleHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setFontStyleHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
    if (Shiboken::Converter<QFont::StyleHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        } else if (Shiboken::Converter<QFont::StyleStrategy >::isConvertible(pyargs[1])) {
            overloadId = 0; // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontStyleHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "strategy");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "strategy";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCharFormat.setFontStyleHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFont::StyleHint cpp_arg0 = Shiboken::Converter<QFont::StyleHint >::toCpp(pyargs[0]);
            QFont::StyleStrategy cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFont::StyleStrategy >::toCpp(pyargs[1]) : QFont::PreferDefault;

            if(!PyErr_Occurred()) {
            // setFontStyleHint(QFont::StyleHint,QFont::StyleStrategy)
            cppSelf->QTextCharFormat::setFontStyleHint(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontStyleHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.StyleHint, PySide.QtGui.QFont.StyleStrategy = QFont.PreferDefault", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCharFormat.setFontStyleHint", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontStyleStrategy(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontStyleStrategy(QFont::StyleStrategy)
    if (Shiboken::Converter<QFont::StyleStrategy >::isConvertible(arg)) {
        overloadId = 0; // setFontStyleStrategy(QFont::StyleStrategy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontStyleStrategy_TypeError;

    // Call function/method
    {
        {
            QFont::StyleStrategy cpp_arg0 = Shiboken::Converter<QFont::StyleStrategy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontStyleStrategy(QFont::StyleStrategy)
            cppSelf->QTextCharFormat::setFontStyleStrategy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontStyleStrategy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont.StyleStrategy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontStyleStrategy", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontUnderline(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontUnderline(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontUnderline_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontUnderline(bool)
            cppSelf->QTextCharFormat::setFontUnderline(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontUnderline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontUnderline", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontWeight(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontWeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontWeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontWeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontWeight(int)
            cppSelf->QTextCharFormat::setFontWeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontWeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontWeight", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setFontWordSpacing(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontWordSpacing(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontWordSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setFontWordSpacing_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontWordSpacing(qreal)
            cppSelf->QTextCharFormat::setFontWordSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setFontWordSpacing_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setFontWordSpacing", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setTableCellColumnSpan(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTableCellColumnSpan(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTableCellColumnSpan(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setTableCellColumnSpan_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTableCellColumnSpan(int)
            cppSelf->QTextCharFormat::setTableCellColumnSpan(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setTableCellColumnSpan_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setTableCellColumnSpan", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setTableCellRowSpan(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTableCellRowSpan(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTableCellRowSpan(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setTableCellRowSpan_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTableCellRowSpan(int)
            cppSelf->QTextCharFormat::setTableCellRowSpan(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setTableCellRowSpan_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setTableCellRowSpan", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setTextOutline(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextOutline(QPen)
    if (Shiboken::Converter<const QPen & >::isConvertible(arg)) {
        overloadId = 0; // setTextOutline(QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setTextOutline_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPen > cpp_arg0_auto_ptr;
            QPen* cpp_arg0 = Shiboken::Converter<QPen* >::toCpp(arg);
            if (!Shiboken::Converter<QPen >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPen >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setTextOutline(QPen)
            cppSelf->QTextCharFormat::setTextOutline(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setTextOutline_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPen", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setTextOutline", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setToolTip(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setToolTip(QString)
            cppSelf->QTextCharFormat::setToolTip(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setToolTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setToolTip", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setUnderlineColor(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUnderlineColor(QColor)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // setUnderlineColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setUnderlineColor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setUnderlineColor(QColor)
            cppSelf->QTextCharFormat::setUnderlineColor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setUnderlineColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setUnderlineColor", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setUnderlineStyle(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUnderlineStyle(QTextCharFormat::UnderlineStyle)
    if (Shiboken::Converter<QTextCharFormat::UnderlineStyle >::isConvertible(arg)) {
        overloadId = 0; // setUnderlineStyle(QTextCharFormat::UnderlineStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setUnderlineStyle_TypeError;

    // Call function/method
    {
        {
            QTextCharFormat::UnderlineStyle cpp_arg0 = Shiboken::Converter<QTextCharFormat::UnderlineStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUnderlineStyle(QTextCharFormat::UnderlineStyle)
            cppSelf->QTextCharFormat::setUnderlineStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setUnderlineStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat.UnderlineStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setUnderlineStyle", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_setVerticalAlignment(PyObject* self, PyObject* arg)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalAlignment(QTextCharFormat::VerticalAlignment)
    if (Shiboken::Converter<QTextCharFormat::VerticalAlignment >::isConvertible(arg)) {
        overloadId = 0; // setVerticalAlignment(QTextCharFormat::VerticalAlignment)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCharFormatFunc_setVerticalAlignment_TypeError;

    // Call function/method
    {
        {
            QTextCharFormat::VerticalAlignment cpp_arg0 = Shiboken::Converter<QTextCharFormat::VerticalAlignment >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVerticalAlignment(QTextCharFormat::VerticalAlignment)
            cppSelf->QTextCharFormat::setVerticalAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCharFormatFunc_setVerticalAlignment_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat.VerticalAlignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCharFormat.setVerticalAlignment", overloads);
        return 0;
}

static PyObject* SbkQTextCharFormatFunc_tableCellColumnSpan(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tableCellColumnSpan()const
            int cppResult = cppSelf->QTextCharFormat::tableCellColumnSpan();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_tableCellRowSpan(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tableCellRowSpan()const
            int cppResult = cppSelf->QTextCharFormat::tableCellRowSpan();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_textOutline(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textOutline()const
            QPen cppResult = cppSelf->QTextCharFormat::textOutline();
            pyResult = Shiboken::Converter<QPen >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_toolTip(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toolTip()const
            QString cppResult = cppSelf->QTextCharFormat::toolTip();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_underlineColor(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // underlineColor()const
            QColor cppResult = cppSelf->QTextCharFormat::underlineColor();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_underlineStyle(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // underlineStyle()const
            QTextCharFormat::UnderlineStyle cppResult = cppSelf->QTextCharFormat::underlineStyle();
            pyResult = Shiboken::Converter<QTextCharFormat::UnderlineStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCharFormatFunc_verticalAlignment(PyObject* self)
{
    QTextCharFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCharFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // verticalAlignment()const
            QTextCharFormat::VerticalAlignment cppResult = cppSelf->QTextCharFormat::verticalAlignment();
            pyResult = Shiboken::Converter<QTextCharFormat::VerticalAlignment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextCharFormat_methods[] = {
    {"anchorHref", (PyCFunction)SbkQTextCharFormatFunc_anchorHref, METH_NOARGS},
    {"anchorNames", (PyCFunction)SbkQTextCharFormatFunc_anchorNames, METH_NOARGS},
    {"font", (PyCFunction)SbkQTextCharFormatFunc_font, METH_NOARGS},
    {"fontCapitalization", (PyCFunction)SbkQTextCharFormatFunc_fontCapitalization, METH_NOARGS},
    {"fontFamily", (PyCFunction)SbkQTextCharFormatFunc_fontFamily, METH_NOARGS},
    {"fontFixedPitch", (PyCFunction)SbkQTextCharFormatFunc_fontFixedPitch, METH_NOARGS},
    {"fontItalic", (PyCFunction)SbkQTextCharFormatFunc_fontItalic, METH_NOARGS},
    {"fontKerning", (PyCFunction)SbkQTextCharFormatFunc_fontKerning, METH_NOARGS},
    {"fontLetterSpacing", (PyCFunction)SbkQTextCharFormatFunc_fontLetterSpacing, METH_NOARGS},
    {"fontOverline", (PyCFunction)SbkQTextCharFormatFunc_fontOverline, METH_NOARGS},
    {"fontPointSize", (PyCFunction)SbkQTextCharFormatFunc_fontPointSize, METH_NOARGS},
    {"fontStrikeOut", (PyCFunction)SbkQTextCharFormatFunc_fontStrikeOut, METH_NOARGS},
    {"fontStyleHint", (PyCFunction)SbkQTextCharFormatFunc_fontStyleHint, METH_NOARGS},
    {"fontStyleStrategy", (PyCFunction)SbkQTextCharFormatFunc_fontStyleStrategy, METH_NOARGS},
    {"fontUnderline", (PyCFunction)SbkQTextCharFormatFunc_fontUnderline, METH_NOARGS},
    {"fontWeight", (PyCFunction)SbkQTextCharFormatFunc_fontWeight, METH_NOARGS},
    {"fontWordSpacing", (PyCFunction)SbkQTextCharFormatFunc_fontWordSpacing, METH_NOARGS},
    {"isAnchor", (PyCFunction)SbkQTextCharFormatFunc_isAnchor, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQTextCharFormatFunc_isValid, METH_NOARGS},
    {"setAnchor", (PyCFunction)SbkQTextCharFormatFunc_setAnchor, METH_O},
    {"setAnchorHref", (PyCFunction)SbkQTextCharFormatFunc_setAnchorHref, METH_O},
    {"setAnchorNames", (PyCFunction)SbkQTextCharFormatFunc_setAnchorNames, METH_O},
    {"setFont", (PyCFunction)SbkQTextCharFormatFunc_setFont, METH_O},
    {"setFontCapitalization", (PyCFunction)SbkQTextCharFormatFunc_setFontCapitalization, METH_O},
    {"setFontFamily", (PyCFunction)SbkQTextCharFormatFunc_setFontFamily, METH_O},
    {"setFontFixedPitch", (PyCFunction)SbkQTextCharFormatFunc_setFontFixedPitch, METH_O},
    {"setFontItalic", (PyCFunction)SbkQTextCharFormatFunc_setFontItalic, METH_O},
    {"setFontKerning", (PyCFunction)SbkQTextCharFormatFunc_setFontKerning, METH_O},
    {"setFontLetterSpacing", (PyCFunction)SbkQTextCharFormatFunc_setFontLetterSpacing, METH_O},
    {"setFontOverline", (PyCFunction)SbkQTextCharFormatFunc_setFontOverline, METH_O},
    {"setFontPointSize", (PyCFunction)SbkQTextCharFormatFunc_setFontPointSize, METH_O},
    {"setFontStrikeOut", (PyCFunction)SbkQTextCharFormatFunc_setFontStrikeOut, METH_O},
    {"setFontStyleHint", (PyCFunction)SbkQTextCharFormatFunc_setFontStyleHint, METH_VARARGS|METH_KEYWORDS},
    {"setFontStyleStrategy", (PyCFunction)SbkQTextCharFormatFunc_setFontStyleStrategy, METH_O},
    {"setFontUnderline", (PyCFunction)SbkQTextCharFormatFunc_setFontUnderline, METH_O},
    {"setFontWeight", (PyCFunction)SbkQTextCharFormatFunc_setFontWeight, METH_O},
    {"setFontWordSpacing", (PyCFunction)SbkQTextCharFormatFunc_setFontWordSpacing, METH_O},
    {"setTableCellColumnSpan", (PyCFunction)SbkQTextCharFormatFunc_setTableCellColumnSpan, METH_O},
    {"setTableCellRowSpan", (PyCFunction)SbkQTextCharFormatFunc_setTableCellRowSpan, METH_O},
    {"setTextOutline", (PyCFunction)SbkQTextCharFormatFunc_setTextOutline, METH_O},
    {"setToolTip", (PyCFunction)SbkQTextCharFormatFunc_setToolTip, METH_O},
    {"setUnderlineColor", (PyCFunction)SbkQTextCharFormatFunc_setUnderlineColor, METH_O},
    {"setUnderlineStyle", (PyCFunction)SbkQTextCharFormatFunc_setUnderlineStyle, METH_O},
    {"setVerticalAlignment", (PyCFunction)SbkQTextCharFormatFunc_setVerticalAlignment, METH_O},
    {"tableCellColumnSpan", (PyCFunction)SbkQTextCharFormatFunc_tableCellColumnSpan, METH_NOARGS},
    {"tableCellRowSpan", (PyCFunction)SbkQTextCharFormatFunc_tableCellRowSpan, METH_NOARGS},
    {"textOutline", (PyCFunction)SbkQTextCharFormatFunc_textOutline, METH_NOARGS},
    {"toolTip", (PyCFunction)SbkQTextCharFormatFunc_toolTip, METH_NOARGS},
    {"underlineColor", (PyCFunction)SbkQTextCharFormatFunc_underlineColor, METH_NOARGS},
    {"underlineStyle", (PyCFunction)SbkQTextCharFormatFunc_underlineStyle, METH_NOARGS},
    {"verticalAlignment", (PyCFunction)SbkQTextCharFormatFunc_verticalAlignment, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextCharFormat_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextCharFormat",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextCharFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextCharFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextCharFormat >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextCharFormat",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "VerticalAlignment",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "UnderlineStyle",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextCharFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextCharFormat_Type);

    SbkQTextCharFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQTextCharFormat_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextCharFormat_Type));
    PyModule_AddObject(module, "QTextCharFormat",
        ((PyObject*)&SbkQTextCharFormat_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: VerticalAlignment
    SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_VERTICALALIGNMENT_IDX] = &SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type);
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
            "VerticalAlignment",((PyObject*)&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type,
        (long) QTextCharFormat::AlignNormal, "AlignNormal");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "AlignNormal", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type.tp_dict,
        "AlignNormal", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type,
        (long) QTextCharFormat::AlignSuperScript, "AlignSuperScript");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "AlignSuperScript", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type.tp_dict,
        "AlignSuperScript", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type,
        (long) QTextCharFormat::AlignSubScript, "AlignSubScript");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "AlignSubScript", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type.tp_dict,
        "AlignSubScript", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type,
        (long) QTextCharFormat::AlignMiddle, "AlignMiddle");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "AlignMiddle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type.tp_dict,
        "AlignMiddle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type,
        (long) QTextCharFormat::AlignTop, "AlignTop");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "AlignTop", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type.tp_dict,
        "AlignTop", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type,
        (long) QTextCharFormat::AlignBottom, "AlignBottom");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "AlignBottom", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_VerticalAlignment_Type.tp_dict,
        "AlignBottom", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCharFormat::VerticalAlignment");

    // init enum class: UnderlineStyle
    SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_UNDERLINESTYLE_IDX] = &SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type);
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
            "UnderlineStyle",((PyObject*)&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::NoUnderline, "NoUnderline");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "NoUnderline", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "NoUnderline", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::SingleUnderline, "SingleUnderline");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "SingleUnderline", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "SingleUnderline", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::DashUnderline, "DashUnderline");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "DashUnderline", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "DashUnderline", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::DotLine, "DotLine");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "DotLine", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "DotLine", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::DashDotLine, "DashDotLine");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "DashDotLine", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "DashDotLine", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::DashDotDotLine, "DashDotDotLine");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "DashDotDotLine", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "DashDotDotLine", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::WaveUnderline, "WaveUnderline");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "WaveUnderline", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "WaveUnderline", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type,
        (long) QTextCharFormat::SpellCheckUnderline, "SpellCheckUnderline");
    PyDict_SetItemString(SbkQTextCharFormat_Type.super.ht_type.tp_dict,
        "SpellCheckUnderline", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCharFormat_UnderlineStyle_Type.tp_dict,
        "SpellCheckUnderline", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCharFormat::UnderlineStyle");


    Shiboken::TypeResolver::createValueTypeResolver<QTextCharFormat >("QTextCharFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextCharFormat >("QTextCharFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextCharFormat >(typeid(QTextCharFormat).name());
    PySide::initQtMetaType<QTextCharFormat >();
}

