/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextcursor_wrapper.h"

// Extra includes
#include <QTextBlock>
#include <QTextDocumentFragment>
#include <qimage.h>
#include <qtextcursor.h>
#include <qtextdocument.h>
#include <qtextdocumentfragment.h>
#include <qtextformat.h>
#include <qtextlist.h>
#include <qtextobject.h>
#include <qtexttable.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextCursor_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextCursor >()))
        return -1;

    QTextCursor* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextCursor", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextCursor()
    // 1: QTextCursor(QTextDocument*)
    // 2: QTextCursor(QTextFrame*)
    // 3: QTextCursor(QTextBlock)
    // 4: QTextCursor(QTextCursor)
    if (numArgs == 0) {
        overloadId = 0; // QTextCursor()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextCursor & >::isConvertible(arg)) {
        overloadId = 4; // QTextCursor(QTextCursor)
    } else if (numArgs == 1 && Shiboken::Converter<const QTextBlock & >::isConvertible(arg)) {
        overloadId = 3; // QTextCursor(QTextBlock)
    } else if (numArgs == 1 && Shiboken::Converter<QTextFrame * >::isConvertible(arg)) {
        overloadId = 2; // QTextCursor(QTextFrame*)
    } else if (numArgs == 1 && Shiboken::Converter<QTextDocument * >::isConvertible(arg)) {
        overloadId = 1; // QTextCursor(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursor_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextCursor()
            {

                if(!PyErr_Occurred()) {
                // QTextCursor()
                cptr = new QTextCursor();
                }
                break;
            }
            case 1: // QTextCursor(QTextDocument*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextDocument* cpp_arg0 = Shiboken::Converter<QTextDocument* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextCursor(QTextDocument*)
                cptr = new QTextCursor(cpp_arg0);
                }
                break;
            }
            case 2: // QTextCursor(QTextFrame*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextFrame* cpp_arg0 = Shiboken::Converter<QTextFrame* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextCursor(QTextFrame*)
                cptr = new QTextCursor(cpp_arg0);
                }
                break;
            }
            case 3: // QTextCursor(QTextBlock)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextBlock* cpp_arg0 = Shiboken::Converter<QTextBlock* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextCursor(QTextBlock)
                cptr = new QTextCursor(*cpp_arg0);
                }
                break;
            }
            case 4: // QTextCursor(QTextCursor)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextCursor* cpp_arg0 = Shiboken::Converter<QTextCursor* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextCursor(QTextCursor)
                cptr = new QTextCursor(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextCursor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextCursor_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextCursor_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextDocument", "PySide.QtGui.QTextFrame", "PySide.QtGui.QTextBlock", "PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor", overloads);
        return -1;
}

static PyObject* SbkQTextCursorFunc_anchor(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // anchor()const
            int cppResult = cppSelf->QTextCursor::anchor();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_atBlockEnd(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atBlockEnd()const
            bool cppResult = cppSelf->QTextCursor::atBlockEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_atBlockStart(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atBlockStart()const
            bool cppResult = cppSelf->QTextCursor::atBlockStart();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_atEnd(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QTextCursor::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_atStart(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atStart()const
            bool cppResult = cppSelf->QTextCursor::atStart();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_beginEditBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // beginEditBlock()
            cppSelf->QTextCursor::beginEditBlock();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextCursorFunc_block(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // block()const
            QTextBlock cppResult = cppSelf->QTextCursor::block();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_blockCharFormat(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blockCharFormat()const
            QTextCharFormat cppResult = cppSelf->QTextCursor::blockCharFormat();
            pyResult = Shiboken::Converter<QTextCharFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_blockFormat(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blockFormat()const
            QTextBlockFormat cppResult = cppSelf->QTextCursor::blockFormat();
            pyResult = Shiboken::Converter<QTextBlockFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_blockNumber(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blockNumber()const
            int cppResult = cppSelf->QTextCursor::blockNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_charFormat(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // charFormat()const
            QTextCharFormat cppResult = cppSelf->QTextCursor::charFormat();
            pyResult = Shiboken::Converter<QTextCharFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_clearSelection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearSelection()
            cppSelf->QTextCursor::clearSelection();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextCursorFunc_columnNumber(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columnNumber()const
            int cppResult = cppSelf->QTextCursor::columnNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_createList(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createList(QTextListFormat::Style)
    // 1: createList(QTextListFormat)
    if (Shiboken::Converter<const QTextListFormat & >::isConvertible(arg)) {
        overloadId = 1; // createList(QTextListFormat)
    } else if (Shiboken::Converter<QTextListFormat::Style >::isConvertible(arg)) {
        overloadId = 0; // createList(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_createList_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // createList(QTextListFormat::Style)
            {
                QTextListFormat::Style cpp_arg0 = Shiboken::Converter<QTextListFormat::Style >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // createList(QTextListFormat::Style)
                QTextList * cppResult = cppSelf->QTextCursor::createList(cpp_arg0);
                pyResult = Shiboken::Converter<QTextList * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // createList(QTextListFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextListFormat* cpp_arg0 = Shiboken::Converter<QTextListFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // createList(QTextListFormat)
                QTextList * cppResult = cppSelf->QTextCursor::createList(*cpp_arg0);
                pyResult = Shiboken::Converter<QTextList * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCursorFunc_createList_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextListFormat.Style", "PySide.QtGui.QTextListFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.createList", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_currentFrame(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentFrame()const
            QTextFrame * cppResult = cppSelf->QTextCursor::currentFrame();
            pyResult = Shiboken::Converter<QTextFrame * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_currentList(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentList()const
            QTextList * cppResult = cppSelf->QTextCursor::currentList();
            pyResult = Shiboken::Converter<QTextList * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_currentTable(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentTable()const
            QTextTable * cppResult = cppSelf->QTextCursor::currentTable();
            pyResult = Shiboken::Converter<QTextTable * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_deleteChar(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deleteChar()
            cppSelf->QTextCursor::deleteChar();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextCursorFunc_deletePreviousChar(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deletePreviousChar()
            cppSelf->QTextCursor::deletePreviousChar();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextCursorFunc_document(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // document()const
            QTextDocument * cppResult = cppSelf->QTextCursor::document();
            pyResult = Shiboken::Converter<QTextDocument * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_endEditBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endEditBlock()
            cppSelf->QTextCursor::endEditBlock();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextCursorFunc_hasComplexSelection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasComplexSelection()const
            bool cppResult = cppSelf->QTextCursor::hasComplexSelection();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_hasSelection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasSelection()const
            bool cppResult = cppSelf->QTextCursor::hasSelection();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_insertBlock(PyObject* self, PyObject* args)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertBlock", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertBlock()
    // 1: insertBlock(QTextBlockFormat)
    // 2: insertBlock(QTextBlockFormat,QTextCharFormat)
    if (numArgs == 0) {
        overloadId = 0; // insertBlock()
    } else if (Shiboken::Converter<const QTextBlockFormat & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // insertBlock(QTextBlockFormat)
        } else if (numArgs == 2 && Shiboken::Converter<const QTextCharFormat & >::isConvertible(pyargs[1])) {
            overloadId = 2; // insertBlock(QTextBlockFormat,QTextCharFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertBlock_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertBlock()
            {

                if(!PyErr_Occurred()) {
                // insertBlock()
                cppSelf->QTextCursor::insertBlock();
                }
                break;
            }
            case 1: // insertBlock(QTextBlockFormat)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTextBlockFormat* cpp_arg0 = Shiboken::Converter<QTextBlockFormat* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // insertBlock(QTextBlockFormat)
                cppSelf->QTextCursor::insertBlock(*cpp_arg0);
                }
                break;
            }
            case 2: // insertBlock(QTextBlockFormat,QTextCharFormat)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTextBlockFormat* cpp_arg0 = Shiboken::Converter<QTextBlockFormat* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextCharFormat* cpp_arg1 = Shiboken::Converter<QTextCharFormat* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // insertBlock(QTextBlockFormat,QTextCharFormat)
                cppSelf->QTextCursor::insertBlock(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_insertBlock_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextBlockFormat", "PySide.QtGui.QTextBlockFormat, PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertBlock", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_insertFragment(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertFragment(QTextDocumentFragment)
    if (Shiboken::Converter<const QTextDocumentFragment & >::isConvertible(arg)) {
        overloadId = 0; // insertFragment(QTextDocumentFragment)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertFragment_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextDocumentFragment* cpp_arg0 = Shiboken::Converter<QTextDocumentFragment* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // insertFragment(QTextDocumentFragment)
            cppSelf->QTextCursor::insertFragment(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_insertFragment_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocumentFragment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertFragment", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_insertFrame(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertFrame(QTextFrameFormat)
    if (Shiboken::Converter<const QTextFrameFormat & >::isConvertible(arg)) {
        overloadId = 0; // insertFrame(QTextFrameFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertFrame_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextFrameFormat* cpp_arg0 = Shiboken::Converter<QTextFrameFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // insertFrame(QTextFrameFormat)
            QTextFrame * cppResult = cppSelf->QTextCursor::insertFrame(*cpp_arg0);
            pyResult = Shiboken::Converter<QTextFrame * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCursorFunc_insertFrame_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrameFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertFrame", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_insertHtml(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertHtml(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // insertHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertHtml_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // insertHtml(QString)
            cppSelf->QTextCursor::insertHtml(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_insertHtml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertHtml", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_insertImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "name" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.insertImage(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.insertImage(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.insertImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:insertImage", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertImage(QImage,QString)
    // 1: insertImage(QString)
    // 2: insertImage(QTextImageFormat)
    // 3: insertImage(QTextImageFormat,QTextFrameFormat::Position)
    if (Shiboken::Converter<const QTextImageFormat & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // insertImage(QTextImageFormat)
        } else if (numArgs == 2 && Shiboken::Converter<QTextFrameFormat::Position >::isConvertible(pyargs[1])) {
            overloadId = 3; // insertImage(QTextImageFormat,QTextFrameFormat::Position)
        }
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // insertImage(QString)
    } else if (Shiboken::Converter<const QImage & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // insertImage(QImage,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertImage(QImage,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertImage_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertImage(QImage,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "name");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "name";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.insertImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QImage* cpp_arg0 = Shiboken::Converter<QImage* >::toCpp(pyargs[0]);
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

                if(!PyErr_Occurred()) {
                // insertImage(QImage,QString)
                cppSelf->QTextCursor::insertImage(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // insertImage(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // insertImage(QString)
                cppSelf->QTextCursor::insertImage(cpp_arg0);
                }
                break;
            }
            case 2: // insertImage(QTextImageFormat)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTextImageFormat* cpp_arg0 = Shiboken::Converter<QTextImageFormat* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // insertImage(QTextImageFormat)
                cppSelf->QTextCursor::insertImage(*cpp_arg0);
                }
                break;
            }
            case 3: // insertImage(QTextImageFormat,QTextFrameFormat::Position)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTextImageFormat* cpp_arg0 = Shiboken::Converter<QTextImageFormat* >::toCpp(pyargs[0]);
                QTextFrameFormat::Position cpp_arg1 = Shiboken::Converter<QTextFrameFormat::Position >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // insertImage(QTextImageFormat,QTextFrameFormat::Position)
                cppSelf->QTextCursor::insertImage(*cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_insertImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, QString = QString()", "QString", "PySide.QtGui.QTextImageFormat", "PySide.QtGui.QTextImageFormat, PySide.QtGui.QTextFrameFormat.Position", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertImage", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_insertList(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertList(QTextListFormat::Style)
    // 1: insertList(QTextListFormat)
    if (Shiboken::Converter<const QTextListFormat & >::isConvertible(arg)) {
        overloadId = 1; // insertList(QTextListFormat)
    } else if (Shiboken::Converter<QTextListFormat::Style >::isConvertible(arg)) {
        overloadId = 0; // insertList(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertList_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertList(QTextListFormat::Style)
            {
                QTextListFormat::Style cpp_arg0 = Shiboken::Converter<QTextListFormat::Style >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // insertList(QTextListFormat::Style)
                QTextList * cppResult = cppSelf->QTextCursor::insertList(cpp_arg0);
                pyResult = Shiboken::Converter<QTextList * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // insertList(QTextListFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextListFormat* cpp_arg0 = Shiboken::Converter<QTextListFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // insertList(QTextListFormat)
                QTextList * cppResult = cppSelf->QTextCursor::insertList(*cpp_arg0);
                pyResult = Shiboken::Converter<QTextList * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCursorFunc_insertList_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextListFormat.Style", "PySide.QtGui.QTextListFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.insertList", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_insertTable(PyObject* self, PyObject* args)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertTable", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insertTable(int,int)
    // 1: insertTable(int,int,QTextTableFormat)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // insertTable(int,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QTextTableFormat & >::isConvertible(pyargs[2])) {
            overloadId = 1; // insertTable(int,int,QTextTableFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertTable_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertTable(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // insertTable(int,int)
                QTextTable * cppResult = cppSelf->QTextCursor::insertTable(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QTextTable * >::toPython(cppResult);

                // Ownership transferences.
                }
                break;
            }
            case 1: // insertTable(int,int,QTextTableFormat)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QTextTableFormat* cpp_arg2 = Shiboken::Converter<QTextTableFormat* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // insertTable(int,int,QTextTableFormat)
                QTextTable * cppResult = cppSelf->QTextCursor::insertTable(cpp_arg0, cpp_arg1, *cpp_arg2);
                pyResult = Shiboken::Converter<QTextTable * >::toPython(cppResult);

                // Ownership transferences.
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCursorFunc_insertTable_TypeError:
        const char* overloads[] = {"int, int", "int, int, PySide.QtGui.QTextTableFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertTable", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_insertText(PyObject* self, PyObject* args)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertText", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertText(QString)
    // 1: insertText(QString,QTextCharFormat)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // insertText(QString)
        } else if (numArgs == 2 && Shiboken::Converter<const QTextCharFormat & >::isConvertible(pyargs[1])) {
            overloadId = 1; // insertText(QString,QTextCharFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_insertText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertText(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // insertText(QString)
                cppSelf->QTextCursor::insertText(cpp_arg0);
                }
                break;
            }
            case 1: // insertText(QString,QTextCharFormat)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextCharFormat* cpp_arg1 = Shiboken::Converter<QTextCharFormat* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // insertText(QString,QTextCharFormat)
                cppSelf->QTextCursor::insertText(cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_insertText_TypeError:
        const char* overloads[] = {"QString", "QString, PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.insertText", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_isCopyOf(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isCopyOf(QTextCursor)const
    if (Shiboken::Converter<const QTextCursor & >::isConvertible(arg)) {
        overloadId = 0; // isCopyOf(QTextCursor)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_isCopyOf_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCursor* cpp_arg0 = Shiboken::Converter<QTextCursor* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isCopyOf(QTextCursor)const
            bool cppResult = cppSelf->QTextCursor::isCopyOf(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCursorFunc_isCopyOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.isCopyOf", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_isNull(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QTextCursor::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_joinPreviousEditBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // joinPreviousEditBlock()
            cppSelf->QTextCursor::joinPreviousEditBlock();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextCursorFunc_keepPositionOnInsert(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keepPositionOnInsert()const
            bool cppResult = cppSelf->QTextCursor::keepPositionOnInsert();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_mergeBlockCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeBlockCharFormat(QTextCharFormat)
    if (Shiboken::Converter<const QTextCharFormat & >::isConvertible(arg)) {
        overloadId = 0; // mergeBlockCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_mergeBlockCharFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCharFormat* cpp_arg0 = Shiboken::Converter<QTextCharFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mergeBlockCharFormat(QTextCharFormat)
            cppSelf->QTextCursor::mergeBlockCharFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_mergeBlockCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.mergeBlockCharFormat", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_mergeBlockFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeBlockFormat(QTextBlockFormat)
    if (Shiboken::Converter<const QTextBlockFormat & >::isConvertible(arg)) {
        overloadId = 0; // mergeBlockFormat(QTextBlockFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_mergeBlockFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextBlockFormat* cpp_arg0 = Shiboken::Converter<QTextBlockFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mergeBlockFormat(QTextBlockFormat)
            cppSelf->QTextCursor::mergeBlockFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_mergeBlockFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlockFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.mergeBlockFormat", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_mergeCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeCharFormat(QTextCharFormat)
    if (Shiboken::Converter<const QTextCharFormat & >::isConvertible(arg)) {
        overloadId = 0; // mergeCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_mergeCharFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCharFormat* cpp_arg0 = Shiboken::Converter<QTextCharFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mergeCharFormat(QTextCharFormat)
            cppSelf->QTextCursor::mergeCharFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_mergeCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.mergeCharFormat", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_movePosition(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "arg__2", "n" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.movePosition(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.movePosition(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.movePosition(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:movePosition", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
    if (Shiboken::Converter<QTextCursor::MoveOperation >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
        } else if (Shiboken::Converter<QTextCursor::MoveMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_movePosition_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "arg__2");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "arg__2";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "n");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "n";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.movePosition(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QTextCursor::MoveOperation cpp_arg0 = Shiboken::Converter<QTextCursor::MoveOperation >::toCpp(pyargs[0]);
            QTextCursor::MoveMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QTextCursor::MoveMode >::toCpp(pyargs[1]) : QTextCursor::MoveAnchor;
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 1;

            if(!PyErr_Occurred()) {
            // movePosition(QTextCursor::MoveOperation,QTextCursor::MoveMode,int)
            bool cppResult = cppSelf->QTextCursor::movePosition(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextCursorFunc_movePosition_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor.MoveOperation, PySide.QtGui.QTextCursor.MoveMode = MoveAnchor, int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.movePosition", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_position(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // position()const
            int cppResult = cppSelf->QTextCursor::position();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_positionInBlock(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // positionInBlock()const
            int cppResult = cppSelf->QTextCursor::positionInBlock();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_removeSelectedText(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // removeSelectedText()
            cppSelf->QTextCursor::removeSelectedText();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextCursorFunc_select(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: select(QTextCursor::SelectionType)
    if (Shiboken::Converter<QTextCursor::SelectionType >::isConvertible(arg)) {
        overloadId = 0; // select(QTextCursor::SelectionType)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_select_TypeError;

    // Call function/method
    {
        {
            QTextCursor::SelectionType cpp_arg0 = Shiboken::Converter<QTextCursor::SelectionType >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // select(QTextCursor::SelectionType)
            cppSelf->QTextCursor::select(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_select_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor.SelectionType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.select", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_selectedText(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectedText()const
            QString cppResult = cppSelf->QTextCursor::selectedText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_selection(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selection()const
            QTextDocumentFragment cppResult = cppSelf->QTextCursor::selection();
            pyResult = Shiboken::Converter<QTextDocumentFragment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_selectionEnd(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectionEnd()const
            int cppResult = cppSelf->QTextCursor::selectionEnd();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_selectionStart(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectionStart()const
            int cppResult = cppSelf->QTextCursor::selectionStart();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_setBlockCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlockCharFormat(QTextCharFormat)
    if (Shiboken::Converter<const QTextCharFormat & >::isConvertible(arg)) {
        overloadId = 0; // setBlockCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_setBlockCharFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCharFormat* cpp_arg0 = Shiboken::Converter<QTextCharFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBlockCharFormat(QTextCharFormat)
            cppSelf->QTextCursor::setBlockCharFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_setBlockCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setBlockCharFormat", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_setBlockFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlockFormat(QTextBlockFormat)
    if (Shiboken::Converter<const QTextBlockFormat & >::isConvertible(arg)) {
        overloadId = 0; // setBlockFormat(QTextBlockFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_setBlockFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextBlockFormat* cpp_arg0 = Shiboken::Converter<QTextBlockFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBlockFormat(QTextBlockFormat)
            cppSelf->QTextCursor::setBlockFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_setBlockFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextBlockFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setBlockFormat", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_setCharFormat(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCharFormat(QTextCharFormat)
    if (Shiboken::Converter<const QTextCharFormat & >::isConvertible(arg)) {
        overloadId = 0; // setCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_setCharFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCharFormat* cpp_arg0 = Shiboken::Converter<QTextCharFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCharFormat(QTextCharFormat)
            cppSelf->QTextCursor::setCharFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_setCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setCharFormat", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_setKeepPositionOnInsert(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKeepPositionOnInsert(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setKeepPositionOnInsert(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_setKeepPositionOnInsert_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setKeepPositionOnInsert(bool)
            cppSelf->QTextCursor::setKeepPositionOnInsert(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_setKeepPositionOnInsert_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setKeepPositionOnInsert", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_setPosition(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.setPosition(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.setPosition(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextCursor.setPosition(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setPosition", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPosition(int,QTextCursor::MoveMode)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setPosition(int,QTextCursor::MoveMode)
        } else if (Shiboken::Converter<QTextCursor::MoveMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setPosition(int,QTextCursor::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_setPosition_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextCursor.setPosition(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QTextCursor::MoveMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QTextCursor::MoveMode >::toCpp(pyargs[1]) : QTextCursor::MoveAnchor;

            if(!PyErr_Occurred()) {
            // setPosition(int,QTextCursor::MoveMode)
            cppSelf->QTextCursor::setPosition(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_setPosition_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTextCursor.MoveMode = MoveAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextCursor.setPosition", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_setVerticalMovementX(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalMovementX(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVerticalMovementX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_setVerticalMovementX_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVerticalMovementX(int)
            cppSelf->QTextCursor::setVerticalMovementX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_setVerticalMovementX_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setVerticalMovementX", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_setVisualNavigation(PyObject* self, PyObject* arg)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisualNavigation(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisualNavigation(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextCursorFunc_setVisualNavigation_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisualNavigation(bool)
            cppSelf->QTextCursor::setVisualNavigation(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextCursorFunc_setVisualNavigation_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextCursor.setVisualNavigation", overloads);
        return 0;
}

static PyObject* SbkQTextCursorFunc_verticalMovementX(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // verticalMovementX()const
            int cppResult = cppSelf->QTextCursor::verticalMovementX();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextCursorFunc_visualNavigation(PyObject* self)
{
    QTextCursor* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextCursor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // visualNavigation()const
            bool cppResult = cppSelf->QTextCursor::visualNavigation();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextCursor_methods[] = {
    {"anchor", (PyCFunction)SbkQTextCursorFunc_anchor, METH_NOARGS},
    {"atBlockEnd", (PyCFunction)SbkQTextCursorFunc_atBlockEnd, METH_NOARGS},
    {"atBlockStart", (PyCFunction)SbkQTextCursorFunc_atBlockStart, METH_NOARGS},
    {"atEnd", (PyCFunction)SbkQTextCursorFunc_atEnd, METH_NOARGS},
    {"atStart", (PyCFunction)SbkQTextCursorFunc_atStart, METH_NOARGS},
    {"beginEditBlock", (PyCFunction)SbkQTextCursorFunc_beginEditBlock, METH_NOARGS},
    {"block", (PyCFunction)SbkQTextCursorFunc_block, METH_NOARGS},
    {"blockCharFormat", (PyCFunction)SbkQTextCursorFunc_blockCharFormat, METH_NOARGS},
    {"blockFormat", (PyCFunction)SbkQTextCursorFunc_blockFormat, METH_NOARGS},
    {"blockNumber", (PyCFunction)SbkQTextCursorFunc_blockNumber, METH_NOARGS},
    {"charFormat", (PyCFunction)SbkQTextCursorFunc_charFormat, METH_NOARGS},
    {"clearSelection", (PyCFunction)SbkQTextCursorFunc_clearSelection, METH_NOARGS},
    {"columnNumber", (PyCFunction)SbkQTextCursorFunc_columnNumber, METH_NOARGS},
    {"createList", (PyCFunction)SbkQTextCursorFunc_createList, METH_O},
    {"currentFrame", (PyCFunction)SbkQTextCursorFunc_currentFrame, METH_NOARGS},
    {"currentList", (PyCFunction)SbkQTextCursorFunc_currentList, METH_NOARGS},
    {"currentTable", (PyCFunction)SbkQTextCursorFunc_currentTable, METH_NOARGS},
    {"deleteChar", (PyCFunction)SbkQTextCursorFunc_deleteChar, METH_NOARGS},
    {"deletePreviousChar", (PyCFunction)SbkQTextCursorFunc_deletePreviousChar, METH_NOARGS},
    {"document", (PyCFunction)SbkQTextCursorFunc_document, METH_NOARGS},
    {"endEditBlock", (PyCFunction)SbkQTextCursorFunc_endEditBlock, METH_NOARGS},
    {"hasComplexSelection", (PyCFunction)SbkQTextCursorFunc_hasComplexSelection, METH_NOARGS},
    {"hasSelection", (PyCFunction)SbkQTextCursorFunc_hasSelection, METH_NOARGS},
    {"insertBlock", (PyCFunction)SbkQTextCursorFunc_insertBlock, METH_VARARGS},
    {"insertFragment", (PyCFunction)SbkQTextCursorFunc_insertFragment, METH_O},
    {"insertFrame", (PyCFunction)SbkQTextCursorFunc_insertFrame, METH_O},
    {"insertHtml", (PyCFunction)SbkQTextCursorFunc_insertHtml, METH_O},
    {"insertImage", (PyCFunction)SbkQTextCursorFunc_insertImage, METH_VARARGS|METH_KEYWORDS},
    {"insertList", (PyCFunction)SbkQTextCursorFunc_insertList, METH_O},
    {"insertTable", (PyCFunction)SbkQTextCursorFunc_insertTable, METH_VARARGS},
    {"insertText", (PyCFunction)SbkQTextCursorFunc_insertText, METH_VARARGS},
    {"isCopyOf", (PyCFunction)SbkQTextCursorFunc_isCopyOf, METH_O},
    {"isNull", (PyCFunction)SbkQTextCursorFunc_isNull, METH_NOARGS},
    {"joinPreviousEditBlock", (PyCFunction)SbkQTextCursorFunc_joinPreviousEditBlock, METH_NOARGS},
    {"keepPositionOnInsert", (PyCFunction)SbkQTextCursorFunc_keepPositionOnInsert, METH_NOARGS},
    {"mergeBlockCharFormat", (PyCFunction)SbkQTextCursorFunc_mergeBlockCharFormat, METH_O},
    {"mergeBlockFormat", (PyCFunction)SbkQTextCursorFunc_mergeBlockFormat, METH_O},
    {"mergeCharFormat", (PyCFunction)SbkQTextCursorFunc_mergeCharFormat, METH_O},
    {"movePosition", (PyCFunction)SbkQTextCursorFunc_movePosition, METH_VARARGS|METH_KEYWORDS},
    {"position", (PyCFunction)SbkQTextCursorFunc_position, METH_NOARGS},
    {"positionInBlock", (PyCFunction)SbkQTextCursorFunc_positionInBlock, METH_NOARGS},
    {"removeSelectedText", (PyCFunction)SbkQTextCursorFunc_removeSelectedText, METH_NOARGS},
    {"select", (PyCFunction)SbkQTextCursorFunc_select, METH_O},
    {"selectedText", (PyCFunction)SbkQTextCursorFunc_selectedText, METH_NOARGS},
    {"selection", (PyCFunction)SbkQTextCursorFunc_selection, METH_NOARGS},
    {"selectionEnd", (PyCFunction)SbkQTextCursorFunc_selectionEnd, METH_NOARGS},
    {"selectionStart", (PyCFunction)SbkQTextCursorFunc_selectionStart, METH_NOARGS},
    {"setBlockCharFormat", (PyCFunction)SbkQTextCursorFunc_setBlockCharFormat, METH_O},
    {"setBlockFormat", (PyCFunction)SbkQTextCursorFunc_setBlockFormat, METH_O},
    {"setCharFormat", (PyCFunction)SbkQTextCursorFunc_setCharFormat, METH_O},
    {"setKeepPositionOnInsert", (PyCFunction)SbkQTextCursorFunc_setKeepPositionOnInsert, METH_O},
    {"setPosition", (PyCFunction)SbkQTextCursorFunc_setPosition, METH_VARARGS|METH_KEYWORDS},
    {"setVerticalMovementX", (PyCFunction)SbkQTextCursorFunc_setVerticalMovementX, METH_O},
    {"setVisualNavigation", (PyCFunction)SbkQTextCursorFunc_setVisualNavigation, METH_O},
    {"verticalMovementX", (PyCFunction)SbkQTextCursorFunc_verticalMovementX, METH_NOARGS},
    {"visualNavigation", (PyCFunction)SbkQTextCursorFunc_visualNavigation, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQTextCursor_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QTextCursor& cpp_self = *Shiboken::Converter<QTextCursor* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QTextCursor & >::isConvertible(other)) {
                // operator!=(const QTextCursor & rhs) const
                QTextCursor* cpp_other = Shiboken::Converter<QTextCursor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextCursor  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQTextCursor_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QTextCursor & >::isConvertible(other)) {
                // operator<(const QTextCursor & rhs) const
                QTextCursor* cpp_other = Shiboken::Converter<QTextCursor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextCursor  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else goto SbkQTextCursor_RichComparison_TypeError;

            break;
        case Py_LE:
            if (Shiboken::Converter<const QTextCursor & >::isConvertible(other)) {
                // operator<=(const QTextCursor & rhs) const
                QTextCursor* cpp_other = Shiboken::Converter<QTextCursor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextCursor  >::toCpp(other) : (cpp_self <= (*cpp_other));
            } else goto SbkQTextCursor_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QTextCursor & >::isConvertible(other)) {
                // operator==(const QTextCursor & rhs) const
                QTextCursor* cpp_other = Shiboken::Converter<QTextCursor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextCursor  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQTextCursor_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter<const QTextCursor & >::isConvertible(other)) {
                // operator>(const QTextCursor & rhs) const
                QTextCursor* cpp_other = Shiboken::Converter<QTextCursor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextCursor  >::toCpp(other) : (cpp_self > (*cpp_other));
            } else goto SbkQTextCursor_RichComparison_TypeError;

            break;
        case Py_GE:
            if (Shiboken::Converter<const QTextCursor & >::isConvertible(other)) {
                // operator>=(const QTextCursor & rhs) const
                QTextCursor* cpp_other = Shiboken::Converter<QTextCursor* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextCursor  >::toCpp(other) : (cpp_self >= (*cpp_other));
            } else goto SbkQTextCursor_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQTextCursor_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextCursor_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextCursor",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQTextCursor_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextCursor_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextCursor_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextCursor >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextCursor",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QTextCursor_MoveMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextCursor_MoveMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextCursor_MoveMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MoveMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextCursor_MoveMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextCursor_MoveMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextCursor_MoveMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QTextCursor_MoveOperation_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextCursor_MoveOperation_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextCursor_MoveOperation_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MoveOperation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextCursor_MoveOperation_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextCursor_MoveOperation_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextCursor_MoveOperation_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QTextCursor_SelectionType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextCursor_SelectionType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextCursor_SelectionType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SelectionType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextCursor_SelectionType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextCursor_SelectionType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextCursor_SelectionType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextCursor(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextCursor_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextCursor_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextCursor_Type));
    PyModule_AddObject(module, "QTextCursor",
        ((PyObject*)&SbkQTextCursor_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: MoveMode
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_MOVEMODE_IDX] = &SbkPySide_QtGui_QTextCursor_MoveMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextCursor_MoveMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextCursor_MoveMode_Type);
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
            "MoveMode",((PyObject*)&SbkPySide_QtGui_QTextCursor_MoveMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveMode_Type,
        (long) QTextCursor::MoveAnchor, "MoveAnchor");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "MoveAnchor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveMode_Type.tp_dict,
        "MoveAnchor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveMode_Type,
        (long) QTextCursor::KeepAnchor, "KeepAnchor");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "KeepAnchor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveMode_Type.tp_dict,
        "KeepAnchor", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCursor::MoveMode");

    // init enum class: MoveOperation
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_MOVEOPERATION_IDX] = &SbkPySide_QtGui_QTextCursor_MoveOperation_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextCursor_MoveOperation_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type);
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
            "MoveOperation",((PyObject*)&SbkPySide_QtGui_QTextCursor_MoveOperation_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::NoMove, "NoMove");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "NoMove", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "NoMove", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::Start, "Start");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "Start", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "Start", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::Up, "Up");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "Up", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "Up", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::StartOfLine, "StartOfLine");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "StartOfLine", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "StartOfLine", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::StartOfBlock, "StartOfBlock");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "StartOfBlock", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "StartOfBlock", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::StartOfWord, "StartOfWord");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "StartOfWord", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "StartOfWord", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::PreviousBlock, "PreviousBlock");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "PreviousBlock", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "PreviousBlock", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::PreviousCharacter, "PreviousCharacter");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "PreviousCharacter", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "PreviousCharacter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::PreviousWord, "PreviousWord");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "PreviousWord", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "PreviousWord", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::Left, "Left");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "Left", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "Left", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::WordLeft, "WordLeft");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "WordLeft", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "WordLeft", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::End, "End");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "End", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "End", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::Down, "Down");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "Down", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "Down", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::EndOfLine, "EndOfLine");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "EndOfLine", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "EndOfLine", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::EndOfWord, "EndOfWord");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "EndOfWord", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "EndOfWord", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::EndOfBlock, "EndOfBlock");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "EndOfBlock", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "EndOfBlock", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::NextBlock, "NextBlock");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "NextBlock", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "NextBlock", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::NextCharacter, "NextCharacter");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "NextCharacter", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "NextCharacter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::NextWord, "NextWord");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "NextWord", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "NextWord", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::Right, "Right");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "Right", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "Right", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::WordRight, "WordRight");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "WordRight", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "WordRight", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::NextCell, "NextCell");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "NextCell", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "NextCell", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::PreviousCell, "PreviousCell");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "PreviousCell", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "PreviousCell", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::NextRow, "NextRow");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "NextRow", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "NextRow", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_MoveOperation_Type,
        (long) QTextCursor::PreviousRow, "PreviousRow");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "PreviousRow", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_MoveOperation_Type.tp_dict,
        "PreviousRow", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCursor::MoveOperation");

    // init enum class: SelectionType
    SbkPySide_QtGuiTypes[SBK_QTEXTCURSOR_SELECTIONTYPE_IDX] = &SbkPySide_QtGui_QTextCursor_SelectionType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextCursor_SelectionType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextCursor_SelectionType_Type);
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
            "SelectionType",((PyObject*)&SbkPySide_QtGui_QTextCursor_SelectionType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_SelectionType_Type,
        (long) QTextCursor::WordUnderCursor, "WordUnderCursor");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "WordUnderCursor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType_Type.tp_dict,
        "WordUnderCursor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_SelectionType_Type,
        (long) QTextCursor::LineUnderCursor, "LineUnderCursor");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "LineUnderCursor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType_Type.tp_dict,
        "LineUnderCursor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_SelectionType_Type,
        (long) QTextCursor::BlockUnderCursor, "BlockUnderCursor");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "BlockUnderCursor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType_Type.tp_dict,
        "BlockUnderCursor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextCursor_SelectionType_Type,
        (long) QTextCursor::Document, "Document");
    PyDict_SetItemString(SbkQTextCursor_Type.super.ht_type.tp_dict,
        "Document", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextCursor_SelectionType_Type.tp_dict,
        "Document", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextCursor::SelectionType");


    Shiboken::TypeResolver::createValueTypeResolver<QTextCursor >("QTextCursor");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextCursor >("QTextCursor*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextCursor >(typeid(QTextCursor).name());
    PySide::initQtMetaType<QTextCursor >();
}

