/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qtextdocument_wrapper.h"

// Extra includes
#include <QList>
#include <QTextBlock>
#include <QTextCursor>
#include <QTextFormat>
#include <QVector>
#include <qabstracttextdocumentlayout.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qfont.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qprinter.h>
#include <qrect.h>
#include <qregexp.h>
#include <qsize.h>
#include <qtextcursor.h>
#include <qtextdocument.h>
#include <qtextformat.h>
#include <qtextobject.h>
#include <qtextoption.h>
#include <qthread.h>
#include <qurl.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QTextDocumentWrapper::QTextDocumentWrapper(QObject * parent) : QTextDocument(parent), m_metaObject(0) {
    // ... middle
}

QTextDocumentWrapper::QTextDocumentWrapper(const QString & text, QObject * parent) : QTextDocument(text, parent), m_metaObject(0) {
    // ... middle
}

void QTextDocumentWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextDocumentWrapper::clear()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "clear"));
    if (py_override.isNull()) {
        return this->QTextDocument::clear();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextDocumentWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QTextObject * QTextDocumentWrapper::createObject(const QTextFormat & f)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createObject"));
    if (py_override.isNull()) {
        return this->QTextDocument::createObject(f);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QTextFormat & >::toPython(f)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QTextObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.createObject", SbkType<QTextObject * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QTextObject * cppResult(Shiboken::Converter<QTextObject * >::toCpp(pyResult));
    return cppResult;
}

void QTextDocumentWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextDocumentWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QTextDocumentWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QTextDocumentWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QVariant QTextDocumentWrapper::loadResource(int type, const QUrl & name)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "loadResource"));
    if (py_override.isNull()) {
        return this->QTextDocument::loadResource(type, name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iN)",
        type,
        Shiboken::Converter<const QUrl & >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.loadResource", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QTextDocumentWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QTextDocumentWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QTextDocument::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QTextDocumentWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTextDocument::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTextDocumentWrapper::~QTextDocumentWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextDocument_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextDocument >()))
        return -1;

    QTextDocumentWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QTextDocument", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTextDocument(QObject*)
    // 1: QTextDocument(QString,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QTextDocument(QObject*)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTextDocument(QString,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QTextDocument(QString,QObject*)
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QTextDocument(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocument_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextDocument(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QTextDocument(QObject*)
                cptr = new QTextDocumentWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QTextDocument(QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QTextDocument(QString,QObject*)
                cptr = new QTextDocumentWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextDocument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextDocument_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQTextDocument_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "QString, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument", overloads);
        return -1;
}

static PyObject* SbkQTextDocumentFunc_addResource(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addResource", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addResource(int,QUrl,QVariant)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[2])) {
        overloadId = 0; // addResource(int,QUrl,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_addResource_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
            QUrl* cpp_arg1 = Shiboken::Converter<QUrl* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);
            QVariant cpp_arg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // addResource(int,QUrl,QVariant)
            cppSelf->QTextDocument::addResource(cpp_arg0, *cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_addResource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.addResource", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_adjustSize(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // adjustSize()
            cppSelf->QTextDocument::adjustSize();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextDocumentFunc_allFormats(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // allFormats()const
            QVector<QTextFormat > cppResult = cppSelf->QTextDocument::allFormats();
            pyResult = Shiboken::Converter<QVector<QTextFormat > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_availableRedoSteps(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // availableRedoSteps()const
            int cppResult = cppSelf->QTextDocument::availableRedoSteps();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_availableUndoSteps(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // availableUndoSteps()const
            int cppResult = cppSelf->QTextDocument::availableUndoSteps();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_begin(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // begin()const
            QTextBlock cppResult = cppSelf->QTextDocument::begin();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_blockCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // blockCount()const
            int cppResult = cppSelf->QTextDocument::blockCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_characterAt(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: characterAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // characterAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_characterAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // characterAt(int)const
            QChar cppResult = cppSelf->QTextDocument::characterAt(cpp_arg0);
            pyResult = Shiboken::Converter<QChar >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_characterAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.characterAt", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_characterCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // characterCount()const
            int cppResult = cppSelf->QTextDocument::characterCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_clear(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QTextDocument::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextDocumentFunc_clearUndoRedoStacks(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "historyToClear" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.clearUndoRedoStacks(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.clearUndoRedoStacks(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:clearUndoRedoStacks", &arg))
        return 0;


    // Overloaded function decisor
    // 0: clearUndoRedoStacks(QTextDocument::Stacks)
    if (numArgs == 0) {
        overloadId = 0; // clearUndoRedoStacks(QTextDocument::Stacks)
    } else if (Shiboken::Converter<QTextDocument::Stacks >::isConvertible(arg)) {
        overloadId = 0; // clearUndoRedoStacks(QTextDocument::Stacks)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_clearUndoRedoStacks_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "historyToClear");
                if (value) {
                    if (arg)
                        errorArgName = "historyToClear";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.clearUndoRedoStacks(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QTextDocument::Stacks cpp_arg0 = arg ? Shiboken::Converter<QTextDocument::Stacks >::toCpp(arg) : QTextDocument::UndoAndRedoStacks;

            if(!PyErr_Occurred()) {
            // clearUndoRedoStacks(QTextDocument::Stacks)
            cppSelf->QTextDocument::clearUndoRedoStacks(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_clearUndoRedoStacks_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument.Stacks = UndoAndRedoStacks", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.clearUndoRedoStacks", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_clone(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.clone(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.clone(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:clone", &arg))
        return 0;


    // Overloaded function decisor
    // 0: clone(QObject*)const
    if (numArgs == 0) {
        overloadId = 0; // clone(QObject*)const
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // clone(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_clone_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.clone(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // clone(QObject*)const
            QTextDocument * cppResult = cppSelf->QTextDocument::clone(cpp_arg0);
            pyResult = Shiboken::Converter<QTextDocument * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_clone_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.clone", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_createObject(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createObject(QTextFormat)
    if (Shiboken::Converter<const QTextFormat & >::isConvertible(arg)) {
        overloadId = 0; // createObject(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_createObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextFormat* cpp_arg0 = Shiboken::Converter<QTextFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createObject(QTextFormat)
            QTextObject * cppResult = cppSelf->QTextDocument::createObject(*cpp_arg0);
            pyResult = Shiboken::Converter<QTextObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_createObject_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.createObject", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_defaultFont(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultFont()const
            QFont cppResult = cppSelf->QTextDocument::defaultFont();
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_defaultStyleSheet(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultStyleSheet()const
            QString cppResult = cppSelf->QTextDocument::defaultStyleSheet();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_defaultTextOption(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultTextOption()const
            QTextOption cppResult = cppSelf->QTextDocument::defaultTextOption();
            pyResult = Shiboken::Converter<QTextOption >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_documentLayout(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentLayout()const
            QAbstractTextDocumentLayout * cppResult = cppSelf->QTextDocument::documentLayout();
            pyResult = Shiboken::Converter<QAbstractTextDocumentLayout * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_documentMargin(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentMargin()const
            qreal cppResult = cppSelf->QTextDocument::documentMargin();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_drawContents(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.drawContents(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.drawContents(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.drawContents(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:drawContents", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawContents(QPainter*,QRectF)
    if (Shiboken::Converter<QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // drawContents(QPainter*,QRectF)
        } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            overloadId = 0; // drawContents(QPainter*,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_drawContents_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "rect");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "rect";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.drawContents(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF cpp_arg1_tmp = QRectF();
            QRectF* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // drawContents(QPainter*,QRectF)
            cppSelf->QTextDocument::drawContents(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_drawContents_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF = QRectF()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.drawContents", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_end(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // end()const
            QTextBlock cppResult = cppSelf->QTextDocument::end();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_find(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from", "options" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:find", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
    // 1: find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
    // 2: find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
    // 3: find(QString,int,QFlags<QTextDocument::FindFlag>)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            }
        } else if (Shiboken::Converter<const QTextCursor & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 2; // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            }
        }
    } else if (Shiboken::Converter<const QRegExp & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
            }
        } else if (Shiboken::Converter<const QTextCursor & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 0; // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_find_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRegExp* cpp_arg0 = Shiboken::Converter<QRegExp* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextCursor* cpp_arg1 = Shiboken::Converter<QTextCursor* >::toCpp(pyargs[1]);
                QFlags<QTextDocument::FindFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = cppSelf->QTextDocument::find(*cpp_arg0, *cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QTextCursor >::toPython(cppResult);
                }
                break;
            }
            case 1: // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRegExp* cpp_arg0 = Shiboken::Converter<QRegExp* >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
                QFlags<QTextDocument::FindFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = cppSelf->QTextDocument::find(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QTextCursor >::toPython(cppResult);
                }
                break;
            }
            case 2: // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextCursor* cpp_arg1 = Shiboken::Converter<QTextCursor* >::toCpp(pyargs[1]);
                QFlags<QTextDocument::FindFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = cppSelf->QTextDocument::find(cpp_arg0, *cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QTextCursor >::toPython(cppResult);
                }
                break;
            }
            case 3: // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
                QFlags<QTextDocument::FindFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                // find(QString,int,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = cppSelf->QTextDocument::find(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QTextCursor >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_find_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp, PySide.QtGui.QTextCursor, PySide.QtGui.QTextDocument.FindFlags = 0", "PySide.QtCore.QRegExp, int = 0, PySide.QtGui.QTextDocument.FindFlags = 0", "QString, PySide.QtGui.QTextCursor, PySide.QtGui.QTextDocument.FindFlags = 0", "QString, int = 0, PySide.QtGui.QTextDocument.FindFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.find", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_findBlock(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findBlock(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // findBlock(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_findBlock_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // findBlock(int)const
            QTextBlock cppResult = cppSelf->QTextDocument::findBlock(cpp_arg0);
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_findBlock_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.findBlock", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_findBlockByLineNumber(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findBlockByLineNumber(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // findBlockByLineNumber(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_findBlockByLineNumber_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // findBlockByLineNumber(int)const
            QTextBlock cppResult = cppSelf->QTextDocument::findBlockByLineNumber(cpp_arg0);
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_findBlockByLineNumber_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.findBlockByLineNumber", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_findBlockByNumber(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findBlockByNumber(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // findBlockByNumber(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_findBlockByNumber_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // findBlockByNumber(int)const
            QTextBlock cppResult = cppSelf->QTextDocument::findBlockByNumber(cpp_arg0);
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_findBlockByNumber_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.findBlockByNumber", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_firstBlock(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // firstBlock()const
            QTextBlock cppResult = cppSelf->QTextDocument::firstBlock();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_frameAt(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: frameAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // frameAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_frameAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // frameAt(int)const
            QTextFrame * cppResult = cppSelf->QTextDocument::frameAt(cpp_arg0);
            pyResult = Shiboken::Converter<QTextFrame * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_frameAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.frameAt", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_idealWidth(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // idealWidth()const
            qreal cppResult = cppSelf->QTextDocument::idealWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_indentWidth(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // indentWidth()const
            qreal cppResult = cppSelf->QTextDocument::indentWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_isEmpty(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QTextDocument::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_isModified(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isModified()const
            bool cppResult = cppSelf->QTextDocument::isModified();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_isRedoAvailable(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRedoAvailable()const
            bool cppResult = cppSelf->QTextDocument::isRedoAvailable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_isUndoAvailable(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isUndoAvailable()const
            bool cppResult = cppSelf->QTextDocument::isUndoAvailable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_isUndoRedoEnabled(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isUndoRedoEnabled()const
            bool cppResult = cppSelf->QTextDocument::isUndoRedoEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_lastBlock(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastBlock()const
            QTextBlock cppResult = cppSelf->QTextDocument::lastBlock();
            pyResult = Shiboken::Converter<QTextBlock >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_lineCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineCount()const
            int cppResult = cppSelf->QTextDocument::lineCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_loadResource(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "loadResource", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: loadResource(int,QUrl)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
        overloadId = 0; // loadResource(int,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_loadResource_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
            QUrl* cpp_arg1 = Shiboken::Converter<QUrl* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // loadResource(int,QUrl)
            QVariant cppResult = cppSelf->QTextDocument::loadResource(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_loadResource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.loadResource", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_markContentsDirty(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "markContentsDirty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: markContentsDirty(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // markContentsDirty(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_markContentsDirty_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // markContentsDirty(int,int)
            cppSelf->QTextDocument::markContentsDirty(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_markContentsDirty_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.markContentsDirty", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_maximumBlockCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumBlockCount()const
            int cppResult = cppSelf->QTextDocument::maximumBlockCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_metaInformation(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metaInformation(QTextDocument::MetaInformation)const
    if (Shiboken::Converter<QTextDocument::MetaInformation >::isConvertible(arg)) {
        overloadId = 0; // metaInformation(QTextDocument::MetaInformation)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_metaInformation_TypeError;

    // Call function/method
    {
        {
            QTextDocument::MetaInformation cpp_arg0 = Shiboken::Converter<QTextDocument::MetaInformation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // metaInformation(QTextDocument::MetaInformation)const
            QString cppResult = cppSelf->QTextDocument::metaInformation(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_metaInformation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument.MetaInformation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.metaInformation", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_object(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: object(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // object(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_object_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // object(int)const
            QTextObject * cppResult = cppSelf->QTextDocument::object(cpp_arg0);
            pyResult = Shiboken::Converter<QTextObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_object_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.object", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_objectForFormat(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectForFormat(QTextFormat)const
    if (Shiboken::Converter<const QTextFormat & >::isConvertible(arg)) {
        overloadId = 0; // objectForFormat(QTextFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_objectForFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextFormat* cpp_arg0 = Shiboken::Converter<QTextFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // objectForFormat(QTextFormat)const
            QTextObject * cppResult = cppSelf->QTextDocument::objectForFormat(*cpp_arg0);
            pyResult = Shiboken::Converter<QTextObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_objectForFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.objectForFormat", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_pageCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pageCount()const
            int cppResult = cppSelf->QTextDocument::pageCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_pageSize(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pageSize()const
            QSizeF cppResult = cppSelf->QTextDocument::pageSize();
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_print_(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: print(QPrinter*)const
    if (Shiboken::Converter<QPrinter * >::isConvertible(arg)) {
        overloadId = 0; // print(QPrinter*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_print__TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPrinter* cpp_arg0 = Shiboken::Converter<QPrinter* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // print(QPrinter*)const
            cppSelf->QTextDocument::print(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_print__TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.print_", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_redo(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // redo()
            cppSelf->QTextDocument::redo();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextDocumentFunc_resource(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resource", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resource(int,QUrl)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
        overloadId = 0; // resource(int,QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_resource_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
            QUrl* cpp_arg1 = Shiboken::Converter<QUrl* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // resource(int,QUrl)const
            QVariant cppResult = cppSelf->QTextDocument::resource(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_resource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.resource", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_revision(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // revision()const
            int cppResult = cppSelf->QTextDocument::revision();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_rootFrame(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rootFrame()const
            QTextFrame * cppResult = cppSelf->QTextDocument::rootFrame();
            pyResult = Shiboken::Converter<QTextFrame * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_setDefaultFont(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setDefaultFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setDefaultFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setDefaultFont(QFont)
            cppSelf->QTextDocument::setDefaultFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setDefaultFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDefaultFont", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setDefaultStyleSheet(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultStyleSheet(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDefaultStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setDefaultStyleSheet_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultStyleSheet(QString)
            cppSelf->QTextDocument::setDefaultStyleSheet(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setDefaultStyleSheet_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDefaultStyleSheet", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setDefaultTextOption(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultTextOption(QTextOption)
    if (Shiboken::Converter<const QTextOption & >::isConvertible(arg)) {
        overloadId = 0; // setDefaultTextOption(QTextOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setDefaultTextOption_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QTextOption > cpp_arg0_auto_ptr;
            QTextOption* cpp_arg0 = Shiboken::Converter<QTextOption* >::toCpp(arg);
            if (!Shiboken::Converter<QTextOption >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QTextOption >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setDefaultTextOption(QTextOption)
            cppSelf->QTextDocument::setDefaultTextOption(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setDefaultTextOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDefaultTextOption", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setDocumentLayout(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentLayout(QAbstractTextDocumentLayout*)
    if (Shiboken::Converter<QAbstractTextDocumentLayout * >::isConvertible(arg)) {
        overloadId = 0; // setDocumentLayout(QAbstractTextDocumentLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setDocumentLayout_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractTextDocumentLayout* cpp_arg0 = Shiboken::Converter<QAbstractTextDocumentLayout* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDocumentLayout(QAbstractTextDocumentLayout*)
            cppSelf->QTextDocument::setDocumentLayout(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setDocumentLayout_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractTextDocumentLayout", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDocumentLayout", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setDocumentMargin(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDocumentMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setDocumentMargin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDocumentMargin(qreal)
            cppSelf->QTextDocument::setDocumentMargin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setDocumentMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDocumentMargin", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setHtml(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHtml(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setHtml_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHtml(QString)
            cppSelf->QTextDocument::setHtml(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setHtml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setHtml", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setIndentWidth(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIndentWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIndentWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setIndentWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIndentWidth(qreal)
            cppSelf->QTextDocument::setIndentWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setIndentWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setIndentWidth", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setMaximumBlockCount(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumBlockCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumBlockCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setMaximumBlockCount_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaximumBlockCount(int)
            cppSelf->QTextDocument::setMaximumBlockCount(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setMaximumBlockCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setMaximumBlockCount", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setMetaInformation(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMetaInformation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMetaInformation(QTextDocument::MetaInformation,QString)
    if (numArgs == 2 && Shiboken::Converter<QTextDocument::MetaInformation >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setMetaInformation(QTextDocument::MetaInformation,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setMetaInformation_TypeError;

    // Call function/method
    {
        {
            QTextDocument::MetaInformation cpp_arg0 = Shiboken::Converter<QTextDocument::MetaInformation >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setMetaInformation(QTextDocument::MetaInformation,QString)
            cppSelf->QTextDocument::setMetaInformation(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setMetaInformation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument.MetaInformation, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.setMetaInformation", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setModified(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "m" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.setModified(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.setModified(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setModified", &arg))
        return 0;


    // Overloaded function decisor
    // 0: setModified(bool)
    if (numArgs == 0) {
        overloadId = 0; // setModified(bool)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // setModified(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setModified_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "m");
                if (value) {
                    if (arg)
                        errorArgName = "m";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.setModified(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cpp_arg0 = arg ? Shiboken::Converter<bool >::toCpp(arg) : true;

            if(!PyErr_Occurred()) {
            // setModified(bool)
            cppSelf->QTextDocument::setModified(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setModified_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setModified", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setPageSize(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPageSize(QSizeF)
    if (Shiboken::Converter<const QSizeF & >::isConvertible(arg)) {
        overloadId = 0; // setPageSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setPageSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QSizeF > cpp_arg0_auto_ptr;
            QSizeF* cpp_arg0 = Shiboken::Converter<QSizeF* >::toCpp(arg);
            if (!Shiboken::Converter<QSizeF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPageSize(QSizeF)
            cppSelf->QTextDocument::setPageSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setPageSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setPageSize", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setPlainText(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPlainText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setPlainText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPlainText(QString)
            cppSelf->QTextDocument::setPlainText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setPlainText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setPlainText", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setTextWidth(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setTextWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextWidth(qreal)
            cppSelf->QTextDocument::setTextWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setTextWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setTextWidth", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setUndoRedoEnabled(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUndoRedoEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUndoRedoEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setUndoRedoEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUndoRedoEnabled(bool)
            cppSelf->QTextDocument::setUndoRedoEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setUndoRedoEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setUndoRedoEnabled", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_setUseDesignMetrics(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUseDesignMetrics(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUseDesignMetrics(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_setUseDesignMetrics_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUseDesignMetrics(bool)
            cppSelf->QTextDocument::setUseDesignMetrics(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextDocumentFunc_setUseDesignMetrics_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setUseDesignMetrics", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_size(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSizeF cppResult = cppSelf->QTextDocument::size();
            pyResult = Shiboken::Converter<QSizeF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_textWidth(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textWidth()const
            qreal cppResult = cppSelf->QTextDocument::textWidth();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_toHtml(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "encoding" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.toHtml(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.toHtml(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toHtml", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toHtml(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toHtml(QByteArray)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // toHtml(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextDocumentFunc_toHtml_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "encoding");
                if (value) {
                    if (arg)
                        errorArgName = "encoding";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.toHtml(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray cpp_arg0_tmp = QByteArray();
            QByteArray* cpp_arg0 = arg ? Shiboken::Converter<QByteArray* >::toCpp(arg) : &cpp_arg0_tmp;
            if (arg && !Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // toHtml(QByteArray)const
            QString cppResult = cppSelf->QTextDocument::toHtml(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextDocumentFunc_toHtml_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.toHtml", overloads);
        return 0;
}

static PyObject* SbkQTextDocumentFunc_toPlainText(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPlainText()const
            QString cppResult = cppSelf->QTextDocument::toPlainText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextDocumentFunc_undo(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // undo()
            cppSelf->QTextDocument::undo();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextDocumentFunc_useDesignMetrics(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // useDesignMetrics()const
            bool cppResult = cppSelf->QTextDocument::useDesignMetrics();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextDocument_methods[] = {
    {"addResource", (PyCFunction)SbkQTextDocumentFunc_addResource, METH_VARARGS},
    {"adjustSize", (PyCFunction)SbkQTextDocumentFunc_adjustSize, METH_NOARGS},
    {"allFormats", (PyCFunction)SbkQTextDocumentFunc_allFormats, METH_NOARGS},
    {"availableRedoSteps", (PyCFunction)SbkQTextDocumentFunc_availableRedoSteps, METH_NOARGS},
    {"availableUndoSteps", (PyCFunction)SbkQTextDocumentFunc_availableUndoSteps, METH_NOARGS},
    {"begin", (PyCFunction)SbkQTextDocumentFunc_begin, METH_NOARGS},
    {"blockCount", (PyCFunction)SbkQTextDocumentFunc_blockCount, METH_NOARGS},
    {"characterAt", (PyCFunction)SbkQTextDocumentFunc_characterAt, METH_O},
    {"characterCount", (PyCFunction)SbkQTextDocumentFunc_characterCount, METH_NOARGS},
    {"clear", (PyCFunction)SbkQTextDocumentFunc_clear, METH_NOARGS},
    {"clearUndoRedoStacks", (PyCFunction)SbkQTextDocumentFunc_clearUndoRedoStacks, METH_VARARGS|METH_KEYWORDS},
    {"clone", (PyCFunction)SbkQTextDocumentFunc_clone, METH_VARARGS|METH_KEYWORDS},
    {"createObject", (PyCFunction)SbkQTextDocumentFunc_createObject, METH_O},
    {"defaultFont", (PyCFunction)SbkQTextDocumentFunc_defaultFont, METH_NOARGS},
    {"defaultStyleSheet", (PyCFunction)SbkQTextDocumentFunc_defaultStyleSheet, METH_NOARGS},
    {"defaultTextOption", (PyCFunction)SbkQTextDocumentFunc_defaultTextOption, METH_NOARGS},
    {"documentLayout", (PyCFunction)SbkQTextDocumentFunc_documentLayout, METH_NOARGS},
    {"documentMargin", (PyCFunction)SbkQTextDocumentFunc_documentMargin, METH_NOARGS},
    {"drawContents", (PyCFunction)SbkQTextDocumentFunc_drawContents, METH_VARARGS|METH_KEYWORDS},
    {"end", (PyCFunction)SbkQTextDocumentFunc_end, METH_NOARGS},
    {"find", (PyCFunction)SbkQTextDocumentFunc_find, METH_VARARGS|METH_KEYWORDS},
    {"findBlock", (PyCFunction)SbkQTextDocumentFunc_findBlock, METH_O},
    {"findBlockByLineNumber", (PyCFunction)SbkQTextDocumentFunc_findBlockByLineNumber, METH_O},
    {"findBlockByNumber", (PyCFunction)SbkQTextDocumentFunc_findBlockByNumber, METH_O},
    {"firstBlock", (PyCFunction)SbkQTextDocumentFunc_firstBlock, METH_NOARGS},
    {"frameAt", (PyCFunction)SbkQTextDocumentFunc_frameAt, METH_O},
    {"idealWidth", (PyCFunction)SbkQTextDocumentFunc_idealWidth, METH_NOARGS},
    {"indentWidth", (PyCFunction)SbkQTextDocumentFunc_indentWidth, METH_NOARGS},
    {"isEmpty", (PyCFunction)SbkQTextDocumentFunc_isEmpty, METH_NOARGS},
    {"isModified", (PyCFunction)SbkQTextDocumentFunc_isModified, METH_NOARGS},
    {"isRedoAvailable", (PyCFunction)SbkQTextDocumentFunc_isRedoAvailable, METH_NOARGS},
    {"isUndoAvailable", (PyCFunction)SbkQTextDocumentFunc_isUndoAvailable, METH_NOARGS},
    {"isUndoRedoEnabled", (PyCFunction)SbkQTextDocumentFunc_isUndoRedoEnabled, METH_NOARGS},
    {"lastBlock", (PyCFunction)SbkQTextDocumentFunc_lastBlock, METH_NOARGS},
    {"lineCount", (PyCFunction)SbkQTextDocumentFunc_lineCount, METH_NOARGS},
    {"loadResource", (PyCFunction)SbkQTextDocumentFunc_loadResource, METH_VARARGS},
    {"markContentsDirty", (PyCFunction)SbkQTextDocumentFunc_markContentsDirty, METH_VARARGS},
    {"maximumBlockCount", (PyCFunction)SbkQTextDocumentFunc_maximumBlockCount, METH_NOARGS},
    {"metaInformation", (PyCFunction)SbkQTextDocumentFunc_metaInformation, METH_O},
    {"object", (PyCFunction)SbkQTextDocumentFunc_object, METH_O},
    {"objectForFormat", (PyCFunction)SbkQTextDocumentFunc_objectForFormat, METH_O},
    {"pageCount", (PyCFunction)SbkQTextDocumentFunc_pageCount, METH_NOARGS},
    {"pageSize", (PyCFunction)SbkQTextDocumentFunc_pageSize, METH_NOARGS},
    {"print_", (PyCFunction)SbkQTextDocumentFunc_print_, METH_O},
    {"redo", (PyCFunction)SbkQTextDocumentFunc_redo, METH_NOARGS},
    {"resource", (PyCFunction)SbkQTextDocumentFunc_resource, METH_VARARGS},
    {"revision", (PyCFunction)SbkQTextDocumentFunc_revision, METH_NOARGS},
    {"rootFrame", (PyCFunction)SbkQTextDocumentFunc_rootFrame, METH_NOARGS},
    {"setDefaultFont", (PyCFunction)SbkQTextDocumentFunc_setDefaultFont, METH_O},
    {"setDefaultStyleSheet", (PyCFunction)SbkQTextDocumentFunc_setDefaultStyleSheet, METH_O},
    {"setDefaultTextOption", (PyCFunction)SbkQTextDocumentFunc_setDefaultTextOption, METH_O},
    {"setDocumentLayout", (PyCFunction)SbkQTextDocumentFunc_setDocumentLayout, METH_O},
    {"setDocumentMargin", (PyCFunction)SbkQTextDocumentFunc_setDocumentMargin, METH_O},
    {"setHtml", (PyCFunction)SbkQTextDocumentFunc_setHtml, METH_O},
    {"setIndentWidth", (PyCFunction)SbkQTextDocumentFunc_setIndentWidth, METH_O},
    {"setMaximumBlockCount", (PyCFunction)SbkQTextDocumentFunc_setMaximumBlockCount, METH_O},
    {"setMetaInformation", (PyCFunction)SbkQTextDocumentFunc_setMetaInformation, METH_VARARGS},
    {"setModified", (PyCFunction)SbkQTextDocumentFunc_setModified, METH_VARARGS|METH_KEYWORDS},
    {"setPageSize", (PyCFunction)SbkQTextDocumentFunc_setPageSize, METH_O},
    {"setPlainText", (PyCFunction)SbkQTextDocumentFunc_setPlainText, METH_O},
    {"setTextWidth", (PyCFunction)SbkQTextDocumentFunc_setTextWidth, METH_O},
    {"setUndoRedoEnabled", (PyCFunction)SbkQTextDocumentFunc_setUndoRedoEnabled, METH_O},
    {"setUseDesignMetrics", (PyCFunction)SbkQTextDocumentFunc_setUseDesignMetrics, METH_O},
    {"size", (PyCFunction)SbkQTextDocumentFunc_size, METH_NOARGS},
    {"textWidth", (PyCFunction)SbkQTextDocumentFunc_textWidth, METH_NOARGS},
    {"toHtml", (PyCFunction)SbkQTextDocumentFunc_toHtml, METH_VARARGS|METH_KEYWORDS},
    {"toPlainText", (PyCFunction)SbkQTextDocumentFunc_toPlainText, METH_NOARGS},
    {"undo", (PyCFunction)SbkQTextDocumentFunc_undo, METH_NOARGS},
    {"useDesignMetrics", (PyCFunction)SbkQTextDocumentFunc_useDesignMetrics, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextDocument_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextDocument",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextDocument_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextDocument_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextDocument >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextDocument*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQTextDocument_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTextDocument*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQTextDocument_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QTextDocument_ResourceType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextDocument_ResourceType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextDocument_ResourceType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ResourceType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextDocument_ResourceType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextDocument_ResourceType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextDocument_ResourceType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QTextDocument_Stacks_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextDocument_Stacks_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextDocument_Stacks_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Stacks",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextDocument_Stacks_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextDocument_Stacks_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextDocument_Stacks_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextDocument::FindFlags >::checkType(self) && Shiboken::Converter<QTextDocument::FindFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        Shiboken::Converter<QTextDocument::FindFlags>::toCpp(self)
        & Shiboken::Converter< QTextDocument::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextDocument::FindFlags >::checkType(self) && Shiboken::Converter<QTextDocument::FindFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        Shiboken::Converter<QTextDocument::FindFlags>::toCpp(self)
        | Shiboken::Converter< QTextDocument::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextDocument::FindFlags >::checkType(self) && Shiboken::Converter<QTextDocument::FindFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        Shiboken::Converter<QTextDocument::FindFlags>::toCpp(self)
        ^ Shiboken::Converter< QTextDocument::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        ~Shiboken::Converter<QTextDocument::FindFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QTextDocument_FindFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QTextDocument_FindFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextDocument_FindFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextDocument_FindFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FindFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QTextDocument_FindFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextDocument_FindFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextDocument_FindFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextDocument_FindFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTextDocument_FindFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FindFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QTextDocument_FindFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QTextDocument_MetaInformation_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextDocument_MetaInformation_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextDocument_MetaInformation_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "MetaInformation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextDocument_MetaInformation_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextDocument_MetaInformation_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextDocument_MetaInformation_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextDocument(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextDocument_Type);

    SbkQTextDocument_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQTextDocument_Type.type_discovery = &SbkQTextDocument_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQTextDocument_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextDocument_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextDocument_Type));
    PyModule_AddObject(module, "QTextDocument",
        ((PyObject*)&SbkQTextDocument_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ResourceType
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_RESOURCETYPE_IDX] = &SbkPySide_QtGui_QTextDocument_ResourceType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextDocument_ResourceType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextDocument_ResourceType_Type);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
            "ResourceType",((PyObject*)&SbkPySide_QtGui_QTextDocument_ResourceType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_ResourceType_Type,
        (long) QTextDocument::HtmlResource, "HtmlResource");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "HtmlResource", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType_Type.tp_dict,
        "HtmlResource", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_ResourceType_Type,
        (long) QTextDocument::ImageResource, "ImageResource");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "ImageResource", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType_Type.tp_dict,
        "ImageResource", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_ResourceType_Type,
        (long) QTextDocument::StyleSheetResource, "StyleSheetResource");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "StyleSheetResource", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType_Type.tp_dict,
        "StyleSheetResource", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_ResourceType_Type,
        (long) QTextDocument::UserResource, "UserResource");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "UserResource", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType_Type.tp_dict,
        "UserResource", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::ResourceType");

    // init enum class: Stacks
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_STACKS_IDX] = &SbkPySide_QtGui_QTextDocument_Stacks_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextDocument_Stacks_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextDocument_Stacks_Type);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
            "Stacks",((PyObject*)&SbkPySide_QtGui_QTextDocument_Stacks_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_Stacks_Type,
        (long) QTextDocument::UndoStack, "UndoStack");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "UndoStack", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_Stacks_Type.tp_dict,
        "UndoStack", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_Stacks_Type,
        (long) QTextDocument::RedoStack, "RedoStack");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "RedoStack", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_Stacks_Type.tp_dict,
        "RedoStack", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_Stacks_Type,
        (long) QTextDocument::UndoAndRedoStacks, "UndoAndRedoStacks");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "UndoAndRedoStacks", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_Stacks_Type.tp_dict,
        "UndoAndRedoStacks", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::Stacks");

    // init enum class: FindFlag
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_FINDFLAG_IDX] = &SbkPySide_QtGui_QTextDocument_FindFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextDocument_FindFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextDocument_FindFlag_Type);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
            "FindFlag",((PyObject*)&SbkPySide_QtGui_QTextDocument_FindFlag_Type));

    // init flags class: QFlags<QTextDocument::FindFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTDOCUMENT_FINDFLAG__IDX] = &SbkPySide_QtGui_QTextDocument_FindFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextDocument_FindFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextDocument_FindFlags_Type);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
            "FindFlags",((PyObject*)&SbkPySide_QtGui_QTextDocument_FindFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_FindFlag_Type,
        (long) QTextDocument::FindBackward, "FindBackward");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "FindBackward", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_FindFlag_Type.tp_dict,
        "FindBackward", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_FindFlag_Type,
        (long) QTextDocument::FindCaseSensitively, "FindCaseSensitively");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "FindCaseSensitively", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_FindFlag_Type.tp_dict,
        "FindCaseSensitively", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_FindFlag_Type,
        (long) QTextDocument::FindWholeWords, "FindWholeWords");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "FindWholeWords", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_FindFlag_Type.tp_dict,
        "FindWholeWords", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::FindFlag");

    // init enum class: MetaInformation
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_METAINFORMATION_IDX] = &SbkPySide_QtGui_QTextDocument_MetaInformation_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextDocument_MetaInformation_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextDocument_MetaInformation_Type);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
            "MetaInformation",((PyObject*)&SbkPySide_QtGui_QTextDocument_MetaInformation_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_MetaInformation_Type,
        (long) QTextDocument::DocumentTitle, "DocumentTitle");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "DocumentTitle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_MetaInformation_Type.tp_dict,
        "DocumentTitle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextDocument_MetaInformation_Type,
        (long) QTextDocument::DocumentUrl, "DocumentUrl");
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict,
        "DocumentUrl", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_MetaInformation_Type.tp_dict,
        "DocumentUrl", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::MetaInformation");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("undoCommandAdded", "void", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "undoCommandAdded", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("modificationChanged", "bool", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "modificationChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("undoAvailable", "bool", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "undoAvailable", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("blockCountChanged", "int", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "blockCountChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("documentLayoutChanged", "void", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "documentLayoutChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("cursorPositionChanged", "const QTextCursor&", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "cursorPositionChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("redoAvailable", "bool", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "redoAvailable", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("contentsChange", "int,int,int", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "contentsChange", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("contentsChanged", "void", NULL);
    PyDict_SetItemString(SbkQTextDocument_Type.super.ht_type.tp_dict, "contentsChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTextDocument >("QTextDocument*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextDocument >(typeid(QTextDocument).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTextDocument >(typeid(QTextDocumentWrapper).name());
    PySide::initQtMetaType<QTextDocument* >();
}

