/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextframeformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qpen.h>
#include <qtextformat.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextFrameFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextFrameFormat >()))
        return -1;

    QTextFrameFormat* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextFrameFormat", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextFrameFormat(QTextFrameFormat)
    // 1: QTextFrameFormat()
    // 2: QTextFrameFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 1; // QTextFrameFormat()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextFormat & >::isConvertible(arg)) {
        overloadId = 2; // QTextFrameFormat(QTextFormat)
    } else if (numArgs == 1 && Shiboken::Converter<const QTextFrameFormat & >::isConvertible(arg)) {
        overloadId = 0; // QTextFrameFormat(QTextFrameFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextFrameFormat(QTextFrameFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextFrameFormat* cpp_arg0 = Shiboken::Converter<QTextFrameFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextFrameFormat(QTextFrameFormat)
                cptr = new QTextFrameFormat(*cpp_arg0);
                }
                break;
            }
            case 1: // QTextFrameFormat()
            {

                if(!PyErr_Occurred()) {
                // QTextFrameFormat()
                cptr = new QTextFrameFormat();
                }
                break;
            }
            case 2: // QTextFrameFormat(QTextFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextFormat* cpp_arg0 = Shiboken::Converter<QTextFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextFrameFormat(QTextFormat)
                cptr = new QTextFrameFormat(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextFrameFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextFrameFormat_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextFrameFormat_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrameFormat", "", "PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextFrameFormat", overloads);
        return -1;
}

static PyObject* SbkQTextFrameFormatFunc_border(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // border()const
            qreal cppResult = cppSelf->QTextFrameFormat::border();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_borderBrush(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // borderBrush()const
            QBrush cppResult = cppSelf->QTextFrameFormat::borderBrush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_borderStyle(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // borderStyle()const
            QTextFrameFormat::BorderStyle cppResult = cppSelf->QTextFrameFormat::borderStyle();
            pyResult = Shiboken::Converter<QTextFrameFormat::BorderStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_bottomMargin(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottomMargin()const
            qreal cppResult = cppSelf->QTextFrameFormat::bottomMargin();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_height(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            QTextLength cppResult = cppSelf->QTextFrameFormat::height();
            pyResult = Shiboken::Converter<QTextLength >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_isValid(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QTextFrameFormat::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_leftMargin(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // leftMargin()const
            qreal cppResult = cppSelf->QTextFrameFormat::leftMargin();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_margin(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // margin()const
            qreal cppResult = cppSelf->QTextFrameFormat::margin();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_padding(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // padding()const
            qreal cppResult = cppSelf->QTextFrameFormat::padding();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_pageBreakPolicy(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pageBreakPolicy()const
            QFlags<QTextFormat::PageBreakFlag> cppResult = cppSelf->QTextFrameFormat::pageBreakPolicy();
            pyResult = Shiboken::Converter<QFlags<QTextFormat::PageBreakFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_position(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // position()const
            QTextFrameFormat::Position cppResult = cppSelf->QTextFrameFormat::position();
            pyResult = Shiboken::Converter<QTextFrameFormat::Position >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_rightMargin(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rightMargin()const
            qreal cppResult = cppSelf->QTextFrameFormat::rightMargin();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_setBorder(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBorder(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBorder(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setBorder_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBorder(qreal)
            cppSelf->QTextFrameFormat::setBorder(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setBorder_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setBorder", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setBorderBrush(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBorderBrush(QBrush)
    if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 0; // setBorderBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setBorderBrush_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
            QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
            if (!Shiboken::Converter<QBrush >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBorderBrush(QBrush)
            cppSelf->QTextFrameFormat::setBorderBrush(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setBorderBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setBorderBrush", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setBorderStyle(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBorderStyle(QTextFrameFormat::BorderStyle)
    if (Shiboken::Converter<QTextFrameFormat::BorderStyle >::isConvertible(arg)) {
        overloadId = 0; // setBorderStyle(QTextFrameFormat::BorderStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setBorderStyle_TypeError;

    // Call function/method
    {
        {
            QTextFrameFormat::BorderStyle cpp_arg0 = Shiboken::Converter<QTextFrameFormat::BorderStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBorderStyle(QTextFrameFormat::BorderStyle)
            cppSelf->QTextFrameFormat::setBorderStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setBorderStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrameFormat.BorderStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setBorderStyle", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setBottomMargin(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottomMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setBottomMargin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBottomMargin(qreal)
            cppSelf->QTextFrameFormat::setBottomMargin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setBottomMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setBottomMargin", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setHeight(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(QTextLength)
    // 1: setHeight(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // setHeight(qreal)
    } else if (Shiboken::Converter<const QTextLength & >::isConvertible(arg)) {
        overloadId = 0; // setHeight(QTextLength)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setHeight_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setHeight(QTextLength)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextLength* cpp_arg0 = Shiboken::Converter<QTextLength* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setHeight(QTextLength)
                cppSelf->QTextFrameFormat::setHeight(*cpp_arg0);
                }
                break;
            }
            case 1: // setHeight(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setHeight(qreal)
                cppSelf->QTextFrameFormat::setHeight(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setHeight_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextLength", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setHeight", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setLeftMargin(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeftMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeftMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setLeftMargin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLeftMargin(qreal)
            cppSelf->QTextFrameFormat::setLeftMargin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setLeftMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setLeftMargin", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setMargin(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setMargin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMargin(qreal)
            cppSelf->QTextFrameFormat::setMargin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setMargin", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setPadding(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setPadding_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPadding(qreal)
            cppSelf->QTextFrameFormat::setPadding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setPadding", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setPageBreakPolicy(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    if (Shiboken::Converter<QFlags<QTextFormat::PageBreakFlag> >::isConvertible(arg)) {
        overloadId = 0; // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setPageBreakPolicy_TypeError;

    // Call function/method
    {
        {
            QFlags<QTextFormat::PageBreakFlag> cpp_arg0 = Shiboken::Converter<QFlags<QTextFormat::PageBreakFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
            cppSelf->QTextFrameFormat::setPageBreakPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setPageBreakPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat.PageBreakFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setPageBreakPolicy", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setPosition(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPosition(QTextFrameFormat::Position)
    if (Shiboken::Converter<QTextFrameFormat::Position >::isConvertible(arg)) {
        overloadId = 0; // setPosition(QTextFrameFormat::Position)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setPosition_TypeError;

    // Call function/method
    {
        {
            QTextFrameFormat::Position cpp_arg0 = Shiboken::Converter<QTextFrameFormat::Position >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPosition(QTextFrameFormat::Position)
            cppSelf->QTextFrameFormat::setPosition(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setPosition_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrameFormat.Position", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setPosition", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setRightMargin(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRightMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRightMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setRightMargin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRightMargin(qreal)
            cppSelf->QTextFrameFormat::setRightMargin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setRightMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setRightMargin", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setTopMargin(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTopMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setTopMargin_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTopMargin(qreal)
            cppSelf->QTextFrameFormat::setTopMargin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setTopMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setTopMargin", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_setWidth(PyObject* self, PyObject* arg)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(QTextLength)
    // 1: setWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // setWidth(qreal)
    } else if (Shiboken::Converter<const QTextLength & >::isConvertible(arg)) {
        overloadId = 0; // setWidth(QTextLength)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextFrameFormatFunc_setWidth_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setWidth(QTextLength)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextLength* cpp_arg0 = Shiboken::Converter<QTextLength* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setWidth(QTextLength)
                cppSelf->QTextFrameFormat::setWidth(*cpp_arg0);
                }
                break;
            }
            case 1: // setWidth(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setWidth(qreal)
                cppSelf->QTextFrameFormat::setWidth(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextFrameFormatFunc_setWidth_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextLength", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFrameFormat.setWidth", overloads);
        return 0;
}

static PyObject* SbkQTextFrameFormatFunc_topMargin(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topMargin()const
            qreal cppResult = cppSelf->QTextFrameFormat::topMargin();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextFrameFormatFunc_width(PyObject* self)
{
    QTextFrameFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextFrameFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            QTextLength cppResult = cppSelf->QTextFrameFormat::width();
            pyResult = Shiboken::Converter<QTextLength >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextFrameFormat_methods[] = {
    {"border", (PyCFunction)SbkQTextFrameFormatFunc_border, METH_NOARGS},
    {"borderBrush", (PyCFunction)SbkQTextFrameFormatFunc_borderBrush, METH_NOARGS},
    {"borderStyle", (PyCFunction)SbkQTextFrameFormatFunc_borderStyle, METH_NOARGS},
    {"bottomMargin", (PyCFunction)SbkQTextFrameFormatFunc_bottomMargin, METH_NOARGS},
    {"height", (PyCFunction)SbkQTextFrameFormatFunc_height, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQTextFrameFormatFunc_isValid, METH_NOARGS},
    {"leftMargin", (PyCFunction)SbkQTextFrameFormatFunc_leftMargin, METH_NOARGS},
    {"margin", (PyCFunction)SbkQTextFrameFormatFunc_margin, METH_NOARGS},
    {"padding", (PyCFunction)SbkQTextFrameFormatFunc_padding, METH_NOARGS},
    {"pageBreakPolicy", (PyCFunction)SbkQTextFrameFormatFunc_pageBreakPolicy, METH_NOARGS},
    {"position", (PyCFunction)SbkQTextFrameFormatFunc_position, METH_NOARGS},
    {"rightMargin", (PyCFunction)SbkQTextFrameFormatFunc_rightMargin, METH_NOARGS},
    {"setBorder", (PyCFunction)SbkQTextFrameFormatFunc_setBorder, METH_O},
    {"setBorderBrush", (PyCFunction)SbkQTextFrameFormatFunc_setBorderBrush, METH_O},
    {"setBorderStyle", (PyCFunction)SbkQTextFrameFormatFunc_setBorderStyle, METH_O},
    {"setBottomMargin", (PyCFunction)SbkQTextFrameFormatFunc_setBottomMargin, METH_O},
    {"setHeight", (PyCFunction)SbkQTextFrameFormatFunc_setHeight, METH_O},
    {"setLeftMargin", (PyCFunction)SbkQTextFrameFormatFunc_setLeftMargin, METH_O},
    {"setMargin", (PyCFunction)SbkQTextFrameFormatFunc_setMargin, METH_O},
    {"setPadding", (PyCFunction)SbkQTextFrameFormatFunc_setPadding, METH_O},
    {"setPageBreakPolicy", (PyCFunction)SbkQTextFrameFormatFunc_setPageBreakPolicy, METH_O},
    {"setPosition", (PyCFunction)SbkQTextFrameFormatFunc_setPosition, METH_O},
    {"setRightMargin", (PyCFunction)SbkQTextFrameFormatFunc_setRightMargin, METH_O},
    {"setTopMargin", (PyCFunction)SbkQTextFrameFormatFunc_setTopMargin, METH_O},
    {"setWidth", (PyCFunction)SbkQTextFrameFormatFunc_setWidth, METH_O},
    {"topMargin", (PyCFunction)SbkQTextFrameFormatFunc_topMargin, METH_NOARGS},
    {"width", (PyCFunction)SbkQTextFrameFormatFunc_width, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextFrameFormat_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextFrameFormat",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextFrameFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextFrameFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextFrameFormat >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextFrameFormat",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QTextFrameFormat_Position_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextFrameFormat_Position_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextFrameFormat_Position_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Position",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextFrameFormat_Position_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextFrameFormat_Position_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextFrameFormat_Position_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QTextFrameFormat_BorderStyle_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextFrameFormat_BorderStyle_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "BorderStyle",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextFrameFormat_BorderStyle_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextFrameFormat_BorderStyle_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextFrameFormat_BorderStyle_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextFrameFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextFrameFormat_Type);

    SbkQTextFrameFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQTextFrameFormat_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextFrameFormat_Type));
    PyModule_AddObject(module, "QTextFrameFormat",
        ((PyObject*)&SbkQTextFrameFormat_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Position
    SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_POSITION_IDX] = &SbkPySide_QtGui_QTextFrameFormat_Position_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextFrameFormat_Position_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextFrameFormat_Position_Type);
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
            "Position",((PyObject*)&SbkPySide_QtGui_QTextFrameFormat_Position_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_Position_Type,
        (long) QTextFrameFormat::InFlow, "InFlow");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "InFlow", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_Position_Type.tp_dict,
        "InFlow", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_Position_Type,
        (long) QTextFrameFormat::FloatLeft, "FloatLeft");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "FloatLeft", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_Position_Type.tp_dict,
        "FloatLeft", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_Position_Type,
        (long) QTextFrameFormat::FloatRight, "FloatRight");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "FloatRight", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_Position_Type.tp_dict,
        "FloatRight", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextFrameFormat::Position");

    // init enum class: BorderStyle
    SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX] = &SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type);
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
            "BorderStyle",((PyObject*)&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_None, "BorderStyle_None");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_None", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_None", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Dotted, "BorderStyle_Dotted");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Dotted", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Dotted", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Dashed, "BorderStyle_Dashed");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Dashed", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Dashed", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Solid, "BorderStyle_Solid");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Solid", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Solid", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Double, "BorderStyle_Double");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Double", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Double", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_DotDash, "BorderStyle_DotDash");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_DotDash", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_DotDash", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_DotDotDash, "BorderStyle_DotDotDash");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_DotDotDash", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_DotDotDash", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Groove, "BorderStyle_Groove");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Groove", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Groove", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Ridge, "BorderStyle_Ridge");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Ridge", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Ridge", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Inset, "BorderStyle_Inset");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Inset", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Inset", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type,
        (long) QTextFrameFormat::BorderStyle_Outset, "BorderStyle_Outset");
    PyDict_SetItemString(SbkQTextFrameFormat_Type.super.ht_type.tp_dict,
        "BorderStyle_Outset", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFrameFormat_BorderStyle_Type.tp_dict,
        "BorderStyle_Outset", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextFrameFormat::BorderStyle");


    Shiboken::TypeResolver::createValueTypeResolver<QTextFrameFormat >("QTextFrameFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextFrameFormat >("QTextFrameFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextFrameFormat >(typeid(QTextFrameFormat).name());
    PySide::initQtMetaType<QTextFrameFormat >();
}

