/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextinlineobject_wrapper.h"

// Extra includes
#include <qrect.h>
#include <qtextformat.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextInlineObject_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextInlineObject >()))
        return -1;

    QTextInlineObject* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextInlineObject", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextInlineObject(QTextInlineObject)
    // 1: QTextInlineObject()
    if (numArgs == 0) {
        overloadId = 1; // QTextInlineObject()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextInlineObject & >::isConvertible(arg)) {
        overloadId = 0; // QTextInlineObject(QTextInlineObject)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextInlineObject_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextInlineObject(QTextInlineObject)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextInlineObject* cpp_arg0 = Shiboken::Converter<QTextInlineObject* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextInlineObject(QTextInlineObject)
                cptr = new QTextInlineObject(*cpp_arg0);
                }
                break;
            }
            case 1: // QTextInlineObject()
            {

                if(!PyErr_Occurred()) {
                // QTextInlineObject()
                cptr = new QTextInlineObject();
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextInlineObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextInlineObject_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextInlineObject_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextInlineObject", "", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextInlineObject", overloads);
        return -1;
}

static PyObject* SbkQTextInlineObjectFunc_ascent(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ascent()const
            qreal cppResult = cppSelf->QTextInlineObject::ascent();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_descent(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // descent()const
            qreal cppResult = cppSelf->QTextInlineObject::descent();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_format(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QTextFormat cppResult = cppSelf->QTextInlineObject::format();
            pyResult = Shiboken::Converter<QTextFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_formatIndex(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // formatIndex()const
            int cppResult = cppSelf->QTextInlineObject::formatIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_height(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            qreal cppResult = cppSelf->QTextInlineObject::height();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_isValid(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QTextInlineObject::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_rect(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rect()const
            QRectF cppResult = cppSelf->QTextInlineObject::rect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_setAscent(PyObject* self, PyObject* arg)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAscent(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAscent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextInlineObjectFunc_setAscent_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAscent(qreal)
            cppSelf->QTextInlineObject::setAscent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextInlineObjectFunc_setAscent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextInlineObject.setAscent", overloads);
        return 0;
}

static PyObject* SbkQTextInlineObjectFunc_setDescent(PyObject* self, PyObject* arg)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDescent(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDescent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextInlineObjectFunc_setDescent_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDescent(qreal)
            cppSelf->QTextInlineObject::setDescent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextInlineObjectFunc_setDescent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextInlineObject.setDescent", overloads);
        return 0;
}

static PyObject* SbkQTextInlineObjectFunc_setWidth(PyObject* self, PyObject* arg)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextInlineObjectFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWidth(qreal)
            cppSelf->QTextInlineObject::setWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextInlineObjectFunc_setWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextInlineObject.setWidth", overloads);
        return 0;
}

static PyObject* SbkQTextInlineObjectFunc_textDirection(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textDirection()const
            Qt::LayoutDirection cppResult = cppSelf->QTextInlineObject::textDirection();
            pyResult = Shiboken::Converter<Qt::LayoutDirection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_textPosition(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textPosition()const
            int cppResult = cppSelf->QTextInlineObject::textPosition();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextInlineObjectFunc_width(PyObject* self)
{
    QTextInlineObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextInlineObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            qreal cppResult = cppSelf->QTextInlineObject::width();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextInlineObject_methods[] = {
    {"ascent", (PyCFunction)SbkQTextInlineObjectFunc_ascent, METH_NOARGS},
    {"descent", (PyCFunction)SbkQTextInlineObjectFunc_descent, METH_NOARGS},
    {"format", (PyCFunction)SbkQTextInlineObjectFunc_format, METH_NOARGS},
    {"formatIndex", (PyCFunction)SbkQTextInlineObjectFunc_formatIndex, METH_NOARGS},
    {"height", (PyCFunction)SbkQTextInlineObjectFunc_height, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQTextInlineObjectFunc_isValid, METH_NOARGS},
    {"rect", (PyCFunction)SbkQTextInlineObjectFunc_rect, METH_NOARGS},
    {"setAscent", (PyCFunction)SbkQTextInlineObjectFunc_setAscent, METH_O},
    {"setDescent", (PyCFunction)SbkQTextInlineObjectFunc_setDescent, METH_O},
    {"setWidth", (PyCFunction)SbkQTextInlineObjectFunc_setWidth, METH_O},
    {"textDirection", (PyCFunction)SbkQTextInlineObjectFunc_textDirection, METH_NOARGS},
    {"textPosition", (PyCFunction)SbkQTextInlineObjectFunc_textPosition, METH_NOARGS},
    {"width", (PyCFunction)SbkQTextInlineObjectFunc_width, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextInlineObject_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextInlineObject",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextInlineObject_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextInlineObject_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextInlineObject >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextInlineObject",
    /*user_data*/           0
};
} //extern


void init_QTextInlineObject(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTINLINEOBJECT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextInlineObject_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextInlineObject_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextInlineObject_Type));
    PyModule_AddObject(module, "QTextInlineObject",
        ((PyObject*)&SbkQTextInlineObject_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextInlineObject >("QTextInlineObject");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextInlineObject >("QTextInlineObject*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextInlineObject >(typeid(QTextInlineObject).name());
    PySide::initQtMetaType<QTextInlineObject >();
}

