/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextlistformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qpen.h>
#include <qtextformat.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextListFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextListFormat >()))
        return -1;

    QTextListFormat* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextListFormat", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextListFormat(QTextListFormat)
    // 1: QTextListFormat()
    // 2: QTextListFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 1; // QTextListFormat()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextFormat & >::isConvertible(arg)) {
        overloadId = 2; // QTextListFormat(QTextFormat)
    } else if (numArgs == 1 && Shiboken::Converter<const QTextListFormat & >::isConvertible(arg)) {
        overloadId = 0; // QTextListFormat(QTextListFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextListFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextListFormat(QTextListFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextListFormat* cpp_arg0 = Shiboken::Converter<QTextListFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextListFormat(QTextListFormat)
                cptr = new QTextListFormat(*cpp_arg0);
                }
                break;
            }
            case 1: // QTextListFormat()
            {

                if(!PyErr_Occurred()) {
                // QTextListFormat()
                cptr = new QTextListFormat();
                }
                break;
            }
            case 2: // QTextListFormat(QTextFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextFormat* cpp_arg0 = Shiboken::Converter<QTextFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextListFormat(QTextFormat)
                cptr = new QTextListFormat(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextListFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextListFormat_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextListFormat_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextListFormat", "", "PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextListFormat", overloads);
        return -1;
}

static PyObject* SbkQTextListFormatFunc_indent(PyObject* self)
{
    QTextListFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextListFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // indent()const
            int cppResult = cppSelf->QTextListFormat::indent();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextListFormatFunc_isValid(PyObject* self)
{
    QTextListFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextListFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QTextListFormat::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextListFormatFunc_setIndent(PyObject* self, PyObject* arg)
{
    QTextListFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextListFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIndent(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextListFormatFunc_setIndent_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIndent(int)
            cppSelf->QTextListFormat::setIndent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextListFormatFunc_setIndent_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextListFormat.setIndent", overloads);
        return 0;
}

static PyObject* SbkQTextListFormatFunc_setStyle(PyObject* self, PyObject* arg)
{
    QTextListFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextListFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QTextListFormat::Style)
    if (Shiboken::Converter<QTextListFormat::Style >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextListFormatFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            QTextListFormat::Style cpp_arg0 = Shiboken::Converter<QTextListFormat::Style >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStyle(QTextListFormat::Style)
            cppSelf->QTextListFormat::setStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextListFormatFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextListFormat.Style", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextListFormat.setStyle", overloads);
        return 0;
}

static PyObject* SbkQTextListFormatFunc_style(PyObject* self)
{
    QTextListFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextListFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()const
            QTextListFormat::Style cppResult = cppSelf->QTextListFormat::style();
            pyResult = Shiboken::Converter<QTextListFormat::Style >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextListFormat_methods[] = {
    {"indent", (PyCFunction)SbkQTextListFormatFunc_indent, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQTextListFormatFunc_isValid, METH_NOARGS},
    {"setIndent", (PyCFunction)SbkQTextListFormatFunc_setIndent, METH_O},
    {"setStyle", (PyCFunction)SbkQTextListFormatFunc_setStyle, METH_O},
    {"style", (PyCFunction)SbkQTextListFormatFunc_style, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextListFormat_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextListFormat",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextListFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextListFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextListFormat >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextListFormat",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QTextListFormat_Style_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextListFormat_Style_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextListFormat_Style_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Style",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextListFormat_Style_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextListFormat_Style_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextListFormat_Style_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextListFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTLISTFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextListFormat_Type);

    SbkQTextListFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQTextListFormat_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextListFormat_Type));
    PyModule_AddObject(module, "QTextListFormat",
        ((PyObject*)&SbkQTextListFormat_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Style
    SbkPySide_QtGuiTypes[SBK_QTEXTLISTFORMAT_STYLE_IDX] = &SbkPySide_QtGui_QTextListFormat_Style_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextListFormat_Style_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextListFormat_Style_Type);
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
            "Style",((PyObject*)&SbkPySide_QtGui_QTextListFormat_Style_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListDisc, "ListDisc");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListDisc", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListDisc", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListCircle, "ListCircle");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListCircle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListCircle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListSquare, "ListSquare");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListSquare", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListSquare", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListDecimal, "ListDecimal");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListDecimal", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListDecimal", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListLowerAlpha, "ListLowerAlpha");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListLowerAlpha", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListLowerAlpha", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListUpperAlpha, "ListUpperAlpha");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListUpperAlpha", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListUpperAlpha", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListLowerRoman, "ListLowerRoman");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListLowerRoman", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListLowerRoman", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListUpperRoman, "ListUpperRoman");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListUpperRoman", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListUpperRoman", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextListFormat_Style_Type,
        (long) QTextListFormat::ListStyleUndefined, "ListStyleUndefined");
    PyDict_SetItemString(SbkQTextListFormat_Type.super.ht_type.tp_dict,
        "ListStyleUndefined", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style_Type.tp_dict,
        "ListStyleUndefined", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextListFormat::Style");


    Shiboken::TypeResolver::createValueTypeResolver<QTextListFormat >("QTextListFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextListFormat >("QTextListFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextListFormat >(typeid(QTextListFormat).name());
    PySide::initQtMetaType<QTextListFormat >();
}

