/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextoption_tab_wrapper.h"

// Extra includes
#include <qtextoption.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextOption_Tab_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextOption::Tab >()))
        return -1;

    QTextOption::Tab* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "delim" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.Tab(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.Tab(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:Tab", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: Tab(QTextOption::Tab)
    // 1: Tab()
    // 2: Tab(qreal,QTextOption::TabType,QChar)
    if (numArgs == 0) {
        overloadId = 1; // Tab()
    } else if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QTextOption::TabType >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // Tab(qreal,QTextOption::TabType,QChar)
        } else if (Shiboken::Converter<QChar >::isConvertible(pyargs[2])) {
            overloadId = 2; // Tab(qreal,QTextOption::TabType,QChar)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QTextOption::Tab & >::isConvertible(pyargs[0])) {
        overloadId = 0; // Tab(QTextOption::Tab)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOption_Tab_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // Tab(QTextOption::Tab)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QTextOption::Tab* cpp_arg0 = Shiboken::Converter<QTextOption::Tab* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // Tab(QTextOption::Tab)
                cptr = new QTextOption::Tab(*cpp_arg0);
                }
                break;
            }
            case 1: // Tab()
            {

                if(!PyErr_Occurred()) {
                // Tab()
                cptr = new QTextOption::Tab();
                }
                break;
            }
            case 2: // Tab(qreal,QTextOption::TabType,QChar)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "delim");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "delim";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.Tab(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                QTextOption::TabType cpp_arg1 = Shiboken::Converter<QTextOption::TabType >::toCpp(pyargs[1]);
                QChar cpp_arg2 = pyargs[2] ? Shiboken::Converter<QChar >::toCpp(pyargs[2]) : QChar();

                if(!PyErr_Occurred()) {
                // Tab(qreal,QTextOption::TabType,QChar)
                cptr = new QTextOption::Tab(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextOption::Tab >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextOption_Tab_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextOption_Tab_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption::Tab", "", "float, PySide.QtGui.QTextOption.TabType, QChar = QChar()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.Tab", overloads);
        return -1;
}

static PyMethodDef SbkQTextOption_Tab_methods[] = {
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQTextOption_Tab_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QTextOption::Tab& cpp_self = *Shiboken::Converter<QTextOption::Tab* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QTextOption::Tab & >::isConvertible(other)) {
                // operator!=(const QTextOption::Tab & other) const
                QTextOption::Tab* cpp_other = Shiboken::Converter<QTextOption::Tab* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextOption::Tab  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQTextOption_Tab_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QTextOption::Tab & >::isConvertible(other)) {
                // operator==(const QTextOption::Tab & other) const
                QTextOption::Tab* cpp_other = Shiboken::Converter<QTextOption::Tab* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QTextOption::Tab  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQTextOption_Tab_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQTextOption_Tab_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

static PyObject* SbkQTextOption_Tab_get_delimiter(PyObject* self, void*)
{
    return Shiboken::Converter<QChar >::toPython(Shiboken::Converter<QTextOption::Tab* >::toCpp(self)->delimiter);
}
static int SbkQTextOption_Tab_set_delimiter(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'delimiter' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QChar >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'delimiter', 'QChar' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QTextOption::Tab* >::toCpp(self)->delimiter = Shiboken::Converter<QChar >::toCpp(value);

    return 0;
}

static PyObject* SbkQTextOption_Tab_get_position(PyObject* self, void*)
{
    return Shiboken::Converter<double >::toPython(Shiboken::Converter<QTextOption::Tab* >::toCpp(self)->position);
}
static int SbkQTextOption_Tab_set_position(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'position' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'position', 'qreal' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QTextOption::Tab* >::toCpp(self)->position = Shiboken::Converter<double >::toCpp(value);

    return 0;
}

static PyObject* SbkQTextOption_Tab_get_type(PyObject* self, void*)
{
    return Shiboken::Converter<QTextOption::TabType >::toPython(Shiboken::Converter<QTextOption::Tab* >::toCpp(self)->type);
}
static int SbkQTextOption_Tab_set_type(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QTextOption::TabType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'TabType' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QTextOption::Tab* >::toCpp(self)->type = Shiboken::Converter<QTextOption::TabType >::toCpp(value);

    return 0;
}

// Getters and Setters for Tab
static PyGetSetDef SbkQTextOption_Tab_getsetlist[] = {
    {const_cast<char*>("delimiter"), SbkQTextOption_Tab_get_delimiter, SbkQTextOption_Tab_set_delimiter},
    {const_cast<char*>("position"), SbkQTextOption_Tab_get_position, SbkQTextOption_Tab_set_position},
    {const_cast<char*>("type"), SbkQTextOption_Tab_get_type, SbkQTextOption_Tab_set_type},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextOption_Tab_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.Tab",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQTextOption_Tab_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextOption_Tab_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQTextOption_Tab_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextOption_Tab_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextOption::Tab >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextOption::Tab",
    /*user_data*/           0
};
} //extern


void init_QTextOption_Tab(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTOPTION_TAB_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextOption_Tab_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextOption_Tab_Type) < 0)
        return;

    PyDict_SetItemString(module,"Tab", (PyObject*)&SbkQTextOption_Tab_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QTextOption::Tab >("QTextOption::Tab");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextOption::Tab >("QTextOption::Tab*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextOption::Tab >(typeid(QTextOption::Tab).name());
    PySide::initQtMetaType<QTextOption::Tab >();
}

