/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextoption_wrapper.h"
#include "qtextoption_tab_wrapper.h"

// Extra includes
#include <QList>
#include <qtextoption.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextOption_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextOption >()))
        return -1;

    QTextOption* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextOption", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextOption()
    // 1: QTextOption(QFlags<Qt::AlignmentFlag>)
    // 2: QTextOption(QTextOption)
    if (numArgs == 0) {
        overloadId = 0; // QTextOption()
    } else if (numArgs == 1 && Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 1; // QTextOption(QFlags<Qt::AlignmentFlag>)
    } else if (numArgs == 1 && Shiboken::Converter<const QTextOption & >::isConvertible(arg)) {
        overloadId = 2; // QTextOption(QTextOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOption_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextOption()
            {

                if(!PyErr_Occurred()) {
                // QTextOption()
                cptr = new QTextOption();
                }
                break;
            }
            case 1: // QTextOption(QFlags<Qt::AlignmentFlag>)
            {
                QFlags<Qt::AlignmentFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextOption(QFlags<Qt::AlignmentFlag>)
                cptr = new QTextOption(cpp_arg0);
                }
                break;
            }
            case 2: // QTextOption(QTextOption)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QTextOption > cpp_arg0_auto_ptr;
                QTextOption* cpp_arg0 = Shiboken::Converter<QTextOption* >::toCpp(arg);
                if (!Shiboken::Converter<QTextOption >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QTextOption >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QTextOption(QTextOption)
                cptr = new QTextOption(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextOption >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextOption_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextOption_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.Alignment", "PySide.QtGui.QTextOption", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextOption", overloads);
        return -1;
}

static PyObject* SbkQTextOptionFunc_alignment(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alignment()const
            QFlags<Qt::AlignmentFlag> cppResult = cppSelf->QTextOption::alignment();
            pyResult = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextOptionFunc_flags(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flags()const
            QFlags<QTextOption::Flag> cppResult = cppSelf->QTextOption::flags();
            pyResult = Shiboken::Converter<QFlags<QTextOption::Flag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextOptionFunc_setAlignment(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->QTextOption::setAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setAlignment", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_setFlags(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFlags(QFlags<QTextOption::Flag>)
    if (Shiboken::Converter<QFlags<QTextOption::Flag> >::isConvertible(arg)) {
        overloadId = 0; // setFlags(QFlags<QTextOption::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QTextOption::Flag> cpp_arg0 = Shiboken::Converter<QFlags<QTextOption::Flag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFlags(QFlags<QTextOption::Flag>)
            cppSelf->QTextOption::setFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption.Flags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setFlags", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_setTabArray(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabArray(QList<qreal>)
    if (Shiboken::Converter<QList<qreal > >::isConvertible(arg)) {
        overloadId = 0; // setTabArray(QList<qreal>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setTabArray_TypeError;

    // Call function/method
    {
        {
            QList<qreal > cpp_arg0 = Shiboken::Converter<QList<qreal > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTabArray(QList<qreal>)
            cppSelf->QTextOption::setTabArray(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setTabArray_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setTabArray", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_setTabStop(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabStop(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTabStop(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setTabStop_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTabStop(qreal)
            cppSelf->QTextOption::setTabStop(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setTabStop_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setTabStop", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_setTabs(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabs(QList<QTextOption::Tab>)
    if (Shiboken::Converter<QList<QTextOption::Tab > >::isConvertible(arg)) {
        overloadId = 0; // setTabs(QList<QTextOption::Tab>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setTabs_TypeError;

    // Call function/method
    {
        {
            QList<QTextOption::Tab > cpp_arg0 = Shiboken::Converter<QList<QTextOption::Tab > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTabs(QList<QTextOption::Tab>)
            cppSelf->QTextOption::setTabs(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setTabs_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setTabs", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_setTextDirection(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextDirection(Qt::LayoutDirection)
    if (Shiboken::Converter<Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setTextDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setTextDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cpp_arg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextDirection(Qt::LayoutDirection)
            cppSelf->QTextOption::setTextDirection(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setTextDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setTextDirection", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_setUseDesignMetrics(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUseDesignMetrics(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUseDesignMetrics(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setUseDesignMetrics_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUseDesignMetrics(bool)
            cppSelf->QTextOption::setUseDesignMetrics(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setUseDesignMetrics_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setUseDesignMetrics", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_setWrapMode(PyObject* self, PyObject* arg)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWrapMode(QTextOption::WrapMode)
    if (Shiboken::Converter<QTextOption::WrapMode >::isConvertible(arg)) {
        overloadId = 0; // setWrapMode(QTextOption::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextOptionFunc_setWrapMode_TypeError;

    // Call function/method
    {
        {
            QTextOption::WrapMode cpp_arg0 = Shiboken::Converter<QTextOption::WrapMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWrapMode(QTextOption::WrapMode)
            cppSelf->QTextOption::setWrapMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextOptionFunc_setWrapMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption.WrapMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextOption.setWrapMode", overloads);
        return 0;
}

static PyObject* SbkQTextOptionFunc_tabArray(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tabArray()const
            QList<qreal > cppResult = cppSelf->QTextOption::tabArray();
            pyResult = Shiboken::Converter<QList<qreal > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextOptionFunc_tabStop(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tabStop()const
            qreal cppResult = cppSelf->QTextOption::tabStop();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextOptionFunc_tabs(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tabs()const
            QList<QTextOption::Tab > cppResult = cppSelf->QTextOption::tabs();
            pyResult = Shiboken::Converter<QList<QTextOption::Tab > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextOptionFunc_textDirection(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textDirection()const
            Qt::LayoutDirection cppResult = cppSelf->QTextOption::textDirection();
            pyResult = Shiboken::Converter<Qt::LayoutDirection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextOptionFunc_useDesignMetrics(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // useDesignMetrics()const
            bool cppResult = cppSelf->QTextOption::useDesignMetrics();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextOptionFunc_wrapMode(PyObject* self)
{
    QTextOption* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextOption* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // wrapMode()const
            QTextOption::WrapMode cppResult = cppSelf->QTextOption::wrapMode();
            pyResult = Shiboken::Converter<QTextOption::WrapMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextOption_methods[] = {
    {"alignment", (PyCFunction)SbkQTextOptionFunc_alignment, METH_NOARGS},
    {"flags", (PyCFunction)SbkQTextOptionFunc_flags, METH_NOARGS},
    {"setAlignment", (PyCFunction)SbkQTextOptionFunc_setAlignment, METH_O},
    {"setFlags", (PyCFunction)SbkQTextOptionFunc_setFlags, METH_O},
    {"setTabArray", (PyCFunction)SbkQTextOptionFunc_setTabArray, METH_O},
    {"setTabStop", (PyCFunction)SbkQTextOptionFunc_setTabStop, METH_O},
    {"setTabs", (PyCFunction)SbkQTextOptionFunc_setTabs, METH_O},
    {"setTextDirection", (PyCFunction)SbkQTextOptionFunc_setTextDirection, METH_O},
    {"setUseDesignMetrics", (PyCFunction)SbkQTextOptionFunc_setUseDesignMetrics, METH_O},
    {"setWrapMode", (PyCFunction)SbkQTextOptionFunc_setWrapMode, METH_O},
    {"tabArray", (PyCFunction)SbkQTextOptionFunc_tabArray, METH_NOARGS},
    {"tabStop", (PyCFunction)SbkQTextOptionFunc_tabStop, METH_NOARGS},
    {"tabs", (PyCFunction)SbkQTextOptionFunc_tabs, METH_NOARGS},
    {"textDirection", (PyCFunction)SbkQTextOptionFunc_textDirection, METH_NOARGS},
    {"useDesignMetrics", (PyCFunction)SbkQTextOptionFunc_useDesignMetrics, METH_NOARGS},
    {"wrapMode", (PyCFunction)SbkQTextOptionFunc_wrapMode, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextOption_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextOption",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextOption_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextOption_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextOption >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextOption",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QTextOption_TabType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextOption_TabType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextOption_TabType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "TabType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextOption_TabType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextOption_TabType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextOption_TabType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QTextOption_Flag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextOption::Flags >::checkType(self) && Shiboken::Converter<QTextOption::Flags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextOption::Flags >::toPython(
        Shiboken::Converter<QTextOption::Flags>::toCpp(self)
        & Shiboken::Converter< QTextOption::Flags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextOption_Flag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextOption::Flags >::checkType(self) && Shiboken::Converter<QTextOption::Flags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextOption::Flags >::toPython(
        Shiboken::Converter<QTextOption::Flags>::toCpp(self)
        | Shiboken::Converter< QTextOption::Flags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextOption_Flag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextOption::Flags >::checkType(self) && Shiboken::Converter<QTextOption::Flags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextOption::Flags >::toPython(
        Shiboken::Converter<QTextOption::Flags>::toCpp(self)
        ^ Shiboken::Converter< QTextOption::Flags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextOption_Flag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextOption::Flags >::toPython(
        ~Shiboken::Converter<QTextOption::Flags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QTextOption_Flag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTextOption_Flag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTextOption_Flag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTextOption_Flag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTextOption_Flag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QTextOption_Flag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextOption_Flag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextOption_Flag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Flag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QTextOption_Flag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextOption_Flag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextOption_Flag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextOption_Flag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTextOption_Flags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Flags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QTextOption_Flag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QTextOption_WrapMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextOption_WrapMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextOption_WrapMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WrapMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextOption_WrapMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextOption_WrapMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextOption_WrapMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextOption(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTOPTION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextOption_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextOption_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextOption_Type));
    PyModule_AddObject(module, "QTextOption",
        ((PyObject*)&SbkQTextOption_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: TabType
    SbkPySide_QtGuiTypes[SBK_QTEXTOPTION_TABTYPE_IDX] = &SbkPySide_QtGui_QTextOption_TabType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextOption_TabType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextOption_TabType_Type);
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
            "TabType",((PyObject*)&SbkPySide_QtGui_QTextOption_TabType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_TabType_Type,
        (long) QTextOption::LeftTab, "LeftTab");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "LeftTab", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_TabType_Type.tp_dict,
        "LeftTab", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_TabType_Type,
        (long) QTextOption::RightTab, "RightTab");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "RightTab", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_TabType_Type.tp_dict,
        "RightTab", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_TabType_Type,
        (long) QTextOption::CenterTab, "CenterTab");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "CenterTab", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_TabType_Type.tp_dict,
        "CenterTab", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_TabType_Type,
        (long) QTextOption::DelimiterTab, "DelimiterTab");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "DelimiterTab", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_TabType_Type.tp_dict,
        "DelimiterTab", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextOption::TabType");

    // init enum class: Flag
    SbkPySide_QtGuiTypes[SBK_QTEXTOPTION_FLAG_IDX] = &SbkPySide_QtGui_QTextOption_Flag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextOption_Flag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextOption_Flag_Type);
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
            "Flag",((PyObject*)&SbkPySide_QtGui_QTextOption_Flag_Type));

    // init flags class: QFlags<QTextOption::Flag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTOPTION_FLAG__IDX] = &SbkPySide_QtGui_QTextOption_Flags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextOption_Flags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextOption_Flags_Type);
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
            "Flags",((PyObject*)&SbkPySide_QtGui_QTextOption_Flags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_Flag_Type,
        (long) QTextOption::ShowTabsAndSpaces, "ShowTabsAndSpaces");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "ShowTabsAndSpaces", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_Flag_Type.tp_dict,
        "ShowTabsAndSpaces", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_Flag_Type,
        (long) QTextOption::ShowLineAndParagraphSeparators, "ShowLineAndParagraphSeparators");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "ShowLineAndParagraphSeparators", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_Flag_Type.tp_dict,
        "ShowLineAndParagraphSeparators", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_Flag_Type,
        (long) QTextOption::AddSpaceForLineAndParagraphSeparators, "AddSpaceForLineAndParagraphSeparators");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "AddSpaceForLineAndParagraphSeparators", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_Flag_Type.tp_dict,
        "AddSpaceForLineAndParagraphSeparators", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_Flag_Type,
        (long) QTextOption::SuppressColors, "SuppressColors");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "SuppressColors", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_Flag_Type.tp_dict,
        "SuppressColors", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_Flag_Type,
        (long) QTextOption::IncludeTrailingSpaces, "IncludeTrailingSpaces");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "IncludeTrailingSpaces", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_Flag_Type.tp_dict,
        "IncludeTrailingSpaces", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextOption::Flag");

    // init enum class: WrapMode
    SbkPySide_QtGuiTypes[SBK_QTEXTOPTION_WRAPMODE_IDX] = &SbkPySide_QtGui_QTextOption_WrapMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextOption_WrapMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextOption_WrapMode_Type);
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
            "WrapMode",((PyObject*)&SbkPySide_QtGui_QTextOption_WrapMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_WrapMode_Type,
        (long) QTextOption::NoWrap, "NoWrap");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "NoWrap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_WrapMode_Type.tp_dict,
        "NoWrap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_WrapMode_Type,
        (long) QTextOption::WordWrap, "WordWrap");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "WordWrap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_WrapMode_Type.tp_dict,
        "WordWrap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_WrapMode_Type,
        (long) QTextOption::ManualWrap, "ManualWrap");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "ManualWrap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_WrapMode_Type.tp_dict,
        "ManualWrap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_WrapMode_Type,
        (long) QTextOption::WrapAnywhere, "WrapAnywhere");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "WrapAnywhere", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_WrapMode_Type.tp_dict,
        "WrapAnywhere", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextOption_WrapMode_Type,
        (long) QTextOption::WrapAtWordBoundaryOrAnywhere, "WrapAtWordBoundaryOrAnywhere");
    PyDict_SetItemString(SbkQTextOption_Type.super.ht_type.tp_dict,
        "WrapAtWordBoundaryOrAnywhere", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextOption_WrapMode_Type.tp_dict,
        "WrapAtWordBoundaryOrAnywhere", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextOption::WrapMode");


    Shiboken::TypeResolver::createValueTypeResolver<QTextOption >("QTextOption");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextOption >("QTextOption*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextOption >(typeid(QTextOption).name());
    PySide::initQtMetaType<QTextOption >();
}

