/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtexttablecellformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QStringList>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qpen.h>
#include <qtextformat.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextTableCellFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextTableCellFormat >()))
        return -1;

    QTextTableCellFormat* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextTableCellFormat", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextTableCellFormat(QTextTableCellFormat)
    // 1: QTextTableCellFormat()
    // 2: QTextTableCellFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 1; // QTextTableCellFormat()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextFormat & >::isConvertible(arg)) {
        overloadId = 2; // QTextTableCellFormat(QTextFormat)
    } else if (numArgs == 1 && Shiboken::Converter<const QTextTableCellFormat & >::isConvertible(arg)) {
        overloadId = 0; // QTextTableCellFormat(QTextTableCellFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableCellFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextTableCellFormat(QTextTableCellFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextTableCellFormat* cpp_arg0 = Shiboken::Converter<QTextTableCellFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextTableCellFormat(QTextTableCellFormat)
                cptr = new QTextTableCellFormat(*cpp_arg0);
                }
                break;
            }
            case 1: // QTextTableCellFormat()
            {

                if(!PyErr_Occurred()) {
                // QTextTableCellFormat()
                cptr = new QTextTableCellFormat();
                }
                break;
            }
            case 2: // QTextTableCellFormat(QTextFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextFormat* cpp_arg0 = Shiboken::Converter<QTextFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextTableCellFormat(QTextFormat)
                cptr = new QTextTableCellFormat(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextTableCellFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextTableCellFormat_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextTableCellFormat_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextTableCellFormat", "", "PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextTableCellFormat", overloads);
        return -1;
}

static PyObject* SbkQTextTableCellFormatFunc_bottomPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bottomPadding()const
            qreal cppResult = cppSelf->QTextTableCellFormat::bottomPadding();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableCellFormatFunc_isValid(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QTextTableCellFormat::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableCellFormatFunc_leftPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // leftPadding()const
            qreal cppResult = cppSelf->QTextTableCellFormat::leftPadding();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableCellFormatFunc_rightPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rightPadding()const
            qreal cppResult = cppSelf->QTextTableCellFormat::rightPadding();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableCellFormatFunc_setBottomPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottomPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableCellFormatFunc_setBottomPadding_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBottomPadding(qreal)
            cppSelf->QTextTableCellFormat::setBottomPadding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableCellFormatFunc_setBottomPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setBottomPadding", overloads);
        return 0;
}

static PyObject* SbkQTextTableCellFormatFunc_setLeftPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeftPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeftPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableCellFormatFunc_setLeftPadding_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLeftPadding(qreal)
            cppSelf->QTextTableCellFormat::setLeftPadding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableCellFormatFunc_setLeftPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setLeftPadding", overloads);
        return 0;
}

static PyObject* SbkQTextTableCellFormatFunc_setPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableCellFormatFunc_setPadding_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPadding(qreal)
            cppSelf->QTextTableCellFormat::setPadding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableCellFormatFunc_setPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setPadding", overloads);
        return 0;
}

static PyObject* SbkQTextTableCellFormatFunc_setRightPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRightPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRightPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableCellFormatFunc_setRightPadding_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRightPadding(qreal)
            cppSelf->QTextTableCellFormat::setRightPadding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableCellFormatFunc_setRightPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setRightPadding", overloads);
        return 0;
}

static PyObject* SbkQTextTableCellFormatFunc_setTopPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTopPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableCellFormatFunc_setTopPadding_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTopPadding(qreal)
            cppSelf->QTextTableCellFormat::setTopPadding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableCellFormatFunc_setTopPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setTopPadding", overloads);
        return 0;
}

static PyObject* SbkQTextTableCellFormatFunc_topPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // topPadding()const
            qreal cppResult = cppSelf->QTextTableCellFormat::topPadding();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQTextTableCellFormat_methods[] = {
    {"bottomPadding", (PyCFunction)SbkQTextTableCellFormatFunc_bottomPadding, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQTextTableCellFormatFunc_isValid, METH_NOARGS},
    {"leftPadding", (PyCFunction)SbkQTextTableCellFormatFunc_leftPadding, METH_NOARGS},
    {"rightPadding", (PyCFunction)SbkQTextTableCellFormatFunc_rightPadding, METH_NOARGS},
    {"setBottomPadding", (PyCFunction)SbkQTextTableCellFormatFunc_setBottomPadding, METH_O},
    {"setLeftPadding", (PyCFunction)SbkQTextTableCellFormatFunc_setLeftPadding, METH_O},
    {"setPadding", (PyCFunction)SbkQTextTableCellFormatFunc_setPadding, METH_O},
    {"setRightPadding", (PyCFunction)SbkQTextTableCellFormatFunc_setRightPadding, METH_O},
    {"setTopPadding", (PyCFunction)SbkQTextTableCellFormatFunc_setTopPadding, METH_O},
    {"topPadding", (PyCFunction)SbkQTextTableCellFormatFunc_topPadding, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextTableCellFormat_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextTableCellFormat",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextTableCellFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextTableCellFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextTableCellFormat >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextTableCellFormat",
    /*user_data*/           0
};
} //extern


void init_QTextTableCellFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextTableCellFormat_Type);

    SbkQTextTableCellFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQTextTableCellFormat_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextTableCellFormat_Type));
    PyModule_AddObject(module, "QTextTableCellFormat",
        ((PyObject*)&SbkQTextTableCellFormat_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextTableCellFormat >("QTextTableCellFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextTableCellFormat >("QTextTableCellFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextTableCellFormat >(typeid(QTextTableCellFormat).name());
    PySide::initQtMetaType<QTextTableCellFormat >();
}

