/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtexttableformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qpen.h>
#include <qtextformat.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextTableFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextTableFormat >()))
        return -1;

    QTextTableFormat* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextTableFormat", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTextTableFormat(QTextTableFormat)
    // 1: QTextTableFormat()
    // 2: QTextTableFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 1; // QTextTableFormat()
    } else if (numArgs == 1 && Shiboken::Converter<const QTextFormat & >::isConvertible(arg)) {
        overloadId = 2; // QTextTableFormat(QTextFormat)
    } else if (numArgs == 1 && Shiboken::Converter<const QTextTableFormat & >::isConvertible(arg)) {
        overloadId = 0; // QTextTableFormat(QTextTableFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextTableFormat(QTextTableFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextTableFormat* cpp_arg0 = Shiboken::Converter<QTextTableFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextTableFormat(QTextTableFormat)
                cptr = new QTextTableFormat(*cpp_arg0);
                }
                break;
            }
            case 1: // QTextTableFormat()
            {

                if(!PyErr_Occurred()) {
                // QTextTableFormat()
                cptr = new QTextTableFormat();
                }
                break;
            }
            case 2: // QTextTableFormat(QTextFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QTextFormat* cpp_arg0 = Shiboken::Converter<QTextFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QTextTableFormat(QTextFormat)
                cptr = new QTextTableFormat(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextTableFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextTableFormat_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQTextTableFormat_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextTableFormat", "", "PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextTableFormat", overloads);
        return -1;
}

static PyObject* SbkQTextTableFormatFunc_alignment(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alignment()const
            QFlags<Qt::AlignmentFlag> cppResult = cppSelf->QTextTableFormat::alignment();
            pyResult = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableFormatFunc_cellPadding(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cellPadding()const
            qreal cppResult = cppSelf->QTextTableFormat::cellPadding();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableFormatFunc_cellSpacing(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cellSpacing()const
            qreal cppResult = cppSelf->QTextTableFormat::cellSpacing();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableFormatFunc_clearColumnWidthConstraints(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearColumnWidthConstraints()
            cppSelf->QTextTableFormat::clearColumnWidthConstraints();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextTableFormatFunc_columnWidthConstraints(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columnWidthConstraints()const
            QVector<QTextLength > cppResult = cppSelf->QTextTableFormat::columnWidthConstraints();
            pyResult = Shiboken::Converter<QVector<QTextLength > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableFormatFunc_columns(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columns()const
            int cppResult = cppSelf->QTextTableFormat::columns();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableFormatFunc_headerRowCount(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // headerRowCount()const
            int cppResult = cppSelf->QTextTableFormat::headerRowCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableFormatFunc_isValid(PyObject* self)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QTextTableFormat::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextTableFormatFunc_setAlignment(PyObject* self, PyObject* arg)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableFormatFunc_setAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->QTextTableFormat::setAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableFormatFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableFormat.setAlignment", overloads);
        return 0;
}

static PyObject* SbkQTextTableFormatFunc_setCellPadding(PyObject* self, PyObject* arg)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCellPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCellPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableFormatFunc_setCellPadding_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCellPadding(qreal)
            cppSelf->QTextTableFormat::setCellPadding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableFormatFunc_setCellPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableFormat.setCellPadding", overloads);
        return 0;
}

static PyObject* SbkQTextTableFormatFunc_setCellSpacing(PyObject* self, PyObject* arg)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCellSpacing(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCellSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableFormatFunc_setCellSpacing_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCellSpacing(qreal)
            cppSelf->QTextTableFormat::setCellSpacing(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableFormatFunc_setCellSpacing_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableFormat.setCellSpacing", overloads);
        return 0;
}

static PyObject* SbkQTextTableFormatFunc_setColumnWidthConstraints(PyObject* self, PyObject* arg)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumnWidthConstraints(QVector<QTextLength>)
    if (Shiboken::Converter< QVector<QTextLength >  >::isConvertible(arg)) {
        overloadId = 0; // setColumnWidthConstraints(QVector<QTextLength>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableFormatFunc_setColumnWidthConstraints_TypeError;

    // Call function/method
    {
        {
            QVector<QTextLength > cpp_arg0 = Shiboken::Converter<QVector<QTextLength > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setColumnWidthConstraints(QVector<QTextLength>)
            cppSelf->QTextTableFormat::setColumnWidthConstraints(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableFormatFunc_setColumnWidthConstraints_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableFormat.setColumnWidthConstraints", overloads);
        return 0;
}

static PyObject* SbkQTextTableFormatFunc_setColumns(PyObject* self, PyObject* arg)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumns(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColumns(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableFormatFunc_setColumns_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setColumns(int)
            cppSelf->QTextTableFormat::setColumns(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableFormatFunc_setColumns_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableFormat.setColumns", overloads);
        return 0;
}

static PyObject* SbkQTextTableFormatFunc_setHeaderRowCount(PyObject* self, PyObject* arg)
{
    QTextTableFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextTableFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeaderRowCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHeaderRowCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextTableFormatFunc_setHeaderRowCount_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHeaderRowCount(int)
            cppSelf->QTextTableFormat::setHeaderRowCount(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextTableFormatFunc_setHeaderRowCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableFormat.setHeaderRowCount", overloads);
        return 0;
}

static PyMethodDef SbkQTextTableFormat_methods[] = {
    {"alignment", (PyCFunction)SbkQTextTableFormatFunc_alignment, METH_NOARGS},
    {"cellPadding", (PyCFunction)SbkQTextTableFormatFunc_cellPadding, METH_NOARGS},
    {"cellSpacing", (PyCFunction)SbkQTextTableFormatFunc_cellSpacing, METH_NOARGS},
    {"clearColumnWidthConstraints", (PyCFunction)SbkQTextTableFormatFunc_clearColumnWidthConstraints, METH_NOARGS},
    {"columnWidthConstraints", (PyCFunction)SbkQTextTableFormatFunc_columnWidthConstraints, METH_NOARGS},
    {"columns", (PyCFunction)SbkQTextTableFormatFunc_columns, METH_NOARGS},
    {"headerRowCount", (PyCFunction)SbkQTextTableFormatFunc_headerRowCount, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQTextTableFormatFunc_isValid, METH_NOARGS},
    {"setAlignment", (PyCFunction)SbkQTextTableFormatFunc_setAlignment, METH_O},
    {"setCellPadding", (PyCFunction)SbkQTextTableFormatFunc_setCellPadding, METH_O},
    {"setCellSpacing", (PyCFunction)SbkQTextTableFormatFunc_setCellSpacing, METH_O},
    {"setColumnWidthConstraints", (PyCFunction)SbkQTextTableFormatFunc_setColumnWidthConstraints, METH_O},
    {"setColumns", (PyCFunction)SbkQTextTableFormatFunc_setColumns, METH_O},
    {"setHeaderRowCount", (PyCFunction)SbkQTextTableFormatFunc_setHeaderRowCount, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextTableFormat_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextTableFormat",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextTableFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextTableFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextTableFormat >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextTableFormat",
    /*user_data*/           0
};
} //extern


void init_QTextTableFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTTABLEFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextTableFormat_Type);

    SbkQTextTableFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQTextTableFormat_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextTableFormat_Type));
    PyModule_AddObject(module, "QTextTableFormat",
        ((PyObject*)&SbkQTextTableFormat_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextTableFormat >("QTextTableFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextTableFormat >("QTextTableFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextTableFormat >(typeid(QTextTableFormat).name());
    PySide::initQtMetaType<QTextTableFormat >();
}

