/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtooltip_wrapper.h"

// Extra includes
#include <qfont.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qwidget.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQToolTipFunc_font(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // font()
            QFont cppResult = QToolTip::font();
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQToolTipFunc_hideText(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hideText()
            QToolTip::hideText();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQToolTipFunc_isVisible(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isVisible()
            bool cppResult = QToolTip::isVisible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQToolTipFunc_palette(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // palette()
            QPalette cppResult = QToolTip::palette();
            pyResult = Shiboken::Converter<QPalette >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQToolTipFunc_setFont(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQToolTipFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFont(QFont)
            QToolTip::setFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQToolTipFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QToolTip.setFont", overloads);
        return 0;
}

static PyObject* SbkQToolTipFunc_setPalette(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPalette(QPalette)
    if (Shiboken::Converter<const QPalette & >::isConvertible(arg)) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQToolTipFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPalette > cpp_arg0_auto_ptr;
            QPalette* cpp_arg0 = Shiboken::Converter<QPalette* >::toCpp(arg);
            if (!Shiboken::Converter<QPalette >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPalette >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPalette(QPalette)
            QToolTip::setPalette(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQToolTipFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QToolTip.setPalette", overloads);
        return 0;
}

static PyObject* SbkQToolTipFunc_showText(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "w" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QToolTip.showText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QToolTip.showText(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QToolTip.showText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:showText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: showText(QPoint,QString,QWidget*)
    // 1: showText(QPoint,QString,QWidget*,QRect)
    if (numArgs >= 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // showText(QPoint,QString,QWidget*)
        } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // showText(QPoint,QString,QWidget*)
            } else if (numArgs == 4 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[3])) {
                overloadId = 1; // showText(QPoint,QString,QWidget*,QRect)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQToolTipFunc_showText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // showText(QPoint,QString,QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "w");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "w";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QToolTip.showText(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QWidget* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // showText(QPoint,QString,QWidget*)
                QToolTip::showText(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // showText(QPoint,QString,QWidget*,QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QWidget* cpp_arg2 = Shiboken::Converter<QWidget* >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QRect* cpp_arg3 = Shiboken::Converter<QRect* >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // showText(QPoint,QString,QWidget*,QRect)
                QToolTip::showText(*cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQToolTipFunc_showText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, QString, PySide.QtGui.QWidget = None", "PySide.QtCore.QPoint, QString, PySide.QtGui.QWidget, PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QToolTip.showText", overloads);
        return 0;
}

static PyObject* SbkQToolTipFunc_text(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()
            QString cppResult = QToolTip::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQToolTip_methods[] = {
    {"font", (PyCFunction)SbkQToolTipFunc_font, METH_NOARGS|METH_STATIC},
    {"hideText", (PyCFunction)SbkQToolTipFunc_hideText, METH_NOARGS|METH_STATIC},
    {"isVisible", (PyCFunction)SbkQToolTipFunc_isVisible, METH_NOARGS|METH_STATIC},
    {"palette", (PyCFunction)SbkQToolTipFunc_palette, METH_NOARGS|METH_STATIC},
    {"setFont", (PyCFunction)SbkQToolTipFunc_setFont, METH_O|METH_STATIC},
    {"setPalette", (PyCFunction)SbkQToolTipFunc_setPalette, METH_O|METH_STATIC},
    {"showText", (PyCFunction)SbkQToolTipFunc_showText, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"text", (PyCFunction)SbkQToolTipFunc_text, METH_NOARGS|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQToolTip_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QToolTip",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQToolTip_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QToolTip >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QToolTip*",
    /*user_data*/           0
};
} //extern


void init_QToolTip(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTOOLTIP_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQToolTip_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQToolTip_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQToolTip_Type));
    PyModule_AddObject(module, "QToolTip",
        ((PyObject*)&SbkQToolTip_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QToolTip >("QToolTip*");
    Shiboken::TypeResolver::createObjectTypeResolver<QToolTip >(typeid(QToolTip).name());
    PySide::initQtMetaType<QToolTip* >();
}

