/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qvector2d_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qpoint.h>
#include <qvector2d.h>
#include <qvector3d.h>
#include <qvector4d.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQVector2D_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QVector2D >()))
        return -1;

    QVector2D* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QVector2D", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QVector2D(QVector2D)
    // 1: QVector2D()
    // 2: QVector2D(QPoint)
    // 3: QVector2D(QPointF)
    // 4: QVector2D(QVector3D)
    // 5: QVector2D(QVector4D)
    // 6: QVector2D(qreal,qreal)
    if (numArgs == 0) {
        overloadId = 1; // QVector2D()
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 6; // QVector2D(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QVector2D(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QVector2D(QPointF)
    } else if (numArgs == 1 && Shiboken::Converter<const QVector2D & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QVector2D(QVector2D)
    } else if (numArgs == 1 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[0])) {
        overloadId = 4; // QVector2D(QVector3D)
    } else if (numArgs == 1 && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[0])) {
        overloadId = 5; // QVector2D(QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2D_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QVector2D(QVector2D)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QVector2D(QVector2D)
                cptr = new QVector2D(*cpp_arg0);
                }
                break;
            }
            case 1: // QVector2D()
            {

                if(!PyErr_Occurred()) {
                // QVector2D()
                cptr = new QVector2D();
                }
                break;
            }
            case 2: // QVector2D(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QVector2D(QPoint)
                cptr = new QVector2D(*cpp_arg0);
                }
                break;
            }
            case 3: // QVector2D(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QVector2D(QPointF)
                cptr = new QVector2D(*cpp_arg0);
                }
                break;
            }
            case 4: // QVector2D(QVector3D)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QVector3D > cpp_arg0_auto_ptr;
                QVector3D* cpp_arg0 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QVector2D(QVector3D)
                cptr = new QVector2D(*cpp_arg0);
                }
                break;
            }
            case 5: // QVector2D(QVector4D)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QVector4D > cpp_arg0_auto_ptr;
                QVector4D* cpp_arg0 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QVector2D(QVector4D)
                cptr = new QVector2D(*cpp_arg0);
                }
                break;
            }
            case 6: // QVector2D(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QVector2D(qreal,qreal)
                cptr = new QVector2D(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QVector2D >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQVector2D_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQVector2D_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D", "", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QVector3D", "PySide.QtGui.QVector4D", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector2D", overloads);
        return -1;
}

static PyObject* SbkQVector2DFunc_dotProduct(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dotProduct", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: dotProduct(QVector2D,QVector2D)
    if (numArgs == 2 && Shiboken::Converter<const QVector2D & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QVector2D & >::isConvertible(pyargs[1])) {
        overloadId = 0; // dotProduct(QVector2D,QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc_dotProduct_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // dotProduct(QVector2D,QVector2D)
            qreal cppResult = QVector2D::dotProduct(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQVector2DFunc_dotProduct_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D, PySide.QtGui.QVector2D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector2D.dotProduct", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc_isNull(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QVector2D::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_length(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            qreal cppResult = cppSelf->QVector2D::length();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_lengthSquared(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lengthSquared()const
            qreal cppResult = cppSelf->QVector2D::lengthSquared();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_normalize(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalize()
            cppSelf->QVector2D::normalize();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQVector2DFunc_normalized(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalized()const
            QVector2D cppResult = cppSelf->QVector2D::normalized();
            pyResult = Shiboken::Converter<QVector2D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_setX(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc_setX_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setX(qreal)
            cppSelf->QVector2D::setX(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQVector2DFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.setX", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc_setY(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc_setY_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setY(qreal)
            cppSelf->QVector2D::setY(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQVector2DFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.setY", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc_toPoint(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPoint()const
            QPoint cppResult = cppSelf->QVector2D::toPoint();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_toPointF(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPointF()const
            QPointF cppResult = cppSelf->QVector2D::toPointF();
            pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_toVector3D(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toVector3D()const
            QVector3D cppResult = cppSelf->QVector2D::toVector3D();
            pyResult = Shiboken::Converter<QVector3D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_toVector4D(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toVector4D()const
            QVector4D cppResult = cppSelf->QVector2D::toVector4D();
            pyResult = Shiboken::Converter<QVector4D >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_x(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x()const
            qreal cppResult = cppSelf->QVector2D::x();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc_y(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y()const
            qreal cppResult = cppSelf->QVector2D::y();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQVector2D_methods[] = {
    {"dotProduct", (PyCFunction)SbkQVector2DFunc_dotProduct, METH_VARARGS|METH_STATIC},
    {"isNull", (PyCFunction)SbkQVector2DFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)SbkQVector2DFunc_length, METH_NOARGS},
    {"lengthSquared", (PyCFunction)SbkQVector2DFunc_lengthSquared, METH_NOARGS},
    {"normalize", (PyCFunction)SbkQVector2DFunc_normalize, METH_NOARGS},
    {"normalized", (PyCFunction)SbkQVector2DFunc_normalized, METH_NOARGS},
    {"setX", (PyCFunction)SbkQVector2DFunc_setX, METH_O},
    {"setY", (PyCFunction)SbkQVector2DFunc_setY, METH_O},
    {"toPoint", (PyCFunction)SbkQVector2DFunc_toPoint, METH_NOARGS},
    {"toPointF", (PyCFunction)SbkQVector2DFunc_toPointF, METH_NOARGS},
    {"toVector3D", (PyCFunction)SbkQVector2DFunc_toVector3D, METH_NOARGS},
    {"toVector4D", (PyCFunction)SbkQVector2DFunc_toVector4D, METH_NOARGS},
    {"x", (PyCFunction)SbkQVector2DFunc_x, METH_NOARGS},
    {"y", (PyCFunction)SbkQVector2DFunc_y, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQVector2DFunc___mul__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QVector2D,QVector2D)
    // 1: operator*(qreal,QVector2D)
    // 2: operator*(QVector2D,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 2; // operator*(QVector2D,qreal)
    } else if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*(qreal,QVector2D)
    } else if (!isReverse && Shiboken::Converter<const QVector2D & >::isConvertible(arg)) {
        overloadId = 0; // operator*(QVector2D,QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QVector2D,QVector2D)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QVector2D,QVector2D)
                const QVector2D cppResult = (*cppSelf) * (*cpp_arg0);
                pyResult = Shiboken::Converter< QVector2D >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(qreal,QVector2D)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(qreal,QVector2D) [reverse operator]
                const QVector2D cppResult = cpp_arg0 * (*cppSelf);
                pyResult = Shiboken::Converter< QVector2D >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(QVector2D,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*(QVector2D,qreal)
                const QVector2D cppResult = (*cppSelf) * cpp_arg0;
                pyResult = Shiboken::Converter< QVector2D >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQVector2DFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D", "float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__mul__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___imul__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QVector2D)
    // 1: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse && Shiboken::Converter<const QVector2D & >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___imul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*=(QVector2D)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*=(QVector2D)
                (*cppSelf) *= (*cpp_arg0);
                }
                break;
            }
            case 1: // operator*=(qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator*=(qreal)
                (*cppSelf) *= cpp_arg0;
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQVector2DFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__imul__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___add__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QVector2D,QVector2D)
    if (!isReverse && Shiboken::Converter<const QVector2D & >::isConvertible(arg)) {
        overloadId = 0; // operator+(QVector2D,QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___add___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+(QVector2D,QVector2D)
            const QVector2D cppResult = (*cppSelf) + (*cpp_arg0);
            pyResult = Shiboken::Converter< QVector2D >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQVector2DFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__add__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___iadd__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QVector2D)
    if (!isReverse && Shiboken::Converter<const QVector2D & >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator+=(QVector2D)
            (*cppSelf) += (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQVector2DFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__iadd__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___neg__(PyObject* self)
{
    QVector2D* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // operator-(QVector2D)
            const QVector2D cppResult = - (*cppSelf);
            pyResult = Shiboken::Converter< QVector2D >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQVector2DFunc___sub__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QVector2D,QVector2D)
    if (!isReverse && Shiboken::Converter<const QVector2D & >::isConvertible(arg)) {
        overloadId = 0; // operator-(QVector2D,QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-(QVector2D,QVector2D)
            const QVector2D cppResult = (*cppSelf) - (*cpp_arg0);
            pyResult = Shiboken::Converter< QVector2D >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQVector2DFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__sub__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___isub__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QVector2D)
    if (!isReverse && Shiboken::Converter<const QVector2D & >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QVector2D* cpp_arg0 = Shiboken::Converter<QVector2D* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator-=(QVector2D)
            (*cppSelf) -= (*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQVector2DFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector2D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__isub__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___div__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QVector2D,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QVector2D,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/(QVector2D,qreal)
            const QVector2D cppResult = (*cppSelf) / cpp_arg0;
            pyResult = Shiboken::Converter< QVector2D >::toPython(cppResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQVector2DFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__div__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___idiv__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator/=(qreal)
            (*cppSelf) /= cpp_arg0;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQVector2DFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__idiv__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___lshift__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QVector2D)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QVector2D) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQVector2DFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQVector2DFunc___rshift__(PyObject* self, PyObject* arg)
{
    QVector2D* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QVector2D >::checkType(arg) && !Shiboken::Converter<QVector2D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QVector2D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QVector2D&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QVector2D&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQVector2DFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QVector2D&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQVector2DFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector2D.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQVector2D_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQVector2DFunc___add__,
    /*nb_subtract*/             (binaryfunc)SbkQVector2DFunc___sub__,
    /*nb_multiply*/             (binaryfunc)SbkQVector2DFunc___mul__,
    /*nb_divide*/               (binaryfunc)SbkQVector2DFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)SbkQVector2DFunc___neg__,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQVector2DFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQVector2DFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQVector2DFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)SbkQVector2DFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)SbkQVector2DFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)SbkQVector2DFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQVector2D_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QVector2D& cpp_self = *Shiboken::Converter<QVector2D* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QVector2D & >::isConvertible(other)) {
                // operator!=(const QVector2D & v2)
                QVector2D* cpp_other = Shiboken::Converter<QVector2D* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QVector2D  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQVector2D_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QVector2D & >::isConvertible(other)) {
                // operator==(const QVector2D & v2)
                QVector2D* cpp_other = Shiboken::Converter<QVector2D* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QVector2D  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQVector2D_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQVector2D_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQVector2D_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QVector2D",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQVector2D_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQVector2D_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQVector2D_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQVector2D_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QVector2D >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QVector2D",
    /*user_data*/           0
};
} //extern


void init_QVector2D(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QVECTOR2D_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQVector2D_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQVector2D_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQVector2D_Type));
    PyModule_AddObject(module, "QVector2D",
        ((PyObject*)&SbkQVector2D_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QVector2D >("QVector2D");
    Shiboken::TypeResolver::createObjectTypeResolver<QVector2D >("QVector2D*");
    Shiboken::TypeResolver::createValueTypeResolver<QVector2D >(typeid(QVector2D).name());
    PySide::initQtMetaType<QVector2D >();
}

