/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qwizard_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractbutton.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qwidget.h>
#include <qwizard.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QWizardWrapper::QWizardWrapper(QWidget * parent, QFlags<Qt::WindowType> flags) : QWizard(parent, flags), m_metaObject(0) {
    // ... middle
}

void QWizardWrapper::accept()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "accept"));
    if (py_override.isNull()) {
        return this->QDialog::accept();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::cleanupPage(int id)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "cleanupPage"));
    if (py_override.isNull()) {
        return this->QWizard::cleanupPage(id);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        id
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QDialog::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QDialog::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QWizardWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::done(int result)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "done"));
    if (py_override.isNull()) {
        return this->QWizard::done(result);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        result
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::dragEnterEvent(QDragEnterEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragEnterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::dragLeaveEvent(QDragLeaveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragLeaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::dragMoveEvent(QDragMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::dropEvent(QDropEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dropEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWizardWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QWizard::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QWizardWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QDialog::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::focusInEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusInEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWizardWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::focusOutEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusOutEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QWizardWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::initializePage(int id)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "initializePage"));
    if (py_override.isNull()) {
        return this->QWizard::initializePage(id);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        id
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QWizardWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::keyPressEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QDialog::keyPressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::keyReleaseEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QWizardWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QWizardWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QDialog::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::mouseDoubleClickEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseDoubleClickEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::mouseMoveEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::mousePressEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mousePressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::mouseReleaseEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QWizardWrapper::nextId() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "nextId"));
    if (py_override.isNull()) {
        return this->QWizard::nextId();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.nextId", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QWizardWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QWizard.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QWizardWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QWizard::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::reject()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reject"));
    if (py_override.isNull()) {
        return this->QDialog::reject();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QWizard::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QWizard::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWizardWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QDialog::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QWizardWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QWizard::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWizardWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QWizardWrapper::validateCurrentPage()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "validateCurrentPage"));
    if (py_override.isNull()) {
        return this->QWizard::validateCurrentPage();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWizard.validateCurrentPage", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QWizardWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QWidget::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QWizardWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QWizard::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QWizardWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QWizard::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QWizardWrapper::~QWizardWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQWizard_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QWizard >()))
        return -1;

    QWizardWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QWizard", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QWizard(QWidget*,QFlags<Qt::WindowType>)
    if (numArgs == 0) {
        overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QWizard(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizard_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWizard(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
            QFlags<Qt::WindowType> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
            // QWizard(QWidget*,QFlags<Qt::WindowType>)
            cptr = new QWizardWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[0], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QWizard >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQWizard_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQWizard_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard", overloads);
        return -1;
}

static PyObject* SbkQWizardFunc_addPage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPage(QWizardPage*)
    if (Shiboken::Converter<QWizardPage * >::isConvertible(arg)) {
        overloadId = 0; // addPage(QWizardPage*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_addPage_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWizardPage* cpp_arg0 = Shiboken::Converter<QWizardPage* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addPage(QWizardPage*)
            int cppResult = cppSelf->QWizard::addPage(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_addPage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizardPage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.addPage", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_back(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // back()
            cppSelf->QWizard::back();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWizardFunc_button(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: button(QWizard::WizardButton)const
    if (Shiboken::Converter<QWizard::WizardButton >::isConvertible(arg)) {
        overloadId = 0; // button(QWizard::WizardButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_button_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cpp_arg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // button(QWizard::WizardButton)const
            QAbstractButton * cppResult = cppSelf->QWizard::button(cpp_arg0);
            pyResult = Shiboken::Converter<QAbstractButton * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_button_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.button", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_buttonText(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: buttonText(QWizard::WizardButton)const
    if (Shiboken::Converter<QWizard::WizardButton >::isConvertible(arg)) {
        overloadId = 0; // buttonText(QWizard::WizardButton)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_buttonText_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cpp_arg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // buttonText(QWizard::WizardButton)const
            QString cppResult = cppSelf->QWizard::buttonText(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_buttonText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.buttonText", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_cleanupPage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: cleanupPage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // cleanupPage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_cleanupPage_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // cleanupPage(int)
            cppSelf->QWizard::cleanupPage(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_cleanupPage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.cleanupPage", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_currentId(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentId()const
            int cppResult = cppSelf->QWizard::currentId();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_currentPage(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentPage()const
            QWizardPage * cppResult = cppSelf->QWizard::currentPage();
            pyResult = Shiboken::Converter<QWizardPage * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_done(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: done(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // done(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_done_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // done(int)
            cppSelf->QWizard::done(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_done_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.done", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_event(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QWizard::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.event", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_field(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: field(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // field(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_field_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // field(QString)const
            QVariant cppResult = cppSelf->QWizard::field(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_field_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.field", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_hasVisitedPage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasVisitedPage(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // hasVisitedPage(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_hasVisitedPage_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasVisitedPage(int)const
            bool cppResult = cppSelf->QWizard::hasVisitedPage(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_hasVisitedPage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.hasVisitedPage", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_initializePage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: initializePage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // initializePage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_initializePage_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // initializePage(int)
            cppSelf->QWizard::initializePage(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_initializePage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.initializePage", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_next(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // next()
            cppSelf->QWizard::next();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWizardFunc_nextId(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextId()const
            int cppResult = cppSelf->QWizard::nextId();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_options(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // options()const
            QFlags<QWizard::WizardOption> cppResult = cppSelf->QWizard::options();
            pyResult = Shiboken::Converter<QFlags<QWizard::WizardOption> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_page(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: page(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // page(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_page_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // page(int)const
            QWizardPage * cppResult = cppSelf->QWizard::page(cpp_arg0);
            pyResult = Shiboken::Converter<QWizardPage * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_page_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.page", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_pageIds(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pageIds()const
            QList<int > cppResult = cppSelf->QWizard::pageIds();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter<QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintEvent* cpp_arg0 = Shiboken::Converter<QPaintEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // paintEvent(QPaintEvent*)
            cppSelf->QWizard::paintEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.paintEvent", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_pixmap(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: pixmap(QWizard::WizardPixmap)const
    if (Shiboken::Converter<QWizard::WizardPixmap >::isConvertible(arg)) {
        overloadId = 0; // pixmap(QWizard::WizardPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_pixmap_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardPixmap cpp_arg0 = Shiboken::Converter<QWizard::WizardPixmap >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // pixmap(QWizard::WizardPixmap)const
            QPixmap cppResult = cppSelf->QWizard::pixmap(cpp_arg0);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_pixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.pixmap", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_removePage(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removePage(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removePage(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_removePage_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removePage(int)
            cppSelf->QWizard::removePage(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_removePage_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.removePage", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter<QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QResizeEvent* cpp_arg0 = Shiboken::Converter<QResizeEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resizeEvent(QResizeEvent*)
            cppSelf->QWizard::resizeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.resizeEvent", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_restart(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // restart()
            cppSelf->QWizard::restart();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWizardFunc_setButton(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setButton", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setButton(QWizard::WizardButton,QAbstractButton*)
    if (numArgs == 2 && Shiboken::Converter<QWizard::WizardButton >::isConvertible(pyargs[0]) && Shiboken::Converter<QAbstractButton * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setButton(QWizard::WizardButton,QAbstractButton*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setButton_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cpp_arg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QAbstractButton* cpp_arg1 = Shiboken::Converter<QAbstractButton* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setButton(QWizard::WizardButton,QAbstractButton*)
            cppSelf->QWizard::setButton(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[1]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setButton_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton, PySide.QtGui.QAbstractButton", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setButton", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setButtonLayout(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setButtonLayout(QList<QWizard::WizardButton>)
    if (Shiboken::Converter< QList<QWizard::WizardButton >  >::isConvertible(arg)) {
        overloadId = 0; // setButtonLayout(QList<QWizard::WizardButton>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setButtonLayout_TypeError;

    // Call function/method
    {
        {
            QList<QWizard::WizardButton > cpp_arg0 = Shiboken::Converter<QList<QWizard::WizardButton > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setButtonLayout(QList<QWizard::WizardButton>)
            cppSelf->QWizard::setButtonLayout(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setButtonLayout_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setButtonLayout", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setButtonText(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setButtonText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setButtonText(QWizard::WizardButton,QString)
    if (numArgs == 2 && Shiboken::Converter<QWizard::WizardButton >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setButtonText(QWizard::WizardButton,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setButtonText_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardButton cpp_arg0 = Shiboken::Converter<QWizard::WizardButton >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setButtonText(QWizard::WizardButton,QString)
            cppSelf->QWizard::setButtonText(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setButtonText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardButton, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setButtonText", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setDefaultProperty(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDefaultProperty", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setDefaultProperty(const char*,const char*,const char*)
    if (numArgs == 3 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && Shiboken::Converter<const char * >::isConvertible(pyargs[1]) && Shiboken::Converter<const char * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setDefaultProperty(const char*,const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setDefaultProperty_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
            const char * cpp_arg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setDefaultProperty(const char*,const char*,const char*)
            cppSelf->QWizard::setDefaultProperty(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setDefaultProperty_TypeError:
        const char* overloads[] = {"str, str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setDefaultProperty", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setField(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setField", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setField(QString,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setField(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setField_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setField(QString,QVariant)
            cppSelf->QWizard::setField(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setField_TypeError:
        const char* overloads[] = {"QString, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setField", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setOption(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "on" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWizard.setOption(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWizard.setOption(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWizard.setOption(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setOption", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOption(QWizard::WizardOption,bool)
    if (Shiboken::Converter<QWizard::WizardOption >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QWizard::WizardOption,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setOption(QWizard::WizardOption,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setOption_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWizard.setOption(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QWizard::WizardOption cpp_arg0 = Shiboken::Converter<QWizard::WizardOption >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setOption(QWizard::WizardOption,bool)
            cppSelf->QWizard::setOption(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardOption, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setOption", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setOptions(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOptions(QFlags<QWizard::WizardOption>)
    if (Shiboken::Converter<QFlags<QWizard::WizardOption> >::isConvertible(arg)) {
        overloadId = 0; // setOptions(QFlags<QWizard::WizardOption>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setOptions_TypeError;

    // Call function/method
    {
        {
            QFlags<QWizard::WizardOption> cpp_arg0 = Shiboken::Converter<QFlags<QWizard::WizardOption> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOptions(QFlags<QWizard::WizardOption>)
            cppSelf->QWizard::setOptions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setOptions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardOptions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setOptions", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setPage(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPage", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPage(int,QWizardPage*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QWizardPage * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPage(int,QWizardPage*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setPage_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QWizardPage* cpp_arg1 = Shiboken::Converter<QWizardPage* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setPage(int,QWizardPage*)
            cppSelf->QWizard::setPage(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setPage_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QWizardPage", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setPage", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setPixmap(PyObject* self, PyObject* args)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPixmap", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPixmap(QWizard::WizardPixmap,QPixmap)
    if (numArgs == 2 && Shiboken::Converter<QWizard::WizardPixmap >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPixmap(QWizard::WizardPixmap,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setPixmap_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardPixmap cpp_arg0 = Shiboken::Converter<QWizard::WizardPixmap >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
            QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setPixmap(QWizard::WizardPixmap,QPixmap)
            cppSelf->QWizard::setPixmap(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardPixmap, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWizard.setPixmap", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setSideWidget(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSideWidget(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setSideWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setSideWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSideWidget(QWidget*)
            cppSelf->QWizard::setSideWidget(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setSideWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setSideWidget", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setStartId(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartId(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartId(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setStartId_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStartId(int)
            cppSelf->QWizard::setStartId(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setStartId_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setStartId", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setSubTitleFormat(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSubTitleFormat(Qt::TextFormat)
    if (Shiboken::Converter<Qt::TextFormat >::isConvertible(arg)) {
        overloadId = 0; // setSubTitleFormat(Qt::TextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setSubTitleFormat_TypeError;

    // Call function/method
    {
        {
            Qt::TextFormat cpp_arg0 = Shiboken::Converter<Qt::TextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSubTitleFormat(Qt::TextFormat)
            cppSelf->QWizard::setSubTitleFormat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setSubTitleFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setSubTitleFormat", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setTitleFormat(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTitleFormat(Qt::TextFormat)
    if (Shiboken::Converter<Qt::TextFormat >::isConvertible(arg)) {
        overloadId = 0; // setTitleFormat(Qt::TextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setTitleFormat_TypeError;

    // Call function/method
    {
        {
            Qt::TextFormat cpp_arg0 = Shiboken::Converter<Qt::TextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTitleFormat(Qt::TextFormat)
            cppSelf->QWizard::setTitleFormat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setTitleFormat_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setTitleFormat", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setVisible(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisible(bool)
            cppSelf->QWizard::setVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setVisible", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_setWizardStyle(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWizardStyle(QWizard::WizardStyle)
    if (Shiboken::Converter<QWizard::WizardStyle >::isConvertible(arg)) {
        overloadId = 0; // setWizardStyle(QWizard::WizardStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_setWizardStyle_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardStyle cpp_arg0 = Shiboken::Converter<QWizard::WizardStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWizardStyle(QWizard::WizardStyle)
            cppSelf->QWizard::setWizardStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWizardFunc_setWizardStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.setWizardStyle", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_sideWidget(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sideWidget()const
            QWidget * cppResult = cppSelf->QWizard::sideWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_sizeHint(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizeHint()const
            QSize cppResult = cppSelf->QWizard::sizeHint();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_startId(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startId()const
            int cppResult = cppSelf->QWizard::startId();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_subTitleFormat(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // subTitleFormat()const
            Qt::TextFormat cppResult = cppSelf->QWizard::subTitleFormat();
            pyResult = Shiboken::Converter<Qt::TextFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_testOption(PyObject* self, PyObject* arg)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testOption(QWizard::WizardOption)const
    if (Shiboken::Converter<QWizard::WizardOption >::isConvertible(arg)) {
        overloadId = 0; // testOption(QWizard::WizardOption)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWizardFunc_testOption_TypeError;

    // Call function/method
    {
        {
            QWizard::WizardOption cpp_arg0 = Shiboken::Converter<QWizard::WizardOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // testOption(QWizard::WizardOption)const
            bool cppResult = cppSelf->QWizard::testOption(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWizardFunc_testOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWizard.WizardOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWizard.testOption", overloads);
        return 0;
}

static PyObject* SbkQWizardFunc_titleFormat(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // titleFormat()const
            Qt::TextFormat cppResult = cppSelf->QWizard::titleFormat();
            pyResult = Shiboken::Converter<Qt::TextFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_validateCurrentPage(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // validateCurrentPage()
            bool cppResult = cppSelf->QWizard::validateCurrentPage();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_visitedPages(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // visitedPages()const
            QList<int > cppResult = cppSelf->QWizard::visitedPages();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWizardFunc_wizardStyle(PyObject* self)
{
    QWizard* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWizard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // wizardStyle()const
            QWizard::WizardStyle cppResult = cppSelf->QWizard::wizardStyle();
            pyResult = Shiboken::Converter<QWizard::WizardStyle >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQWizard_methods[] = {
    {"addPage", (PyCFunction)SbkQWizardFunc_addPage, METH_O},
    {"back", (PyCFunction)SbkQWizardFunc_back, METH_NOARGS},
    {"button", (PyCFunction)SbkQWizardFunc_button, METH_O},
    {"buttonText", (PyCFunction)SbkQWizardFunc_buttonText, METH_O},
    {"cleanupPage", (PyCFunction)SbkQWizardFunc_cleanupPage, METH_O},
    {"currentId", (PyCFunction)SbkQWizardFunc_currentId, METH_NOARGS},
    {"currentPage", (PyCFunction)SbkQWizardFunc_currentPage, METH_NOARGS},
    {"done", (PyCFunction)SbkQWizardFunc_done, METH_O},
    {"event", (PyCFunction)SbkQWizardFunc_event, METH_O},
    {"field", (PyCFunction)SbkQWizardFunc_field, METH_O},
    {"hasVisitedPage", (PyCFunction)SbkQWizardFunc_hasVisitedPage, METH_O},
    {"initializePage", (PyCFunction)SbkQWizardFunc_initializePage, METH_O},
    {"next", (PyCFunction)SbkQWizardFunc_next, METH_NOARGS},
    {"nextId", (PyCFunction)SbkQWizardFunc_nextId, METH_NOARGS},
    {"options", (PyCFunction)SbkQWizardFunc_options, METH_NOARGS},
    {"page", (PyCFunction)SbkQWizardFunc_page, METH_O},
    {"pageIds", (PyCFunction)SbkQWizardFunc_pageIds, METH_NOARGS},
    {"paintEvent", (PyCFunction)SbkQWizardFunc_paintEvent, METH_O},
    {"pixmap", (PyCFunction)SbkQWizardFunc_pixmap, METH_O},
    {"removePage", (PyCFunction)SbkQWizardFunc_removePage, METH_O},
    {"resizeEvent", (PyCFunction)SbkQWizardFunc_resizeEvent, METH_O},
    {"restart", (PyCFunction)SbkQWizardFunc_restart, METH_NOARGS},
    {"setButton", (PyCFunction)SbkQWizardFunc_setButton, METH_VARARGS},
    {"setButtonLayout", (PyCFunction)SbkQWizardFunc_setButtonLayout, METH_O},
    {"setButtonText", (PyCFunction)SbkQWizardFunc_setButtonText, METH_VARARGS},
    {"setDefaultProperty", (PyCFunction)SbkQWizardFunc_setDefaultProperty, METH_VARARGS},
    {"setField", (PyCFunction)SbkQWizardFunc_setField, METH_VARARGS},
    {"setOption", (PyCFunction)SbkQWizardFunc_setOption, METH_VARARGS|METH_KEYWORDS},
    {"setOptions", (PyCFunction)SbkQWizardFunc_setOptions, METH_O},
    {"setPage", (PyCFunction)SbkQWizardFunc_setPage, METH_VARARGS},
    {"setPixmap", (PyCFunction)SbkQWizardFunc_setPixmap, METH_VARARGS},
    {"setSideWidget", (PyCFunction)SbkQWizardFunc_setSideWidget, METH_O},
    {"setStartId", (PyCFunction)SbkQWizardFunc_setStartId, METH_O},
    {"setSubTitleFormat", (PyCFunction)SbkQWizardFunc_setSubTitleFormat, METH_O},
    {"setTitleFormat", (PyCFunction)SbkQWizardFunc_setTitleFormat, METH_O},
    {"setVisible", (PyCFunction)SbkQWizardFunc_setVisible, METH_O},
    {"setWizardStyle", (PyCFunction)SbkQWizardFunc_setWizardStyle, METH_O},
    {"sideWidget", (PyCFunction)SbkQWizardFunc_sideWidget, METH_NOARGS},
    {"sizeHint", (PyCFunction)SbkQWizardFunc_sizeHint, METH_NOARGS},
    {"startId", (PyCFunction)SbkQWizardFunc_startId, METH_NOARGS},
    {"subTitleFormat", (PyCFunction)SbkQWizardFunc_subTitleFormat, METH_NOARGS},
    {"testOption", (PyCFunction)SbkQWizardFunc_testOption, METH_O},
    {"titleFormat", (PyCFunction)SbkQWizardFunc_titleFormat, METH_NOARGS},
    {"validateCurrentPage", (PyCFunction)SbkQWizardFunc_validateCurrentPage, METH_NOARGS},
    {"visitedPages", (PyCFunction)SbkQWizardFunc_visitedPages, METH_NOARGS},
    {"wizardStyle", (PyCFunction)SbkQWizardFunc_wizardStyle, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQWizardSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QWizard* me = reinterpret_cast<QWizard*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]))
        return static_cast<QDialog*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWizard_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QWizard",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWizard_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQWizard_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQWizardSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QWizard >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWizard*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQWizard_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QWizard*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQWizard_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QWizard*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQWizard_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QWizard_WizardButton_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QWizard_WizardButton_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QWizard_WizardButton_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WizardButton",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QWizard_WizardButton_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QWizard_WizardButton_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QWizard_WizardButton_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QWizard_WizardStyle_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QWizard_WizardStyle_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QWizard_WizardStyle_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WizardStyle",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QWizard_WizardStyle_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QWizard_WizardStyle_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QWizard_WizardStyle_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QWizard_WizardPixmap_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QWizard_WizardPixmap_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QWizard_WizardPixmap_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WizardPixmap",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QWizard_WizardPixmap_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QWizard_WizardPixmap_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QWizard_WizardPixmap_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QWizard::WizardOptions >::checkType(self) && Shiboken::Converter<QWizard::WizardOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        Shiboken::Converter<QWizard::WizardOptions>::toCpp(self)
        & Shiboken::Converter< QWizard::WizardOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QWizard::WizardOptions >::checkType(self) && Shiboken::Converter<QWizard::WizardOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        Shiboken::Converter<QWizard::WizardOptions>::toCpp(self)
        | Shiboken::Converter< QWizard::WizardOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QWizard::WizardOptions >::checkType(self) && Shiboken::Converter<QWizard::WizardOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        Shiboken::Converter<QWizard::WizardOptions>::toCpp(self)
        ^ Shiboken::Converter< QWizard::WizardOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWizard_WizardOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWizard::WizardOptions >::toPython(
        ~Shiboken::Converter<QWizard::WizardOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QWizard_WizardOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QWizard_WizardOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QWizard_WizardOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QWizard_WizardOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QWizard_WizardOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QWizard_WizardOption_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QWizard_WizardOption_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QWizard_WizardOption_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WizardOption",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QWizard_WizardOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QWizard_WizardOption_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QWizard_WizardOption_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QWizard_WizardOption_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QWizard_WizardOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WizardOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QWizard_WizardOption_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QWizard(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QWIZARD_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWizard_Type);

    SbkQWizard_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX];
    SbkQWizard_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX])->mi_init;

    // Fill type discovery information
    SbkQWizard_Type.type_discovery = &SbkQWizard_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]), &SbkQWizard_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWizard_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWizard_Type));
    PyModule_AddObject(module, "QWizard",
        ((PyObject*)&SbkQWizard_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: WizardButton
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDBUTTON_IDX] = &SbkPySide_QtGui_QWizard_WizardButton_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWizard_WizardButton_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QWizard_WizardButton_Type);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
            "WizardButton",((PyObject*)&SbkPySide_QtGui_QWizard_WizardButton_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::BackButton, "BackButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "BackButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "BackButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::NextButton, "NextButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NextButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "NextButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::CommitButton, "CommitButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "CommitButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "CommitButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::FinishButton, "FinishButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "FinishButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "FinishButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::CancelButton, "CancelButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "CancelButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "CancelButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::HelpButton, "HelpButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HelpButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "HelpButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::CustomButton1, "CustomButton1");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "CustomButton1", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "CustomButton1", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::CustomButton2, "CustomButton2");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "CustomButton2", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "CustomButton2", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::CustomButton3, "CustomButton3");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "CustomButton3", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "CustomButton3", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::Stretch, "Stretch");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "Stretch", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "Stretch", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::NoButton, "NoButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NoButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "NoButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::NStandardButtons, "NStandardButtons");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NStandardButtons", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "NStandardButtons", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardButton_Type,
        (long) QWizard::NButtons, "NButtons");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NButtons", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardButton_Type.tp_dict,
        "NButtons", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardButton");

    // init enum class: WizardStyle
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDSTYLE_IDX] = &SbkPySide_QtGui_QWizard_WizardStyle_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWizard_WizardStyle_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QWizard_WizardStyle_Type);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
            "WizardStyle",((PyObject*)&SbkPySide_QtGui_QWizard_WizardStyle_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardStyle_Type,
        (long) QWizard::ClassicStyle, "ClassicStyle");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "ClassicStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle_Type.tp_dict,
        "ClassicStyle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardStyle_Type,
        (long) QWizard::ModernStyle, "ModernStyle");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "ModernStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle_Type.tp_dict,
        "ModernStyle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardStyle_Type,
        (long) QWizard::MacStyle, "MacStyle");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "MacStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle_Type.tp_dict,
        "MacStyle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardStyle_Type,
        (long) QWizard::AeroStyle, "AeroStyle");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "AeroStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle_Type.tp_dict,
        "AeroStyle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardStyle_Type,
        (long) QWizard::NStyles, "NStyles");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NStyles", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardStyle_Type.tp_dict,
        "NStyles", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardStyle");

    // init enum class: WizardPixmap
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDPIXMAP_IDX] = &SbkPySide_QtGui_QWizard_WizardPixmap_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWizard_WizardPixmap_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QWizard_WizardPixmap_Type);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
            "WizardPixmap",((PyObject*)&SbkPySide_QtGui_QWizard_WizardPixmap_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardPixmap_Type,
        (long) QWizard::WatermarkPixmap, "WatermarkPixmap");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "WatermarkPixmap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap_Type.tp_dict,
        "WatermarkPixmap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardPixmap_Type,
        (long) QWizard::LogoPixmap, "LogoPixmap");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "LogoPixmap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap_Type.tp_dict,
        "LogoPixmap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardPixmap_Type,
        (long) QWizard::BannerPixmap, "BannerPixmap");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "BannerPixmap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap_Type.tp_dict,
        "BannerPixmap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardPixmap_Type,
        (long) QWizard::BackgroundPixmap, "BackgroundPixmap");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "BackgroundPixmap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap_Type.tp_dict,
        "BackgroundPixmap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardPixmap_Type,
        (long) QWizard::NPixmaps, "NPixmaps");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NPixmaps", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardPixmap_Type.tp_dict,
        "NPixmaps", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardPixmap");

    // init enum class: WizardOption
    SbkPySide_QtGuiTypes[SBK_QWIZARD_WIZARDOPTION_IDX] = &SbkPySide_QtGui_QWizard_WizardOption_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWizard_WizardOption_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QWizard_WizardOption_Type);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
            "WizardOption",((PyObject*)&SbkPySide_QtGui_QWizard_WizardOption_Type));

    // init flags class: QFlags<QWizard::WizardOption>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QWIZARD_WIZARDOPTION__IDX] = &SbkPySide_QtGui_QWizard_WizardOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWizard_WizardOptions_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QWizard_WizardOptions_Type);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
            "WizardOptions",((PyObject*)&SbkPySide_QtGui_QWizard_WizardOptions_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::IndependentPages, "IndependentPages");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "IndependentPages", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "IndependentPages", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::IgnoreSubTitles, "IgnoreSubTitles");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "IgnoreSubTitles", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "IgnoreSubTitles", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::ExtendedWatermarkPixmap, "ExtendedWatermarkPixmap");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "ExtendedWatermarkPixmap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "ExtendedWatermarkPixmap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::NoDefaultButton, "NoDefaultButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NoDefaultButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "NoDefaultButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::NoBackButtonOnStartPage, "NoBackButtonOnStartPage");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NoBackButtonOnStartPage", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "NoBackButtonOnStartPage", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::NoBackButtonOnLastPage, "NoBackButtonOnLastPage");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NoBackButtonOnLastPage", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "NoBackButtonOnLastPage", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::DisabledBackButtonOnLastPage, "DisabledBackButtonOnLastPage");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "DisabledBackButtonOnLastPage", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "DisabledBackButtonOnLastPage", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::HaveNextButtonOnLastPage, "HaveNextButtonOnLastPage");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HaveNextButtonOnLastPage", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "HaveNextButtonOnLastPage", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::HaveFinishButtonOnEarlyPages, "HaveFinishButtonOnEarlyPages");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HaveFinishButtonOnEarlyPages", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "HaveFinishButtonOnEarlyPages", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::NoCancelButton, "NoCancelButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "NoCancelButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "NoCancelButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::CancelButtonOnLeft, "CancelButtonOnLeft");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "CancelButtonOnLeft", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "CancelButtonOnLeft", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::HaveHelpButton, "HaveHelpButton");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HaveHelpButton", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "HaveHelpButton", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::HelpButtonOnRight, "HelpButtonOnRight");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HelpButtonOnRight", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "HelpButtonOnRight", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::HaveCustomButton1, "HaveCustomButton1");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HaveCustomButton1", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "HaveCustomButton1", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::HaveCustomButton2, "HaveCustomButton2");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HaveCustomButton2", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "HaveCustomButton2", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWizard_WizardOption_Type,
        (long) QWizard::HaveCustomButton3, "HaveCustomButton3");
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict,
        "HaveCustomButton3", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWizard_WizardOption_Type.tp_dict,
        "HaveCustomButton3", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWizard::WizardOption");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("currentIdChanged", "int", NULL);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict, "currentIdChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("customButtonClicked", "int", NULL);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict, "customButtonClicked", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("pageRemoved", "int", NULL);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict, "pageRemoved", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("pageAdded", "int", NULL);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict, "pageAdded", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("helpRequested", "void", NULL);
    PyDict_SetItemString(SbkQWizard_Type.super.ht_type.tp_dict, "helpRequested", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QWizard >("QWizard*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWizard >(typeid(QWizard).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QWizard >(typeid(QWizardWrapper).name());
    PySide::initQtMetaType<QWizard* >();
}

