/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qx11info_wrapper.h"

// Extra includes
#include <qpaintdevice.h>
#include <qx11info_x11.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQX11Info_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QX11Info >()))
        return -1;

    QX11Info* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QX11Info", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QX11Info()
    // 1: QX11Info(QX11Info)
    if (numArgs == 0) {
        overloadId = 0; // QX11Info()
    } else if (numArgs == 1 && Shiboken::Converter<const QX11Info & >::isConvertible(arg)) {
        overloadId = 1; // QX11Info(QX11Info)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11Info_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QX11Info()
            {

                if(!PyErr_Occurred()) {
                // QX11Info()
                cptr = new QX11Info();
                }
                break;
            }
            case 1: // QX11Info(QX11Info)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QX11Info* cpp_arg0 = Shiboken::Converter<QX11Info* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QX11Info(QX11Info)
                cptr = new QX11Info(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QX11Info >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQX11Info_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQX11Info_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QX11Info", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info", overloads);
        return -1;
}

static PyObject* SbkQX11InfoFunc_appCells(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appCells(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appCells(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appCells", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appCells(int)
    if (numArgs == 0) {
        overloadId = 0; // appCells(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appCells(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appCells_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appCells(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appCells(int)
            int cppResult = QX11Info::appCells(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appCells_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appCells", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appClass(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // appClass()
            const char * cppResult = QX11Info::appClass();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_appColormap(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appColormap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appColormap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appColormap", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appColormap(int)
    if (numArgs == 0) {
        overloadId = 0; // appColormap(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appColormap(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appColormap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appColormap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appColormap(int)
            Qt::HANDLE cppResult = QX11Info::appColormap(cpp_arg0);
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appColormap_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appColormap", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appDefaultColormap(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultColormap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultColormap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDefaultColormap", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appDefaultColormap(int)
    if (numArgs == 0) {
        overloadId = 0; // appDefaultColormap(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appDefaultColormap(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appDefaultColormap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultColormap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appDefaultColormap(int)
            bool cppResult = QX11Info::appDefaultColormap(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appDefaultColormap_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appDefaultColormap", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appDefaultVisual(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultVisual(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultVisual(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDefaultVisual", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appDefaultVisual(int)
    if (numArgs == 0) {
        overloadId = 0; // appDefaultVisual(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appDefaultVisual(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appDefaultVisual_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDefaultVisual(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appDefaultVisual(int)
            bool cppResult = QX11Info::appDefaultVisual(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appDefaultVisual_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appDefaultVisual", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appDepth(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDepth(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDepth(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDepth", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appDepth(int)
    if (numArgs == 0) {
        overloadId = 0; // appDepth(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appDepth_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDepth(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appDepth(int)
            int cppResult = QX11Info::appDepth(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appDepth_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appDepth", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appDpiX(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiX(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiX(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDpiX", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appDpiX(int)
    if (numArgs == 0) {
        overloadId = 0; // appDpiX(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appDpiX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appDpiX_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiX(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appDpiX(int)
            int cppResult = QX11Info::appDpiX(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appDpiX_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appDpiX", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appDpiY(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiY(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiY(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appDpiY", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appDpiY(int)
    if (numArgs == 0) {
        overloadId = 0; // appDpiY(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appDpiY(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appDpiY_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appDpiY(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appDpiY(int)
            int cppResult = QX11Info::appDpiY(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appDpiY_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appDpiY", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appRootWindow(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "screen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appRootWindow(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QX11Info.appRootWindow(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:appRootWindow", &arg))
        return 0;


    // Overloaded function decisor
    // 0: appRootWindow(int)
    if (numArgs == 0) {
        overloadId = 0; // appRootWindow(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // appRootWindow(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_appRootWindow_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "screen");
                if (value) {
                    if (arg)
                        errorArgName = "screen";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QX11Info.appRootWindow(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : -1;

            if(!PyErr_Occurred()) {
            // appRootWindow(int)
            Qt::HANDLE cppResult = QX11Info::appRootWindow(cpp_arg0);
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQX11InfoFunc_appRootWindow_TypeError:
        const char* overloads[] = {"int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.appRootWindow", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_appScreen(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // appScreen()
            int cppResult = QX11Info::appScreen();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_appTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // appTime()
            unsigned long cppResult = QX11Info::appTime();
            pyResult = Shiboken::Converter<unsigned long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_appUserTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // appUserTime()
            unsigned long cppResult = QX11Info::appUserTime();
            pyResult = Shiboken::Converter<unsigned long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_cells(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cells()const
            int cppResult = cppSelf->QX11Info::cells();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_cloneX11Data(PyObject* self, PyObject* arg)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: cloneX11Data(const QPaintDevice*)
    if (Shiboken::Converter< QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // cloneX11Data(const QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_cloneX11Data_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // cloneX11Data(const QPaintDevice*)
            cppSelf->QX11Info::cloneX11Data(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQX11InfoFunc_cloneX11Data_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.cloneX11Data", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_colormap(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // colormap()const
            Qt::HANDLE cppResult = cppSelf->QX11Info::colormap();
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_copyX11Data(PyObject* self, PyObject* arg)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: copyX11Data(const QPaintDevice*)
    if (Shiboken::Converter< QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // copyX11Data(const QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_copyX11Data_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // copyX11Data(const QPaintDevice*)
            cppSelf->QX11Info::copyX11Data(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQX11InfoFunc_copyX11Data_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.copyX11Data", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_defaultColormap(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultColormap()const
            bool cppResult = cppSelf->QX11Info::defaultColormap();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_defaultVisual(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultVisual()const
            bool cppResult = cppSelf->QX11Info::defaultVisual();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_depth(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // depth()const
            int cppResult = cppSelf->QX11Info::depth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_isCompositingManagerRunning(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCompositingManagerRunning()
            bool cppResult = QX11Info::isCompositingManagerRunning();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_screen(PyObject* self)
{
    QX11Info* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QX11Info* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // screen()const
            int cppResult = cppSelf->QX11Info::screen();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQX11InfoFunc_setAppDpiX(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAppDpiX", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAppDpiX(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setAppDpiX(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_setAppDpiX_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setAppDpiX(int,int)
            QX11Info::setAppDpiX(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQX11InfoFunc_setAppDpiX_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.setAppDpiX", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_setAppDpiY(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAppDpiY", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAppDpiY(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setAppDpiY(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_setAppDpiY_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setAppDpiY(int,int)
            QX11Info::setAppDpiY(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQX11InfoFunc_setAppDpiY_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QX11Info.setAppDpiY", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_setAppTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAppTime(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAppTime(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_setAppTime_TypeError;

    // Call function/method
    {
        {
            unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAppTime(ulong)
            QX11Info::setAppTime(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQX11InfoFunc_setAppTime_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.setAppTime", overloads);
        return 0;
}

static PyObject* SbkQX11InfoFunc_setAppUserTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAppUserTime(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAppUserTime(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQX11InfoFunc_setAppUserTime_TypeError;

    // Call function/method
    {
        {
            unsigned long cpp_arg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAppUserTime(ulong)
            QX11Info::setAppUserTime(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQX11InfoFunc_setAppUserTime_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QX11Info.setAppUserTime", overloads);
        return 0;
}

static PyMethodDef SbkQX11Info_methods[] = {
    {"appCells", (PyCFunction)SbkQX11InfoFunc_appCells, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appClass", (PyCFunction)SbkQX11InfoFunc_appClass, METH_NOARGS|METH_STATIC},
    {"appColormap", (PyCFunction)SbkQX11InfoFunc_appColormap, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDefaultColormap", (PyCFunction)SbkQX11InfoFunc_appDefaultColormap, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDefaultVisual", (PyCFunction)SbkQX11InfoFunc_appDefaultVisual, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDepth", (PyCFunction)SbkQX11InfoFunc_appDepth, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDpiX", (PyCFunction)SbkQX11InfoFunc_appDpiX, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appDpiY", (PyCFunction)SbkQX11InfoFunc_appDpiY, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appRootWindow", (PyCFunction)SbkQX11InfoFunc_appRootWindow, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"appScreen", (PyCFunction)SbkQX11InfoFunc_appScreen, METH_NOARGS|METH_STATIC},
    {"appTime", (PyCFunction)SbkQX11InfoFunc_appTime, METH_NOARGS|METH_STATIC},
    {"appUserTime", (PyCFunction)SbkQX11InfoFunc_appUserTime, METH_NOARGS|METH_STATIC},
    {"cells", (PyCFunction)SbkQX11InfoFunc_cells, METH_NOARGS},
    {"cloneX11Data", (PyCFunction)SbkQX11InfoFunc_cloneX11Data, METH_O},
    {"colormap", (PyCFunction)SbkQX11InfoFunc_colormap, METH_NOARGS},
    {"copyX11Data", (PyCFunction)SbkQX11InfoFunc_copyX11Data, METH_O},
    {"defaultColormap", (PyCFunction)SbkQX11InfoFunc_defaultColormap, METH_NOARGS},
    {"defaultVisual", (PyCFunction)SbkQX11InfoFunc_defaultVisual, METH_NOARGS},
    {"depth", (PyCFunction)SbkQX11InfoFunc_depth, METH_NOARGS},
    {"isCompositingManagerRunning", (PyCFunction)SbkQX11InfoFunc_isCompositingManagerRunning, METH_NOARGS|METH_STATIC},
    {"screen", (PyCFunction)SbkQX11InfoFunc_screen, METH_NOARGS},
    {"setAppDpiX", (PyCFunction)SbkQX11InfoFunc_setAppDpiX, METH_VARARGS|METH_STATIC},
    {"setAppDpiY", (PyCFunction)SbkQX11InfoFunc_setAppDpiY, METH_VARARGS|METH_STATIC},
    {"setAppTime", (PyCFunction)SbkQX11InfoFunc_setAppTime, METH_O|METH_STATIC},
    {"setAppUserTime", (PyCFunction)SbkQX11InfoFunc_setAppUserTime, METH_O|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQX11Info_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QX11Info",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQX11Info_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQX11Info_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QX11Info >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QX11Info",
    /*user_data*/           0
};
} //extern


void init_QX11Info(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QX11INFO_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQX11Info_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQX11Info_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQX11Info_Type));
    PyModule_AddObject(module, "QX11Info",
        ((PyObject*)&SbkQX11Info_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QX11Info >("QX11Info");
    Shiboken::TypeResolver::createObjectTypeResolver<QX11Info >("QX11Info*");
    Shiboken::TypeResolver::createValueTypeResolver<QX11Info >(typeid(QX11Info).name());
    PySide::initQtMetaType<QX11Info >();
}

