/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qthelp_python.h"

#include "qhelpcontentitem_wrapper.h"

// Extra includes
#include <qhelpcontentwidget.h>
#include <qurl.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQHelpContentItemFunc_child(PyObject* self, PyObject* arg)
{
    QHelpContentItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpContentItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: child(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // child(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpContentItemFunc_child_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // child(int)const
            QHelpContentItem * cppResult = cppSelf->QHelpContentItem::child(cpp_arg0);
            pyResult = Shiboken::Converter<QHelpContentItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpContentItemFunc_child_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpContentItem.child", overloads);
        return 0;
}

static PyObject* SbkQHelpContentItemFunc_childCount(PyObject* self)
{
    QHelpContentItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpContentItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childCount()const
            int cppResult = cppSelf->QHelpContentItem::childCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpContentItemFunc_childPosition(PyObject* self, PyObject* arg)
{
    QHelpContentItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpContentItem* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: childPosition(QHelpContentItem*)const
    if (Shiboken::Converter<QHelpContentItem * >::isConvertible(arg)) {
        overloadId = 0; // childPosition(QHelpContentItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpContentItemFunc_childPosition_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QHelpContentItem* cpp_arg0 = Shiboken::Converter<QHelpContentItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // childPosition(QHelpContentItem*)const
            int cppResult = cppSelf->QHelpContentItem::childPosition(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpContentItemFunc_childPosition_TypeError:
        const char* overloads[] = {"PySide.QtHelp.QHelpContentItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpContentItem.childPosition", overloads);
        return 0;
}

static PyObject* SbkQHelpContentItemFunc_parent(PyObject* self)
{
    QHelpContentItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpContentItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parent()const
            QHelpContentItem * cppResult = cppSelf->QHelpContentItem::parent();
            pyResult = Shiboken::Converter<QHelpContentItem * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpContentItemFunc_row(PyObject* self)
{
    QHelpContentItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpContentItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // row()const
            int cppResult = cppSelf->QHelpContentItem::row();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpContentItemFunc_title(PyObject* self)
{
    QHelpContentItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpContentItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // title()const
            QString cppResult = cppSelf->QHelpContentItem::title();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpContentItemFunc_url(PyObject* self)
{
    QHelpContentItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpContentItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = cppSelf->QHelpContentItem::url();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQHelpContentItem_methods[] = {
    {"child", (PyCFunction)SbkQHelpContentItemFunc_child, METH_O},
    {"childCount", (PyCFunction)SbkQHelpContentItemFunc_childCount, METH_NOARGS},
    {"childPosition", (PyCFunction)SbkQHelpContentItemFunc_childPosition, METH_O},
    {"parent", (PyCFunction)SbkQHelpContentItemFunc_parent, METH_NOARGS},
    {"row", (PyCFunction)SbkQHelpContentItemFunc_row, METH_NOARGS},
    {"title", (PyCFunction)SbkQHelpContentItemFunc_title, METH_NOARGS},
    {"url", (PyCFunction)SbkQHelpContentItemFunc_url, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQHelpContentItem_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtHelp.QHelpContentItem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQHelpContentItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QHelpContentItem >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QHelpContentItem",
    /*user_data*/           0
};
} //extern


void init_QHelpContentItem(PyObject* module)
{
    SbkPySide_QtHelpTypes[SBK_QHELPCONTENTITEM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQHelpContentItem_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQHelpContentItem_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQHelpContentItem_Type));
    PyModule_AddObject(module, "QHelpContentItem",
        ((PyObject*)&SbkQHelpContentItem_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QHelpContentItem >("QHelpContentItem");
    Shiboken::TypeResolver::createObjectTypeResolver<QHelpContentItem >("QHelpContentItem*");
    Shiboken::TypeResolver::createValueTypeResolver<QHelpContentItem >(typeid(QHelpContentItem).name());
    PySide::initQtMetaType<QHelpContentItem >();
}

