/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qthelp_python.h"

#include "qhelpenginecore_wrapper.h"

// Extra includes
#include <QList>
#include <QMap>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QHelpEngineCoreWrapper::QHelpEngineCoreWrapper(const QString & collectionFile, QObject * parent) : QHelpEngineCore(collectionFile, parent), m_metaObject(0) {
    // ... middle
}

void QHelpEngineCoreWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QHelpEngineCoreWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QHelpEngineCoreWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QHelpEngineCoreWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QHelpEngineCoreWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHelpEngineCore.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QHelpEngineCoreWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHelpEngineCore.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QHelpEngineCoreWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QHelpEngineCoreWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QHelpEngineCore::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QHelpEngineCoreWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QHelpEngineCore::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QHelpEngineCoreWrapper::~QHelpEngineCoreWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQHelpEngineCore_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QHelpEngineCore >()))
        return -1;

    QHelpEngineCoreWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QHelpEngineCore", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QHelpEngineCore(QString,QObject*)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QHelpEngineCore(QString,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QHelpEngineCore(QString,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCore_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return -1;
            QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // QHelpEngineCore(QString,QObject*)
            cptr = new QHelpEngineCoreWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[1], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QHelpEngineCore >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQHelpEngineCore_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQHelpEngineCore_Init_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore", overloads);
        return -1;
}

static PyObject* SbkQHelpEngineCoreFunc_addCustomFilter(PyObject* self, PyObject* args)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addCustomFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addCustomFilter(QString,QStringList)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
        overloadId = 0; // addCustomFilter(QString,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_addCustomFilter_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // addCustomFilter(QString,QStringList)
            bool cppResult = cppSelf->QHelpEngineCore::addCustomFilter(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_addCustomFilter_TypeError:
        const char* overloads[] = {"QString, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.addCustomFilter", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_autoSaveFilter(PyObject* self)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoSaveFilter()const
            bool cppResult = cppSelf->QHelpEngineCore::autoSaveFilter();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpEngineCoreFunc_collectionFile(PyObject* self)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // collectionFile()const
            QString cppResult = cppSelf->QHelpEngineCore::collectionFile();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpEngineCoreFunc_copyCollectionFile(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: copyCollectionFile(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // copyCollectionFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_copyCollectionFile_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // copyCollectionFile(QString)
            bool cppResult = cppSelf->QHelpEngineCore::copyCollectionFile(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_copyCollectionFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.copyCollectionFile", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_currentFilter(PyObject* self)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentFilter()const
            QString cppResult = cppSelf->QHelpEngineCore::currentFilter();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpEngineCoreFunc_customFilters(PyObject* self)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // customFilters()const
            QStringList cppResult = cppSelf->QHelpEngineCore::customFilters();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpEngineCoreFunc_customValue(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "defaultValue" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.customValue(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.customValue(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.customValue(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:customValue", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: customValue(QString,QVariant)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // customValue(QString,QVariant)const
        } else if (Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
            overloadId = 0; // customValue(QString,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_customValue_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "defaultValue";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.customValue(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = pyargs[1] ? Shiboken::Converter<QVariant >::toCpp(pyargs[1]) : QVariant();

            if(!PyErr_Occurred()) {
            // customValue(QString,QVariant)const
            QVariant cppResult = cppSelf->QHelpEngineCore::customValue(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_customValue_TypeError:
        const char* overloads[] = {"QString, QVariant = QVariant()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.customValue", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_documentationFileName(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: documentationFileName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // documentationFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_documentationFileName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // documentationFileName(QString)
            QString cppResult = cppSelf->QHelpEngineCore::documentationFileName(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_documentationFileName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.documentationFileName", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_error(PyObject* self)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QString cppResult = cppSelf->QHelpEngineCore::error();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpEngineCoreFunc_fileData(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fileData(QUrl)const
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // fileData(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_fileData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // fileData(QUrl)const
            QByteArray cppResult = cppSelf->QHelpEngineCore::fileData(*cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_fileData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.fileData", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_files(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "extensionFilter" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.files(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.files(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.files(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:files", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: files(QString,QStringList,QString)
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // files(QString,QStringList,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // files(QString,QStringList,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_files_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "extensionFilter");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "extensionFilter";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtHelp.QHelpEngineCore.files(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();

            if(!PyErr_Occurred()) {
            // files(QString,QStringList,QString)
            QList<QUrl > cppResult = cppSelf->QHelpEngineCore::files(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QList<QUrl > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_files_TypeError:
        const char* overloads[] = {"QString, list, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.files", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_filterAttributeSets(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: filterAttributeSets(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // filterAttributeSets(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_filterAttributeSets_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // filterAttributeSets(QString)const
            QList<QStringList > cppResult = cppSelf->QHelpEngineCore::filterAttributeSets(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QStringList > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_filterAttributeSets_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.filterAttributeSets", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_filterAttributes(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: filterAttributes()const
    // 1: filterAttributes(QString)const
    if (numArgs == 0) {
        overloadId = 0; // filterAttributes()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // filterAttributes(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_filterAttributes_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // filterAttributes()const
            {

                if(!PyErr_Occurred()) {
                // filterAttributes()const
                QStringList cppResult = cppSelf->QHelpEngineCore::filterAttributes();
                pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
                }
                break;
            }
            case 1: // filterAttributes(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // filterAttributes(QString)const
                QStringList cppResult = cppSelf->QHelpEngineCore::filterAttributes(cpp_arg0);
                pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_filterAttributes_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.filterAttributes", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_findFile(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findFile(QUrl)const
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // findFile(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_findFile_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // findFile(QUrl)const
            QUrl cppResult = cppSelf->QHelpEngineCore::findFile(*cpp_arg0);
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_findFile_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.findFile", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_linksForIdentifier(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: linksForIdentifier(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // linksForIdentifier(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_linksForIdentifier_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // linksForIdentifier(QString)const
            QMap<QString, QUrl > cppResult = cppSelf->QHelpEngineCore::linksForIdentifier(cpp_arg0);
            pyResult = Shiboken::Converter<QMap<QString, QUrl > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_linksForIdentifier_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.linksForIdentifier", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_metaData(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "metaData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: metaData(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // metaData(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_metaData_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // metaData(QString,QString)
            QVariant cppResult = QHelpEngineCore::metaData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_metaData_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.metaData", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_namespaceName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namespaceName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // namespaceName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_namespaceName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // namespaceName(QString)
            QString cppResult = QHelpEngineCore::namespaceName(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_namespaceName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.namespaceName", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_registerDocumentation(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: registerDocumentation(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // registerDocumentation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_registerDocumentation_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // registerDocumentation(QString)
            bool cppResult = cppSelf->QHelpEngineCore::registerDocumentation(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_registerDocumentation_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.registerDocumentation", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_registeredDocumentations(PyObject* self)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // registeredDocumentations()const
            QStringList cppResult = cppSelf->QHelpEngineCore::registeredDocumentations();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpEngineCoreFunc_removeCustomFilter(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeCustomFilter(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeCustomFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_removeCustomFilter_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeCustomFilter(QString)
            bool cppResult = cppSelf->QHelpEngineCore::removeCustomFilter(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_removeCustomFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.removeCustomFilter", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_removeCustomValue(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeCustomValue(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeCustomValue(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_removeCustomValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeCustomValue(QString)
            bool cppResult = cppSelf->QHelpEngineCore::removeCustomValue(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_removeCustomValue_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.removeCustomValue", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_setAutoSaveFilter(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoSaveFilter(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoSaveFilter(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_setAutoSaveFilter_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoSaveFilter(bool)
            cppSelf->QHelpEngineCore::setAutoSaveFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHelpEngineCoreFunc_setAutoSaveFilter_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.setAutoSaveFilter", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_setCollectionFile(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCollectionFile(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setCollectionFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_setCollectionFile_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCollectionFile(QString)
            cppSelf->QHelpEngineCore::setCollectionFile(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHelpEngineCoreFunc_setCollectionFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.setCollectionFile", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_setCurrentFilter(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentFilter(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setCurrentFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_setCurrentFilter_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentFilter(QString)
            cppSelf->QHelpEngineCore::setCurrentFilter(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHelpEngineCoreFunc_setCurrentFilter_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.setCurrentFilter", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_setCustomValue(PyObject* self, PyObject* args)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCustomValue", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCustomValue(QString,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setCustomValue(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_setCustomValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setCustomValue(QString,QVariant)
            bool cppResult = cppSelf->QHelpEngineCore::setCustomValue(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_setCustomValue_TypeError:
        const char* overloads[] = {"QString, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpEngineCore.setCustomValue", overloads);
        return 0;
}

static PyObject* SbkQHelpEngineCoreFunc_setupData(PyObject* self)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // setupData()
            bool cppResult = cppSelf->QHelpEngineCore::setupData();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHelpEngineCoreFunc_unregisterDocumentation(PyObject* self, PyObject* arg)
{
    QHelpEngineCore* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHelpEngineCore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unregisterDocumentation(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // unregisterDocumentation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpEngineCoreFunc_unregisterDocumentation_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // unregisterDocumentation(QString)
            bool cppResult = cppSelf->QHelpEngineCore::unregisterDocumentation(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHelpEngineCoreFunc_unregisterDocumentation_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtHelp.QHelpEngineCore.unregisterDocumentation", overloads);
        return 0;
}

static PyMethodDef SbkQHelpEngineCore_methods[] = {
    {"addCustomFilter", (PyCFunction)SbkQHelpEngineCoreFunc_addCustomFilter, METH_VARARGS},
    {"autoSaveFilter", (PyCFunction)SbkQHelpEngineCoreFunc_autoSaveFilter, METH_NOARGS},
    {"collectionFile", (PyCFunction)SbkQHelpEngineCoreFunc_collectionFile, METH_NOARGS},
    {"copyCollectionFile", (PyCFunction)SbkQHelpEngineCoreFunc_copyCollectionFile, METH_O},
    {"currentFilter", (PyCFunction)SbkQHelpEngineCoreFunc_currentFilter, METH_NOARGS},
    {"customFilters", (PyCFunction)SbkQHelpEngineCoreFunc_customFilters, METH_NOARGS},
    {"customValue", (PyCFunction)SbkQHelpEngineCoreFunc_customValue, METH_VARARGS|METH_KEYWORDS},
    {"documentationFileName", (PyCFunction)SbkQHelpEngineCoreFunc_documentationFileName, METH_O},
    {"error", (PyCFunction)SbkQHelpEngineCoreFunc_error, METH_NOARGS},
    {"fileData", (PyCFunction)SbkQHelpEngineCoreFunc_fileData, METH_O},
    {"files", (PyCFunction)SbkQHelpEngineCoreFunc_files, METH_VARARGS|METH_KEYWORDS},
    {"filterAttributeSets", (PyCFunction)SbkQHelpEngineCoreFunc_filterAttributeSets, METH_O},
    {"filterAttributes", (PyCFunction)SbkQHelpEngineCoreFunc_filterAttributes, METH_NOARGS|METH_O},
    {"findFile", (PyCFunction)SbkQHelpEngineCoreFunc_findFile, METH_O},
    {"linksForIdentifier", (PyCFunction)SbkQHelpEngineCoreFunc_linksForIdentifier, METH_O},
    {"metaData", (PyCFunction)SbkQHelpEngineCoreFunc_metaData, METH_VARARGS|METH_STATIC},
    {"namespaceName", (PyCFunction)SbkQHelpEngineCoreFunc_namespaceName, METH_O|METH_STATIC},
    {"registerDocumentation", (PyCFunction)SbkQHelpEngineCoreFunc_registerDocumentation, METH_O},
    {"registeredDocumentations", (PyCFunction)SbkQHelpEngineCoreFunc_registeredDocumentations, METH_NOARGS},
    {"removeCustomFilter", (PyCFunction)SbkQHelpEngineCoreFunc_removeCustomFilter, METH_O},
    {"removeCustomValue", (PyCFunction)SbkQHelpEngineCoreFunc_removeCustomValue, METH_O},
    {"setAutoSaveFilter", (PyCFunction)SbkQHelpEngineCoreFunc_setAutoSaveFilter, METH_O},
    {"setCollectionFile", (PyCFunction)SbkQHelpEngineCoreFunc_setCollectionFile, METH_O},
    {"setCurrentFilter", (PyCFunction)SbkQHelpEngineCoreFunc_setCurrentFilter, METH_O},
    {"setCustomValue", (PyCFunction)SbkQHelpEngineCoreFunc_setCustomValue, METH_VARARGS},
    {"setupData", (PyCFunction)SbkQHelpEngineCoreFunc_setupData, METH_NOARGS},
    {"unregisterDocumentation", (PyCFunction)SbkQHelpEngineCoreFunc_unregisterDocumentation, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQHelpEngineCore_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtHelp.QHelpEngineCore",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQHelpEngineCore_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQHelpEngineCore_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QHelpEngineCore >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QHelpEngineCore*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQHelpEngineCore_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QHelpEngineCore*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQHelpEngineCore_Type;
    return 0;
}


void init_QHelpEngineCore(PyObject* module)
{
    SbkPySide_QtHelpTypes[SBK_QHELPENGINECORE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQHelpEngineCore_Type);

    SbkQHelpEngineCore_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQHelpEngineCore_Type.type_discovery = &SbkQHelpEngineCore_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQHelpEngineCore_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQHelpEngineCore_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQHelpEngineCore_Type));
    PyModule_AddObject(module, "QHelpEngineCore",
        ((PyObject*)&SbkQHelpEngineCore_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("setupStarted", "void", NULL);
    PyDict_SetItemString(SbkQHelpEngineCore_Type.super.ht_type.tp_dict, "setupStarted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("setupFinished", "void", NULL);
    PyDict_SetItemString(SbkQHelpEngineCore_Type.super.ht_type.tp_dict, "setupFinished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("warning", "const QString&", NULL);
    PyDict_SetItemString(SbkQHelpEngineCore_Type.super.ht_type.tp_dict, "warning", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("currentFilterChanged", "const QString&", NULL);
    PyDict_SetItemString(SbkQHelpEngineCore_Type.super.ht_type.tp_dict, "currentFilterChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QHelpEngineCore >("QHelpEngineCore*");
    Shiboken::TypeResolver::createObjectTypeResolver<QHelpEngineCore >(typeid(QHelpEngineCore).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QHelpEngineCore >(typeid(QHelpEngineCoreWrapper).name());
    PySide::initQtMetaType<QHelpEngineCore* >();
}

