/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qthelp_python.h"

#include "qhelpsearchquery_wrapper.h"

// Extra includes
#include <QStringList>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQHelpSearchQuery_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QHelpSearchQuery >()))
        return -1;

    QHelpSearchQuery* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QHelpSearchQuery", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QHelpSearchQuery(QHelpSearchQuery)
    // 1: QHelpSearchQuery()
    // 2: QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
    if (numArgs == 0) {
        overloadId = 1; // QHelpSearchQuery()
    } else if (numArgs == 2 && Shiboken::Converter<QHelpSearchQuery::FieldName >::isConvertible(pyargs[0]) && Shiboken::Converter< QStringList  >::isConvertible(pyargs[1])) {
        overloadId = 2; // QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
    } else if (numArgs == 1 && Shiboken::Converter<const QHelpSearchQuery & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QHelpSearchQuery(QHelpSearchQuery)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHelpSearchQuery_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHelpSearchQuery(QHelpSearchQuery)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QHelpSearchQuery* cpp_arg0 = Shiboken::Converter<QHelpSearchQuery* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QHelpSearchQuery(QHelpSearchQuery)
                cptr = new QHelpSearchQuery(*cpp_arg0);
                }
                break;
            }
            case 1: // QHelpSearchQuery()
            {

                if(!PyErr_Occurred()) {
                // QHelpSearchQuery()
                cptr = new QHelpSearchQuery();
                }
                break;
            }
            case 2: // QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
            {
                QHelpSearchQuery::FieldName cpp_arg0 = Shiboken::Converter<QHelpSearchQuery::FieldName >::toCpp(pyargs[0]);
                QStringList cpp_arg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
                cptr = new QHelpSearchQuery(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QHelpSearchQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQHelpSearchQuery_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQHelpSearchQuery_Init_TypeError:
        const char* overloads[] = {"PySide.QtHelp.QHelpSearchQuery", "", "PySide.QtHelp.QHelpSearchQuery.FieldName, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtHelp.QHelpSearchQuery", overloads);
        return -1;
}

static PyMethodDef SbkQHelpSearchQuery_methods[] = {
    {0} // Sentinel
};

static PyObject* SbkQHelpSearchQuery_get_wordList(PyObject* self, void*)
{
    return Shiboken::Converter<QStringList >::toPython(Shiboken::Converter<QHelpSearchQuery* >::toCpp(self)->wordList);
}
static int SbkQHelpSearchQuery_set_wordList(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'wordList' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QStringList >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'wordList', 'QList' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QHelpSearchQuery* >::toCpp(self)->wordList = Shiboken::Converter<QStringList >::toCpp(value);

    return 0;
}

static PyObject* SbkQHelpSearchQuery_get_fieldName(PyObject* self, void*)
{
    return Shiboken::Converter<QHelpSearchQuery::FieldName >::toPython(Shiboken::Converter<QHelpSearchQuery* >::toCpp(self)->fieldName);
}
static int SbkQHelpSearchQuery_set_fieldName(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'fieldName' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QHelpSearchQuery::FieldName >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'fieldName', 'FieldName' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QHelpSearchQuery* >::toCpp(self)->fieldName = Shiboken::Converter<QHelpSearchQuery::FieldName >::toCpp(value);

    return 0;
}

// Getters and Setters for QHelpSearchQuery
static PyGetSetDef SbkQHelpSearchQuery_getsetlist[] = {
    {const_cast<char*>("wordList"), SbkQHelpSearchQuery_get_wordList, SbkQHelpSearchQuery_set_wordList},
    {const_cast<char*>("fieldName"), SbkQHelpSearchQuery_get_fieldName, SbkQHelpSearchQuery_set_fieldName},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQHelpSearchQuery_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtHelp.QHelpSearchQuery",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQHelpSearchQuery_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQHelpSearchQuery_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQHelpSearchQuery_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QHelpSearchQuery >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QHelpSearchQuery",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtHelp_QHelpSearchQuery_FieldName_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtHelp_QHelpSearchQuery_FieldName_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FieldName",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtHelp_QHelpSearchQuery_FieldName_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtHelp_QHelpSearchQuery_FieldName_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtHelp_QHelpSearchQuery_FieldName_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QHelpSearchQuery(PyObject* module)
{
    SbkPySide_QtHelpTypes[SBK_QHELPSEARCHQUERY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQHelpSearchQuery_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQHelpSearchQuery_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQHelpSearchQuery_Type));
    PyModule_AddObject(module, "QHelpSearchQuery",
        ((PyObject*)&SbkQHelpSearchQuery_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: FieldName
    SbkPySide_QtHelpTypes[SBK_QHELPSEARCHQUERY_FIELDNAME_IDX] = &SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type);
    PyDict_SetItemString(SbkQHelpSearchQuery_Type.super.ht_type.tp_dict,
            "FieldName",((PyObject*)&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type,
        (long) QHelpSearchQuery::DEFAULT, "DEFAULT");
    PyDict_SetItemString(SbkQHelpSearchQuery_Type.super.ht_type.tp_dict,
        "DEFAULT", enum_item);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type.tp_dict,
        "DEFAULT", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type,
        (long) QHelpSearchQuery::FUZZY, "FUZZY");
    PyDict_SetItemString(SbkQHelpSearchQuery_Type.super.ht_type.tp_dict,
        "FUZZY", enum_item);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type.tp_dict,
        "FUZZY", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type,
        (long) QHelpSearchQuery::WITHOUT, "WITHOUT");
    PyDict_SetItemString(SbkQHelpSearchQuery_Type.super.ht_type.tp_dict,
        "WITHOUT", enum_item);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type.tp_dict,
        "WITHOUT", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type,
        (long) QHelpSearchQuery::PHRASE, "PHRASE");
    PyDict_SetItemString(SbkQHelpSearchQuery_Type.super.ht_type.tp_dict,
        "PHRASE", enum_item);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type.tp_dict,
        "PHRASE", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type,
        (long) QHelpSearchQuery::ALL, "ALL");
    PyDict_SetItemString(SbkQHelpSearchQuery_Type.super.ht_type.tp_dict,
        "ALL", enum_item);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type.tp_dict,
        "ALL", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type,
        (long) QHelpSearchQuery::ATLEAST, "ATLEAST");
    PyDict_SetItemString(SbkQHelpSearchQuery_Type.super.ht_type.tp_dict,
        "ATLEAST", enum_item);
    PyDict_SetItemString(SbkPySide_QtHelp_QHelpSearchQuery_FieldName_Type.tp_dict,
        "ATLEAST", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHelpSearchQuery::FieldName");


    Shiboken::TypeResolver::createValueTypeResolver<QHelpSearchQuery >("QHelpSearchQuery");
    Shiboken::TypeResolver::createObjectTypeResolver<QHelpSearchQuery >("QHelpSearchQuery*");
    Shiboken::TypeResolver::createValueTypeResolver<QHelpSearchQuery >(typeid(QHelpSearchQuery).name());
    PySide::initQtMetaType<QHelpSearchQuery >();
}

