/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtmultimedia_python.h"

#include "qaudiodeviceinfo_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qaudiodeviceinfo.h>
#include <qaudioformat.h>
#include <qbytearray.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAudioDeviceInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAudioDeviceInfo >()))
        return -1;

    QAudioDeviceInfo* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QAudioDeviceInfo", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QAudioDeviceInfo()
    // 1: QAudioDeviceInfo(QAudioDeviceInfo)
    if (numArgs == 0) {
        overloadId = 0; // QAudioDeviceInfo()
    } else if (numArgs == 1 && Shiboken::Converter<const QAudioDeviceInfo & >::isConvertible(arg)) {
        overloadId = 1; // QAudioDeviceInfo(QAudioDeviceInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioDeviceInfo_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QAudioDeviceInfo()
            {

                if(!PyErr_Occurred()) {
                // QAudioDeviceInfo()
                cptr = new QAudioDeviceInfo();
                }
                break;
            }
            case 1: // QAudioDeviceInfo(QAudioDeviceInfo)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QAudioDeviceInfo* cpp_arg0 = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QAudioDeviceInfo(QAudioDeviceInfo)
                cptr = new QAudioDeviceInfo(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAudioDeviceInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAudioDeviceInfo_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQAudioDeviceInfo_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtMultimedia.QAudioDeviceInfo", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioDeviceInfo", overloads);
        return -1;
}

static PyObject* SbkQAudioDeviceInfoFunc_availableDevices(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: availableDevices(QAudio::Mode)
    if (Shiboken::Converter<QAudio::Mode >::isConvertible(arg)) {
        overloadId = 0; // availableDevices(QAudio::Mode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioDeviceInfoFunc_availableDevices_TypeError;

    // Call function/method
    {
        {
            QAudio::Mode cpp_arg0 = Shiboken::Converter<QAudio::Mode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // availableDevices(QAudio::Mode)
            QList<QAudioDeviceInfo > cppResult = QAudioDeviceInfo::availableDevices(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QAudioDeviceInfo > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAudioDeviceInfoFunc_availableDevices_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudio.Mode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioDeviceInfo.availableDevices", overloads);
        return 0;
}

static PyObject* SbkQAudioDeviceInfoFunc_defaultInputDevice(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultInputDevice()
            QAudioDeviceInfo cppResult = QAudioDeviceInfo::defaultInputDevice();
            pyResult = Shiboken::Converter<QAudioDeviceInfo >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_defaultOutputDevice(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultOutputDevice()
            QAudioDeviceInfo cppResult = QAudioDeviceInfo::defaultOutputDevice();
            pyResult = Shiboken::Converter<QAudioDeviceInfo >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_deviceName(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deviceName()const
            QString cppResult = cppSelf->QAudioDeviceInfo::deviceName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_isFormatSupported(PyObject* self, PyObject* arg)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isFormatSupported(QAudioFormat)const
    if (Shiboken::Converter<const QAudioFormat & >::isConvertible(arg)) {
        overloadId = 0; // isFormatSupported(QAudioFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioDeviceInfoFunc_isFormatSupported_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAudioFormat* cpp_arg0 = Shiboken::Converter<QAudioFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isFormatSupported(QAudioFormat)const
            bool cppResult = cppSelf->QAudioDeviceInfo::isFormatSupported(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAudioDeviceInfoFunc_isFormatSupported_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudioFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioDeviceInfo.isFormatSupported", overloads);
        return 0;
}

static PyObject* SbkQAudioDeviceInfoFunc_isNull(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QAudioDeviceInfo::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_nearestFormat(PyObject* self, PyObject* arg)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: nearestFormat(QAudioFormat)const
    if (Shiboken::Converter<const QAudioFormat & >::isConvertible(arg)) {
        overloadId = 0; // nearestFormat(QAudioFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioDeviceInfoFunc_nearestFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAudioFormat* cpp_arg0 = Shiboken::Converter<QAudioFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // nearestFormat(QAudioFormat)const
            QAudioFormat cppResult = cppSelf->QAudioDeviceInfo::nearestFormat(*cpp_arg0);
            pyResult = Shiboken::Converter<QAudioFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAudioDeviceInfoFunc_nearestFormat_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudioFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioDeviceInfo.nearestFormat", overloads);
        return 0;
}

static PyObject* SbkQAudioDeviceInfoFunc_preferredFormat(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // preferredFormat()const
            QAudioFormat cppResult = cppSelf->QAudioDeviceInfo::preferredFormat();
            pyResult = Shiboken::Converter<QAudioFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedByteOrders(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedByteOrders()const
            QList<QAudioFormat::Endian > cppResult = cppSelf->QAudioDeviceInfo::supportedByteOrders();
            pyResult = Shiboken::Converter<QList<QAudioFormat::Endian > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedChannelCounts(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedChannelCounts()const
            QList<int > cppResult = cppSelf->QAudioDeviceInfo::supportedChannelCounts();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedChannels(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedChannels()const
            QList<int > cppResult = cppSelf->QAudioDeviceInfo::supportedChannels();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedCodecs(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedCodecs()const
            QStringList cppResult = cppSelf->QAudioDeviceInfo::supportedCodecs();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedFrequencies(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedFrequencies()const
            QList<int > cppResult = cppSelf->QAudioDeviceInfo::supportedFrequencies();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedSampleRates(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedSampleRates()const
            QList<int > cppResult = cppSelf->QAudioDeviceInfo::supportedSampleRates();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedSampleSizes(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedSampleSizes()const
            QList<int > cppResult = cppSelf->QAudioDeviceInfo::supportedSampleSizes();
            pyResult = Shiboken::Converter<QList<int > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAudioDeviceInfoFunc_supportedSampleTypes(PyObject* self)
{
    QAudioDeviceInfo* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioDeviceInfo* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedSampleTypes()const
            QList<QAudioFormat::SampleType > cppResult = cppSelf->QAudioDeviceInfo::supportedSampleTypes();
            pyResult = Shiboken::Converter<QList<QAudioFormat::SampleType > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQAudioDeviceInfo_methods[] = {
    {"availableDevices", (PyCFunction)SbkQAudioDeviceInfoFunc_availableDevices, METH_O|METH_STATIC},
    {"defaultInputDevice", (PyCFunction)SbkQAudioDeviceInfoFunc_defaultInputDevice, METH_NOARGS|METH_STATIC},
    {"defaultOutputDevice", (PyCFunction)SbkQAudioDeviceInfoFunc_defaultOutputDevice, METH_NOARGS|METH_STATIC},
    {"deviceName", (PyCFunction)SbkQAudioDeviceInfoFunc_deviceName, METH_NOARGS},
    {"isFormatSupported", (PyCFunction)SbkQAudioDeviceInfoFunc_isFormatSupported, METH_O},
    {"isNull", (PyCFunction)SbkQAudioDeviceInfoFunc_isNull, METH_NOARGS},
    {"nearestFormat", (PyCFunction)SbkQAudioDeviceInfoFunc_nearestFormat, METH_O},
    {"preferredFormat", (PyCFunction)SbkQAudioDeviceInfoFunc_preferredFormat, METH_NOARGS},
    {"supportedByteOrders", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedByteOrders, METH_NOARGS},
    {"supportedChannelCounts", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedChannelCounts, METH_NOARGS},
    {"supportedChannels", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedChannels, METH_NOARGS},
    {"supportedCodecs", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedCodecs, METH_NOARGS},
    {"supportedFrequencies", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedFrequencies, METH_NOARGS},
    {"supportedSampleRates", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedSampleRates, METH_NOARGS},
    {"supportedSampleSizes", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedSampleSizes, METH_NOARGS},
    {"supportedSampleTypes", (PyCFunction)SbkQAudioDeviceInfoFunc_supportedSampleTypes, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAudioDeviceInfo_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QAudioDeviceInfo",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAudioDeviceInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAudioDeviceInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAudioDeviceInfo >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAudioDeviceInfo",
    /*user_data*/           0
};
} //extern


void init_QAudioDeviceInfo(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QAUDIODEVICEINFO_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAudioDeviceInfo_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAudioDeviceInfo_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAudioDeviceInfo_Type));
    PyModule_AddObject(module, "QAudioDeviceInfo",
        ((PyObject*)&SbkQAudioDeviceInfo_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QAudioDeviceInfo >("QAudioDeviceInfo");
    Shiboken::TypeResolver::createObjectTypeResolver<QAudioDeviceInfo >("QAudioDeviceInfo*");
    Shiboken::TypeResolver::createValueTypeResolver<QAudioDeviceInfo >(typeid(QAudioDeviceInfo).name());
    PySide::initQtMetaType<QAudioDeviceInfo >();
}

