/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtmultimedia_python.h"

#include "qaudioengineplugin_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qaudioengine.h>
#include <qaudioformat.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QAudioEnginePluginWrapper::QAudioEnginePluginWrapper(QObject * parent) : QAudioEnginePlugin(parent), m_metaObject(0) {
    // ... middle
}

QList<QByteArray > QAudioEnginePluginWrapper::availableDevices(QAudio::Mode arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "availableDevices"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.availableDevices()' not implemented.");
        return QList<QByteArray >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QAudio::Mode >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QByteArray >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QList<QByteArray > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.availableDevices", "list", pyResult->ob_type->tp_name);
        return QList<QByteArray >();
    }
    QList<QByteArray > cppResult(Shiboken::Converter<QList<QByteArray > >::toCpp(pyResult));
    return cppResult;
}

void QAudioEnginePluginWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAudioEnginePluginWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QAbstractAudioDeviceInfo * QAudioEnginePluginWrapper::createDeviceInfo(const QByteArray & device, QAudio::Mode mode)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createDeviceInfo"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createDeviceInfo()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QByteArray & >::toPython(device),
        Shiboken::Converter<QAudio::Mode >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QAbstractAudioDeviceInfo * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.createDeviceInfo", SbkType<QAbstractAudioDeviceInfo * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAbstractAudioDeviceInfo * cppResult(Shiboken::Converter<QAbstractAudioDeviceInfo * >::toCpp(pyResult));
    return cppResult;
}

QAbstractAudioInput * QAudioEnginePluginWrapper::createInput(const QByteArray & device, const QAudioFormat & format)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createInput"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createInput()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QByteArray & >::toPython(device),
        Shiboken::Converter<const QAudioFormat & >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QAbstractAudioInput * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.createInput", SbkType<QAbstractAudioInput * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAbstractAudioInput * cppResult(Shiboken::Converter<QAbstractAudioInput * >::toCpp(pyResult));
    return cppResult;
}

QAbstractAudioOutput * QAudioEnginePluginWrapper::createOutput(const QByteArray & device, const QAudioFormat & format)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createOutput"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createOutput()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QByteArray & >::toPython(device),
        Shiboken::Converter<const QAudioFormat & >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QAbstractAudioOutput * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.createOutput", SbkType<QAbstractAudioOutput * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QAbstractAudioOutput * cppResult(Shiboken::Converter<QAbstractAudioOutput * >::toCpp(pyResult));
    return cppResult;
}

void QAudioEnginePluginWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAudioEnginePluginWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QAudioEnginePluginWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAudioEnginePluginWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QStringList QAudioEnginePluginWrapper::keys() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keys"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.keys()' not implemented.");
        return QStringList();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.keys", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter<QStringList >::toCpp(pyResult));
    return cppResult;
}

void QAudioEnginePluginWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

const QMetaObject* QAudioEnginePluginWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QAudioEnginePlugin::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QAudioEnginePluginWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAudioEnginePlugin::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QAudioEnginePluginWrapper::~QAudioEnginePluginWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAudioEnginePlugin_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAudioEnginePlugin >()))
        return -1;

    QAudioEnginePluginWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEPLUGIN_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAudioEnginePlugin' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }

        type->mi_init = myType->mi_init;
        type->mi_offsets = myType->mi_offsets;
        type->mi_specialcast = myType->mi_specialcast;

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QAudioEnginePlugin", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QAudioEnginePlugin(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QAudioEnginePlugin(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QAudioEnginePlugin(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioEnginePlugin_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QAudioEnginePlugin(QObject*)
            cptr = new QAudioEnginePluginWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAudioEnginePlugin >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAudioEnginePlugin_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQAudioEnginePlugin_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin", overloads);
        return -1;
}

static PyObject* SbkQAudioEnginePluginFunc_availableDevices(PyObject* self, PyObject* arg)
{
    QAudioEnginePlugin* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioEnginePlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: availableDevices(QAudio::Mode)const
    if (Shiboken::Converter<QAudio::Mode >::isConvertible(arg)) {
        overloadId = 0; // availableDevices(QAudio::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioEnginePluginFunc_availableDevices_TypeError;

    // Call function/method
    {
        {
            QAudio::Mode cpp_arg0 = Shiboken::Converter<QAudio::Mode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // availableDevices(QAudio::Mode)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.availableDevices()' not implemented.");
                return 0;
            }
            QList<QByteArray > cppResult = cppSelf->availableDevices(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAudioEnginePluginFunc_availableDevices_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudio.Mode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAudioEnginePlugin.availableDevices", overloads);
        return 0;
}

static PyObject* SbkQAudioEnginePluginFunc_createDeviceInfo(PyObject* self, PyObject* args)
{
    QAudioEnginePlugin* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioEnginePlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createDeviceInfo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createDeviceInfo(QByteArray,QAudio::Mode)
    if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && Shiboken::Converter<QAudio::Mode >::isConvertible(pyargs[1])) {
        overloadId = 0; // createDeviceInfo(QByteArray,QAudio::Mode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioEnginePluginFunc_createDeviceInfo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            QAudio::Mode cpp_arg1 = Shiboken::Converter<QAudio::Mode >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // createDeviceInfo(QByteArray,QAudio::Mode)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createDeviceInfo()' not implemented.");
                return 0;
            }
            QAbstractAudioDeviceInfo * cppResult = cppSelf->createDeviceInfo(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QAbstractAudioDeviceInfo * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAudioEnginePluginFunc_createDeviceInfo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudio.Mode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin.createDeviceInfo", overloads);
        return 0;
}

static PyObject* SbkQAudioEnginePluginFunc_createInput(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAudioEnginePlugin* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioEnginePlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createInput(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createInput(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createInput(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createInput", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createInput(QByteArray,QAudioFormat)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createInput(QByteArray,QAudioFormat)
        } else if (Shiboken::Converter<const QAudioFormat & >::isConvertible(pyargs[1])) {
            overloadId = 0; // createInput(QByteArray,QAudioFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioEnginePluginFunc_createInput_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createInput(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QAudioFormat cpp_arg1_tmp = QAudioFormat();
            QAudioFormat* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QAudioFormat* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

            if(!PyErr_Occurred()) {
            // createInput(QByteArray,QAudioFormat)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createInput()' not implemented.");
                return 0;
            }
            QAbstractAudioInput * cppResult = cppSelf->createInput(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QAbstractAudioInput * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAudioEnginePluginFunc_createInput_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudioFormat = QAudioFormat()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin.createInput", overloads);
        return 0;
}

static PyObject* SbkQAudioEnginePluginFunc_createOutput(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAudioEnginePlugin* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioEnginePlugin* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createOutput", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createOutput(QByteArray,QAudioFormat)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createOutput(QByteArray,QAudioFormat)
        } else if (Shiboken::Converter<const QAudioFormat & >::isConvertible(pyargs[1])) {
            overloadId = 0; // createOutput(QByteArray,QAudioFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAudioEnginePluginFunc_createOutput_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QAudioFormat cpp_arg1_tmp = QAudioFormat();
            QAudioFormat* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QAudioFormat* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

            if(!PyErr_Occurred()) {
            // createOutput(QByteArray,QAudioFormat)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createOutput()' not implemented.");
                return 0;
            }
            QAbstractAudioOutput * cppResult = cppSelf->createOutput(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QAbstractAudioOutput * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAudioEnginePluginFunc_createOutput_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudioFormat = QAudioFormat()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput", overloads);
        return 0;
}

static PyObject* SbkQAudioEnginePluginFunc_keys(PyObject* self)
{
    QAudioEnginePlugin* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAudioEnginePlugin* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keys()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.keys()' not implemented.");
                return 0;
            }
            QStringList cppResult = cppSelf->keys();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQAudioEnginePlugin_methods[] = {
    {"availableDevices", (PyCFunction)SbkQAudioEnginePluginFunc_availableDevices, METH_O},
    {"createDeviceInfo", (PyCFunction)SbkQAudioEnginePluginFunc_createDeviceInfo, METH_VARARGS},
    {"createInput", (PyCFunction)SbkQAudioEnginePluginFunc_createInput, METH_VARARGS|METH_KEYWORDS},
    {"createOutput", (PyCFunction)SbkQAudioEnginePluginFunc_createOutput, METH_VARARGS|METH_KEYWORDS},
    {"keys", (PyCFunction)SbkQAudioEnginePluginFunc_keys, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1, -1, -1, -1, -1 };
int*
SbkQAudioEnginePlugin_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QAudioEnginePlugin* class_ptr = reinterpret_cast<const QAudioEnginePlugin*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((QAudioEnginePlugin*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QAudioEngineFactoryInterface*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QAudioEngineFactoryInterface*>((QAudioEnginePlugin*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QFactoryInterface*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QFactoryInterface*>((QAudioEngineFactoryInterface*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* SbkQAudioEnginePluginSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QAudioEnginePlugin* me = reinterpret_cast<QAudioEnginePlugin*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX]))
        return static_cast<QAudioEngineFactoryInterface*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QFACTORYINTERFACE_IDX]))
        return static_cast<QFactoryInterface*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAudioEnginePlugin_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QAudioEnginePlugin",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAudioEnginePlugin_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAudioEnginePlugin_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             SbkQAudioEnginePlugin_mi_init,
    /*mi_specialcast*/      &SbkQAudioEnginePluginSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAudioEnginePlugin >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAudioEnginePlugin*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQAudioEnginePlugin_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAudioEnginePlugin*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQAudioEnginePlugin_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QFactoryInterface >()) && dynamic_cast<QAudioEnginePlugin*>(reinterpret_cast<QFactoryInterface*>(cptr)))
        return &SbkQAudioEnginePlugin_Type;
    return 0;
}


void init_QAudioEnginePlugin(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEPLUGIN_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAudioEnginePlugin_Type);

    SbkQAudioEnginePlugin_Type.super.ht_type.tp_base = SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX];
    SbkQAudioEnginePlugin_Type.super.ht_type.tp_bases = PyTuple_Pack(2,
        (PyTypeObject*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX], (PyTypeObject*)SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX]);

    // Fill type discovery information
    SbkQAudioEnginePlugin_Type.type_discovery = &SbkQAudioEnginePlugin_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQAudioEnginePlugin_Type);
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX]), &SbkQAudioEnginePlugin_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAudioEnginePlugin_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAudioEnginePlugin_Type));
    PyModule_AddObject(module, "QAudioEnginePlugin",
        ((PyObject*)&SbkQAudioEnginePlugin_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QAudioEnginePlugin >("QAudioEnginePlugin*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAudioEnginePlugin >(typeid(QAudioEnginePlugin).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAudioEnginePlugin >(typeid(QAudioEnginePluginWrapper).name());
    PySide::initQtMetaType<QAudioEnginePlugin* >();
}

