/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtnetwork_python.h"

#include "qabstractsocket_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractsocket.h>
#include <qauthenticator.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qhostaddress.h>
#include <qnetworkproxy.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QAbstractSocketWrapper::QAbstractSocketWrapper(QAbstractSocket::SocketType socketType, QObject * parent) : QAbstractSocket(socketType, parent), m_metaObject(0) {
    // ... middle
}

bool QAbstractSocketWrapper::atEnd() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "atEnd"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::atEnd();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.atEnd", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractSocketWrapper::bytesAvailable() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesAvailable"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::bytesAvailable();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.bytesAvailable", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractSocketWrapper::bytesToWrite() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesToWrite"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::bytesToWrite();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.bytesToWrite", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractSocketWrapper::canReadLine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "canReadLine"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::canReadLine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.canReadLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractSocketWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractSocketWrapper::close()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QAbstractSocket::close();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractSocketWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractSocketWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractSocketWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QAbstractSocketWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QAbstractSocketWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QAbstractSocketWrapper::isSequential() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isSequential"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::isSequential();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.isSequential", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractSocketWrapper::open(QFlags<QIODevice::OpenModeFlag> mode)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::open(mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractSocketWrapper::pos() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pos"));
    if (py_override.isNull()) {
        return this->QIODevice::pos();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.pos", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractSocketWrapper::readData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readData"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::readData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.readData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractSocketWrapper::readLineData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readLineData"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::readLineData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.readLineData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractSocketWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QIODevice::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.reset", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractSocketWrapper::seek(qint64 pos)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::seek(pos);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(pos)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.seek", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractSocketWrapper::size() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "size"));
    if (py_override.isNull()) {
        return this->QIODevice::size();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.size", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

void QAbstractSocketWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QAbstractSocketWrapper::waitForBytesWritten(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForBytesWritten"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QAbstractSocket::waitForBytesWritten(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.waitForBytesWritten", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractSocketWrapper::waitForReadyRead(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForReadyRead"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QAbstractSocket::waitForReadyRead(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.waitForReadyRead", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QAbstractSocketWrapper::writeData(const char * data, qint64 len)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "writeData"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::writeData(data, len);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<const char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(len)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractSocket.writeData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QAbstractSocketWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QAbstractSocket::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QAbstractSocketWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAbstractSocket::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QAbstractSocketWrapper::~QAbstractSocketWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAbstractSocket_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractSocket >()))
        return -1;

    QAbstractSocketWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QAbstractSocket", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QAbstractSocket(QAbstractSocket::SocketType,QObject*)
    if (numArgs == 2 && Shiboken::Converter<QAbstractSocket::SocketType >::isConvertible(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        overloadId = 0; // QAbstractSocket(QAbstractSocket::SocketType,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocket_Init_TypeError;

    // Call function/method
    {
        {
            QAbstractSocket::SocketType cpp_arg0 = Shiboken::Converter<QAbstractSocket::SocketType >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return -1;
            QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // QAbstractSocket(QAbstractSocket::SocketType,QObject*)
            cptr = new QAbstractSocketWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[1], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractSocket >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAbstractSocket_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQAbstractSocket_Init_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractSocket.SocketType, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket", overloads);
        return -1;
}

static PyObject* SbkQAbstractSocketFunc_abort(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // abort()
            cppSelf->QAbstractSocket::abort();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractSocketFunc_atEnd(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QAbstractSocket::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_bytesAvailable(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesAvailable()const
            qint64 cppResult = cppSelf->QAbstractSocket::bytesAvailable();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_bytesToWrite(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesToWrite()const
            qint64 cppResult = cppSelf->QAbstractSocket::bytesToWrite();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_canReadLine(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canReadLine()const
            bool cppResult = cppSelf->QAbstractSocket::canReadLine();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_close(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // close()
            threadStateSaver.save();
            cppSelf->QAbstractSocket::close();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractSocketFunc_connectToHost(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHost(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHost(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHost(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:connectToHost", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: connectToHost(QHostAddress,quint16,QFlags<QIODevice::OpenModeFlag>)
    // 1: connectToHost(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // connectToHost(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
            overloadId = 1; // connectToHost(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QHostAddress & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // connectToHost(QHostAddress,quint16,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
            overloadId = 0; // connectToHost(QHostAddress,quint16,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_connectToHost_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // connectToHost(QHostAddress,quint16,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHost(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QHostAddress > cpp_arg0_auto_ptr;
                QHostAddress* cpp_arg0 = Shiboken::Converter<QHostAddress* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QHostAddress >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QHostAddress >(cpp_arg0);
                quint16 cpp_arg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);
                QFlags<QIODevice::OpenModeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // connectToHost(QHostAddress,quint16,QFlags<QIODevice::OpenModeFlag>)
                threadStateSaver.save();
                cppSelf->QAbstractSocket::connectToHost(*cpp_arg0, cpp_arg1, cpp_arg2);
                threadStateSaver.restore();
                }
                break;
            }
            case 1: // connectToHost(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHost(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                quint16 cpp_arg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);
                QFlags<QIODevice::OpenModeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // connectToHost(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
                threadStateSaver.save();
                cppSelf->QAbstractSocket::connectToHost(cpp_arg0, cpp_arg1, cpp_arg2);
                threadStateSaver.restore();
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_connectToHost_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress, unsigned short, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", "QString, unsigned short, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket.connectToHost", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_connectToHostImplementation(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHostImplementation(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHostImplementation(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHostImplementation(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:connectToHostImplementation", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: connectToHostImplementation(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // connectToHostImplementation(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
            overloadId = 0; // connectToHostImplementation(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_connectToHostImplementation_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "mode";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.connectToHostImplementation(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            quint16 cpp_arg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);
            QFlags<QIODevice::OpenModeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

            if(!PyErr_Occurred()) {
            // connectToHostImplementation(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
            cppSelf->QAbstractSocket::connectToHostImplementation(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_connectToHostImplementation_TypeError:
        const char* overloads[] = {"QString, unsigned short, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket.connectToHostImplementation", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_disconnectFromHost(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // disconnectFromHost()
            threadStateSaver.save();
            cppSelf->QAbstractSocket::disconnectFromHost();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractSocketFunc_disconnectFromHostImplementation(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // disconnectFromHostImplementation()
            cppSelf->QAbstractSocket::disconnectFromHostImplementation();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractSocketFunc_error(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QAbstractSocket::SocketError cppResult = cppSelf->QAbstractSocket::error();
            pyResult = Shiboken::Converter<QAbstractSocket::SocketError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_flush(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flush()
            bool cppResult = cppSelf->QAbstractSocket::flush();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_isSequential(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSequential()const
            bool cppResult = cppSelf->QAbstractSocket::isSequential();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_isValid(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QAbstractSocket::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_localAddress(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // localAddress()const
            QHostAddress cppResult = cppSelf->QAbstractSocket::localAddress();
            pyResult = Shiboken::Converter<QHostAddress >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_localPort(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // localPort()const
            quint16 cppResult = cppSelf->QAbstractSocket::localPort();
            pyResult = Shiboken::Converter<unsigned short >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_peerAddress(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // peerAddress()const
            QHostAddress cppResult = cppSelf->QAbstractSocket::peerAddress();
            pyResult = Shiboken::Converter<QHostAddress >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_peerName(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // peerName()const
            QString cppResult = cppSelf->QAbstractSocket::peerName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_peerPort(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // peerPort()const
            quint16 cppResult = cppSelf->QAbstractSocket::peerPort();
            pyResult = Shiboken::Converter<unsigned short >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_proxy(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // proxy()const
            QNetworkProxy cppResult = cppSelf->QAbstractSocket::proxy();
            pyResult = Shiboken::Converter<QNetworkProxy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_readBufferSize(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // readBufferSize()const
            qint64 cppResult = cppSelf->QAbstractSocket::readBufferSize();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_readData(PyObject* self, PyObject* args)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_readData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readData(char*,qint64)
            qint64 cppResult = cppSelf->QAbstractSocket::readData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_readData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket.readData", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_readLineData(PyObject* self, PyObject* args)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readLineData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readLineData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readLineData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_readLineData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readLineData(char*,qint64)
            qint64 cppResult = cppSelf->QAbstractSocket::readLineData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_readLineData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket.readLineData", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setLocalAddress(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocalAddress(QHostAddress)
    if (Shiboken::Converter<const QHostAddress & >::isConvertible(arg)) {
        overloadId = 0; // setLocalAddress(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setLocalAddress_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QHostAddress > cpp_arg0_auto_ptr;
            QHostAddress* cpp_arg0 = Shiboken::Converter<QHostAddress* >::toCpp(arg);
            if (!Shiboken::Converter<QHostAddress >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QHostAddress >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setLocalAddress(QHostAddress)
            cppSelf->QAbstractSocket::setLocalAddress(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setLocalAddress_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setLocalAddress", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setLocalPort(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocalPort(quint16)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLocalPort(quint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setLocalPort_TypeError;

    // Call function/method
    {
        {
            quint16 cpp_arg0 = Shiboken::Converter<quint16 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLocalPort(quint16)
            cppSelf->QAbstractSocket::setLocalPort(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setLocalPort_TypeError:
        const char* overloads[] = {"unsigned short", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setLocalPort", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setPeerAddress(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerAddress(QHostAddress)
    if (Shiboken::Converter<const QHostAddress & >::isConvertible(arg)) {
        overloadId = 0; // setPeerAddress(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setPeerAddress_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QHostAddress > cpp_arg0_auto_ptr;
            QHostAddress* cpp_arg0 = Shiboken::Converter<QHostAddress* >::toCpp(arg);
            if (!Shiboken::Converter<QHostAddress >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QHostAddress >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPeerAddress(QHostAddress)
            cppSelf->QAbstractSocket::setPeerAddress(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setPeerAddress_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setPeerAddress", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setPeerName(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPeerName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setPeerName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPeerName(QString)
            cppSelf->QAbstractSocket::setPeerName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setPeerName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setPeerName", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setPeerPort(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerPort(quint16)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPeerPort(quint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setPeerPort_TypeError;

    // Call function/method
    {
        {
            quint16 cpp_arg0 = Shiboken::Converter<quint16 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPeerPort(quint16)
            cppSelf->QAbstractSocket::setPeerPort(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setPeerPort_TypeError:
        const char* overloads[] = {"unsigned short", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setPeerPort", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setProxy(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProxy(QNetworkProxy)
    if (Shiboken::Converter<const QNetworkProxy & >::isConvertible(arg)) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setProxy_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QNetworkProxy > cpp_arg0_auto_ptr;
            QNetworkProxy* cpp_arg0 = Shiboken::Converter<QNetworkProxy* >::toCpp(arg);
            if (!Shiboken::Converter<QNetworkProxy >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QNetworkProxy >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setProxy(QNetworkProxy)
            cppSelf->QAbstractSocket::setProxy(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setProxy", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setReadBufferSize(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadBufferSize(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setReadBufferSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setReadBufferSize_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setReadBufferSize(qint64)
            cppSelf->QAbstractSocket::setReadBufferSize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setReadBufferSize_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setReadBufferSize", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setSocketDescriptor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "openMode", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.setSocketDescriptor(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.setSocketDescriptor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.setSocketDescriptor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setSocketDescriptor", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QAbstractSocket::SocketState >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
            } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
                overloadId = 0; // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setSocketDescriptor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "state";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "openMode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "openMode";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.setSocketDescriptor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QAbstractSocket::SocketState cpp_arg1 = pyargs[1] ? Shiboken::Converter<QAbstractSocket::SocketState >::toCpp(pyargs[1]) : QAbstractSocket::ConnectedState;
            QFlags<QIODevice::OpenModeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

            if(!PyErr_Occurred()) {
            // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
            bool cppResult = cppSelf->QAbstractSocket::setSocketDescriptor(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_setSocketDescriptor_TypeError:
        const char* overloads[] = {"int, PySide.QtNetwork.QAbstractSocket.SocketState = ConnectedState, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket.setSocketDescriptor", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setSocketError(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSocketError(QAbstractSocket::SocketError)
    if (Shiboken::Converter<QAbstractSocket::SocketError >::isConvertible(arg)) {
        overloadId = 0; // setSocketError(QAbstractSocket::SocketError)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setSocketError_TypeError;

    // Call function/method
    {
        {
            QAbstractSocket::SocketError cpp_arg0 = Shiboken::Converter<QAbstractSocket::SocketError >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSocketError(QAbstractSocket::SocketError)
            cppSelf->QAbstractSocket::setSocketError(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setSocketError_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractSocket.SocketError", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setSocketError", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setSocketOption(PyObject* self, PyObject* args)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSocketOption", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSocketOption(QAbstractSocket::SocketOption,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QAbstractSocket::SocketOption >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSocketOption(QAbstractSocket::SocketOption,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setSocketOption_TypeError;

    // Call function/method
    {
        {
            QAbstractSocket::SocketOption cpp_arg0 = Shiboken::Converter<QAbstractSocket::SocketOption >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setSocketOption(QAbstractSocket::SocketOption,QVariant)
            cppSelf->QAbstractSocket::setSocketOption(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setSocketOption_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractSocket.SocketOption, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket.setSocketOption", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_setSocketState(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSocketState(QAbstractSocket::SocketState)
    if (Shiboken::Converter<QAbstractSocket::SocketState >::isConvertible(arg)) {
        overloadId = 0; // setSocketState(QAbstractSocket::SocketState)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_setSocketState_TypeError;

    // Call function/method
    {
        {
            QAbstractSocket::SocketState cpp_arg0 = Shiboken::Converter<QAbstractSocket::SocketState >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSocketState(QAbstractSocket::SocketState)
            cppSelf->QAbstractSocket::setSocketState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractSocketFunc_setSocketState_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractSocket.SocketState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.setSocketState", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_socketDescriptor(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // socketDescriptor()const
            int cppResult = cppSelf->QAbstractSocket::socketDescriptor();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_socketOption(PyObject* self, PyObject* arg)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: socketOption(QAbstractSocket::SocketOption)
    if (Shiboken::Converter<QAbstractSocket::SocketOption >::isConvertible(arg)) {
        overloadId = 0; // socketOption(QAbstractSocket::SocketOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_socketOption_TypeError;

    // Call function/method
    {
        {
            QAbstractSocket::SocketOption cpp_arg0 = Shiboken::Converter<QAbstractSocket::SocketOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // socketOption(QAbstractSocket::SocketOption)
            QVariant cppResult = cppSelf->QAbstractSocket::socketOption(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_socketOption_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractSocket.SocketOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.socketOption", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_socketType(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // socketType()const
            QAbstractSocket::SocketType cppResult = cppSelf->QAbstractSocket::socketType();
            pyResult = Shiboken::Converter<QAbstractSocket::SocketType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_state(PyObject* self)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QAbstractSocket::SocketState cppResult = cppSelf->QAbstractSocket::state();
            pyResult = Shiboken::Converter<QAbstractSocket::SocketState >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractSocketFunc_waitForBytesWritten(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForBytesWritten(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForBytesWritten(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForBytesWritten", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForBytesWritten(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForBytesWritten(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_waitForBytesWritten_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForBytesWritten(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForBytesWritten(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QAbstractSocket::waitForBytesWritten(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_waitForBytesWritten_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.waitForBytesWritten", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_waitForConnected(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForConnected(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForConnected(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForConnected", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForConnected(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForConnected(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForConnected(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_waitForConnected_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForConnected(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForConnected(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QAbstractSocket::waitForConnected(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_waitForConnected_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.waitForConnected", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_waitForDisconnected(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForDisconnected(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForDisconnected(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForDisconnected", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForDisconnected(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForDisconnected(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForDisconnected(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_waitForDisconnected_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForDisconnected(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForDisconnected(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QAbstractSocket::waitForDisconnected(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_waitForDisconnected_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.waitForDisconnected", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_waitForReadyRead(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForReadyRead(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForReadyRead(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForReadyRead", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForReadyRead(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForReadyRead(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_waitForReadyRead_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QAbstractSocket.waitForReadyRead(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForReadyRead(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QAbstractSocket::waitForReadyRead(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_waitForReadyRead_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAbstractSocket.waitForReadyRead", overloads);
        return 0;
}

static PyObject* SbkQAbstractSocketFunc_writeData(PyObject* self, PyObject* args)
{
    QAbstractSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeData(const char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractSocketFunc_writeData_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // writeData(const char*,qint64)
            qint64 cppResult = cppSelf->QAbstractSocket::writeData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractSocketFunc_writeData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAbstractSocket.writeData", overloads);
        return 0;
}

static PyMethodDef SbkQAbstractSocket_methods[] = {
    {"abort", (PyCFunction)SbkQAbstractSocketFunc_abort, METH_NOARGS},
    {"atEnd", (PyCFunction)SbkQAbstractSocketFunc_atEnd, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)SbkQAbstractSocketFunc_bytesAvailable, METH_NOARGS},
    {"bytesToWrite", (PyCFunction)SbkQAbstractSocketFunc_bytesToWrite, METH_NOARGS},
    {"canReadLine", (PyCFunction)SbkQAbstractSocketFunc_canReadLine, METH_NOARGS},
    {"close", (PyCFunction)SbkQAbstractSocketFunc_close, METH_NOARGS},
    {"connectToHost", (PyCFunction)SbkQAbstractSocketFunc_connectToHost, METH_VARARGS|METH_KEYWORDS},
    {"connectToHostImplementation", (PyCFunction)SbkQAbstractSocketFunc_connectToHostImplementation, METH_VARARGS|METH_KEYWORDS},
    {"disconnectFromHost", (PyCFunction)SbkQAbstractSocketFunc_disconnectFromHost, METH_NOARGS},
    {"disconnectFromHostImplementation", (PyCFunction)SbkQAbstractSocketFunc_disconnectFromHostImplementation, METH_NOARGS},
    {"error", (PyCFunction)SbkQAbstractSocketFunc_error, METH_NOARGS},
    {"flush", (PyCFunction)SbkQAbstractSocketFunc_flush, METH_NOARGS},
    {"isSequential", (PyCFunction)SbkQAbstractSocketFunc_isSequential, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQAbstractSocketFunc_isValid, METH_NOARGS},
    {"localAddress", (PyCFunction)SbkQAbstractSocketFunc_localAddress, METH_NOARGS},
    {"localPort", (PyCFunction)SbkQAbstractSocketFunc_localPort, METH_NOARGS},
    {"peerAddress", (PyCFunction)SbkQAbstractSocketFunc_peerAddress, METH_NOARGS},
    {"peerName", (PyCFunction)SbkQAbstractSocketFunc_peerName, METH_NOARGS},
    {"peerPort", (PyCFunction)SbkQAbstractSocketFunc_peerPort, METH_NOARGS},
    {"proxy", (PyCFunction)SbkQAbstractSocketFunc_proxy, METH_NOARGS},
    {"readBufferSize", (PyCFunction)SbkQAbstractSocketFunc_readBufferSize, METH_NOARGS},
    {"readData", (PyCFunction)SbkQAbstractSocketFunc_readData, METH_VARARGS},
    {"readLineData", (PyCFunction)SbkQAbstractSocketFunc_readLineData, METH_VARARGS},
    {"setLocalAddress", (PyCFunction)SbkQAbstractSocketFunc_setLocalAddress, METH_O},
    {"setLocalPort", (PyCFunction)SbkQAbstractSocketFunc_setLocalPort, METH_O},
    {"setPeerAddress", (PyCFunction)SbkQAbstractSocketFunc_setPeerAddress, METH_O},
    {"setPeerName", (PyCFunction)SbkQAbstractSocketFunc_setPeerName, METH_O},
    {"setPeerPort", (PyCFunction)SbkQAbstractSocketFunc_setPeerPort, METH_O},
    {"setProxy", (PyCFunction)SbkQAbstractSocketFunc_setProxy, METH_O},
    {"setReadBufferSize", (PyCFunction)SbkQAbstractSocketFunc_setReadBufferSize, METH_O},
    {"setSocketDescriptor", (PyCFunction)SbkQAbstractSocketFunc_setSocketDescriptor, METH_VARARGS|METH_KEYWORDS},
    {"setSocketError", (PyCFunction)SbkQAbstractSocketFunc_setSocketError, METH_O},
    {"setSocketOption", (PyCFunction)SbkQAbstractSocketFunc_setSocketOption, METH_VARARGS},
    {"setSocketState", (PyCFunction)SbkQAbstractSocketFunc_setSocketState, METH_O},
    {"socketDescriptor", (PyCFunction)SbkQAbstractSocketFunc_socketDescriptor, METH_NOARGS},
    {"socketOption", (PyCFunction)SbkQAbstractSocketFunc_socketOption, METH_O},
    {"socketType", (PyCFunction)SbkQAbstractSocketFunc_socketType, METH_NOARGS},
    {"state", (PyCFunction)SbkQAbstractSocketFunc_state, METH_NOARGS},
    {"waitForBytesWritten", (PyCFunction)SbkQAbstractSocketFunc_waitForBytesWritten, METH_VARARGS|METH_KEYWORDS},
    {"waitForConnected", (PyCFunction)SbkQAbstractSocketFunc_waitForConnected, METH_VARARGS|METH_KEYWORDS},
    {"waitForDisconnected", (PyCFunction)SbkQAbstractSocketFunc_waitForDisconnected, METH_VARARGS|METH_KEYWORDS},
    {"waitForReadyRead", (PyCFunction)SbkQAbstractSocketFunc_waitForReadyRead, METH_VARARGS|METH_KEYWORDS},
    {"writeData", (PyCFunction)SbkQAbstractSocketFunc_writeData, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAbstractSocket_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QAbstractSocket",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAbstractSocket_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAbstractSocket_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAbstractSocket >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAbstractSocket*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQAbstractSocket_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAbstractSocket*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQAbstractSocket_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtNetwork_QAbstractSocket_SocketType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SocketType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QAbstractSocket_SocketType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QAbstractSocket_SocketType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QAbstractSocket_SocketError_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketError_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SocketError",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QAbstractSocket_SocketError_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QAbstractSocket_SocketError_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketError_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "NetworkLayerProtocol",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QAbstractSocket_SocketOption_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketOption_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SocketOption",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QAbstractSocket_SocketOption_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QAbstractSocket_SocketOption_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketOption_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QAbstractSocket_SocketState_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketState_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SocketState",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QAbstractSocket_SocketState_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QAbstractSocket_SocketState_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QAbstractSocket_SocketState_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QAbstractSocket(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAbstractSocket_Type);

    SbkQAbstractSocket_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX];
    // Fill type discovery information
    SbkQAbstractSocket_Type.type_discovery = &SbkQAbstractSocket_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX]), &SbkQAbstractSocket_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAbstractSocket_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAbstractSocket_Type));
    PyModule_AddObject(module, "QAbstractSocket",
        ((PyObject*)&SbkQAbstractSocket_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: SocketType
    SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETTYPE_IDX] = &SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
            "SocketType",((PyObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type,
        (long) QAbstractSocket::TcpSocket, "TcpSocket");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "TcpSocket", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type.tp_dict,
        "TcpSocket", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type,
        (long) QAbstractSocket::UdpSocket, "UdpSocket");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "UdpSocket", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type.tp_dict,
        "UdpSocket", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type,
        (long) QAbstractSocket::UnknownSocketType, "UnknownSocketType");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "UnknownSocketType", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketType_Type.tp_dict,
        "UnknownSocketType", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractSocket::SocketType");

    // init enum class: SocketError
    SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETERROR_IDX] = &SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
            "SocketError",((PyObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::ConnectionRefusedError, "ConnectionRefusedError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ConnectionRefusedError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "ConnectionRefusedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::RemoteHostClosedError, "RemoteHostClosedError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "RemoteHostClosedError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "RemoteHostClosedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::HostNotFoundError, "HostNotFoundError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "HostNotFoundError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "HostNotFoundError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::SocketAccessError, "SocketAccessError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "SocketAccessError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "SocketAccessError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::SocketResourceError, "SocketResourceError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "SocketResourceError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "SocketResourceError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::SocketTimeoutError, "SocketTimeoutError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "SocketTimeoutError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "SocketTimeoutError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::DatagramTooLargeError, "DatagramTooLargeError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "DatagramTooLargeError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "DatagramTooLargeError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::NetworkError, "NetworkError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "NetworkError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "NetworkError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::AddressInUseError, "AddressInUseError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "AddressInUseError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "AddressInUseError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::SocketAddressNotAvailableError, "SocketAddressNotAvailableError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "SocketAddressNotAvailableError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "SocketAddressNotAvailableError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::UnsupportedSocketOperationError, "UnsupportedSocketOperationError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "UnsupportedSocketOperationError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "UnsupportedSocketOperationError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::UnfinishedSocketOperationError, "UnfinishedSocketOperationError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "UnfinishedSocketOperationError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "UnfinishedSocketOperationError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::ProxyAuthenticationRequiredError, "ProxyAuthenticationRequiredError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ProxyAuthenticationRequiredError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "ProxyAuthenticationRequiredError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::SslHandshakeFailedError, "SslHandshakeFailedError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "SslHandshakeFailedError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "SslHandshakeFailedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::ProxyConnectionRefusedError, "ProxyConnectionRefusedError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ProxyConnectionRefusedError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "ProxyConnectionRefusedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::ProxyConnectionClosedError, "ProxyConnectionClosedError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ProxyConnectionClosedError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "ProxyConnectionClosedError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::ProxyConnectionTimeoutError, "ProxyConnectionTimeoutError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ProxyConnectionTimeoutError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "ProxyConnectionTimeoutError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::ProxyNotFoundError, "ProxyNotFoundError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ProxyNotFoundError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "ProxyNotFoundError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::ProxyProtocolError, "ProxyProtocolError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ProxyProtocolError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "ProxyProtocolError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type,
        (long) QAbstractSocket::UnknownSocketError, "UnknownSocketError");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "UnknownSocketError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketError_Type.tp_dict,
        "UnknownSocketError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractSocket::SocketError");

    // init enum class: NetworkLayerProtocol
    SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_NETWORKLAYERPROTOCOL_IDX] = &SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
            "NetworkLayerProtocol",((PyObject*)&SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type,
        (long) QAbstractSocket::IPv4Protocol, "IPv4Protocol");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "IPv4Protocol", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type.tp_dict,
        "IPv4Protocol", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type,
        (long) QAbstractSocket::IPv6Protocol, "IPv6Protocol");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "IPv6Protocol", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type.tp_dict,
        "IPv6Protocol", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type,
        (long) QAbstractSocket::UnknownNetworkLayerProtocol, "UnknownNetworkLayerProtocol");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "UnknownNetworkLayerProtocol", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_NetworkLayerProtocol_Type.tp_dict,
        "UnknownNetworkLayerProtocol", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractSocket::NetworkLayerProtocol");

    // init enum class: SocketOption
    SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETOPTION_IDX] = &SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
            "SocketOption",((PyObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type,
        (long) QAbstractSocket::LowDelayOption, "LowDelayOption");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "LowDelayOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type.tp_dict,
        "LowDelayOption", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type,
        (long) QAbstractSocket::KeepAliveOption, "KeepAliveOption");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "KeepAliveOption", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketOption_Type.tp_dict,
        "KeepAliveOption", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractSocket::SocketOption");

    // init enum class: SocketState
    SbkPySide_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETSTATE_IDX] = &SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
            "SocketState",((PyObject*)&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type,
        (long) QAbstractSocket::UnconnectedState, "UnconnectedState");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "UnconnectedState", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type.tp_dict,
        "UnconnectedState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type,
        (long) QAbstractSocket::HostLookupState, "HostLookupState");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "HostLookupState", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type.tp_dict,
        "HostLookupState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type,
        (long) QAbstractSocket::ConnectingState, "ConnectingState");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ConnectingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type.tp_dict,
        "ConnectingState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type,
        (long) QAbstractSocket::ConnectedState, "ConnectedState");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ConnectedState", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type.tp_dict,
        "ConnectedState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type,
        (long) QAbstractSocket::BoundState, "BoundState");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "BoundState", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type.tp_dict,
        "BoundState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type,
        (long) QAbstractSocket::ListeningState, "ListeningState");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ListeningState", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type.tp_dict,
        "ListeningState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type,
        (long) QAbstractSocket::ClosingState, "ClosingState");
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict,
        "ClosingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QAbstractSocket_SocketState_Type.tp_dict,
        "ClosingState", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractSocket::SocketState");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("disconnected", "void", NULL);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict, "disconnected", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("error", "QAbstractSocket::SocketError", NULL);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict, "error", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("hostFound", "void", NULL);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict, "hostFound", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("proxyAuthenticationRequired", "const QNetworkProxy&,QAuthenticator*", NULL);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict, "proxyAuthenticationRequired", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "QAbstractSocket::SocketState", NULL);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("connected", "void", NULL);
    PyDict_SetItemString(SbkQAbstractSocket_Type.super.ht_type.tp_dict, "connected", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractSocket >("QAbstractSocket*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractSocket >(typeid(QAbstractSocket).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractSocket >(typeid(QAbstractSocketWrapper).name());
    PySide::initQtMetaType<QAbstractSocket* >();
}

