/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qauthenticator_wrapper.h"

// Extra includes
#include <pysideconversions.h>
#include <qauthenticator.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAuthenticator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAuthenticator >()))
        return -1;

    QAuthenticator* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QAuthenticator", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QAuthenticator()
    // 1: QAuthenticator(QAuthenticator)
    if (numArgs == 0) {
        overloadId = 0; // QAuthenticator()
    } else if (numArgs == 1 && Shiboken::Converter<const QAuthenticator & >::isConvertible(arg)) {
        overloadId = 1; // QAuthenticator(QAuthenticator)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAuthenticator_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QAuthenticator()
            {

                if(!PyErr_Occurred()) {
                // QAuthenticator()
                cptr = new QAuthenticator();
                }
                break;
            }
            case 1: // QAuthenticator(QAuthenticator)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QAuthenticator* cpp_arg0 = Shiboken::Converter<QAuthenticator* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QAuthenticator(QAuthenticator)
                cptr = new QAuthenticator(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAuthenticator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAuthenticator_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQAuthenticator_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QAuthenticator", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAuthenticator", overloads);
        return -1;
}

static PyObject* SbkQAuthenticatorFunc_isNull(PyObject* self)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QAuthenticator::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAuthenticatorFunc_option(PyObject* self, PyObject* arg)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: option(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // option(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAuthenticatorFunc_option_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // option(QString)const
            QVariant cppResult = cppSelf->QAuthenticator::option(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAuthenticatorFunc_option_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAuthenticator.option", overloads);
        return 0;
}

static PyObject* SbkQAuthenticatorFunc_options(PyObject* self)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // options()const
            QHash<QString, QVariant > cppResult = cppSelf->QAuthenticator::options();
            pyResult = Shiboken::Converter<QHash<QString, QVariant > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAuthenticatorFunc_password(PyObject* self)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // password()const
            QString cppResult = cppSelf->QAuthenticator::password();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAuthenticatorFunc_realm(PyObject* self)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // realm()const
            QString cppResult = cppSelf->QAuthenticator::realm();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAuthenticatorFunc_setOption(PyObject* self, PyObject* args)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setOption", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOption(QString,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setOption(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAuthenticatorFunc_setOption_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setOption(QString,QVariant)
            cppSelf->QAuthenticator::setOption(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAuthenticatorFunc_setOption_TypeError:
        const char* overloads[] = {"QString, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QAuthenticator.setOption", overloads);
        return 0;
}

static PyObject* SbkQAuthenticatorFunc_setPassword(PyObject* self, PyObject* arg)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPassword(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAuthenticatorFunc_setPassword_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPassword(QString)
            cppSelf->QAuthenticator::setPassword(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAuthenticatorFunc_setPassword_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAuthenticator.setPassword", overloads);
        return 0;
}

static PyObject* SbkQAuthenticatorFunc_setUser(PyObject* self, PyObject* arg)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUser(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setUser(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAuthenticatorFunc_setUser_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUser(QString)
            cppSelf->QAuthenticator::setUser(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAuthenticatorFunc_setUser_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QAuthenticator.setUser", overloads);
        return 0;
}

static PyObject* SbkQAuthenticatorFunc_user(PyObject* self)
{
    QAuthenticator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAuthenticator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // user()const
            QString cppResult = cppSelf->QAuthenticator::user();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQAuthenticator_methods[] = {
    {"isNull", (PyCFunction)SbkQAuthenticatorFunc_isNull, METH_NOARGS},
    {"option", (PyCFunction)SbkQAuthenticatorFunc_option, METH_O},
    {"options", (PyCFunction)SbkQAuthenticatorFunc_options, METH_NOARGS},
    {"password", (PyCFunction)SbkQAuthenticatorFunc_password, METH_NOARGS},
    {"realm", (PyCFunction)SbkQAuthenticatorFunc_realm, METH_NOARGS},
    {"setOption", (PyCFunction)SbkQAuthenticatorFunc_setOption, METH_VARARGS},
    {"setPassword", (PyCFunction)SbkQAuthenticatorFunc_setPassword, METH_O},
    {"setUser", (PyCFunction)SbkQAuthenticatorFunc_setUser, METH_O},
    {"user", (PyCFunction)SbkQAuthenticatorFunc_user, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQAuthenticator_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QAuthenticator& cpp_self = *Shiboken::Converter<QAuthenticator* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QAuthenticator & >::isConvertible(other)) {
                // operator!=(const QAuthenticator & other) const
                QAuthenticator* cpp_other = Shiboken::Converter<QAuthenticator* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QAuthenticator  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQAuthenticator_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QAuthenticator & >::isConvertible(other)) {
                // operator==(const QAuthenticator & other) const
                QAuthenticator* cpp_other = Shiboken::Converter<QAuthenticator* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QAuthenticator  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQAuthenticator_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQAuthenticator_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAuthenticator_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QAuthenticator",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQAuthenticator_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAuthenticator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAuthenticator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAuthenticator >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAuthenticator",
    /*user_data*/           0
};
} //extern


void init_QAuthenticator(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QAUTHENTICATOR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAuthenticator_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAuthenticator_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAuthenticator_Type));
    PyModule_AddObject(module, "QAuthenticator",
        ((PyObject*)&SbkQAuthenticator_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QAuthenticator >("QAuthenticator");
    Shiboken::TypeResolver::createObjectTypeResolver<QAuthenticator >("QAuthenticator*");
    Shiboken::TypeResolver::createValueTypeResolver<QAuthenticator >(typeid(QAuthenticator).name());
    PySide::initQtMetaType<QAuthenticator >();
}

