/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtnetwork_python.h"

#include "qftp_wrapper.h"

// Extra includes
#include <QList>
#include <autoarraypointer.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qftp.h>
#include <qiodevice.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurlinfo.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QFtpWrapper::QFtpWrapper(QObject * parent) : QFtp(parent), m_metaObject(0) {
    // ... middle
}

void QFtpWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFtpWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QFtpWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QFtpWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QFtpWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFtp.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QFtpWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QFtp.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QFtpWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QFtpWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QFtp::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QFtpWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QFtp::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QFtpWrapper::~QFtpWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQFtp_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QFtp >()))
        return -1;

    QFtpWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QFtp", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QFtp(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QFtp(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QFtp(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtp_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QFtp(QObject*)
            cptr = new QFtpWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QFtp >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQFtp_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQFtp_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp", overloads);
        return -1;
}

static PyObject* SbkQFtpFunc_abort(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // abort()
            cppSelf->QFtp::abort();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQFtpFunc_bytesAvailable(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesAvailable()const
            qint64 cppResult = cppSelf->QFtp::bytesAvailable();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_cd(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cd(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // cd(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_cd_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // cd(QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::cd(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_cd_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.cd", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_clearPendingCommands(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearPendingCommands()
            cppSelf->QFtp::clearPendingCommands();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQFtpFunc_close(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // close()
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::close();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_connectToHost(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "port" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.connectToHost(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.connectToHost(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.connectToHost(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:connectToHost", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: connectToHost(QString,quint16)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // connectToHost(QString,quint16)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // connectToHost(QString,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_connectToHost_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "port");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "port";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.connectToHost(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            quint16 cpp_arg1 = pyargs[1] ? Shiboken::Converter<quint16 >::toCpp(pyargs[1]) : 21;

            if(!PyErr_Occurred()) {
            // connectToHost(QString,quint16)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::connectToHost(cpp_arg0, cpp_arg1);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_connectToHost_TypeError:
        const char* overloads[] = {"QString, unsigned short = 21", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.connectToHost", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_currentCommand(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentCommand()const
            QFtp::Command cppResult = cppSelf->QFtp::currentCommand();
            pyResult = Shiboken::Converter<QFtp::Command >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_currentDevice(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentDevice()const
            QIODevice * cppResult = cppSelf->QFtp::currentDevice();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_currentId(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentId()const
            int cppResult = cppSelf->QFtp::currentId();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_error(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QFtp::Error cppResult = cppSelf->QFtp::error();
            pyResult = Shiboken::Converter<QFtp::Error >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_errorString(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QFtp::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_get(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "dev", "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.get(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.get(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.get(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:get", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: get(QString,QIODevice*,QFtp::TransferType)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // get(QString,QIODevice*,QFtp::TransferType)
        } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // get(QString,QIODevice*,QFtp::TransferType)
            } else if (Shiboken::Converter<QFtp::TransferType >::isConvertible(pyargs[2])) {
                overloadId = 0; // get(QString,QIODevice*,QFtp::TransferType)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_get_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "dev");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "dev";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "type";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.get(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QIODevice* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]) : 0;
            QFtp::TransferType cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFtp::TransferType >::toCpp(pyargs[2]) : QFtp::Binary;

            if(!PyErr_Occurred()) {
            // get(QString,QIODevice*,QFtp::TransferType)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::get(cpp_arg0, cpp_arg1, cpp_arg2);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_get_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice = None, PySide.QtNetwork.QFtp.TransferType = Binary", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.get", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_hasPendingCommands(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasPendingCommands()const
            bool cppResult = cppSelf->QFtp::hasPendingCommands();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_list(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "dir" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.list(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.list(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:list", &arg))
        return 0;


    // Overloaded function decisor
    // 0: list(QString)
    if (numArgs == 0) {
        overloadId = 0; // list(QString)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // list(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_list_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "dir");
                if (value) {
                    if (arg)
                        errorArgName = "dir";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.list(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // list(QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::list(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_list_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.list", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_login(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "password", "user" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.login(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.login(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:login", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: login(QString,QString)
    if (numArgs == 0) {
        overloadId = 0; // login(QString,QString)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // login(QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // login(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_login_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "user");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "user";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "password");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "password";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.login(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // login(QString,QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::login(cpp_arg0, cpp_arg1);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_login_TypeError:
        const char* overloads[] = {"QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.login", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_mkdir(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mkdir(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // mkdir(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_mkdir_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mkdir(QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::mkdir(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_mkdir_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.mkdir", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_put(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:put", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: put(QIODevice*,QString,QFtp::TransferType)
    // 1: put(QByteArray,QString,QFtp::TransferType)
    if (numArgs >= 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // put(QByteArray,QString,QFtp::TransferType)
        } else if (Shiboken::Converter<QFtp::TransferType >::isConvertible(pyargs[2])) {
            overloadId = 1; // put(QByteArray,QString,QFtp::TransferType)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // put(QIODevice*,QString,QFtp::TransferType)
        } else if (Shiboken::Converter<QFtp::TransferType >::isConvertible(pyargs[2])) {
            overloadId = 0; // put(QIODevice*,QString,QFtp::TransferType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_put_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // put(QIODevice*,QString,QFtp::TransferType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QFtp::TransferType cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFtp::TransferType >::toCpp(pyargs[2]) : QFtp::Binary;

                if(!PyErr_Occurred()) {
                // put(QIODevice*,QString,QFtp::TransferType)
                threadStateSaver.save();
                int cppResult = cppSelf->QFtp::put(cpp_arg0, cpp_arg1, cpp_arg2);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // put(QByteArray,QString,QFtp::TransferType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QFtp.put(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QFtp::TransferType cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFtp::TransferType >::toCpp(pyargs[2]) : QFtp::Binary;

                if(!PyErr_Occurred()) {
                // put(QByteArray,QString,QFtp::TransferType)
                threadStateSaver.save();
                int cppResult = cppSelf->QFtp::put(*cpp_arg0, cpp_arg1, cpp_arg2);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_put_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, QString, PySide.QtNetwork.QFtp.TransferType = Binary", "PySide.QtCore.QByteArray, QString, PySide.QtNetwork.QFtp.TransferType = Binary", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.put", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_rawCommand(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rawCommand(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // rawCommand(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_rawCommand_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rawCommand(QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::rawCommand(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_rawCommand_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.rawCommand", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_read(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(char*,qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_read_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // read(char*,qint64)
            threadStateSaver.save();
            // Begin code injection
            
            // TEMPLATE - read_wrapper - START
            PySide::AutoArrayPointer<char> _data(cpp_arg0);
            qint64 _size = cppSelf->read(_data, cpp_arg0);
            if (_size > 0)
            pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray(_data, _size));
            else
            pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray());
            // TEMPLATE - read_wrapper - END
            
            // End of code injection

            threadStateSaver.restore();

            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_read_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.read", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_readAll(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // readAll()
            threadStateSaver.save();
            QByteArray cppResult = cppSelf->QFtp::readAll();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQFtpFunc_remove(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: remove(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_remove_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // remove(QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::remove(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_remove_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.remove", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_rename(PyObject* self, PyObject* args)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rename", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rename(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // rename(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_rename_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // rename(QString,QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::rename(cpp_arg0, cpp_arg1);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_rename_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.rename", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_rmdir(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rmdir(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // rmdir(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_rmdir_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rmdir(QString)
            threadStateSaver.save();
            int cppResult = cppSelf->QFtp::rmdir(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_rmdir_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.rmdir", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_setProxy(PyObject* self, PyObject* args)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProxy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProxy(QString,quint16)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setProxy(QString,quint16)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_setProxy_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            quint16 cpp_arg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setProxy(QString,quint16)
            int cppResult = cppSelf->QFtp::setProxy(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_setProxy_TypeError:
        const char* overloads[] = {"QString, unsigned short", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QFtp.setProxy", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_setTransferMode(PyObject* self, PyObject* arg)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransferMode(QFtp::TransferMode)
    if (Shiboken::Converter<QFtp::TransferMode >::isConvertible(arg)) {
        overloadId = 0; // setTransferMode(QFtp::TransferMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQFtpFunc_setTransferMode_TypeError;

    // Call function/method
    {
        {
            QFtp::TransferMode cpp_arg0 = Shiboken::Converter<QFtp::TransferMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTransferMode(QFtp::TransferMode)
            int cppResult = cppSelf->QFtp::setTransferMode(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQFtpFunc_setTransferMode_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QFtp.TransferMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QFtp.setTransferMode", overloads);
        return 0;
}

static PyObject* SbkQFtpFunc_state(PyObject* self)
{
    QFtp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QFtp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QFtp::State cppResult = cppSelf->QFtp::state();
            pyResult = Shiboken::Converter<QFtp::State >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQFtp_methods[] = {
    {"abort", (PyCFunction)SbkQFtpFunc_abort, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)SbkQFtpFunc_bytesAvailable, METH_NOARGS},
    {"cd", (PyCFunction)SbkQFtpFunc_cd, METH_O},
    {"clearPendingCommands", (PyCFunction)SbkQFtpFunc_clearPendingCommands, METH_NOARGS},
    {"close", (PyCFunction)SbkQFtpFunc_close, METH_NOARGS},
    {"connectToHost", (PyCFunction)SbkQFtpFunc_connectToHost, METH_VARARGS|METH_KEYWORDS},
    {"currentCommand", (PyCFunction)SbkQFtpFunc_currentCommand, METH_NOARGS},
    {"currentDevice", (PyCFunction)SbkQFtpFunc_currentDevice, METH_NOARGS},
    {"currentId", (PyCFunction)SbkQFtpFunc_currentId, METH_NOARGS},
    {"error", (PyCFunction)SbkQFtpFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQFtpFunc_errorString, METH_NOARGS},
    {"get", (PyCFunction)SbkQFtpFunc_get, METH_VARARGS|METH_KEYWORDS},
    {"hasPendingCommands", (PyCFunction)SbkQFtpFunc_hasPendingCommands, METH_NOARGS},
    {"list", (PyCFunction)SbkQFtpFunc_list, METH_VARARGS|METH_KEYWORDS},
    {"login", (PyCFunction)SbkQFtpFunc_login, METH_VARARGS|METH_KEYWORDS},
    {"mkdir", (PyCFunction)SbkQFtpFunc_mkdir, METH_O},
    {"put", (PyCFunction)SbkQFtpFunc_put, METH_VARARGS|METH_KEYWORDS},
    {"rawCommand", (PyCFunction)SbkQFtpFunc_rawCommand, METH_O},
    {"read", (PyCFunction)SbkQFtpFunc_read, METH_O},
    {"readAll", (PyCFunction)SbkQFtpFunc_readAll, METH_NOARGS},
    {"remove", (PyCFunction)SbkQFtpFunc_remove, METH_O},
    {"rename", (PyCFunction)SbkQFtpFunc_rename, METH_VARARGS},
    {"rmdir", (PyCFunction)SbkQFtpFunc_rmdir, METH_O},
    {"setProxy", (PyCFunction)SbkQFtpFunc_setProxy, METH_VARARGS},
    {"setTransferMode", (PyCFunction)SbkQFtpFunc_setTransferMode, METH_O},
    {"state", (PyCFunction)SbkQFtpFunc_state, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQFtp_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QFtp",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQFtp_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQFtp_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QFtp >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QFtp*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQFtp_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QFtp*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQFtp_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtNetwork_QFtp_TransferType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QFtp_TransferType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QFtp_TransferType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "TransferType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QFtp_TransferType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QFtp_TransferType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QFtp_TransferType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QFtp_Error_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QFtp_Error_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QFtp_Error_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Error",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QFtp_Error_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QFtp_Error_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QFtp_Error_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QFtp_Command_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QFtp_Command_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QFtp_Command_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Command",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QFtp_Command_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QFtp_Command_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QFtp_Command_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QFtp_TransferMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QFtp_TransferMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QFtp_TransferMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "TransferMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QFtp_TransferMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QFtp_TransferMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QFtp_TransferMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QFtp_State_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QFtp_State_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QFtp_State_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "State",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QFtp_State_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QFtp_State_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QFtp_State_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QFtp(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QFTP_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQFtp_Type);

    SbkQFtp_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQFtp_Type.type_discovery = &SbkQFtp_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQFtp_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQFtp_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQFtp_Type));
    PyModule_AddObject(module, "QFtp",
        ((PyObject*)&SbkQFtp_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: TransferType
    SbkPySide_QtNetworkTypes[SBK_QFTP_TRANSFERTYPE_IDX] = &SbkPySide_QtNetwork_QFtp_TransferType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QFtp_TransferType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QFtp_TransferType_Type);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
            "TransferType",((PyObject*)&SbkPySide_QtNetwork_QFtp_TransferType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_TransferType_Type,
        (long) QFtp::Binary, "Binary");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Binary", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferType_Type.tp_dict,
        "Binary", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_TransferType_Type,
        (long) QFtp::Ascii, "Ascii");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Ascii", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferType_Type.tp_dict,
        "Ascii", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::TransferType");

    // init enum class: Error
    SbkPySide_QtNetworkTypes[SBK_QFTP_ERROR_IDX] = &SbkPySide_QtNetwork_QFtp_Error_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QFtp_Error_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QFtp_Error_Type);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)&SbkPySide_QtNetwork_QFtp_Error_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Error_Type,
        (long) QFtp::NoError, "NoError");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Error_Type,
        (long) QFtp::UnknownError, "UnknownError");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "UnknownError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error_Type.tp_dict,
        "UnknownError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Error_Type,
        (long) QFtp::HostNotFound, "HostNotFound");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "HostNotFound", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error_Type.tp_dict,
        "HostNotFound", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Error_Type,
        (long) QFtp::ConnectionRefused, "ConnectionRefused");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "ConnectionRefused", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error_Type.tp_dict,
        "ConnectionRefused", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Error_Type,
        (long) QFtp::NotConnected, "NotConnected");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "NotConnected", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Error_Type.tp_dict,
        "NotConnected", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::Error");

    // init enum class: Command
    SbkPySide_QtNetworkTypes[SBK_QFTP_COMMAND_IDX] = &SbkPySide_QtNetwork_QFtp_Command_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QFtp_Command_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QFtp_Command_Type);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
            "Command",((PyObject*)&SbkPySide_QtNetwork_QFtp_Command_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::None, "None");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "None", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "None", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::SetTransferMode, "SetTransferMode");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "SetTransferMode", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "SetTransferMode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::SetProxy, "SetProxy");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "SetProxy", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "SetProxy", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::ConnectToHost, "ConnectToHost");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "ConnectToHost", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "ConnectToHost", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Login, "Login");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Login", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Login", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Close, "Close");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Close", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Close", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::List, "List");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "List", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "List", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Cd, "Cd");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Cd", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Cd", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Get, "Get");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Get", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Get", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Put, "Put");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Put", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Put", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Remove, "Remove");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Remove", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Remove", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Mkdir, "Mkdir");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Mkdir", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Mkdir", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Rmdir, "Rmdir");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Rmdir", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Rmdir", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::Rename, "Rename");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Rename", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "Rename", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_Command_Type,
        (long) QFtp::RawCommand, "RawCommand");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "RawCommand", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_Command_Type.tp_dict,
        "RawCommand", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::Command");

    // init enum class: TransferMode
    SbkPySide_QtNetworkTypes[SBK_QFTP_TRANSFERMODE_IDX] = &SbkPySide_QtNetwork_QFtp_TransferMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QFtp_TransferMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QFtp_TransferMode_Type);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
            "TransferMode",((PyObject*)&SbkPySide_QtNetwork_QFtp_TransferMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_TransferMode_Type,
        (long) QFtp::Active, "Active");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Active", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferMode_Type.tp_dict,
        "Active", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_TransferMode_Type,
        (long) QFtp::Passive, "Passive");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Passive", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_TransferMode_Type.tp_dict,
        "Passive", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::TransferMode");

    // init enum class: State
    SbkPySide_QtNetworkTypes[SBK_QFTP_STATE_IDX] = &SbkPySide_QtNetwork_QFtp_State_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QFtp_State_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QFtp_State_Type);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
            "State",((PyObject*)&SbkPySide_QtNetwork_QFtp_State_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_State_Type,
        (long) QFtp::Unconnected, "Unconnected");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Unconnected", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State_Type.tp_dict,
        "Unconnected", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_State_Type,
        (long) QFtp::HostLookup, "HostLookup");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "HostLookup", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State_Type.tp_dict,
        "HostLookup", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_State_Type,
        (long) QFtp::Connecting, "Connecting");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Connecting", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State_Type.tp_dict,
        "Connecting", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_State_Type,
        (long) QFtp::Connected, "Connected");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Connected", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State_Type.tp_dict,
        "Connected", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_State_Type,
        (long) QFtp::LoggedIn, "LoggedIn");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "LoggedIn", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State_Type.tp_dict,
        "LoggedIn", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QFtp_State_Type,
        (long) QFtp::Closing, "Closing");
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict,
        "Closing", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QFtp_State_Type.tp_dict,
        "Closing", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFtp::State");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("done", "bool", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "done", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("rawCommandReply", "int,const QString&", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "rawCommandReply", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("commandStarted", "int", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "commandStarted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("dataTransferProgress", "qint64,qint64", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "dataTransferProgress", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("commandFinished", "int,bool", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "commandFinished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("listInfo", "const QUrlInfo&", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "listInfo", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "int", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("readyRead", "void", NULL);
    PyDict_SetItemString(SbkQFtp_Type.super.ht_type.tp_dict, "readyRead", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QFtp >("QFtp*");
    Shiboken::TypeResolver::createObjectTypeResolver<QFtp >(typeid(QFtp).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QFtp >(typeid(QFtpWrapper).name());
    PySide::initQtMetaType<QFtp* >();
}

