/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtnetwork_python.h"

#include "qhttp_wrapper.h"

// Extra includes
#include <QList>
#include <autoarraypointer.h>
#include <qauthenticator.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qhttp.h>
#include <qiodevice.h>
#include <qnetworkproxy.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsslerror.h>
#include <qtcpsocket.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QHttpWrapper::QHttpWrapper(QObject * parent) : QHttp(parent), m_metaObject(0) {
    // ... middle
}

QHttpWrapper::QHttpWrapper(const QString & hostname, QHttp::ConnectionMode mode, quint16 port, QObject * parent) : QHttp(hostname, mode, port, parent), m_metaObject(0) {
    // ... middle
}

QHttpWrapper::QHttpWrapper(const QString & hostname, quint16 port, QObject * parent) : QHttp(hostname, port, parent), m_metaObject(0) {
    // ... middle
}

void QHttpWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QHttpWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QHttpWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QHttpWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QHttpWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttp.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QHttpWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttp.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QHttpWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QHttpWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QHttp::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QHttpWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QHttp::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QHttpWrapper::~QHttpWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQHttp_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QHttp >()))
        return -1;

    QHttpWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent", "port" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOOO:QHttp", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QHttp(QObject*)
    // 1: QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
    // 2: QHttp(QString,quint16,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QHttp(QObject*)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QHttp(QString,quint16,QObject*)
        } else if (Shiboken::Converter<QHttp::ConnectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
                } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[3])) {
                    overloadId = 1; // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
                }
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QHttp(QString,quint16,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 2; // QHttp(QString,quint16,QObject*)
            }
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QHttp(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttp_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHttp(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QHttp(QObject*)
                cptr = new QHttpWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "port";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "parent";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QHttp::ConnectionMode cpp_arg1 = Shiboken::Converter<QHttp::ConnectionMode >::toCpp(pyargs[1]);
                quint16 cpp_arg2 = pyargs[2] ? Shiboken::Converter<quint16 >::toCpp(pyargs[2]) : 0;
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return -1;
                QObject* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QObject* >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // QHttp(QString,QHttp::ConnectionMode,quint16,QObject*)
                cptr = new QHttpWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                Shiboken::setParent(pyargs[3], self);
                }
                break;
            }
            case 2: // QHttp(QString,quint16,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "port";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                quint16 cpp_arg1 = pyargs[1] ? Shiboken::Converter<quint16 >::toCpp(pyargs[1]) : 80;
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QHttp(QString,quint16,QObject*)
                cptr = new QHttpWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QHttp >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQHttp_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQHttp_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "QString, PySide.QtNetwork.QHttp.ConnectionMode, unsigned short = 0, PySide.QtCore.QObject = None", "QString, unsigned short = 80, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp", overloads);
        return -1;
}

static PyObject* SbkQHttpFunc_abort(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // abort()
            cppSelf->QHttp::abort();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQHttpFunc_bytesAvailable(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesAvailable()const
            qint64 cppResult = cppSelf->QHttp::bytesAvailable();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_clearPendingRequests(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearPendingRequests()
            cppSelf->QHttp::clearPendingRequests();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQHttpFunc_close(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // close()
            int cppResult = cppSelf->QHttp::close();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_currentDestinationDevice(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentDestinationDevice()const
            QIODevice * cppResult = cppSelf->QHttp::currentDestinationDevice();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_currentId(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentId()const
            int cppResult = cppSelf->QHttp::currentId();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_currentRequest(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentRequest()const
            QHttpRequestHeader cppResult = cppSelf->QHttp::currentRequest();
            pyResult = Shiboken::Converter<QHttpRequestHeader >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_currentSourceDevice(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentSourceDevice()const
            QIODevice * cppResult = cppSelf->QHttp::currentSourceDevice();
            pyResult = Shiboken::Converter<QIODevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_error(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // error()const
            QHttp::Error cppResult = cppSelf->QHttp::error();
            pyResult = Shiboken::Converter<QHttp::Error >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_errorString(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QHttp::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_get(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "to" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.get(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.get(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.get(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:get", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: get(QString,QIODevice*)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // get(QString,QIODevice*)
        } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // get(QString,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_get_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "to");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "to";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.get(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QIODevice* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // get(QString,QIODevice*)
            int cppResult = cppSelf->QHttp::get(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_get_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.get", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_hasPendingRequests(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasPendingRequests()const
            bool cppResult = cppSelf->QHttp::hasPendingRequests();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_head(PyObject* self, PyObject* arg)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: head(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // head(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_head_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // head(QString)
            int cppResult = cppSelf->QHttp::head(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_head_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttp.head", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_ignoreSslErrors(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ignoreSslErrors()
            cppSelf->QHttp::ignoreSslErrors();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQHttpFunc_lastResponse(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastResponse()const
            QHttpResponseHeader cppResult = cppSelf->QHttp::lastResponse();
            pyResult = Shiboken::Converter<QHttpResponseHeader >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_post(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "to" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:post", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: post(QString,QIODevice*,QIODevice*)
    // 1: post(QString,QByteArray,QIODevice*)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // post(QString,QByteArray,QIODevice*)
            } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 1; // post(QString,QByteArray,QIODevice*)
            }
        } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // post(QString,QIODevice*,QIODevice*)
            } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 0; // post(QString,QIODevice*,QIODevice*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_post_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // post(QString,QIODevice*,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QIODevice* cpp_arg1 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QIODevice* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // post(QString,QIODevice*,QIODevice*)
                int cppResult = cppSelf->QHttp::post(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // post(QString,QByteArray,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.post(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QIODevice* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // post(QString,QByteArray,QIODevice*)
                int cppResult = cppSelf->QHttp::post(cpp_arg0, *cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_post_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice, PySide.QtCore.QIODevice = None", "QString, PySide.QtCore.QByteArray, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.post", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_read(PyObject* self, PyObject* arg)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(char*,qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // read(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_read_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // read(char*,qint64)
            threadStateSaver.save();
            // Begin code injection
            
            // TEMPLATE - read_wrapper - START
            PySide::AutoArrayPointer<char> _data(cpp_arg0);
            qint64 _size = cppSelf->read(_data, cpp_arg0);
            if (_size > 0)
            pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray(_data, _size));
            else
            pyResult = Shiboken::Converter<QByteArray >::toPython(QByteArray());
            // TEMPLATE - read_wrapper - END
            
            // End of code injection

            threadStateSaver.restore();

            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_read_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttp.read", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_readAll(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // readAll()
            threadStateSaver.save();
            QByteArray cppResult = cppSelf->QHttp::readAll();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpFunc_request(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "device", "to" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:request", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: request(QHttpRequestHeader,QIODevice*,QIODevice*)
    // 1: request(QHttpRequestHeader,QByteArray,QIODevice*)
    if (Shiboken::Converter<const QHttpRequestHeader & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // request(QHttpRequestHeader,QIODevice*,QIODevice*)
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // request(QHttpRequestHeader,QByteArray,QIODevice*)
            } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 1; // request(QHttpRequestHeader,QByteArray,QIODevice*)
            }
        } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // request(QHttpRequestHeader,QIODevice*,QIODevice*)
            } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[2])) {
                overloadId = 0; // request(QHttpRequestHeader,QIODevice*,QIODevice*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_request_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // request(QHttpRequestHeader,QIODevice*,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "device");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "device";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QHttpRequestHeader > cpp_arg0_auto_ptr;
                QHttpRequestHeader* cpp_arg0 = Shiboken::Converter<QHttpRequestHeader* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QHttpRequestHeader >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QHttpRequestHeader >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QIODevice* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]) : 0;
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QIODevice* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // request(QHttpRequestHeader,QIODevice*,QIODevice*)
                int cppResult = cppSelf->QHttp::request(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // request(QHttpRequestHeader,QByteArray,QIODevice*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "to");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "to";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.request(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QHttpRequestHeader > cpp_arg0_auto_ptr;
                QHttpRequestHeader* cpp_arg0 = Shiboken::Converter<QHttpRequestHeader* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QHttpRequestHeader >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QHttpRequestHeader >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QIODevice* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // request(QHttpRequestHeader,QByteArray,QIODevice*)
                int cppResult = cppSelf->QHttp::request(*cpp_arg0, *cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_request_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHttpRequestHeader, PySide.QtCore.QIODevice = None, PySide.QtCore.QIODevice = None", "PySide.QtNetwork.QHttpRequestHeader, PySide.QtCore.QByteArray, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.request", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_setHost(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "port" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setHost", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setHost(QString,QHttp::ConnectionMode,quint16)
    // 1: setHost(QString,quint16)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setHost(QString,quint16)
        } else if (Shiboken::Converter<QHttp::ConnectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setHost(QString,QHttp::ConnectionMode,quint16)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // setHost(QString,QHttp::ConnectionMode,quint16)
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // setHost(QString,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_setHost_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setHost(QString,QHttp::ConnectionMode,quint16)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "port";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QHttp::ConnectionMode cpp_arg1 = Shiboken::Converter<QHttp::ConnectionMode >::toCpp(pyargs[1]);
                quint16 cpp_arg2 = pyargs[2] ? Shiboken::Converter<quint16 >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // setHost(QString,QHttp::ConnectionMode,quint16)
                int cppResult = cppSelf->QHttp::setHost(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // setHost(QString,quint16)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "port");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "port";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setHost(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                quint16 cpp_arg1 = pyargs[1] ? Shiboken::Converter<quint16 >::toCpp(pyargs[1]) : 80;

                if(!PyErr_Occurred()) {
                // setHost(QString,quint16)
                int cppResult = cppSelf->QHttp::setHost(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_setHost_TypeError:
        const char* overloads[] = {"QString, PySide.QtNetwork.QHttp.ConnectionMode, unsigned short = 0", "QString, unsigned short = 80", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.setHost", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_setProxy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "password", "username" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setProxy(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setProxy(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setProxy(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setProxy", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setProxy(QNetworkProxy)
    // 1: setProxy(QString,int,QString,QString)
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // setProxy(QString,int,QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // setProxy(QString,int,QString,QString)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                overloadId = 1; // setProxy(QString,int,QString,QString)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QNetworkProxy & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_setProxy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setProxy(QNetworkProxy)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QNetworkProxy > cpp_arg0_auto_ptr;
                QNetworkProxy* cpp_arg0 = Shiboken::Converter<QNetworkProxy* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QNetworkProxy >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QNetworkProxy >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setProxy(QNetworkProxy)
                int cppResult = cppSelf->QHttp::setProxy(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // setProxy(QString,int,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "username");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "username";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "password");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "password";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setProxy(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();

                if(!PyErr_Occurred()) {
                // setProxy(QString,int,QString,QString)
                int cppResult = cppSelf->QHttp::setProxy(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_setProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy", "QString, int, QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.setProxy", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_setSocket(PyObject* self, PyObject* arg)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSocket(QTcpSocket*)
    if (Shiboken::Converter<QTcpSocket * >::isConvertible(arg)) {
        overloadId = 0; // setSocket(QTcpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_setSocket_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTcpSocket* cpp_arg0 = Shiboken::Converter<QTcpSocket* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSocket(QTcpSocket*)
            int cppResult = cppSelf->QHttp::setSocket(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_setSocket_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QTcpSocket", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttp.setSocket", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_setUser(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "password" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setUser(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setUser(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttp.setUser(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setUser", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUser(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setUser(QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // setUser(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpFunc_setUser_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "password");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "password";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttp.setUser(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // setUser(QString,QString)
            int cppResult = cppSelf->QHttp::setUser(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpFunc_setUser_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttp.setUser", overloads);
        return 0;
}

static PyObject* SbkQHttpFunc_state(PyObject* self)
{
    QHttp* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QHttp::State cppResult = cppSelf->QHttp::state();
            pyResult = Shiboken::Converter<QHttp::State >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQHttp_methods[] = {
    {"abort", (PyCFunction)SbkQHttpFunc_abort, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)SbkQHttpFunc_bytesAvailable, METH_NOARGS},
    {"clearPendingRequests", (PyCFunction)SbkQHttpFunc_clearPendingRequests, METH_NOARGS},
    {"close", (PyCFunction)SbkQHttpFunc_close, METH_NOARGS},
    {"currentDestinationDevice", (PyCFunction)SbkQHttpFunc_currentDestinationDevice, METH_NOARGS},
    {"currentId", (PyCFunction)SbkQHttpFunc_currentId, METH_NOARGS},
    {"currentRequest", (PyCFunction)SbkQHttpFunc_currentRequest, METH_NOARGS},
    {"currentSourceDevice", (PyCFunction)SbkQHttpFunc_currentSourceDevice, METH_NOARGS},
    {"error", (PyCFunction)SbkQHttpFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQHttpFunc_errorString, METH_NOARGS},
    {"get", (PyCFunction)SbkQHttpFunc_get, METH_VARARGS|METH_KEYWORDS},
    {"hasPendingRequests", (PyCFunction)SbkQHttpFunc_hasPendingRequests, METH_NOARGS},
    {"head", (PyCFunction)SbkQHttpFunc_head, METH_O},
    {"ignoreSslErrors", (PyCFunction)SbkQHttpFunc_ignoreSslErrors, METH_NOARGS},
    {"lastResponse", (PyCFunction)SbkQHttpFunc_lastResponse, METH_NOARGS},
    {"post", (PyCFunction)SbkQHttpFunc_post, METH_VARARGS|METH_KEYWORDS},
    {"read", (PyCFunction)SbkQHttpFunc_read, METH_O},
    {"readAll", (PyCFunction)SbkQHttpFunc_readAll, METH_NOARGS},
    {"request", (PyCFunction)SbkQHttpFunc_request, METH_VARARGS|METH_KEYWORDS},
    {"setHost", (PyCFunction)SbkQHttpFunc_setHost, METH_VARARGS|METH_KEYWORDS},
    {"setProxy", (PyCFunction)SbkQHttpFunc_setProxy, METH_VARARGS|METH_KEYWORDS},
    {"setSocket", (PyCFunction)SbkQHttpFunc_setSocket, METH_O},
    {"setUser", (PyCFunction)SbkQHttpFunc_setUser, METH_VARARGS|METH_KEYWORDS},
    {"state", (PyCFunction)SbkQHttpFunc_state, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQHttp_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QHttp",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQHttp_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQHttp_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QHttp >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QHttp*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQHttp_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QHttp*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQHttp_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtNetwork_QHttp_Error_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QHttp_Error_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QHttp_Error_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Error",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QHttp_Error_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QHttp_Error_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QHttp_Error_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QHttp_ConnectionMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QHttp_ConnectionMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QHttp_ConnectionMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ConnectionMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QHttp_ConnectionMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QHttp_ConnectionMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QHttp_ConnectionMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QHttp_State_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QHttp_State_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QHttp_State_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "State",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QHttp_State_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QHttp_State_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QHttp_State_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QHttp(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QHTTP_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQHttp_Type);

    SbkQHttp_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQHttp_Type.type_discovery = &SbkQHttp_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQHttp_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQHttp_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQHttp_Type));
    PyModule_AddObject(module, "QHttp",
        ((PyObject*)&SbkQHttp_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Error
    SbkPySide_QtNetworkTypes[SBK_QHTTP_ERROR_IDX] = &SbkPySide_QtNetwork_QHttp_Error_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QHttp_Error_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QHttp_Error_Type);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)&SbkPySide_QtNetwork_QHttp_Error_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::NoError, "NoError");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::UnknownError, "UnknownError");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "UnknownError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "UnknownError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::HostNotFound, "HostNotFound");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "HostNotFound", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "HostNotFound", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::ConnectionRefused, "ConnectionRefused");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "ConnectionRefused", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "ConnectionRefused", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::UnexpectedClose, "UnexpectedClose");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "UnexpectedClose", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "UnexpectedClose", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::InvalidResponseHeader, "InvalidResponseHeader");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "InvalidResponseHeader", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "InvalidResponseHeader", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::WrongContentLength, "WrongContentLength");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "WrongContentLength", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "WrongContentLength", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::Aborted, "Aborted");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "Aborted", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "Aborted", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::AuthenticationRequiredError, "AuthenticationRequiredError");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "AuthenticationRequiredError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "AuthenticationRequiredError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_Error_Type,
        (long) QHttp::ProxyAuthenticationRequiredError, "ProxyAuthenticationRequiredError");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "ProxyAuthenticationRequiredError", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_Error_Type.tp_dict,
        "ProxyAuthenticationRequiredError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHttp::Error");

    // init enum class: ConnectionMode
    SbkPySide_QtNetworkTypes[SBK_QHTTP_CONNECTIONMODE_IDX] = &SbkPySide_QtNetwork_QHttp_ConnectionMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QHttp_ConnectionMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QHttp_ConnectionMode_Type);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
            "ConnectionMode",((PyObject*)&SbkPySide_QtNetwork_QHttp_ConnectionMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_ConnectionMode_Type,
        (long) QHttp::ConnectionModeHttp, "ConnectionModeHttp");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "ConnectionModeHttp", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_ConnectionMode_Type.tp_dict,
        "ConnectionModeHttp", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_ConnectionMode_Type,
        (long) QHttp::ConnectionModeHttps, "ConnectionModeHttps");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "ConnectionModeHttps", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_ConnectionMode_Type.tp_dict,
        "ConnectionModeHttps", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHttp::ConnectionMode");

    // init enum class: State
    SbkPySide_QtNetworkTypes[SBK_QHTTP_STATE_IDX] = &SbkPySide_QtNetwork_QHttp_State_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QHttp_State_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QHttp_State_Type);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
            "State",((PyObject*)&SbkPySide_QtNetwork_QHttp_State_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_State_Type,
        (long) QHttp::Unconnected, "Unconnected");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "Unconnected", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State_Type.tp_dict,
        "Unconnected", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_State_Type,
        (long) QHttp::HostLookup, "HostLookup");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "HostLookup", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State_Type.tp_dict,
        "HostLookup", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_State_Type,
        (long) QHttp::Connecting, "Connecting");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "Connecting", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State_Type.tp_dict,
        "Connecting", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_State_Type,
        (long) QHttp::Sending, "Sending");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "Sending", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State_Type.tp_dict,
        "Sending", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_State_Type,
        (long) QHttp::Reading, "Reading");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "Reading", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State_Type.tp_dict,
        "Reading", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_State_Type,
        (long) QHttp::Connected, "Connected");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "Connected", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State_Type.tp_dict,
        "Connected", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QHttp_State_Type,
        (long) QHttp::Closing, "Closing");
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict,
        "Closing", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QHttp_State_Type.tp_dict,
        "Closing", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHttp::State");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("requestStarted", "int", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "requestStarted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("sslErrors", "const QList<QSslError>&", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "sslErrors", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("dataSendProgress", "int,int", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "dataSendProgress", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("done", "bool", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "done", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("authenticationRequired", "const QString&,quint16,QAuthenticator*", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "authenticationRequired", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("responseHeaderReceived", "const QHttpResponseHeader&", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "responseHeaderReceived", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("dataReadProgress", "int,int", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "dataReadProgress", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("proxyAuthenticationRequired", "const QNetworkProxy&,QAuthenticator*", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "proxyAuthenticationRequired", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("requestFinished", "int,bool", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "requestFinished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "int", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("readyRead", "const QHttpResponseHeader&", NULL);
    PyDict_SetItemString(SbkQHttp_Type.super.ht_type.tp_dict, "readyRead", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QHttp >("QHttp*");
    Shiboken::TypeResolver::createObjectTypeResolver<QHttp >(typeid(QHttp).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QHttp >(typeid(QHttpWrapper).name());
    PySide::initQtMetaType<QHttp* >();
}

