/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qhttpheader_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <QStringList>
#include <qhttp.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QHttpHeaderWrapper::QHttpHeaderWrapper() : QHttpHeader() {
    // ... middle
}

QHttpHeaderWrapper::QHttpHeaderWrapper(const QString & str) : QHttpHeader(str) {
    // ... middle
}

int QHttpHeaderWrapper::majorVersion() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "majorVersion"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QHttpHeader.majorVersion()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpHeader.majorVersion", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QHttpHeaderWrapper::minorVersion() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minorVersion"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QHttpHeader.minorVersion()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpHeader.minorVersion", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

bool QHttpHeaderWrapper::parseLine(const QString & line, int number)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "parseLine"));
    if (py_override.isNull()) {
        return this->QHttpHeader::parseLine(line, number);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Ni)",
        Shiboken::Converter<QString >::toPython(line),
        number
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpHeader.parseLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QString QHttpHeaderWrapper::toString() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "toString"));
    if (py_override.isNull()) {
        return this->QHttpHeader::toString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpHeader.toString", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

QHttpHeaderWrapper::~QHttpHeaderWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQHttpHeader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QHttpHeader >()))
        return -1;

    QHttpHeaderWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtNetworkTypes[SBK_QHTTPHEADER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QHttpHeader' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QHttpHeader", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QHttpHeader()
    // 1: QHttpHeader(QString)
    if (numArgs == 0) {
        overloadId = 0; // QHttpHeader()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // QHttpHeader(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHttpHeader()
            {

                if(!PyErr_Occurred()) {
                // QHttpHeader()
                cptr = new QHttpHeaderWrapper();
                }
                break;
            }
            case 1: // QHttpHeader(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QHttpHeader(QString)
                cptr = new QHttpHeaderWrapper(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QHttpHeader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQHttpHeader_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQHttpHeader_Init_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttpHeader", overloads);
        return -1;
}

static PyObject* SbkQHttpHeaderFunc_addValue(PyObject* self, PyObject* args)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addValue", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addValue(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // addValue(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_addValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // addValue(QString,QString)
            cppSelf->QHttpHeader::addValue(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_addValue_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttpHeader.addValue", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_allValues(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: allValues(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // allValues(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_allValues_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // allValues(QString)const
            QStringList cppResult = cppSelf->QHttpHeader::allValues(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpHeaderFunc_allValues_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.allValues", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_contentLength(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contentLength()const
            uint cppResult = cppSelf->QHttpHeader::contentLength();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_contentType(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contentType()const
            QString cppResult = cppSelf->QHttpHeader::contentType();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_hasContentLength(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasContentLength()const
            bool cppResult = cppSelf->QHttpHeader::hasContentLength();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_hasContentType(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasContentType()const
            bool cppResult = cppSelf->QHttpHeader::hasContentType();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_hasKey(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasKey(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasKey(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_hasKey_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasKey(QString)const
            bool cppResult = cppSelf->QHttpHeader::hasKey(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpHeaderFunc_hasKey_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.hasKey", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_isValid(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QHttpHeader::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_keys(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keys()const
            QStringList cppResult = cppSelf->QHttpHeader::keys();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_majorVersion(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // majorVersion()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QHttpHeader.majorVersion()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->majorVersion();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_minorVersion(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minorVersion()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QHttpHeader.minorVersion()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->minorVersion();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_parse(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: parse(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // parse(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_parse_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // parse(QString)
            bool cppResult = cppSelf->QHttpHeader::parse(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpHeaderFunc_parse_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.parse", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_parseLine(PyObject* self, PyObject* args)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "parseLine", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: parseLine(QString,int)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // parseLine(QString,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_parseLine_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // parseLine(QString,int)
            bool cppResult = cppSelf->QHttpHeader::parseLine(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpHeaderFunc_parseLine_TypeError:
        const char* overloads[] = {"QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttpHeader.parseLine", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_removeAllValues(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAllValues(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeAllValues(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_removeAllValues_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAllValues(QString)
            cppSelf->QHttpHeader::removeAllValues(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_removeAllValues_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.removeAllValues", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_removeValue(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeValue(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeValue(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_removeValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeValue(QString)
            cppSelf->QHttpHeader::removeValue(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_removeValue_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.removeValue", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_setContentLength(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContentLength(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setContentLength(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_setContentLength_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setContentLength(int)
            cppSelf->QHttpHeader::setContentLength(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_setContentLength_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.setContentLength", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_setContentType(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContentType(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setContentType(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_setContentType_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setContentType(QString)
            cppSelf->QHttpHeader::setContentType(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_setContentType_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.setContentType", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_setValid(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setValid(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setValid(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_setValid_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setValid(bool)
            cppSelf->QHttpHeader::setValid(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_setValid_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.setValid", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_setValue(PyObject* self, PyObject* args)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setValue", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setValue(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setValue(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_setValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setValue(QString,QString)
            cppSelf->QHttpHeader::setValue(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_setValue_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttpHeader.setValue", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_setValues(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setValues(QList<QPair<QString,QString> >)
    if (Shiboken::Converter< QList<QPair<QString, QString > >  >::isConvertible(arg)) {
        overloadId = 0; // setValues(QList<QPair<QString,QString> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_setValues_TypeError;

    // Call function/method
    {
        {
            QList<QPair<QString, QString > > cpp_arg0 = Shiboken::Converter<QList<QPair<QString, QString > > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setValues(QList<QPair<QString,QString> >)
            cppSelf->QHttpHeader::setValues(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQHttpHeaderFunc_setValues_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.setValues", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_toString(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toString()const
            QString cppResult = cppSelf->QHttpHeader::toString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQHttpHeaderFunc_value(PyObject* self, PyObject* arg)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: value(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // value(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQHttpHeaderFunc_value_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // value(QString)const
            QString cppResult = cppSelf->QHttpHeader::value(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQHttpHeaderFunc_value_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QHttpHeader.value", overloads);
        return 0;
}

static PyObject* SbkQHttpHeaderFunc_values(PyObject* self)
{
    QHttpHeader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QHttpHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // values()const
            QList<QPair<QString, QString > > cppResult = cppSelf->QHttpHeader::values();
            pyResult = Shiboken::Converter<QList<QPair<QString, QString > > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQHttpHeader_methods[] = {
    {"addValue", (PyCFunction)SbkQHttpHeaderFunc_addValue, METH_VARARGS},
    {"allValues", (PyCFunction)SbkQHttpHeaderFunc_allValues, METH_O},
    {"contentLength", (PyCFunction)SbkQHttpHeaderFunc_contentLength, METH_NOARGS},
    {"contentType", (PyCFunction)SbkQHttpHeaderFunc_contentType, METH_NOARGS},
    {"hasContentLength", (PyCFunction)SbkQHttpHeaderFunc_hasContentLength, METH_NOARGS},
    {"hasContentType", (PyCFunction)SbkQHttpHeaderFunc_hasContentType, METH_NOARGS},
    {"hasKey", (PyCFunction)SbkQHttpHeaderFunc_hasKey, METH_O},
    {"isValid", (PyCFunction)SbkQHttpHeaderFunc_isValid, METH_NOARGS},
    {"keys", (PyCFunction)SbkQHttpHeaderFunc_keys, METH_NOARGS},
    {"majorVersion", (PyCFunction)SbkQHttpHeaderFunc_majorVersion, METH_NOARGS},
    {"minorVersion", (PyCFunction)SbkQHttpHeaderFunc_minorVersion, METH_NOARGS},
    {"parse", (PyCFunction)SbkQHttpHeaderFunc_parse, METH_O},
    {"parseLine", (PyCFunction)SbkQHttpHeaderFunc_parseLine, METH_VARARGS},
    {"removeAllValues", (PyCFunction)SbkQHttpHeaderFunc_removeAllValues, METH_O},
    {"removeValue", (PyCFunction)SbkQHttpHeaderFunc_removeValue, METH_O},
    {"setContentLength", (PyCFunction)SbkQHttpHeaderFunc_setContentLength, METH_O},
    {"setContentType", (PyCFunction)SbkQHttpHeaderFunc_setContentType, METH_O},
    {"setValid", (PyCFunction)SbkQHttpHeaderFunc_setValid, METH_O},
    {"setValue", (PyCFunction)SbkQHttpHeaderFunc_setValue, METH_VARARGS},
    {"setValues", (PyCFunction)SbkQHttpHeaderFunc_setValues, METH_O},
    {"toString", (PyCFunction)SbkQHttpHeaderFunc_toString, METH_NOARGS},
    {"value", (PyCFunction)SbkQHttpHeaderFunc_value, METH_O},
    {"values", (PyCFunction)SbkQHttpHeaderFunc_values, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQHttpHeader_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QHttpHeader",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQHttpHeader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQHttpHeader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QHttpHeader >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QHttpHeader*",
    /*user_data*/           0
};
} //extern


void init_QHttpHeader(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QHTTPHEADER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQHttpHeader_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQHttpHeader_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQHttpHeader_Type));
    PyModule_AddObject(module, "QHttpHeader",
        ((PyObject*)&SbkQHttpHeader_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QHttpHeader >("QHttpHeader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QHttpHeader >(typeid(QHttpHeader).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QHttpHeader >(typeid(QHttpHeaderWrapper).name());
    PySide::initQtMetaType<QHttpHeader* >();
}

