/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtnetwork_python.h"

#include "qnetworkaccessmanager_wrapper.h"

// Extra includes
#include <QList>
#include <qauthenticator.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qnetworkconfiguration.h>
#include <qnetworkcookiejar.h>
#include <qnetworkproxy.h>
#include <qnetworkreply.h>
#include <qnetworkrequest.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsslerror.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QNetworkAccessManagerWrapper::QNetworkAccessManagerWrapper(QObject * parent) : QNetworkAccessManager(parent), m_metaObject(0) {
    // ... middle
}

void QNetworkAccessManagerWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QNetworkAccessManagerWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QNetworkReply * QNetworkAccessManagerWrapper::createRequest(QNetworkAccessManager::Operation op, const QNetworkRequest & request, QIODevice * outgoingData)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createRequest"));
    if (py_override.isNull()) {
        return this->QNetworkAccessManager::createRequest(op, request, outgoingData);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter<QNetworkAccessManager::Operation >::toPython(op),
        Shiboken::Converter<const QNetworkRequest & >::toPython(request),
        Shiboken::Converter<QIODevice * >::toPython(outgoingData)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QNetworkReply * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkAccessManager.createRequest", SbkType<QNetworkReply * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QNetworkReply * cppResult(Shiboken::Converter<QNetworkReply * >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 2));
    return cppResult;
}

void QNetworkAccessManagerWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QNetworkAccessManagerWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QNetworkAccessManagerWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkAccessManager.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QNetworkAccessManagerWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkAccessManager.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QNetworkAccessManagerWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QNetworkAccessManagerWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QNetworkAccessManager::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QNetworkAccessManagerWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QNetworkAccessManager::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QNetworkAccessManagerWrapper::~QNetworkAccessManagerWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQNetworkAccessManager_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkAccessManager >()))
        return -1;

    QNetworkAccessManagerWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QNetworkAccessManager", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkAccessManager(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkAccessManager(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QNetworkAccessManager(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManager_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QNetworkAccessManager(QObject*)
            cptr = new QNetworkAccessManagerWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkAccessManager >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQNetworkAccessManager_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQNetworkAccessManager_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager", overloads);
        return -1;
}

static PyObject* SbkQNetworkAccessManagerFunc_activeConfiguration(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // activeConfiguration()const
            QNetworkConfiguration cppResult = cppSelf->QNetworkAccessManager::activeConfiguration();
            pyResult = Shiboken::Converter<QNetworkConfiguration >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkAccessManagerFunc_configuration(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // configuration()const
            QNetworkConfiguration cppResult = cppSelf->QNetworkAccessManager::configuration();
            pyResult = Shiboken::Converter<QNetworkConfiguration >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkAccessManagerFunc_cookieJar(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cookieJar()const
            QNetworkCookieJar * cppResult = cppSelf->QNetworkAccessManager::cookieJar();
            pyResult = Shiboken::Converter<QNetworkCookieJar * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkAccessManagerFunc_createRequest(PyObject* self, PyObject* args, PyObject* kwds)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "outgoingData" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.createRequest(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.createRequest(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.createRequest(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:createRequest", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
    if (numArgs >= 2 && Shiboken::Converter<QNetworkAccessManager::Operation >::isConvertible(pyargs[0]) && Shiboken::Converter<const QNetworkRequest & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
        } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[2])) {
            overloadId = 0; // createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_createRequest_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "outgoingData");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "outgoingData";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.createRequest(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QNetworkAccessManager::Operation cpp_arg0 = Shiboken::Converter<QNetworkAccessManager::Operation >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QNetworkRequest* cpp_arg1 = Shiboken::Converter<QNetworkRequest* >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QIODevice* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
            // createRequest(QNetworkAccessManager::Operation,QNetworkRequest,QIODevice*)
            QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::createRequest(cpp_arg0, *cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkAccessManagerFunc_createRequest_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkAccessManager.Operation, PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager.createRequest", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_deleteResource(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: deleteResource(QNetworkRequest)
    if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(arg)) {
        overloadId = 0; // deleteResource(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_deleteResource_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // deleteResource(QNetworkRequest)
            QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::deleteResource(*cpp_arg0);
            pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkAccessManagerFunc_deleteResource_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.deleteResource", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_get(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: get(QNetworkRequest)
    if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(arg)) {
        overloadId = 0; // get(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_get_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // get(QNetworkRequest)
            threadStateSaver.save();
            QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::get(*cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkAccessManagerFunc_get_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.get", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_head(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: head(QNetworkRequest)
    if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(arg)) {
        overloadId = 0; // head(QNetworkRequest)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_head_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // head(QNetworkRequest)
            QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::head(*cpp_arg0);
            pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkAccessManagerFunc_head_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.head", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_networkAccessible(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // networkAccessible()const
            QNetworkAccessManager::NetworkAccessibility cppResult = cppSelf->QNetworkAccessManager::networkAccessible();
            pyResult = Shiboken::Converter<QNetworkAccessManager::NetworkAccessibility >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkAccessManagerFunc_post(PyObject* self, PyObject* args)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "post", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: post(QNetworkRequest,QIODevice*)
    // 1: post(QNetworkRequest,QByteArray)
    if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 1; // post(QNetworkRequest,QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // post(QNetworkRequest,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_post_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // post(QNetworkRequest,QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QIODevice* cpp_arg1 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // post(QNetworkRequest,QIODevice*)
                threadStateSaver.save();
                QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::post(*cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // post(QNetworkRequest,QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // post(QNetworkRequest,QByteArray)
                threadStateSaver.save();
                QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::post(*cpp_arg0, *cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkAccessManagerFunc_post_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QIODevice", "PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager.post", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_proxy(PyObject* self)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // proxy()const
            QNetworkProxy cppResult = cppSelf->QNetworkAccessManager::proxy();
            pyResult = Shiboken::Converter<QNetworkProxy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkAccessManagerFunc_put(PyObject* self, PyObject* args)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "put", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: put(QNetworkRequest,QIODevice*)
    // 1: put(QNetworkRequest,QByteArray)
    if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 1; // put(QNetworkRequest,QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // put(QNetworkRequest,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_put_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // put(QNetworkRequest,QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QIODevice* cpp_arg1 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // put(QNetworkRequest,QIODevice*)
                threadStateSaver.save();
                QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::put(*cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // put(QNetworkRequest,QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // put(QNetworkRequest,QByteArray)
                threadStateSaver.save();
                QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::put(*cpp_arg0, *cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkAccessManagerFunc_put_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QIODevice", "PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager.put", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_sendCustomRequest(PyObject* self, PyObject* args, PyObject* kwds)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "data" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.sendCustomRequest(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.sendCustomRequest(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.sendCustomRequest(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:sendCustomRequest", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*)
    if (numArgs >= 2 && Shiboken::Converter<const QNetworkRequest & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*)
        } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[2])) {
            overloadId = 0; // sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_sendCustomRequest_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "data");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "data";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkAccessManager.sendCustomRequest(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
            QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QIODevice* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QIODevice* >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
            // sendCustomRequest(QNetworkRequest,QByteArray,QIODevice*)
            threadStateSaver.save();
            QNetworkReply * cppResult = cppSelf->QNetworkAccessManager::sendCustomRequest(*cpp_arg0, *cpp_arg1, cpp_arg2);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QNetworkReply * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQNetworkAccessManagerFunc_sendCustomRequest_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest, PySide.QtCore.QByteArray, PySide.QtCore.QIODevice = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkAccessManager.sendCustomRequest", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_setConfiguration(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setConfiguration(QNetworkConfiguration)
    if (Shiboken::Converter<const QNetworkConfiguration & >::isConvertible(arg)) {
        overloadId = 0; // setConfiguration(QNetworkConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_setConfiguration_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QNetworkConfiguration* cpp_arg0 = Shiboken::Converter<QNetworkConfiguration* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setConfiguration(QNetworkConfiguration)
            cppSelf->QNetworkAccessManager::setConfiguration(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkAccessManagerFunc_setConfiguration_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setConfiguration", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_setCookieJar(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCookieJar(QNetworkCookieJar*)
    if (Shiboken::Converter<QNetworkCookieJar * >::isConvertible(arg)) {
        overloadId = 0; // setCookieJar(QNetworkCookieJar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_setCookieJar_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QNetworkCookieJar* cpp_arg0 = Shiboken::Converter<QNetworkCookieJar* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCookieJar(QNetworkCookieJar*)
            cppSelf->QNetworkAccessManager::setCookieJar(cpp_arg0);

            // Ownership transferences.
            BindingManager::instance().transferOwnershipToCpp(arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkAccessManagerFunc_setCookieJar_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkCookieJar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setCookieJar", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_setNetworkAccessible(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNetworkAccessible(QNetworkAccessManager::NetworkAccessibility)
    if (Shiboken::Converter<QNetworkAccessManager::NetworkAccessibility >::isConvertible(arg)) {
        overloadId = 0; // setNetworkAccessible(QNetworkAccessManager::NetworkAccessibility)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_setNetworkAccessible_TypeError;

    // Call function/method
    {
        {
            QNetworkAccessManager::NetworkAccessibility cpp_arg0 = Shiboken::Converter<QNetworkAccessManager::NetworkAccessibility >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNetworkAccessible(QNetworkAccessManager::NetworkAccessibility)
            cppSelf->QNetworkAccessManager::setNetworkAccessible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkAccessManagerFunc_setNetworkAccessible_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkAccessManager.NetworkAccessibility", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setNetworkAccessible", overloads);
        return 0;
}

static PyObject* SbkQNetworkAccessManagerFunc_setProxy(PyObject* self, PyObject* arg)
{
    QNetworkAccessManager* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkAccessManager* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProxy(QNetworkProxy)
    if (Shiboken::Converter<const QNetworkProxy & >::isConvertible(arg)) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkAccessManagerFunc_setProxy_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QNetworkProxy > cpp_arg0_auto_ptr;
            QNetworkProxy* cpp_arg0 = Shiboken::Converter<QNetworkProxy* >::toCpp(arg);
            if (!Shiboken::Converter<QNetworkProxy >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QNetworkProxy >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setProxy(QNetworkProxy)
            cppSelf->QNetworkAccessManager::setProxy(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQNetworkAccessManagerFunc_setProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkAccessManager.setProxy", overloads);
        return 0;
}

static PyMethodDef SbkQNetworkAccessManager_methods[] = {
    {"activeConfiguration", (PyCFunction)SbkQNetworkAccessManagerFunc_activeConfiguration, METH_NOARGS},
    {"configuration", (PyCFunction)SbkQNetworkAccessManagerFunc_configuration, METH_NOARGS},
    {"cookieJar", (PyCFunction)SbkQNetworkAccessManagerFunc_cookieJar, METH_NOARGS},
    {"createRequest", (PyCFunction)SbkQNetworkAccessManagerFunc_createRequest, METH_VARARGS|METH_KEYWORDS},
    {"deleteResource", (PyCFunction)SbkQNetworkAccessManagerFunc_deleteResource, METH_O},
    {"get", (PyCFunction)SbkQNetworkAccessManagerFunc_get, METH_O},
    {"head", (PyCFunction)SbkQNetworkAccessManagerFunc_head, METH_O},
    {"networkAccessible", (PyCFunction)SbkQNetworkAccessManagerFunc_networkAccessible, METH_NOARGS},
    {"post", (PyCFunction)SbkQNetworkAccessManagerFunc_post, METH_VARARGS},
    {"proxy", (PyCFunction)SbkQNetworkAccessManagerFunc_proxy, METH_NOARGS},
    {"put", (PyCFunction)SbkQNetworkAccessManagerFunc_put, METH_VARARGS},
    {"sendCustomRequest", (PyCFunction)SbkQNetworkAccessManagerFunc_sendCustomRequest, METH_VARARGS|METH_KEYWORDS},
    {"setConfiguration", (PyCFunction)SbkQNetworkAccessManagerFunc_setConfiguration, METH_O},
    {"setCookieJar", (PyCFunction)SbkQNetworkAccessManagerFunc_setCookieJar, METH_O},
    {"setNetworkAccessible", (PyCFunction)SbkQNetworkAccessManagerFunc_setNetworkAccessible, METH_O},
    {"setProxy", (PyCFunction)SbkQNetworkAccessManagerFunc_setProxy, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQNetworkAccessManager_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkAccessManager",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQNetworkAccessManager_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQNetworkAccessManager_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QNetworkAccessManager >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QNetworkAccessManager*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQNetworkAccessManager_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QNetworkAccessManager*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQNetworkAccessManager_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "NetworkAccessibility",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkAccessManager_Operation_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkAccessManager_Operation_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Operation",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkAccessManager_Operation_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkAccessManager_Operation_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkAccessManager_Operation_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QNetworkAccessManager(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQNetworkAccessManager_Type);

    SbkQNetworkAccessManager_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQNetworkAccessManager_Type.type_discovery = &SbkQNetworkAccessManager_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQNetworkAccessManager_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQNetworkAccessManager_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQNetworkAccessManager_Type));
    PyModule_AddObject(module, "QNetworkAccessManager",
        ((PyObject*)&SbkQNetworkAccessManager_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: NetworkAccessibility
    SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_NETWORKACCESSIBILITY_IDX] = &SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
            "NetworkAccessibility",((PyObject*)&SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type,
        (long) QNetworkAccessManager::UnknownAccessibility, "UnknownAccessibility");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "UnknownAccessibility", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type.tp_dict,
        "UnknownAccessibility", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type,
        (long) QNetworkAccessManager::NotAccessible, "NotAccessible");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "NotAccessible", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type.tp_dict,
        "NotAccessible", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type,
        (long) QNetworkAccessManager::Accessible, "Accessible");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "Accessible", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_NetworkAccessibility_Type.tp_dict,
        "Accessible", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkAccessManager::NetworkAccessibility");

    // init enum class: Operation
    SbkPySide_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_OPERATION_IDX] = &SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
            "Operation",((PyObject*)&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type,
        (long) QNetworkAccessManager::HeadOperation, "HeadOperation");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "HeadOperation", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type.tp_dict,
        "HeadOperation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type,
        (long) QNetworkAccessManager::GetOperation, "GetOperation");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "GetOperation", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type.tp_dict,
        "GetOperation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type,
        (long) QNetworkAccessManager::PutOperation, "PutOperation");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "PutOperation", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type.tp_dict,
        "PutOperation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type,
        (long) QNetworkAccessManager::PostOperation, "PostOperation");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "PostOperation", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type.tp_dict,
        "PostOperation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type,
        (long) QNetworkAccessManager::DeleteOperation, "DeleteOperation");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "DeleteOperation", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type.tp_dict,
        "DeleteOperation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type,
        (long) QNetworkAccessManager::CustomOperation, "CustomOperation");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "CustomOperation", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type.tp_dict,
        "CustomOperation", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type,
        (long) QNetworkAccessManager::UnknownOperation, "UnknownOperation");
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict,
        "UnknownOperation", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkAccessManager_Operation_Type.tp_dict,
        "UnknownOperation", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkAccessManager::Operation");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("sslErrors", "QNetworkReply*,const QList<QSslError>&", NULL);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict, "sslErrors", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("authenticationRequired", "QNetworkReply*,QAuthenticator*", NULL);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict, "authenticationRequired", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("networkSessionConnected", "void", NULL);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict, "networkSessionConnected", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("finished", "QNetworkReply*", NULL);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict, "finished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("networkAccessibleChanged", "QNetworkAccessManager::NetworkAccessibility", NULL);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict, "networkAccessibleChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("proxyAuthenticationRequired", "const QNetworkProxy&,QAuthenticator*", NULL);
    PyDict_SetItemString(SbkQNetworkAccessManager_Type.super.ht_type.tp_dict, "proxyAuthenticationRequired", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkAccessManager >("QNetworkAccessManager*");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkAccessManager >(typeid(QNetworkAccessManager).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkAccessManager >(typeid(QNetworkAccessManagerWrapper).name());
    PySide::initQtMetaType<QNetworkAccessManager* >();
}

