/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkconfiguration_wrapper.h"

// Extra includes
#include <QList>
#include <qnetworkconfiguration.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQNetworkConfiguration_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkConfiguration >()))
        return -1;

    QNetworkConfiguration* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QNetworkConfiguration", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkConfiguration()
    // 1: QNetworkConfiguration(QNetworkConfiguration)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkConfiguration()
    } else if (numArgs == 1 && Shiboken::Converter<const QNetworkConfiguration & >::isConvertible(arg)) {
        overloadId = 1; // QNetworkConfiguration(QNetworkConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQNetworkConfiguration_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkConfiguration()
            {

                if(!PyErr_Occurred()) {
                // QNetworkConfiguration()
                cptr = new QNetworkConfiguration();
                }
                break;
            }
            case 1: // QNetworkConfiguration(QNetworkConfiguration)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QNetworkConfiguration* cpp_arg0 = Shiboken::Converter<QNetworkConfiguration* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QNetworkConfiguration(QNetworkConfiguration)
                cptr = new QNetworkConfiguration(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkConfiguration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQNetworkConfiguration_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQNetworkConfiguration_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QNetworkConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkConfiguration", overloads);
        return -1;
}

static PyObject* SbkQNetworkConfigurationFunc_bearerName(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bearerName()const
            QString cppResult = cppSelf->QNetworkConfiguration::bearerName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_bearerType(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bearerType()const
            QNetworkConfiguration::BearerType cppResult = cppSelf->QNetworkConfiguration::bearerType();
            pyResult = Shiboken::Converter<QNetworkConfiguration::BearerType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_bearerTypeName(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bearerTypeName()const
            QString cppResult = cppSelf->QNetworkConfiguration::bearerTypeName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_children(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // children()const
            QList<QNetworkConfiguration > cppResult = cppSelf->QNetworkConfiguration::children();
            pyResult = Shiboken::Converter<QList<QNetworkConfiguration > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_identifier(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // identifier()const
            QString cppResult = cppSelf->QNetworkConfiguration::identifier();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_isRoamingAvailable(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRoamingAvailable()const
            bool cppResult = cppSelf->QNetworkConfiguration::isRoamingAvailable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_isValid(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QNetworkConfiguration::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_name(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QNetworkConfiguration::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_purpose(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // purpose()const
            QNetworkConfiguration::Purpose cppResult = cppSelf->QNetworkConfiguration::purpose();
            pyResult = Shiboken::Converter<QNetworkConfiguration::Purpose >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_state(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QFlags<QNetworkConfiguration::StateFlag> cppResult = cppSelf->QNetworkConfiguration::state();
            pyResult = Shiboken::Converter<QFlags<QNetworkConfiguration::StateFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQNetworkConfigurationFunc_type(PyObject* self)
{
    QNetworkConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            QNetworkConfiguration::Type cppResult = cppSelf->QNetworkConfiguration::type();
            pyResult = Shiboken::Converter<QNetworkConfiguration::Type >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQNetworkConfiguration_methods[] = {
    {"bearerName", (PyCFunction)SbkQNetworkConfigurationFunc_bearerName, METH_NOARGS},
    {"bearerType", (PyCFunction)SbkQNetworkConfigurationFunc_bearerType, METH_NOARGS},
    {"bearerTypeName", (PyCFunction)SbkQNetworkConfigurationFunc_bearerTypeName, METH_NOARGS},
    {"children", (PyCFunction)SbkQNetworkConfigurationFunc_children, METH_NOARGS},
    {"identifier", (PyCFunction)SbkQNetworkConfigurationFunc_identifier, METH_NOARGS},
    {"isRoamingAvailable", (PyCFunction)SbkQNetworkConfigurationFunc_isRoamingAvailable, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQNetworkConfigurationFunc_isValid, METH_NOARGS},
    {"name", (PyCFunction)SbkQNetworkConfigurationFunc_name, METH_NOARGS},
    {"purpose", (PyCFunction)SbkQNetworkConfigurationFunc_purpose, METH_NOARGS},
    {"state", (PyCFunction)SbkQNetworkConfigurationFunc_state, METH_NOARGS},
    {"type", (PyCFunction)SbkQNetworkConfigurationFunc_type, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQNetworkConfiguration_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QNetworkConfiguration& cpp_self = *Shiboken::Converter<QNetworkConfiguration* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QNetworkConfiguration & >::isConvertible(other)) {
                // operator!=(const QNetworkConfiguration & cp) const
                QNetworkConfiguration* cpp_other = Shiboken::Converter<QNetworkConfiguration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QNetworkConfiguration  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQNetworkConfiguration_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QNetworkConfiguration & >::isConvertible(other)) {
                // operator==(const QNetworkConfiguration & cp) const
                QNetworkConfiguration* cpp_other = Shiboken::Converter<QNetworkConfiguration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QNetworkConfiguration  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQNetworkConfiguration_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQNetworkConfiguration_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQNetworkConfiguration_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkConfiguration",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQNetworkConfiguration_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQNetworkConfiguration_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQNetworkConfiguration_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QNetworkConfiguration >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QNetworkConfiguration",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "BearerType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Purpose",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QNetworkConfiguration_Type_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_Type_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Type",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkConfiguration_Type_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkConfiguration_Type_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_Type_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QNetworkConfiguration::StateFlags >::checkType(self) && Shiboken::Converter<QNetworkConfiguration::StateFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        Shiboken::Converter<QNetworkConfiguration::StateFlags>::toCpp(self)
        & Shiboken::Converter< QNetworkConfiguration::StateFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QNetworkConfiguration::StateFlags >::checkType(self) && Shiboken::Converter<QNetworkConfiguration::StateFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        Shiboken::Converter<QNetworkConfiguration::StateFlags>::toCpp(self)
        | Shiboken::Converter< QNetworkConfiguration::StateFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QNetworkConfiguration::StateFlags >::checkType(self) && Shiboken::Converter<QNetworkConfiguration::StateFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        Shiboken::Converter<QNetworkConfiguration::StateFlags>::toCpp(self)
        ^ Shiboken::Converter< QNetworkConfiguration::StateFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkConfiguration::StateFlags >::toPython(
        ~Shiboken::Converter<QNetworkConfiguration::StateFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StateFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StateFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QNetworkConfiguration(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQNetworkConfiguration_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQNetworkConfiguration_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQNetworkConfiguration_Type));
    PyModule_AddObject(module, "QNetworkConfiguration",
        ((PyObject*)&SbkQNetworkConfiguration_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: BearerType
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_BEARERTYPE_IDX] = &SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type);
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
            "BearerType",((PyObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerUnknown, "BearerUnknown");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerUnknown", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerUnknown", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerEthernet, "BearerEthernet");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerEthernet", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerEthernet", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerWLAN, "BearerWLAN");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerWLAN", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerWLAN", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::Bearer2G, "Bearer2G");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "Bearer2G", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "Bearer2G", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerCDMA2000, "BearerCDMA2000");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerCDMA2000", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerCDMA2000", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerWCDMA, "BearerWCDMA");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerWCDMA", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerWCDMA", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerHSPA, "BearerHSPA");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerHSPA", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerHSPA", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerBluetooth, "BearerBluetooth");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerBluetooth", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerBluetooth", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type,
        (long) QNetworkConfiguration::BearerWiMAX, "BearerWiMAX");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "BearerWiMAX", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_BearerType_Type.tp_dict,
        "BearerWiMAX", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::BearerType");

    // init enum class: Purpose
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_PURPOSE_IDX] = &SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type);
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
            "Purpose",((PyObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type,
        (long) QNetworkConfiguration::UnknownPurpose, "UnknownPurpose");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "UnknownPurpose", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type.tp_dict,
        "UnknownPurpose", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type,
        (long) QNetworkConfiguration::PublicPurpose, "PublicPurpose");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "PublicPurpose", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type.tp_dict,
        "PublicPurpose", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type,
        (long) QNetworkConfiguration::PrivatePurpose, "PrivatePurpose");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "PrivatePurpose", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type.tp_dict,
        "PrivatePurpose", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type,
        (long) QNetworkConfiguration::ServiceSpecificPurpose, "ServiceSpecificPurpose");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "ServiceSpecificPurpose", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Purpose_Type.tp_dict,
        "ServiceSpecificPurpose", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::Purpose");

    // init enum class: Type
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_TYPE_IDX] = &SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type);
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type,
        (long) QNetworkConfiguration::InternetAccessPoint, "InternetAccessPoint");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "InternetAccessPoint", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type.tp_dict,
        "InternetAccessPoint", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type,
        (long) QNetworkConfiguration::ServiceNetwork, "ServiceNetwork");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "ServiceNetwork", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type.tp_dict,
        "ServiceNetwork", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type,
        (long) QNetworkConfiguration::UserChoice, "UserChoice");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "UserChoice", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type.tp_dict,
        "UserChoice", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type,
        (long) QNetworkConfiguration::Invalid, "Invalid");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "Invalid", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_Type_Type.tp_dict,
        "Invalid", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::Type");

    // init enum class: StateFlag
    SbkPySide_QtNetworkTypes[SBK_QNETWORKCONFIGURATION_STATEFLAG_IDX] = &SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type);
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
            "StateFlag",((PyObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type));

    // init flags class: QFlags<QNetworkConfiguration::StateFlag>
    SbkPySide_QtNetworkTypes[SBK_QFLAGS_QNETWORKCONFIGURATION_STATEFLAG__IDX] = &SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type);
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
            "StateFlags",((PyObject*)&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type,
        (long) QNetworkConfiguration::Undefined, "Undefined");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "Undefined", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type.tp_dict,
        "Undefined", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type,
        (long) QNetworkConfiguration::Defined, "Defined");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "Defined", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type.tp_dict,
        "Defined", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type,
        (long) QNetworkConfiguration::Discovered, "Discovered");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "Discovered", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type.tp_dict,
        "Discovered", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type,
        (long) QNetworkConfiguration::Active, "Active");
    PyDict_SetItemString(SbkQNetworkConfiguration_Type.super.ht_type.tp_dict,
        "Active", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkConfiguration_StateFlag_Type.tp_dict,
        "Active", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkConfiguration::StateFlag");


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkConfiguration >("QNetworkConfiguration");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkConfiguration >("QNetworkConfiguration*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkConfiguration >(typeid(QNetworkConfiguration).name());
    PySide::initQtMetaType<QNetworkConfiguration >();
}

