/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qsslcipher_wrapper.h"

// Extra includes
#include <qsslcipher.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSslCipher_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSslCipher >()))
        return -1;

    QSslCipher* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSslCipher", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QSslCipher()
    // 1: QSslCipher(QSslCipher)
    // 2: QSslCipher(QString,QSsl::SslProtocol)
    if (numArgs == 0) {
        overloadId = 0; // QSslCipher()
    } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QSsl::SslProtocol >::isConvertible(pyargs[1])) {
        overloadId = 2; // QSslCipher(QString,QSsl::SslProtocol)
    } else if (numArgs == 1 && Shiboken::Converter<const QSslCipher & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QSslCipher(QSslCipher)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslCipher_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSslCipher()
            {

                if(!PyErr_Occurred()) {
                // QSslCipher()
                cptr = new QSslCipher();
                }
                break;
            }
            case 1: // QSslCipher(QSslCipher)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSslCipher* cpp_arg0 = Shiboken::Converter<QSslCipher* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QSslCipher(QSslCipher)
                cptr = new QSslCipher(*cpp_arg0);
                }
                break;
            }
            case 2: // QSslCipher(QString,QSsl::SslProtocol)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QSsl::SslProtocol cpp_arg1 = Shiboken::Converter<QSsl::SslProtocol >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QSslCipher(QString,QSsl::SslProtocol)
                cptr = new QSslCipher(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSslCipher >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSslCipher_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQSslCipher_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QSslCipher", "QString, PySide.QtNetwork.QSsl.SslProtocol", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslCipher", overloads);
        return -1;
}

static PyObject* SbkQSslCipherFunc_authenticationMethod(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // authenticationMethod()const
            QString cppResult = cppSelf->QSslCipher::authenticationMethod();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_encryptionMethod(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encryptionMethod()const
            QString cppResult = cppSelf->QSslCipher::encryptionMethod();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_isNull(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QSslCipher::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_keyExchangeMethod(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keyExchangeMethod()const
            QString cppResult = cppSelf->QSslCipher::keyExchangeMethod();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_name(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QSslCipher::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_protocol(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // protocol()const
            QSsl::SslProtocol cppResult = cppSelf->QSslCipher::protocol();
            pyResult = Shiboken::Converter<QSsl::SslProtocol >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_protocolString(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // protocolString()const
            QString cppResult = cppSelf->QSslCipher::protocolString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_supportedBits(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedBits()const
            int cppResult = cppSelf->QSslCipher::supportedBits();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslCipherFunc_usedBits(PyObject* self)
{
    QSslCipher* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslCipher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // usedBits()const
            int cppResult = cppSelf->QSslCipher::usedBits();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQSslCipher_methods[] = {
    {"authenticationMethod", (PyCFunction)SbkQSslCipherFunc_authenticationMethod, METH_NOARGS},
    {"encryptionMethod", (PyCFunction)SbkQSslCipherFunc_encryptionMethod, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQSslCipherFunc_isNull, METH_NOARGS},
    {"keyExchangeMethod", (PyCFunction)SbkQSslCipherFunc_keyExchangeMethod, METH_NOARGS},
    {"name", (PyCFunction)SbkQSslCipherFunc_name, METH_NOARGS},
    {"protocol", (PyCFunction)SbkQSslCipherFunc_protocol, METH_NOARGS},
    {"protocolString", (PyCFunction)SbkQSslCipherFunc_protocolString, METH_NOARGS},
    {"supportedBits", (PyCFunction)SbkQSslCipherFunc_supportedBits, METH_NOARGS},
    {"usedBits", (PyCFunction)SbkQSslCipherFunc_usedBits, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQSslCipher_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QSslCipher& cpp_self = *Shiboken::Converter<QSslCipher* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QSslCipher & >::isConvertible(other)) {
                // operator!=(const QSslCipher & other) const
                QSslCipher* cpp_other = Shiboken::Converter<QSslCipher* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QSslCipher  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQSslCipher_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QSslCipher & >::isConvertible(other)) {
                // operator==(const QSslCipher & other) const
                QSslCipher* cpp_other = Shiboken::Converter<QSslCipher* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QSslCipher  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQSslCipher_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQSslCipher_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSslCipher_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSslCipher",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQSslCipher_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSslCipher_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSslCipher_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSslCipher >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSslCipher",
    /*user_data*/           0
};
} //extern


void init_QSslCipher(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSLCIPHER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSslCipher_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSslCipher_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSslCipher_Type));
    PyModule_AddObject(module, "QSslCipher",
        ((PyObject*)&SbkQSslCipher_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSslCipher >("QSslCipher");
    Shiboken::TypeResolver::createObjectTypeResolver<QSslCipher >("QSslCipher*");
    Shiboken::TypeResolver::createValueTypeResolver<QSslCipher >(typeid(QSslCipher).name());
    PySide::initQtMetaType<QSslCipher >();
}

