/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qsslconfiguration_wrapper.h"

// Extra includes
#include <QList>
#include <qsslcipher.h>
#include <qsslconfiguration.h>
#include <qsslkey.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSslConfiguration_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSslConfiguration >()))
        return -1;

    QSslConfiguration* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSslConfiguration", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QSslConfiguration()
    // 1: QSslConfiguration(QSslConfiguration)
    if (numArgs == 0) {
        overloadId = 0; // QSslConfiguration()
    } else if (numArgs == 1 && Shiboken::Converter<const QSslConfiguration & >::isConvertible(arg)) {
        overloadId = 1; // QSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslConfiguration_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSslConfiguration()
            {

                if(!PyErr_Occurred()) {
                // QSslConfiguration()
                cptr = new QSslConfiguration();
                }
                break;
            }
            case 1: // QSslConfiguration(QSslConfiguration)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QSslConfiguration* cpp_arg0 = Shiboken::Converter<QSslConfiguration* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QSslConfiguration(QSslConfiguration)
                cptr = new QSslConfiguration(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSslConfiguration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSslConfiguration_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQSslConfiguration_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QSslConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslConfiguration", overloads);
        return -1;
}

static PyObject* SbkQSslConfigurationFunc_ciphers(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ciphers()const
            QList<QSslCipher > cppResult = cppSelf->QSslConfiguration::ciphers();
            pyResult = Shiboken::Converter<QList<QSslCipher > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_defaultConfiguration(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultConfiguration()
            QSslConfiguration cppResult = QSslConfiguration::defaultConfiguration();
            pyResult = Shiboken::Converter<QSslConfiguration >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_isNull(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QSslConfiguration::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_peerVerifyDepth(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // peerVerifyDepth()const
            int cppResult = cppSelf->QSslConfiguration::peerVerifyDepth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_peerVerifyMode(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // peerVerifyMode()const
            QSslSocket::PeerVerifyMode cppResult = cppSelf->QSslConfiguration::peerVerifyMode();
            pyResult = Shiboken::Converter<QSslSocket::PeerVerifyMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_privateKey(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // privateKey()const
            QSslKey cppResult = cppSelf->QSslConfiguration::privateKey();
            pyResult = Shiboken::Converter<QSslKey >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_protocol(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // protocol()const
            QSsl::SslProtocol cppResult = cppSelf->QSslConfiguration::protocol();
            pyResult = Shiboken::Converter<QSsl::SslProtocol >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_sessionCipher(PyObject* self)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sessionCipher()const
            QSslCipher cppResult = cppSelf->QSslConfiguration::sessionCipher();
            pyResult = Shiboken::Converter<QSslCipher >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslConfigurationFunc_setCiphers(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCiphers(QList<QSslCipher>)
    if (Shiboken::Converter< QList<QSslCipher >  >::isConvertible(arg)) {
        overloadId = 0; // setCiphers(QList<QSslCipher>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslConfigurationFunc_setCiphers_TypeError;

    // Call function/method
    {
        {
            QList<QSslCipher > cpp_arg0 = Shiboken::Converter<QList<QSslCipher > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCiphers(QList<QSslCipher>)
            cppSelf->QSslConfiguration::setCiphers(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslConfigurationFunc_setCiphers_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setCiphers", overloads);
        return 0;
}

static PyObject* SbkQSslConfigurationFunc_setDefaultConfiguration(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultConfiguration(QSslConfiguration)
    if (Shiboken::Converter<const QSslConfiguration & >::isConvertible(arg)) {
        overloadId = 0; // setDefaultConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslConfigurationFunc_setDefaultConfiguration_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSslConfiguration* cpp_arg0 = Shiboken::Converter<QSslConfiguration* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultConfiguration(QSslConfiguration)
            QSslConfiguration::setDefaultConfiguration(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslConfigurationFunc_setDefaultConfiguration_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setDefaultConfiguration", overloads);
        return 0;
}

static PyObject* SbkQSslConfigurationFunc_setPeerVerifyDepth(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerVerifyDepth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPeerVerifyDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslConfigurationFunc_setPeerVerifyDepth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPeerVerifyDepth(int)
            cppSelf->QSslConfiguration::setPeerVerifyDepth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslConfigurationFunc_setPeerVerifyDepth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setPeerVerifyDepth", overloads);
        return 0;
}

static PyObject* SbkQSslConfigurationFunc_setPeerVerifyMode(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerVerifyMode(QSslSocket::PeerVerifyMode)
    if (Shiboken::Converter<QSslSocket::PeerVerifyMode >::isConvertible(arg)) {
        overloadId = 0; // setPeerVerifyMode(QSslSocket::PeerVerifyMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslConfigurationFunc_setPeerVerifyMode_TypeError;

    // Call function/method
    {
        {
            QSslSocket::PeerVerifyMode cpp_arg0 = Shiboken::Converter<QSslSocket::PeerVerifyMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPeerVerifyMode(QSslSocket::PeerVerifyMode)
            cppSelf->QSslConfiguration::setPeerVerifyMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslConfigurationFunc_setPeerVerifyMode_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslSocket.PeerVerifyMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setPeerVerifyMode", overloads);
        return 0;
}

static PyObject* SbkQSslConfigurationFunc_setPrivateKey(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrivateKey(QSslKey)
    if (Shiboken::Converter<const QSslKey & >::isConvertible(arg)) {
        overloadId = 0; // setPrivateKey(QSslKey)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslConfigurationFunc_setPrivateKey_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSslKey* cpp_arg0 = Shiboken::Converter<QSslKey* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPrivateKey(QSslKey)
            cppSelf->QSslConfiguration::setPrivateKey(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslConfigurationFunc_setPrivateKey_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslKey", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setPrivateKey", overloads);
        return 0;
}

static PyObject* SbkQSslConfigurationFunc_setProtocol(PyObject* self, PyObject* arg)
{
    QSslConfiguration* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProtocol(QSsl::SslProtocol)
    if (Shiboken::Converter<QSsl::SslProtocol >::isConvertible(arg)) {
        overloadId = 0; // setProtocol(QSsl::SslProtocol)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslConfigurationFunc_setProtocol_TypeError;

    // Call function/method
    {
        {
            QSsl::SslProtocol cpp_arg0 = Shiboken::Converter<QSsl::SslProtocol >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setProtocol(QSsl::SslProtocol)
            cppSelf->QSslConfiguration::setProtocol(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslConfigurationFunc_setProtocol_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSsl.SslProtocol", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslConfiguration.setProtocol", overloads);
        return 0;
}

static PyMethodDef SbkQSslConfiguration_methods[] = {
    {"ciphers", (PyCFunction)SbkQSslConfigurationFunc_ciphers, METH_NOARGS},
    {"defaultConfiguration", (PyCFunction)SbkQSslConfigurationFunc_defaultConfiguration, METH_NOARGS|METH_STATIC},
    {"isNull", (PyCFunction)SbkQSslConfigurationFunc_isNull, METH_NOARGS},
    {"peerVerifyDepth", (PyCFunction)SbkQSslConfigurationFunc_peerVerifyDepth, METH_NOARGS},
    {"peerVerifyMode", (PyCFunction)SbkQSslConfigurationFunc_peerVerifyMode, METH_NOARGS},
    {"privateKey", (PyCFunction)SbkQSslConfigurationFunc_privateKey, METH_NOARGS},
    {"protocol", (PyCFunction)SbkQSslConfigurationFunc_protocol, METH_NOARGS},
    {"sessionCipher", (PyCFunction)SbkQSslConfigurationFunc_sessionCipher, METH_NOARGS},
    {"setCiphers", (PyCFunction)SbkQSslConfigurationFunc_setCiphers, METH_O},
    {"setDefaultConfiguration", (PyCFunction)SbkQSslConfigurationFunc_setDefaultConfiguration, METH_O|METH_STATIC},
    {"setPeerVerifyDepth", (PyCFunction)SbkQSslConfigurationFunc_setPeerVerifyDepth, METH_O},
    {"setPeerVerifyMode", (PyCFunction)SbkQSslConfigurationFunc_setPeerVerifyMode, METH_O},
    {"setPrivateKey", (PyCFunction)SbkQSslConfigurationFunc_setPrivateKey, METH_O},
    {"setProtocol", (PyCFunction)SbkQSslConfigurationFunc_setProtocol, METH_O},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQSslConfiguration_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QSslConfiguration& cpp_self = *Shiboken::Converter<QSslConfiguration* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QSslConfiguration & >::isConvertible(other)) {
                // operator!=(const QSslConfiguration & other) const
                QSslConfiguration* cpp_other = Shiboken::Converter<QSslConfiguration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QSslConfiguration  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQSslConfiguration_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QSslConfiguration & >::isConvertible(other)) {
                // operator==(const QSslConfiguration & other) const
                QSslConfiguration* cpp_other = Shiboken::Converter<QSslConfiguration* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QSslConfiguration  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQSslConfiguration_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQSslConfiguration_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSslConfiguration_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSslConfiguration",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQSslConfiguration_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSslConfiguration_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSslConfiguration_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSslConfiguration >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSslConfiguration",
    /*user_data*/           0
};
} //extern


void init_QSslConfiguration(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSLCONFIGURATION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSslConfiguration_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSslConfiguration_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSslConfiguration_Type));
    PyModule_AddObject(module, "QSslConfiguration",
        ((PyObject*)&SbkQSslConfiguration_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSslConfiguration >("QSslConfiguration");
    Shiboken::TypeResolver::createObjectTypeResolver<QSslConfiguration >("QSslConfiguration*");
    Shiboken::TypeResolver::createValueTypeResolver<QSslConfiguration >(typeid(QSslConfiguration).name());
    PySide::initQtMetaType<QSslConfiguration >();
}

