/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtnetwork_python.h"

#include "qsslsocket_wrapper.h"

// Extra includes
#include <QList>
#include <qauthenticator.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qhostaddress.h>
#include <qnetworkproxy.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsslcipher.h>
#include <qsslconfiguration.h>
#include <qsslerror.h>
#include <qsslkey.h>
#include <qsslsocket.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QSslSocketWrapper::QSslSocketWrapper(QObject * parent) : QSslSocket(parent), m_metaObject(0) {
    // ... middle
}

bool QSslSocketWrapper::atEnd() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "atEnd"));
    if (py_override.isNull()) {
        return this->QSslSocket::atEnd();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.atEnd", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QSslSocketWrapper::bytesAvailable() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesAvailable"));
    if (py_override.isNull()) {
        return this->QSslSocket::bytesAvailable();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.bytesAvailable", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QSslSocketWrapper::bytesToWrite() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "bytesToWrite"));
    if (py_override.isNull()) {
        return this->QSslSocket::bytesToWrite();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.bytesToWrite", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QSslSocketWrapper::canReadLine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "canReadLine"));
    if (py_override.isNull()) {
        return this->QSslSocket::canReadLine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.canReadLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QSslSocketWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSslSocketWrapper::close()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QSslSocket::close();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSslSocketWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSslSocketWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSslSocketWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QSslSocketWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QSslSocketWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QSslSocketWrapper::isSequential() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isSequential"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::isSequential();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.isSequential", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QSslSocketWrapper::open(QFlags<QIODevice::OpenModeFlag> mode)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::open(mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QSslSocketWrapper::pos() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pos"));
    if (py_override.isNull()) {
        return this->QIODevice::pos();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.pos", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QSslSocketWrapper::readData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readData"));
    if (py_override.isNull()) {
        return this->QSslSocket::readData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.readData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QSslSocketWrapper::readLineData(char * data, qint64 maxlen)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "readLineData"));
    if (py_override.isNull()) {
        return this->QAbstractSocket::readLineData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(maxlen)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.readLineData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

bool QSslSocketWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QIODevice::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.reset", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QSslSocketWrapper::seek(qint64 pos)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QIODevice::seek(pos);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(pos)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.seek", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QSslSocketWrapper::size() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "size"));
    if (py_override.isNull()) {
        return this->QIODevice::size();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.size", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

void QSslSocketWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QSslSocketWrapper::waitForBytesWritten(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForBytesWritten"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QSslSocket::waitForBytesWritten(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.waitForBytesWritten", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QSslSocketWrapper::waitForReadyRead(int msecs)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "waitForReadyRead"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QSslSocket::waitForReadyRead(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.waitForReadyRead", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QSslSocketWrapper::writeData(const char * data, qint64 len)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "writeData"));
    if (py_override.isNull()) {
        return this->QSslSocket::writeData(data, len);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter<const char * >::toPython(data),
        Shiboken::Converter<long long >::toPython(len)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSslSocket.writeData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QSslSocketWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QSslSocket::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QSslSocketWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QSslSocket::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QSslSocketWrapper::~QSslSocketWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSslSocket_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSslSocket >()))
        return -1;

    QSslSocketWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QSslSocket", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QSslSocket(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSslSocket(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QSslSocket(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocket_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QSslSocket(QObject*)
            cptr = new QSslSocketWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSslSocket >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSslSocket_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQSslSocket_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket", overloads);
        return -1;
}

static PyObject* SbkQSslSocketFunc_abort(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // abort()
            cppSelf->QSslSocket::abort();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSslSocketFunc_addCaCertificates(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format", "syntax" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addCaCertificates(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addCaCertificates(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addCaCertificates(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addCaCertificates", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
        } else if (Shiboken::Converter<QSsl::EncodingFormat >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
            } else if (Shiboken::Converter<QRegExp::PatternSyntax >::isConvertible(pyargs[2])) {
                overloadId = 0; // addCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_addCaCertificates_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "syntax");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "syntax";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addCaCertificates(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSsl::EncodingFormat cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[1]) : QSsl::Pem;
            QRegExp::PatternSyntax cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegExp::PatternSyntax >::toCpp(pyargs[2]) : QRegExp::FixedString;

            if(!PyErr_Occurred()) {
            // addCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
            bool cppResult = cppSelf->QSslSocket::addCaCertificates(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_addCaCertificates_TypeError:
        const char* overloads[] = {"QString, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtCore.QRegExp.PatternSyntax = QRegExp.FixedString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.addCaCertificates", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_addDefaultCaCertificates(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format", "syntax" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addDefaultCaCertificates(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addDefaultCaCertificates(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addDefaultCaCertificates(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addDefaultCaCertificates", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addDefaultCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addDefaultCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
        } else if (Shiboken::Converter<QSsl::EncodingFormat >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addDefaultCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
            } else if (Shiboken::Converter<QRegExp::PatternSyntax >::isConvertible(pyargs[2])) {
                overloadId = 0; // addDefaultCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_addDefaultCaCertificates_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "syntax");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "syntax";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.addDefaultCaCertificates(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSsl::EncodingFormat cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[1]) : QSsl::Pem;
            QRegExp::PatternSyntax cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegExp::PatternSyntax >::toCpp(pyargs[2]) : QRegExp::FixedString;

            if(!PyErr_Occurred()) {
            // addDefaultCaCertificates(QString,QSsl::EncodingFormat,QRegExp::PatternSyntax)
            bool cppResult = QSslSocket::addDefaultCaCertificates(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_addDefaultCaCertificates_TypeError:
        const char* overloads[] = {"QString, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtCore.QRegExp.PatternSyntax = QRegExp.FixedString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.addDefaultCaCertificates", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_atEnd(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // atEnd()const
            bool cppResult = cppSelf->QSslSocket::atEnd();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_bytesAvailable(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesAvailable()const
            qint64 cppResult = cppSelf->QSslSocket::bytesAvailable();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_bytesToWrite(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bytesToWrite()const
            qint64 cppResult = cppSelf->QSslSocket::bytesToWrite();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_canReadLine(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canReadLine()const
            bool cppResult = cppSelf->QSslSocket::canReadLine();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_ciphers(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ciphers()const
            QList<QSslCipher > cppResult = cppSelf->QSslSocket::ciphers();
            pyResult = Shiboken::Converter<QList<QSslCipher > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_close(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);


    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // close()
            threadStateSaver.save();
            cppSelf->QSslSocket::close();
            threadStateSaver.restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSslSocketFunc_connectToHostEncrypted(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.connectToHostEncrypted(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.connectToHostEncrypted(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.connectToHostEncrypted(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:connectToHostEncrypted", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: connectToHostEncrypted(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
    // 1: connectToHostEncrypted(QString,quint16,QString,QFlags<QIODevice::OpenModeFlag>)
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // connectToHostEncrypted(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // connectToHostEncrypted(QString,quint16,QString,QFlags<QIODevice::OpenModeFlag>)
            } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[3])) {
                overloadId = 1; // connectToHostEncrypted(QString,quint16,QString,QFlags<QIODevice::OpenModeFlag>)
            }
        } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
            overloadId = 0; // connectToHostEncrypted(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_connectToHostEncrypted_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // connectToHostEncrypted(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.connectToHostEncrypted(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                quint16 cpp_arg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);
                QFlags<QIODevice::OpenModeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // connectToHostEncrypted(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
                threadStateSaver.save();
                cppSelf->QSslSocket::connectToHostEncrypted(cpp_arg0, cpp_arg1, cpp_arg2);
                threadStateSaver.restore();
                }
                break;
            }
            case 1: // connectToHostEncrypted(QString,quint16,QString,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.connectToHostEncrypted(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                quint16 cpp_arg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
                QFlags<QIODevice::OpenModeFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[3]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                // connectToHostEncrypted(QString,quint16,QString,QFlags<QIODevice::OpenModeFlag>)
                cppSelf->QSslSocket::connectToHostEncrypted(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_connectToHostEncrypted_TypeError:
        const char* overloads[] = {"QString, unsigned short, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", "QString, unsigned short, QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.connectToHostEncrypted", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_connectToHostImplementation(PyObject* self, PyObject* args)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "connectToHostImplementation", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: connectToHostImplementation(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
    if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
        overloadId = 0; // connectToHostImplementation(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_connectToHostImplementation_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            quint16 cpp_arg1 = Shiboken::Converter<quint16 >::toCpp(pyargs[1]);
            QFlags<QIODevice::OpenModeFlag> cpp_arg2 = Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // connectToHostImplementation(QString,quint16,QFlags<QIODevice::OpenModeFlag>)
            cppSelf->QSslSocket::connectToHostImplementation(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_connectToHostImplementation_TypeError:
        const char* overloads[] = {"QString, unsigned short, PySide.QtCore.QIODevice.OpenMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.connectToHostImplementation", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_defaultCiphers(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultCiphers()
            QList<QSslCipher > cppResult = QSslSocket::defaultCiphers();
            pyResult = Shiboken::Converter<QList<QSslCipher > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_disconnectFromHostImplementation(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // disconnectFromHostImplementation()
            cppSelf->QSslSocket::disconnectFromHostImplementation();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSslSocketFunc_encryptedBytesAvailable(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encryptedBytesAvailable()const
            qint64 cppResult = cppSelf->QSslSocket::encryptedBytesAvailable();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_encryptedBytesToWrite(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // encryptedBytesToWrite()const
            qint64 cppResult = cppSelf->QSslSocket::encryptedBytesToWrite();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_flush(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flush()
            bool cppResult = cppSelf->QSslSocket::flush();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_ignoreSslErrors(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: ignoreSslErrors()
    // 1: ignoreSslErrors(QList<QSslError>)
    if (numArgs == 0) {
        overloadId = 0; // ignoreSslErrors()
    } else if (Shiboken::Converter< QList<QSslError >  >::isConvertible(arg)) {
        overloadId = 1; // ignoreSslErrors(QList<QSslError>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_ignoreSslErrors_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // ignoreSslErrors()
            {

                if(!PyErr_Occurred()) {
                // ignoreSslErrors()
                cppSelf->QSslSocket::ignoreSslErrors();
                }
                break;
            }
            case 1: // ignoreSslErrors(QList<QSslError>)
            {
                QList<QSslError > cpp_arg0 = Shiboken::Converter<QList<QSslError > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // ignoreSslErrors(QList<QSslError>)
                cppSelf->QSslSocket::ignoreSslErrors(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_ignoreSslErrors_TypeError:
        const char* overloads[] = {"", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.ignoreSslErrors", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_isEncrypted(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEncrypted()const
            bool cppResult = cppSelf->QSslSocket::isEncrypted();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_mode(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mode()const
            QSslSocket::SslMode cppResult = cppSelf->QSslSocket::mode();
            pyResult = Shiboken::Converter<QSslSocket::SslMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_peerVerifyDepth(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // peerVerifyDepth()const
            int cppResult = cppSelf->QSslSocket::peerVerifyDepth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_peerVerifyMode(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // peerVerifyMode()const
            QSslSocket::PeerVerifyMode cppResult = cppSelf->QSslSocket::peerVerifyMode();
            pyResult = Shiboken::Converter<QSslSocket::PeerVerifyMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_privateKey(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // privateKey()const
            QSslKey cppResult = cppSelf->QSslSocket::privateKey();
            pyResult = Shiboken::Converter<QSslKey >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_protocol(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // protocol()const
            QSsl::SslProtocol cppResult = cppSelf->QSslSocket::protocol();
            pyResult = Shiboken::Converter<QSsl::SslProtocol >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_readData(PyObject* self, PyObject* args)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: readData(char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_readData_TypeError;

    // Call function/method
    {
        {
            char * cpp_arg0 = Shiboken::Converter<char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // readData(char*,qint64)
            qint64 cppResult = cppSelf->QSslSocket::readData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_readData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.readData", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_sessionCipher(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sessionCipher()const
            QSslCipher cppResult = cppSelf->QSslSocket::sessionCipher();
            pyResult = Shiboken::Converter<QSslCipher >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_setCiphers(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCiphers(QList<QSslCipher>)
    // 1: setCiphers(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // setCiphers(QString)
    } else if (Shiboken::Converter< QList<QSslCipher >  >::isConvertible(arg)) {
        overloadId = 0; // setCiphers(QList<QSslCipher>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setCiphers_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setCiphers(QList<QSslCipher>)
            {
                QList<QSslCipher > cpp_arg0 = Shiboken::Converter<QList<QSslCipher > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setCiphers(QList<QSslCipher>)
                cppSelf->QSslSocket::setCiphers(cpp_arg0);
                }
                break;
            }
            case 1: // setCiphers(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setCiphers(QString)
                cppSelf->QSslSocket::setCiphers(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setCiphers_TypeError:
        const char* overloads[] = {"list", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.setCiphers", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setDefaultCiphers(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultCiphers(QList<QSslCipher>)
    if (Shiboken::Converter< QList<QSslCipher >  >::isConvertible(arg)) {
        overloadId = 0; // setDefaultCiphers(QList<QSslCipher>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setDefaultCiphers_TypeError;

    // Call function/method
    {
        {
            QList<QSslCipher > cpp_arg0 = Shiboken::Converter<QList<QSslCipher > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultCiphers(QList<QSslCipher>)
            QSslSocket::setDefaultCiphers(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setDefaultCiphers_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.setDefaultCiphers", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setLocalCertificate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "format" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setLocalCertificate(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setLocalCertificate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setLocalCertificate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setLocalCertificate", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setLocalCertificate(QString,QSsl::EncodingFormat)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setLocalCertificate(QString,QSsl::EncodingFormat)
        } else if (Shiboken::Converter<QSsl::EncodingFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // setLocalCertificate(QString,QSsl::EncodingFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setLocalCertificate_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setLocalCertificate(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSsl::EncodingFormat cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[1]) : QSsl::Pem;

            if(!PyErr_Occurred()) {
            // setLocalCertificate(QString,QSsl::EncodingFormat)
            cppSelf->QSslSocket::setLocalCertificate(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setLocalCertificate_TypeError:
        const char* overloads[] = {"QString, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.setLocalCertificate", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setPeerVerifyDepth(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerVerifyDepth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPeerVerifyDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setPeerVerifyDepth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPeerVerifyDepth(int)
            cppSelf->QSslSocket::setPeerVerifyDepth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setPeerVerifyDepth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.setPeerVerifyDepth", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setPeerVerifyMode(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeerVerifyMode(QSslSocket::PeerVerifyMode)
    if (Shiboken::Converter<QSslSocket::PeerVerifyMode >::isConvertible(arg)) {
        overloadId = 0; // setPeerVerifyMode(QSslSocket::PeerVerifyMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setPeerVerifyMode_TypeError;

    // Call function/method
    {
        {
            QSslSocket::PeerVerifyMode cpp_arg0 = Shiboken::Converter<QSslSocket::PeerVerifyMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPeerVerifyMode(QSslSocket::PeerVerifyMode)
            cppSelf->QSslSocket::setPeerVerifyMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setPeerVerifyMode_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslSocket.PeerVerifyMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.setPeerVerifyMode", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setPrivateKey(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "algorithm", "format", "passPhrase" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setPrivateKey(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setPrivateKey(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setPrivateKey(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setPrivateKey", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setPrivateKey(QSslKey)
    // 1: setPrivateKey(QString,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QByteArray)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setPrivateKey(QString,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QByteArray)
        } else if (Shiboken::Converter<QSsl::KeyAlgorithm >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // setPrivateKey(QString,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QByteArray)
            } else if (Shiboken::Converter<QSsl::EncodingFormat >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // setPrivateKey(QString,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QByteArray)
                } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[3])) {
                    overloadId = 1; // setPrivateKey(QString,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QByteArray)
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QSslKey & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setPrivateKey(QSslKey)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setPrivateKey_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPrivateKey(QSslKey)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSslKey* cpp_arg0 = Shiboken::Converter<QSslKey* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setPrivateKey(QSslKey)
                cppSelf->QSslSocket::setPrivateKey(*cpp_arg0);
                }
                break;
            }
            case 1: // setPrivateKey(QString,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "algorithm");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "algorithm";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "passPhrase");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "passPhrase";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setPrivateKey(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QSsl::KeyAlgorithm cpp_arg1 = pyargs[1] ? Shiboken::Converter<QSsl::KeyAlgorithm >::toCpp(pyargs[1]) : QSsl::Rsa;
                QSsl::EncodingFormat cpp_arg2 = pyargs[2] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[2]) : QSsl::Pem;
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg3_auto_ptr;
                QByteArray cpp_arg3_tmp = QByteArray();
                QByteArray* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;
                if (pyargs[3] && !Shiboken::Converter<QByteArray >::checkType(pyargs[3]))
                    cpp_arg3_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg3);

                if(!PyErr_Occurred()) {
                // setPrivateKey(QString,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QByteArray)
                cppSelf->QSslSocket::setPrivateKey(cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setPrivateKey_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslKey", "QString, PySide.QtNetwork.QSsl.KeyAlgorithm = QSsl.Rsa, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.setPrivateKey", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setProtocol(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProtocol(QSsl::SslProtocol)
    if (Shiboken::Converter<QSsl::SslProtocol >::isConvertible(arg)) {
        overloadId = 0; // setProtocol(QSsl::SslProtocol)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setProtocol_TypeError;

    // Call function/method
    {
        {
            QSsl::SslProtocol cpp_arg0 = Shiboken::Converter<QSsl::SslProtocol >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setProtocol(QSsl::SslProtocol)
            cppSelf->QSslSocket::setProtocol(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setProtocol_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSsl.SslProtocol", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.setProtocol", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setReadBufferSize(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadBufferSize(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setReadBufferSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setReadBufferSize_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setReadBufferSize(qint64)
            cppSelf->QSslSocket::setReadBufferSize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setReadBufferSize_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.setReadBufferSize", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setSocketDescriptor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "openMode", "state" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setSocketDescriptor(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setSocketDescriptor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setSocketDescriptor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setSocketDescriptor", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter<QAbstractSocket::SocketState >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
            } else if (Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
                overloadId = 0; // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setSocketDescriptor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "state";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "openMode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "openMode";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.setSocketDescriptor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            QAbstractSocket::SocketState cpp_arg1 = pyargs[1] ? Shiboken::Converter<QAbstractSocket::SocketState >::toCpp(pyargs[1]) : QAbstractSocket::ConnectedState;
            QFlags<QIODevice::OpenModeFlag> cpp_arg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

            if(!PyErr_Occurred()) {
            // setSocketDescriptor(int,QAbstractSocket::SocketState,QFlags<QIODevice::OpenModeFlag>)
            bool cppResult = cppSelf->QSslSocket::setSocketDescriptor(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_setSocketDescriptor_TypeError:
        const char* overloads[] = {"int, PySide.QtNetwork.QAbstractSocket.SocketState = ConnectedState, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.setSocketDescriptor", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setSocketOption(PyObject* self, PyObject* args)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSocketOption", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSocketOption(QAbstractSocket::SocketOption,QVariant)
    if (numArgs == 2 && Shiboken::Converter<QAbstractSocket::SocketOption >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSocketOption(QAbstractSocket::SocketOption,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setSocketOption_TypeError;

    // Call function/method
    {
        {
            QAbstractSocket::SocketOption cpp_arg0 = Shiboken::Converter<QAbstractSocket::SocketOption >::toCpp(pyargs[0]);
            QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setSocketOption(QAbstractSocket::SocketOption,QVariant)
            cppSelf->QSslSocket::setSocketOption(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setSocketOption_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractSocket.SocketOption, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.setSocketOption", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_setSslConfiguration(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSslConfiguration(QSslConfiguration)
    if (Shiboken::Converter<const QSslConfiguration & >::isConvertible(arg)) {
        overloadId = 0; // setSslConfiguration(QSslConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_setSslConfiguration_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSslConfiguration* cpp_arg0 = Shiboken::Converter<QSslConfiguration* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSslConfiguration(QSslConfiguration)
            cppSelf->QSslSocket::setSslConfiguration(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSslSocketFunc_setSslConfiguration_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QSslConfiguration", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.setSslConfiguration", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_socketOption(PyObject* self, PyObject* arg)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: socketOption(QAbstractSocket::SocketOption)
    if (Shiboken::Converter<QAbstractSocket::SocketOption >::isConvertible(arg)) {
        overloadId = 0; // socketOption(QAbstractSocket::SocketOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_socketOption_TypeError;

    // Call function/method
    {
        {
            QAbstractSocket::SocketOption cpp_arg0 = Shiboken::Converter<QAbstractSocket::SocketOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // socketOption(QAbstractSocket::SocketOption)
            QVariant cppResult = cppSelf->QSslSocket::socketOption(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_socketOption_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QAbstractSocket.SocketOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.socketOption", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_sslConfiguration(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sslConfiguration()const
            QSslConfiguration cppResult = cppSelf->QSslSocket::sslConfiguration();
            pyResult = Shiboken::Converter<QSslConfiguration >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_sslErrors(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sslErrors()const
            QList<QSslError > cppResult = cppSelf->QSslSocket::sslErrors();
            pyResult = Shiboken::Converter<QList<QSslError > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_startClientEncryption(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startClientEncryption()
            cppSelf->QSslSocket::startClientEncryption();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSslSocketFunc_startServerEncryption(PyObject* self)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startServerEncryption()
            cppSelf->QSslSocket::startServerEncryption();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSslSocketFunc_supportedCiphers(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportedCiphers()
            QList<QSslCipher > cppResult = QSslSocket::supportedCiphers();
            pyResult = Shiboken::Converter<QList<QSslCipher > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_supportsSsl(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // supportsSsl()
            bool cppResult = QSslSocket::supportsSsl();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSslSocketFunc_waitForBytesWritten(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForBytesWritten(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForBytesWritten(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForBytesWritten", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForBytesWritten(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForBytesWritten(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_waitForBytesWritten_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForBytesWritten(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForBytesWritten(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QSslSocket::waitForBytesWritten(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_waitForBytesWritten_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.waitForBytesWritten", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_waitForConnected(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForConnected(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForConnected(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForConnected", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForConnected(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForConnected(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForConnected(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_waitForConnected_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForConnected(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForConnected(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QSslSocket::waitForConnected(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_waitForConnected_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.waitForConnected", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_waitForDisconnected(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForDisconnected(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForDisconnected(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForDisconnected", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForDisconnected(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForDisconnected(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForDisconnected(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_waitForDisconnected_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForDisconnected(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForDisconnected(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QSslSocket::waitForDisconnected(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_waitForDisconnected_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.waitForDisconnected", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_waitForEncrypted(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForEncrypted(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForEncrypted(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForEncrypted", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForEncrypted(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForEncrypted(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForEncrypted(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_waitForEncrypted_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForEncrypted(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForEncrypted(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QSslSocket::waitForEncrypted(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_waitForEncrypted_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.waitForEncrypted", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_waitForReadyRead(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "msecs" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForReadyRead(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForReadyRead(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForReadyRead", &arg))
        return 0;


    // Overloaded function decisor
    // 0: waitForReadyRead(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForReadyRead(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_waitForReadyRead_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (arg)
                        errorArgName = "msecs";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslSocket.waitForReadyRead(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 30000;

            if(!PyErr_Occurred()) {
            // waitForReadyRead(int)
            threadStateSaver.save();
            bool cppResult = cppSelf->QSslSocket::waitForReadyRead(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_waitForReadyRead_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QSslSocket.waitForReadyRead", overloads);
        return 0;
}

static PyObject* SbkQSslSocketFunc_writeData(PyObject* self, PyObject* args)
{
    QSslSocket* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSslSocket* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeData(const char*,qint64)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSslSocketFunc_writeData_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            qint64 cpp_arg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // writeData(const char*,qint64)
            qint64 cppResult = cppSelf->QSslSocket::writeData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSslSocketFunc_writeData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslSocket.writeData", overloads);
        return 0;
}

static PyMethodDef SbkQSslSocket_methods[] = {
    {"abort", (PyCFunction)SbkQSslSocketFunc_abort, METH_NOARGS},
    {"addCaCertificates", (PyCFunction)SbkQSslSocketFunc_addCaCertificates, METH_VARARGS|METH_KEYWORDS},
    {"addDefaultCaCertificates", (PyCFunction)SbkQSslSocketFunc_addDefaultCaCertificates, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"atEnd", (PyCFunction)SbkQSslSocketFunc_atEnd, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)SbkQSslSocketFunc_bytesAvailable, METH_NOARGS},
    {"bytesToWrite", (PyCFunction)SbkQSslSocketFunc_bytesToWrite, METH_NOARGS},
    {"canReadLine", (PyCFunction)SbkQSslSocketFunc_canReadLine, METH_NOARGS},
    {"ciphers", (PyCFunction)SbkQSslSocketFunc_ciphers, METH_NOARGS},
    {"close", (PyCFunction)SbkQSslSocketFunc_close, METH_NOARGS},
    {"connectToHostEncrypted", (PyCFunction)SbkQSslSocketFunc_connectToHostEncrypted, METH_VARARGS|METH_KEYWORDS},
    {"connectToHostImplementation", (PyCFunction)SbkQSslSocketFunc_connectToHostImplementation, METH_VARARGS},
    {"defaultCiphers", (PyCFunction)SbkQSslSocketFunc_defaultCiphers, METH_NOARGS|METH_STATIC},
    {"disconnectFromHostImplementation", (PyCFunction)SbkQSslSocketFunc_disconnectFromHostImplementation, METH_NOARGS},
    {"encryptedBytesAvailable", (PyCFunction)SbkQSslSocketFunc_encryptedBytesAvailable, METH_NOARGS},
    {"encryptedBytesToWrite", (PyCFunction)SbkQSslSocketFunc_encryptedBytesToWrite, METH_NOARGS},
    {"flush", (PyCFunction)SbkQSslSocketFunc_flush, METH_NOARGS},
    {"ignoreSslErrors", (PyCFunction)SbkQSslSocketFunc_ignoreSslErrors, METH_NOARGS|METH_O},
    {"isEncrypted", (PyCFunction)SbkQSslSocketFunc_isEncrypted, METH_NOARGS},
    {"mode", (PyCFunction)SbkQSslSocketFunc_mode, METH_NOARGS},
    {"peerVerifyDepth", (PyCFunction)SbkQSslSocketFunc_peerVerifyDepth, METH_NOARGS},
    {"peerVerifyMode", (PyCFunction)SbkQSslSocketFunc_peerVerifyMode, METH_NOARGS},
    {"privateKey", (PyCFunction)SbkQSslSocketFunc_privateKey, METH_NOARGS},
    {"protocol", (PyCFunction)SbkQSslSocketFunc_protocol, METH_NOARGS},
    {"readData", (PyCFunction)SbkQSslSocketFunc_readData, METH_VARARGS},
    {"sessionCipher", (PyCFunction)SbkQSslSocketFunc_sessionCipher, METH_NOARGS},
    {"setCiphers", (PyCFunction)SbkQSslSocketFunc_setCiphers, METH_O},
    {"setDefaultCiphers", (PyCFunction)SbkQSslSocketFunc_setDefaultCiphers, METH_O|METH_STATIC},
    {"setLocalCertificate", (PyCFunction)SbkQSslSocketFunc_setLocalCertificate, METH_VARARGS|METH_KEYWORDS},
    {"setPeerVerifyDepth", (PyCFunction)SbkQSslSocketFunc_setPeerVerifyDepth, METH_O},
    {"setPeerVerifyMode", (PyCFunction)SbkQSslSocketFunc_setPeerVerifyMode, METH_O},
    {"setPrivateKey", (PyCFunction)SbkQSslSocketFunc_setPrivateKey, METH_VARARGS|METH_KEYWORDS},
    {"setProtocol", (PyCFunction)SbkQSslSocketFunc_setProtocol, METH_O},
    {"setReadBufferSize", (PyCFunction)SbkQSslSocketFunc_setReadBufferSize, METH_O},
    {"setSocketDescriptor", (PyCFunction)SbkQSslSocketFunc_setSocketDescriptor, METH_VARARGS|METH_KEYWORDS},
    {"setSocketOption", (PyCFunction)SbkQSslSocketFunc_setSocketOption, METH_VARARGS},
    {"setSslConfiguration", (PyCFunction)SbkQSslSocketFunc_setSslConfiguration, METH_O},
    {"socketOption", (PyCFunction)SbkQSslSocketFunc_socketOption, METH_O},
    {"sslConfiguration", (PyCFunction)SbkQSslSocketFunc_sslConfiguration, METH_NOARGS},
    {"sslErrors", (PyCFunction)SbkQSslSocketFunc_sslErrors, METH_NOARGS},
    {"startClientEncryption", (PyCFunction)SbkQSslSocketFunc_startClientEncryption, METH_NOARGS},
    {"startServerEncryption", (PyCFunction)SbkQSslSocketFunc_startServerEncryption, METH_NOARGS},
    {"supportedCiphers", (PyCFunction)SbkQSslSocketFunc_supportedCiphers, METH_NOARGS|METH_STATIC},
    {"supportsSsl", (PyCFunction)SbkQSslSocketFunc_supportsSsl, METH_NOARGS|METH_STATIC},
    {"waitForBytesWritten", (PyCFunction)SbkQSslSocketFunc_waitForBytesWritten, METH_VARARGS|METH_KEYWORDS},
    {"waitForConnected", (PyCFunction)SbkQSslSocketFunc_waitForConnected, METH_VARARGS|METH_KEYWORDS},
    {"waitForDisconnected", (PyCFunction)SbkQSslSocketFunc_waitForDisconnected, METH_VARARGS|METH_KEYWORDS},
    {"waitForEncrypted", (PyCFunction)SbkQSslSocketFunc_waitForEncrypted, METH_VARARGS|METH_KEYWORDS},
    {"waitForReadyRead", (PyCFunction)SbkQSslSocketFunc_waitForReadyRead, METH_VARARGS|METH_KEYWORDS},
    {"writeData", (PyCFunction)SbkQSslSocketFunc_writeData, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSslSocket_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSslSocket",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSslSocket_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSslSocket_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSslSocket >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSslSocket*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQSslSocket_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QSslSocket*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQSslSocket_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtNetwork_QSslSocket_SslMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QSslSocket_SslMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QSslSocket_SslMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SslMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QSslSocket_SslMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QSslSocket_SslMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QSslSocket_SslMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PeerVerifyMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QSslSocket(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSLSOCKET_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSslSocket_Type);

    SbkQSslSocket_Type.super.ht_type.tp_base = SbkPySide_QtNetworkTypes[SBK_QTCPSOCKET_IDX];
    // Fill type discovery information
    SbkQSslSocket_Type.type_discovery = &SbkQSslSocket_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtNetworkTypes[SBK_QTCPSOCKET_IDX]), &SbkQSslSocket_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSslSocket_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSslSocket_Type));
    PyModule_AddObject(module, "QSslSocket",
        ((PyObject*)&SbkQSslSocket_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: SslMode
    SbkPySide_QtNetworkTypes[SBK_QSSLSOCKET_SSLMODE_IDX] = &SbkPySide_QtNetwork_QSslSocket_SslMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QSslSocket_SslMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QSslSocket_SslMode_Type);
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
            "SslMode",((PyObject*)&SbkPySide_QtNetwork_QSslSocket_SslMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QSslSocket_SslMode_Type,
        (long) QSslSocket::UnencryptedMode, "UnencryptedMode");
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
        "UnencryptedMode", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslSocket_SslMode_Type.tp_dict,
        "UnencryptedMode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QSslSocket_SslMode_Type,
        (long) QSslSocket::SslClientMode, "SslClientMode");
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
        "SslClientMode", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslSocket_SslMode_Type.tp_dict,
        "SslClientMode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QSslSocket_SslMode_Type,
        (long) QSslSocket::SslServerMode, "SslServerMode");
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
        "SslServerMode", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslSocket_SslMode_Type.tp_dict,
        "SslServerMode", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSslSocket::SslMode");

    // init enum class: PeerVerifyMode
    SbkPySide_QtNetworkTypes[SBK_QSSLSOCKET_PEERVERIFYMODE_IDX] = &SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type);
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
            "PeerVerifyMode",((PyObject*)&SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type,
        (long) QSslSocket::VerifyNone, "VerifyNone");
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
        "VerifyNone", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type.tp_dict,
        "VerifyNone", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type,
        (long) QSslSocket::QueryPeer, "QueryPeer");
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
        "QueryPeer", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type.tp_dict,
        "QueryPeer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type,
        (long) QSslSocket::VerifyPeer, "VerifyPeer");
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
        "VerifyPeer", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type.tp_dict,
        "VerifyPeer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type,
        (long) QSslSocket::AutoVerifyPeer, "AutoVerifyPeer");
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict,
        "AutoVerifyPeer", enum_item);
    PyDict_SetItemString(SbkPySide_QtNetwork_QSslSocket_PeerVerifyMode_Type.tp_dict,
        "AutoVerifyPeer", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSslSocket::PeerVerifyMode");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("sslErrors", "const QList<QSslError>&", NULL);
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict, "sslErrors", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("encryptedBytesWritten", "qint64", NULL);
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict, "encryptedBytesWritten", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("peerVerifyError", "const QSslError&", NULL);
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict, "peerVerifyError", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("encrypted", "void", NULL);
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict, "encrypted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("modeChanged", "QSslSocket::SslMode", NULL);
    PyDict_SetItemString(SbkQSslSocket_Type.super.ht_type.tp_dict, "modeChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QSslSocket >("QSslSocket*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSslSocket >(typeid(QSslSocket).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSslSocket >(typeid(QSslSocketWrapper).name());
    PySide::initQtMetaType<QSslSocket* >();
}

