/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtnetwork_python.h"

#include "qtcpserver_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qhostaddress.h>
#include <qnetworkproxy.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtcpserver.h>
#include <qtcpsocket.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QTcpServerWrapper::QTcpServerWrapper(QObject * parent) : QTcpServer(parent), m_metaObject(0) {
    // ... middle
}

void QTcpServerWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTcpServerWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTcpServerWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTcpServerWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QTcpServerWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTcpServer.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QTcpServerWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTcpServer.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QTcpServerWrapper::hasPendingConnections() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasPendingConnections"));
    if (py_override.isNull()) {
        return this->QTcpServer::hasPendingConnections();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTcpServer.hasPendingConnections", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QTcpServerWrapper::incomingConnection(int handle)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "incomingConnection"));
    if (py_override.isNull()) {
        return this->QTcpServer::incomingConnection(handle);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        handle
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QTcpSocket * QTcpServerWrapper::nextPendingConnection()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "nextPendingConnection"));
    if (py_override.isNull()) {
        return this->QTcpServer::nextPendingConnection();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QTcpSocket * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTcpServer.nextPendingConnection", SbkType<QTcpSocket * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QTcpSocket * cppResult(Shiboken::Converter<QTcpSocket * >::toCpp(pyResult));
    return cppResult;
}

void QTcpServerWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QTcpServerWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QTcpServer::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QTcpServerWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTcpServer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTcpServerWrapper::~QTcpServerWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTcpServer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTcpServer >()))
        return -1;

    QTcpServerWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QTcpServer", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QTcpServer(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QTcpServer(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QTcpServer(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServer_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QTcpServer(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QTcpServer(QObject*)
            cptr = new QTcpServerWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTcpServer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTcpServer_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQTcpServer_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QTcpServer", overloads);
        return -1;
}

static PyObject* SbkQTcpServerFunc_addPendingConnection(PyObject* self, PyObject* arg)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPendingConnection(QTcpSocket*)
    if (Shiboken::Converter<QTcpSocket * >::isConvertible(arg)) {
        overloadId = 0; // addPendingConnection(QTcpSocket*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServerFunc_addPendingConnection_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTcpSocket* cpp_arg0 = Shiboken::Converter<QTcpSocket* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addPendingConnection(QTcpSocket*)
            cppSelf->QTcpServer::addPendingConnection(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTcpServerFunc_addPendingConnection_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QTcpSocket", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QTcpServer.addPendingConnection", overloads);
        return 0;
}

static PyObject* SbkQTcpServerFunc_close(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // close()
            cppSelf->QTcpServer::close();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTcpServerFunc_errorString(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->QTcpServer::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_hasPendingConnections(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasPendingConnections()const
            bool cppResult = cppSelf->QTcpServer::hasPendingConnections();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_incomingConnection(PyObject* self, PyObject* arg)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: incomingConnection(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // incomingConnection(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServerFunc_incomingConnection_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // incomingConnection(int)
            cppSelf->QTcpServer::incomingConnection(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTcpServerFunc_incomingConnection_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QTcpServer.incomingConnection", overloads);
        return 0;
}

static PyObject* SbkQTcpServerFunc_isListening(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isListening()const
            bool cppResult = cppSelf->QTcpServer::isListening();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_listen(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "address", "port" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QTcpServer.listen(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QTcpServer.listen(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:listen", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: listen(QHostAddress,quint16)
    if (numArgs == 0) {
        overloadId = 0; // listen(QHostAddress,quint16)
    } else if (Shiboken::Converter<const QHostAddress & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // listen(QHostAddress,quint16)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // listen(QHostAddress,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServerFunc_listen_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "address");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "address";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "port");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "port";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QTcpServer.listen(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QHostAddress > cpp_arg0_auto_ptr;
            QHostAddress cpp_arg0_tmp = QHostAddress::Any;
            QHostAddress* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QHostAddress* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
            if (pyargs[0] && !Shiboken::Converter<QHostAddress >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QHostAddress >(cpp_arg0);
            quint16 cpp_arg1 = pyargs[1] ? Shiboken::Converter<quint16 >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // listen(QHostAddress,quint16)
            bool cppResult = cppSelf->QTcpServer::listen(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTcpServerFunc_listen_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostAddress = QHostAddress.Any, unsigned short = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QTcpServer.listen", overloads);
        return 0;
}

static PyObject* SbkQTcpServerFunc_maxPendingConnections(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maxPendingConnections()const
            int cppResult = cppSelf->QTcpServer::maxPendingConnections();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_nextPendingConnection(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextPendingConnection()
            QTcpSocket * cppResult = cppSelf->QTcpServer::nextPendingConnection();
            pyResult = Shiboken::Converter<QTcpSocket * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_proxy(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // proxy()const
            QNetworkProxy cppResult = cppSelf->QTcpServer::proxy();
            pyResult = Shiboken::Converter<QNetworkProxy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_serverAddress(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // serverAddress()const
            QHostAddress cppResult = cppSelf->QTcpServer::serverAddress();
            pyResult = Shiboken::Converter<QHostAddress >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_serverError(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // serverError()const
            QAbstractSocket::SocketError cppResult = cppSelf->QTcpServer::serverError();
            pyResult = Shiboken::Converter<QAbstractSocket::SocketError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_serverPort(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // serverPort()const
            quint16 cppResult = cppSelf->QTcpServer::serverPort();
            pyResult = Shiboken::Converter<unsigned short >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_setMaxPendingConnections(PyObject* self, PyObject* arg)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaxPendingConnections(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaxPendingConnections(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServerFunc_setMaxPendingConnections_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaxPendingConnections(int)
            cppSelf->QTcpServer::setMaxPendingConnections(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTcpServerFunc_setMaxPendingConnections_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QTcpServer.setMaxPendingConnections", overloads);
        return 0;
}

static PyObject* SbkQTcpServerFunc_setProxy(PyObject* self, PyObject* arg)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProxy(QNetworkProxy)
    if (Shiboken::Converter<const QNetworkProxy & >::isConvertible(arg)) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServerFunc_setProxy_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QNetworkProxy > cpp_arg0_auto_ptr;
            QNetworkProxy* cpp_arg0 = Shiboken::Converter<QNetworkProxy* >::toCpp(arg);
            if (!Shiboken::Converter<QNetworkProxy >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QNetworkProxy >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setProxy(QNetworkProxy)
            cppSelf->QTcpServer::setProxy(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTcpServerFunc_setProxy_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkProxy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QTcpServer.setProxy", overloads);
        return 0;
}

static PyObject* SbkQTcpServerFunc_setSocketDescriptor(PyObject* self, PyObject* arg)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSocketDescriptor(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSocketDescriptor(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServerFunc_setSocketDescriptor_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSocketDescriptor(int)
            bool cppResult = cppSelf->QTcpServer::setSocketDescriptor(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTcpServerFunc_setSocketDescriptor_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QTcpServer.setSocketDescriptor", overloads);
        return 0;
}

static PyObject* SbkQTcpServerFunc_socketDescriptor(PyObject* self)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // socketDescriptor()const
            int cppResult = cppSelf->QTcpServer::socketDescriptor();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTcpServerFunc_waitForNewConnection(PyObject* self, PyObject* arg)
{
    QTcpServer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTcpServer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: waitForNewConnection(int,bool*)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // waitForNewConnection(int,bool*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTcpServerFunc_waitForNewConnection_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // waitForNewConnection(int,bool*)
            threadStateSaver.save();
            // Begin code injection
            
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            bool retval_ = cppSelf->waitForNewConnection(cpp_arg0, &ok_);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_args,bool* - END
            
            // End of code injection

            threadStateSaver.restore();

            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTcpServerFunc_waitForNewConnection_TypeError:
        const char* overloads[] = {"int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QTcpServer.waitForNewConnection", overloads);
        return 0;
}

static PyMethodDef SbkQTcpServer_methods[] = {
    {"addPendingConnection", (PyCFunction)SbkQTcpServerFunc_addPendingConnection, METH_O},
    {"close", (PyCFunction)SbkQTcpServerFunc_close, METH_NOARGS},
    {"errorString", (PyCFunction)SbkQTcpServerFunc_errorString, METH_NOARGS},
    {"hasPendingConnections", (PyCFunction)SbkQTcpServerFunc_hasPendingConnections, METH_NOARGS},
    {"incomingConnection", (PyCFunction)SbkQTcpServerFunc_incomingConnection, METH_O},
    {"isListening", (PyCFunction)SbkQTcpServerFunc_isListening, METH_NOARGS},
    {"listen", (PyCFunction)SbkQTcpServerFunc_listen, METH_VARARGS|METH_KEYWORDS},
    {"maxPendingConnections", (PyCFunction)SbkQTcpServerFunc_maxPendingConnections, METH_NOARGS},
    {"nextPendingConnection", (PyCFunction)SbkQTcpServerFunc_nextPendingConnection, METH_NOARGS},
    {"proxy", (PyCFunction)SbkQTcpServerFunc_proxy, METH_NOARGS},
    {"serverAddress", (PyCFunction)SbkQTcpServerFunc_serverAddress, METH_NOARGS},
    {"serverError", (PyCFunction)SbkQTcpServerFunc_serverError, METH_NOARGS},
    {"serverPort", (PyCFunction)SbkQTcpServerFunc_serverPort, METH_NOARGS},
    {"setMaxPendingConnections", (PyCFunction)SbkQTcpServerFunc_setMaxPendingConnections, METH_O},
    {"setProxy", (PyCFunction)SbkQTcpServerFunc_setProxy, METH_O},
    {"setSocketDescriptor", (PyCFunction)SbkQTcpServerFunc_setSocketDescriptor, METH_O},
    {"socketDescriptor", (PyCFunction)SbkQTcpServerFunc_socketDescriptor, METH_NOARGS},
    {"waitForNewConnection", (PyCFunction)SbkQTcpServerFunc_waitForNewConnection, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTcpServer_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QTcpServer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTcpServer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTcpServer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTcpServer >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTcpServer*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQTcpServer_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTcpServer*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQTcpServer_Type;
    return 0;
}


void init_QTcpServer(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QTCPSERVER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTcpServer_Type);

    SbkQTcpServer_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQTcpServer_Type.type_discovery = &SbkQTcpServer_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQTcpServer_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTcpServer_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTcpServer_Type));
    PyModule_AddObject(module, "QTcpServer",
        ((PyObject*)&SbkQTcpServer_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("newConnection", "void", NULL);
    PyDict_SetItemString(SbkQTcpServer_Type.super.ht_type.tp_dict, "newConnection", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTcpServer >("QTcpServer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTcpServer >(typeid(QTcpServer).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTcpServer >(typeid(QTcpServerWrapper).name());
    PySide::initQtMetaType<QTcpServer* >();
}

