/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglbuffer_wrapper.h"

// Extra includes
#include <qglbuffer.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGLBuffer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLBuffer >()))
        return -1;

    QGLBuffer* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGLBuffer", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGLBuffer()
    // 1: QGLBuffer(QGLBuffer::Type)
    // 2: QGLBuffer(QGLBuffer)
    if (numArgs == 0) {
        overloadId = 0; // QGLBuffer()
    } else if (numArgs == 1 && Shiboken::Converter< QGLBuffer & >::isConvertible(arg)) {
        overloadId = 2; // QGLBuffer(QGLBuffer)
    } else if (numArgs == 1 && Shiboken::Converter<QGLBuffer::Type >::isConvertible(arg)) {
        overloadId = 1; // QGLBuffer(QGLBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLBuffer_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLBuffer()
            {

                if(!PyErr_Occurred()) {
                // QGLBuffer()
                cptr = new QGLBuffer();
                }
                break;
            }
            case 1: // QGLBuffer(QGLBuffer::Type)
            {
                QGLBuffer::Type cpp_arg0 = Shiboken::Converter<QGLBuffer::Type >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QGLBuffer(QGLBuffer::Type)
                cptr = new QGLBuffer(cpp_arg0);
                }
                break;
            }
            case 2: // QGLBuffer(QGLBuffer)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QGLBuffer* cpp_arg0 = Shiboken::Converter<QGLBuffer* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QGLBuffer(QGLBuffer)
                cptr = new QGLBuffer(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGLBuffer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGLBuffer_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGLBuffer_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtOpenGL.QGLBuffer.Type", "PySide.QtOpenGL.QGLBuffer", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer", overloads);
        return -1;
}

static PyObject* SbkQGLBufferFunc_allocate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "count" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.allocate(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.allocate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.allocate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:allocate", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: allocate(const void*,int)
    // 1: allocate(int)
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // allocate(int)
    } else if (Shiboken::Converter<const QByteArray & >::checkType(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // allocate(const void*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // allocate(const void*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLBufferFunc_allocate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // allocate(const void*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "count");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "count";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.allocate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

                if(!PyErr_Occurred()) {
                // allocate(const void*,int)
                // Begin code injection
                
                int size = cpp_arg1;
                if (size < 0)
                    size = cpp_arg0->size();
                cppSelf->allocate((const void*) cpp_arg0->data(), size);
                
                // End of code injection


                }
                break;
            }
            case 1: // allocate(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // allocate(int)
                cppSelf->QGLBuffer::allocate(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLBufferFunc_allocate_TypeError:
        const char* overloads[] = {"void, int = -1", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer.allocate", overloads);
        return 0;
}

static PyObject* SbkQGLBufferFunc_bind(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bind()
            bool cppResult = cppSelf->QGLBuffer::bind();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_bufferId(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bufferId()const
            unsigned int cppResult = cppSelf->QGLBuffer::bufferId();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_create(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // create()
            bool cppResult = cppSelf->QGLBuffer::create();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_destroy(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // destroy()
            cppSelf->QGLBuffer::destroy();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGLBufferFunc_isCreated(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCreated()const
            bool cppResult = cppSelf->QGLBuffer::isCreated();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_map(PyObject* self, PyObject* arg)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: map(QGLBuffer::Access)
    if (Shiboken::Converter<QGLBuffer::Access >::isConvertible(arg)) {
        overloadId = 0; // map(QGLBuffer::Access)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLBufferFunc_map_TypeError;

    // Call function/method
    {
        {
            QGLBuffer::Access cpp_arg0 = Shiboken::Converter<QGLBuffer::Access >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // map(QGLBuffer::Access)
            // Begin code injection
            
            void *data = cppSelf->map(cpp_arg0);
            QByteArray ret;
            if (data)
                ret.append((const char*)data, cppSelf->size());
            pyResult = Shiboken::Converter<QByteArray >::toPython(ret);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLBufferFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLBuffer.Access", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLBuffer.map", overloads);
        return 0;
}

static PyObject* SbkQGLBufferFunc_read(PyObject* self, PyObject* args)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "read", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: read(int,void*,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // read(int,void*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLBufferFunc_read_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // read(int,void*,int)
            // Begin code injection
            
            char *data = new char[cpp_arg1];
            bool result = cppSelf->read(cpp_arg0, data, cpp_arg1);
            QByteArray ret;
            if (result)
                ret.append((const char*)data, cpp_arg1);
            pyResult = Shiboken::makeTuple(result, ret);
            delete[] data;
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLBufferFunc_read_TypeError:
        const char* overloads[] = {"int, void, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer.read", overloads);
        return 0;
}

static PyObject* SbkQGLBufferFunc_release(PyObject* self, PyObject* arg)
{
    QGLBuffer* cppSelf = 0;
    if (self) {
        if (Shiboken::cppObjectIsInvalid(self))
            return 0;
        cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);
    }

    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: release()
    // 1: release(QGLBuffer::Type)
    if (numArgs == 0) {
        overloadId = 0; // release()
    } else if (Shiboken::Converter<QGLBuffer::Type >::isConvertible(arg)) {
        overloadId = 1; // release(QGLBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLBufferFunc_release_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // release()
            {

                if(!PyErr_Occurred()) {
                // release()
                cppSelf->QGLBuffer::release();
                }
                break;
            }
            case 1: // release(QGLBuffer::Type)
            {
                QGLBuffer::Type cpp_arg0 = Shiboken::Converter<QGLBuffer::Type >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // release(QGLBuffer::Type)
                QGLBuffer::release(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLBufferFunc_release_TypeError:
        const char* overloads[] = {"", "PySide.QtOpenGL.QGLBuffer.Type", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLBuffer.release", overloads);
        return 0;
}

static PyObject* SbkQGLBufferFunc_setUsagePattern(PyObject* self, PyObject* arg)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUsagePattern(QGLBuffer::UsagePattern)
    if (Shiboken::Converter<QGLBuffer::UsagePattern >::isConvertible(arg)) {
        overloadId = 0; // setUsagePattern(QGLBuffer::UsagePattern)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLBufferFunc_setUsagePattern_TypeError;

    // Call function/method
    {
        {
            QGLBuffer::UsagePattern cpp_arg0 = Shiboken::Converter<QGLBuffer::UsagePattern >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUsagePattern(QGLBuffer::UsagePattern)
            cppSelf->QGLBuffer::setUsagePattern(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLBufferFunc_setUsagePattern_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLBuffer.UsagePattern", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLBuffer.setUsagePattern", overloads);
        return 0;
}

static PyObject* SbkQGLBufferFunc_size(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            int cppResult = cppSelf->QGLBuffer::size();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_type(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            QGLBuffer::Type cppResult = cppSelf->QGLBuffer::type();
            pyResult = Shiboken::Converter<QGLBuffer::Type >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_unmap(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unmap()
            bool cppResult = cppSelf->QGLBuffer::unmap();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_usagePattern(PyObject* self)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // usagePattern()const
            QGLBuffer::UsagePattern cppResult = cppSelf->QGLBuffer::usagePattern();
            pyResult = Shiboken::Converter<QGLBuffer::UsagePattern >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLBufferFunc_write(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLBuffer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLBuffer* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "count" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.write(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.write(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.write(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:write", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: write(int,const void*,int)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QByteArray & >::checkType(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // write(int,const void*,int)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // write(int,const void*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLBufferFunc_write_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "count");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "count";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLBuffer.write(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
            QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

            if(!PyErr_Occurred()) {
            // write(int,const void*,int)
            // Begin code injection
            
            int size = cpp_arg2;
            if (size < 0)
                size = cpp_arg1->size();
            cppSelf->write(cpp_arg0, (const void*) cpp_arg1->data(), size);
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLBufferFunc_write_TypeError:
        const char* overloads[] = {"int, void, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLBuffer.write", overloads);
        return 0;
}

static PyMethodDef SbkQGLBufferMethod_release = {
    "release", (PyCFunction)SbkQGLBufferFunc_release, METH_NOARGS|METH_O|METH_STATIC
};

static PyMethodDef SbkQGLBuffer_methods[] = {
    {"allocate", (PyCFunction)SbkQGLBufferFunc_allocate, METH_VARARGS|METH_KEYWORDS},
    {"bind", (PyCFunction)SbkQGLBufferFunc_bind, METH_NOARGS},
    {"bufferId", (PyCFunction)SbkQGLBufferFunc_bufferId, METH_NOARGS},
    {"create", (PyCFunction)SbkQGLBufferFunc_create, METH_NOARGS},
    {"destroy", (PyCFunction)SbkQGLBufferFunc_destroy, METH_NOARGS},
    {"isCreated", (PyCFunction)SbkQGLBufferFunc_isCreated, METH_NOARGS},
    {"map", (PyCFunction)SbkQGLBufferFunc_map, METH_O},
    {"read", (PyCFunction)SbkQGLBufferFunc_read, METH_VARARGS},
    SbkQGLBufferMethod_release,
    {"setUsagePattern", (PyCFunction)SbkQGLBufferFunc_setUsagePattern, METH_O},
    {"size", (PyCFunction)SbkQGLBufferFunc_size, METH_NOARGS},
    {"type", (PyCFunction)SbkQGLBufferFunc_type, METH_NOARGS},
    {"unmap", (PyCFunction)SbkQGLBufferFunc_unmap, METH_NOARGS},
    {"usagePattern", (PyCFunction)SbkQGLBufferFunc_usagePattern, METH_NOARGS},
    {"write", (PyCFunction)SbkQGLBufferFunc_write, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

static PyObject* SbkQGLBuffer_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (SbkBaseWrapper_instanceDict(self)) {
            PyObject* meth = PyDict_GetItem(SbkBaseWrapper_instanceDict(self), name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "release") == 0)
            return PyCFunction_NewEx(&SbkQGLBufferMethod_release, self, 0);
    }
    PyObject* attr = PyObject_GenericGetAttr(self, name);
    if (attr && PySide::isQPropertyType(attr)) {
        PyObject *value = PySide::qproperty_get(attr, self);
        Py_DECREF(attr);
        Py_INCREF(value);
        attr = value;
    }
    return attr;
}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGLBuffer_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLBuffer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         SbkQGLBuffer_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGLBuffer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGLBuffer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGLBuffer >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGLBuffer*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtOpenGL_QGLBuffer_Access_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtOpenGL_QGLBuffer_Access_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtOpenGL_QGLBuffer_Access_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Access",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtOpenGL_QGLBuffer_Access_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtOpenGL_QGLBuffer_Access_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtOpenGL_QGLBuffer_Access_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "UsagePattern",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtOpenGL_QGLBuffer_Type_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtOpenGL_QGLBuffer_Type_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtOpenGL_QGLBuffer_Type_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Type",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtOpenGL_QGLBuffer_Type_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtOpenGL_QGLBuffer_Type_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtOpenGL_QGLBuffer_Type_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QGLBuffer(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGLBuffer_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGLBuffer_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGLBuffer_Type));
    PyModule_AddObject(module, "QGLBuffer",
        ((PyObject*)&SbkQGLBuffer_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Access
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_ACCESS_IDX] = &SbkPySide_QtOpenGL_QGLBuffer_Access_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLBuffer_Access_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLBuffer_Access_Type);
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
            "Access",((PyObject*)&SbkPySide_QtOpenGL_QGLBuffer_Access_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_Access_Type,
        (long) QGLBuffer::ReadOnly, "ReadOnly");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "ReadOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Access_Type.tp_dict,
        "ReadOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_Access_Type,
        (long) QGLBuffer::WriteOnly, "WriteOnly");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "WriteOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Access_Type.tp_dict,
        "WriteOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_Access_Type,
        (long) QGLBuffer::ReadWrite, "ReadWrite");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "ReadWrite", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Access_Type.tp_dict,
        "ReadWrite", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLBuffer::Access");

    // init enum class: UsagePattern
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_USAGEPATTERN_IDX] = &SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type);
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
            "UsagePattern",((PyObject*)&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::StreamDraw, "StreamDraw");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "StreamDraw", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "StreamDraw", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::StreamRead, "StreamRead");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "StreamRead", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "StreamRead", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::StreamCopy, "StreamCopy");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "StreamCopy", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "StreamCopy", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::StaticDraw, "StaticDraw");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "StaticDraw", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "StaticDraw", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::StaticRead, "StaticRead");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "StaticRead", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "StaticRead", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::StaticCopy, "StaticCopy");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "StaticCopy", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "StaticCopy", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::DynamicDraw, "DynamicDraw");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "DynamicDraw", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "DynamicDraw", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::DynamicRead, "DynamicRead");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "DynamicRead", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "DynamicRead", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type,
        (long) QGLBuffer::DynamicCopy, "DynamicCopy");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "DynamicCopy", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_UsagePattern_Type.tp_dict,
        "DynamicCopy", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLBuffer::UsagePattern");

    // init enum class: Type
    SbkPySide_QtOpenGLTypes[SBK_QGLBUFFER_TYPE_IDX] = &SbkPySide_QtOpenGL_QGLBuffer_Type_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLBuffer_Type_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLBuffer_Type_Type);
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)&SbkPySide_QtOpenGL_QGLBuffer_Type_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_Type_Type,
        (long) QGLBuffer::VertexBuffer, "VertexBuffer");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "VertexBuffer", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type_Type.tp_dict,
        "VertexBuffer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_Type_Type,
        (long) QGLBuffer::IndexBuffer, "IndexBuffer");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "IndexBuffer", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type_Type.tp_dict,
        "IndexBuffer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_Type_Type,
        (long) QGLBuffer::PixelPackBuffer, "PixelPackBuffer");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "PixelPackBuffer", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type_Type.tp_dict,
        "PixelPackBuffer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLBuffer_Type_Type,
        (long) QGLBuffer::PixelUnpackBuffer, "PixelUnpackBuffer");
    PyDict_SetItemString(SbkQGLBuffer_Type.super.ht_type.tp_dict,
        "PixelUnpackBuffer", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLBuffer_Type_Type.tp_dict,
        "PixelUnpackBuffer", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLBuffer::Type");


    Shiboken::TypeResolver::createObjectTypeResolver<QGLBuffer >("QGLBuffer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLBuffer >(typeid(QGLBuffer).name());
    PySide::initQtMetaType<QGLBuffer* >();
}

