/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglframebufferobject_wrapper.h"

// Extra includes
#include <qglframebufferobject.h>
#include <qimage.h>
#include <qpaintengine.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(const QSize & size, QGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internal_format) : QGLFramebufferObject(size, attachment, target, internal_format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(const QSize & size, const QGLFramebufferObjectFormat & format) : QGLFramebufferObject(size, format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(const QSize & size, unsigned int target) : QGLFramebufferObject(size, target) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(int width, int height, QGLFramebufferObject::Attachment attachment, unsigned int target, unsigned int internal_format) : QGLFramebufferObject(width, height, attachment, target, internal_format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(int width, int height, const QGLFramebufferObjectFormat & format) : QGLFramebufferObject(width, height, format) {
    // ... middle
}

QGLFramebufferObjectWrapper::QGLFramebufferObjectWrapper(int width, int height, unsigned int target) : QGLFramebufferObject(width, height, target) {
    // ... middle
}

int QGLFramebufferObjectWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QGLFramebufferObject::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLFramebufferObject.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QGLFramebufferObjectWrapper::metric(QPaintDevice::PaintDeviceMetric metric) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QGLFramebufferObject::metric(metric);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(metric)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLFramebufferObject.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QGLFramebufferObjectWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QGLFramebufferObject::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLFramebufferObject.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QGLFramebufferObject.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QGLFramebufferObjectWrapper::~QGLFramebufferObjectWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGLFramebufferObject_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLFramebufferObject >()))
        return -1;

    QGLFramebufferObjectWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "internal_format", "target" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): too many arguments");
        return -1;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QGLFramebufferObject", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
    // 1: QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
    // 2: QGLFramebufferObject(QSize,uint)
    // 3: QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
    // 4: QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
    // 5: QGLFramebufferObject(int,int,uint)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 5; // QGLFramebufferObject(int,int,uint)
        } else if (numArgs == 3 && Shiboken::Converter<const QGLFramebufferObjectFormat & >::isConvertible(pyargs[2])) {
            overloadId = 4; // QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
        } else if (Shiboken::Converter<QGLFramebufferObject::Attachment >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
            } else if (SbkNumber_Check(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 3; // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
                } else if (SbkNumber_Check(pyargs[4])) {
                    overloadId = 3; // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
                }
            }
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 5; // QGLFramebufferObject(int,int,uint)
        }
    } else if (Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QGLFramebufferObject(QSize,uint)
        } else if (numArgs == 2 && Shiboken::Converter<const QGLFramebufferObjectFormat & >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
        } else if (Shiboken::Converter<QGLFramebufferObject::Attachment >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
                } else if (SbkNumber_Check(pyargs[3])) {
                    overloadId = 0; // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
                }
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // QGLFramebufferObject(QSize,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObject_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "target";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "internal_format");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "internal_format";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
                QGLFramebufferObject::Attachment cpp_arg1 = Shiboken::Converter<QGLFramebufferObject::Attachment >::toCpp(pyargs[1]);
                unsigned int cpp_arg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;
                unsigned int cpp_arg3 = pyargs[3] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[3]) : 0x8058;

                if(!PyErr_Occurred()) {
                // QGLFramebufferObject(QSize,QGLFramebufferObject::Attachment,uint,uint)
                cptr = new QGLFramebufferObjectWrapper(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 1: // QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QGLFramebufferObjectFormat* cpp_arg1 = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QGLFramebufferObject(QSize,QGLFramebufferObjectFormat)
                cptr = new QGLFramebufferObjectWrapper(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // QGLFramebufferObject(QSize,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);
                unsigned int cpp_arg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                // QGLFramebufferObject(QSize,uint)
                cptr = new QGLFramebufferObjectWrapper(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "target";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "internal_format");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "internal_format";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QGLFramebufferObject::Attachment cpp_arg2 = Shiboken::Converter<QGLFramebufferObject::Attachment >::toCpp(pyargs[2]);
                unsigned int cpp_arg3 = pyargs[3] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[3]) : 0x0DE1;
                unsigned int cpp_arg4 = pyargs[4] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[4]) : 0x8058;

                if(!PyErr_Occurred()) {
                // QGLFramebufferObject(int,int,QGLFramebufferObject::Attachment,uint,uint)
                cptr = new QGLFramebufferObjectWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 4: // QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QGLFramebufferObjectFormat* cpp_arg2 = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // QGLFramebufferObject(int,int,QGLFramebufferObjectFormat)
                cptr = new QGLFramebufferObjectWrapper(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 5: // QGLFramebufferObject(int,int,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "target";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                unsigned int cpp_arg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                // QGLFramebufferObject(int,int,uint)
                cptr = new QGLFramebufferObjectWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGLFramebufferObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGLFramebufferObject_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGLFramebufferObject_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtOpenGL.QGLFramebufferObject.Attachment, unsigned int = 0x0DE1, unsigned int = 0x8058", "PySide.QtCore.QSize, PySide.QtOpenGL.QGLFramebufferObjectFormat", "PySide.QtCore.QSize, unsigned int = 0x0DE1", "int, int, PySide.QtOpenGL.QGLFramebufferObject.Attachment, unsigned int = 0x0DE1, unsigned int = 0x8058", "int, int, PySide.QtOpenGL.QGLFramebufferObjectFormat", "int, int, unsigned int = 0x0DE1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObject", overloads);
        return -1;
}

static PyObject* SbkQGLFramebufferObjectFunc_attachment(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // attachment()const
            QGLFramebufferObject::Attachment cppResult = cppSelf->QGLFramebufferObject::attachment();
            pyResult = Shiboken::Converter<QGLFramebufferObject::Attachment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_bind(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bind()
            bool cppResult = cppSelf->QGLFramebufferObject::bind();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_bindDefault(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bindDefault()
            bool cppResult = QGLFramebufferObject::bindDefault();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_blitFramebuffer(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "buffers", "filter" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:blitFramebuffer", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
    if (numArgs >= 4 && Shiboken::Converter<QGLFramebufferObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QRect & >::isConvertible(pyargs[1]) && Shiboken::Converter<QGLFramebufferObject * >::isConvertible(pyargs[2]) && Shiboken::Converter<const QRect & >::isConvertible(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 0; // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
            } else if (SbkNumber_Check(pyargs[5])) {
                overloadId = 0; // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFunc_blitFramebuffer_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "buffers");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "buffers";
                    else
                        pyargs[4] = value;
                }
                value = PyDict_GetItemString(kwds, "filter");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "filter";
                    else
                        pyargs[5] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGLFramebufferObject* cpp_arg0 = Shiboken::Converter<QGLFramebufferObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QRect* cpp_arg1 = Shiboken::Converter<QRect* >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QGLFramebufferObject* cpp_arg2 = Shiboken::Converter<QGLFramebufferObject* >::toCpp(pyargs[2]);
            if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                return 0;
            QRect* cpp_arg3 = Shiboken::Converter<QRect* >::toCpp(pyargs[3]);
            unsigned int cpp_arg4 = pyargs[4] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[4]) : 0x00004000;
            unsigned int cpp_arg5 = pyargs[5] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[5]) : 0x2600;

            if(!PyErr_Occurred()) {
            // blitFramebuffer(QGLFramebufferObject*,QRect,QGLFramebufferObject*,QRect,uint,uint)
            QGLFramebufferObject::blitFramebuffer(cpp_arg0, *cpp_arg1, cpp_arg2, *cpp_arg3, cpp_arg4, cpp_arg5);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLFramebufferObjectFunc_blitFramebuffer_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFramebufferObject, PySide.QtCore.QRect, PySide.QtOpenGL.QGLFramebufferObject, PySide.QtCore.QRect, unsigned int = 0x00004000, unsigned int = 0x2600", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObject.blitFramebuffer", overloads);
        return 0;
}

static PyObject* SbkQGLFramebufferObjectFunc_devType(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // devType()const
            int cppResult = cppSelf->QGLFramebufferObject::devType();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_drawTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "textureTarget" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:drawTexture", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawTexture(QPointF,uint,uint)
    // 1: drawTexture(QRectF,uint,uint)
    if (numArgs >= 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFunc_drawTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTexture(QPointF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cpp_arg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                // drawTexture(QPointF,uint,uint)
                cppSelf->QGLFramebufferObject::drawTexture(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // drawTexture(QRectF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cpp_arg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                // drawTexture(QRectF,uint,uint)
                cppSelf->QGLFramebufferObject::drawTexture(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLFramebufferObjectFunc_drawTexture_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, unsigned int, unsigned int = 0x0DE1", "PySide.QtCore.QRectF, unsigned int, unsigned int = 0x0DE1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObject.drawTexture", overloads);
        return 0;
}

static PyObject* SbkQGLFramebufferObjectFunc_format(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // format()const
            QGLFramebufferObjectFormat cppResult = cppSelf->QGLFramebufferObject::format();
            pyResult = Shiboken::Converter<QGLFramebufferObjectFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_handle(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // handle()const
            unsigned int cppResult = cppSelf->QGLFramebufferObject::handle();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_hasOpenGLFramebufferBlit(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasOpenGLFramebufferBlit()
            bool cppResult = QGLFramebufferObject::hasOpenGLFramebufferBlit();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_hasOpenGLFramebufferObjects(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasOpenGLFramebufferObjects()
            bool cppResult = QGLFramebufferObject::hasOpenGLFramebufferObjects();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_isBound(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isBound()const
            bool cppResult = cppSelf->QGLFramebufferObject::isBound();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_isValid(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QGLFramebufferObject::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_metric(PyObject* self, PyObject* arg)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cpp_arg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = cppSelf->QGLFramebufferObject::metric(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLFramebufferObjectFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObject.metric", overloads);
        return 0;
}

static PyObject* SbkQGLFramebufferObjectFunc_paintEngine(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // paintEngine()const
            QPaintEngine * cppResult = cppSelf->QGLFramebufferObject::paintEngine();
            pyResult = Shiboken::Converter<QPaintEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_release(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // release()
            bool cppResult = cppSelf->QGLFramebufferObject::release();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_size(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSize cppResult = cppSelf->QGLFramebufferObject::size();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_texture(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // texture()const
            unsigned int cppResult = cppSelf->QGLFramebufferObject::texture();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFunc_toImage(PyObject* self)
{
    QGLFramebufferObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toImage()const
            QImage cppResult = cppSelf->QGLFramebufferObject::toImage();
            pyResult = Shiboken::Converter<QImage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGLFramebufferObject_methods[] = {
    {"attachment", (PyCFunction)SbkQGLFramebufferObjectFunc_attachment, METH_NOARGS},
    {"bind", (PyCFunction)SbkQGLFramebufferObjectFunc_bind, METH_NOARGS},
    {"bindDefault", (PyCFunction)SbkQGLFramebufferObjectFunc_bindDefault, METH_NOARGS|METH_STATIC},
    {"blitFramebuffer", (PyCFunction)SbkQGLFramebufferObjectFunc_blitFramebuffer, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"devType", (PyCFunction)SbkQGLFramebufferObjectFunc_devType, METH_NOARGS},
    {"drawTexture", (PyCFunction)SbkQGLFramebufferObjectFunc_drawTexture, METH_VARARGS|METH_KEYWORDS},
    {"format", (PyCFunction)SbkQGLFramebufferObjectFunc_format, METH_NOARGS},
    {"handle", (PyCFunction)SbkQGLFramebufferObjectFunc_handle, METH_NOARGS},
    {"hasOpenGLFramebufferBlit", (PyCFunction)SbkQGLFramebufferObjectFunc_hasOpenGLFramebufferBlit, METH_NOARGS|METH_STATIC},
    {"hasOpenGLFramebufferObjects", (PyCFunction)SbkQGLFramebufferObjectFunc_hasOpenGLFramebufferObjects, METH_NOARGS|METH_STATIC},
    {"isBound", (PyCFunction)SbkQGLFramebufferObjectFunc_isBound, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQGLFramebufferObjectFunc_isValid, METH_NOARGS},
    {"metric", (PyCFunction)SbkQGLFramebufferObjectFunc_metric, METH_O},
    {"paintEngine", (PyCFunction)SbkQGLFramebufferObjectFunc_paintEngine, METH_NOARGS},
    {"release", (PyCFunction)SbkQGLFramebufferObjectFunc_release, METH_NOARGS},
    {"size", (PyCFunction)SbkQGLFramebufferObjectFunc_size, METH_NOARGS},
    {"texture", (PyCFunction)SbkQGLFramebufferObjectFunc_texture, METH_NOARGS},
    {"toImage", (PyCFunction)SbkQGLFramebufferObjectFunc_toImage, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGLFramebufferObject_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLFramebufferObject",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGLFramebufferObject_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGLFramebufferObject_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGLFramebufferObject >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGLFramebufferObject*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGLFramebufferObject_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QGLFramebufferObject*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQGLFramebufferObject_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Attachment",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QGLFramebufferObject(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGLFramebufferObject_Type);

    SbkQGLFramebufferObject_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    // Fill type discovery information
    SbkQGLFramebufferObject_Type.type_discovery = &SbkQGLFramebufferObject_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &SbkQGLFramebufferObject_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGLFramebufferObject_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGLFramebufferObject_Type));
    PyModule_AddObject(module, "QGLFramebufferObject",
        ((PyObject*)&SbkQGLFramebufferObject_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: Attachment
    SbkPySide_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECT_ATTACHMENT_IDX] = &SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type);
    PyDict_SetItemString(SbkQGLFramebufferObject_Type.super.ht_type.tp_dict,
            "Attachment",((PyObject*)&SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type,
        (long) QGLFramebufferObject::NoAttachment, "NoAttachment");
    PyDict_SetItemString(SbkQGLFramebufferObject_Type.super.ht_type.tp_dict,
        "NoAttachment", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type.tp_dict,
        "NoAttachment", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type,
        (long) QGLFramebufferObject::CombinedDepthStencil, "CombinedDepthStencil");
    PyDict_SetItemString(SbkQGLFramebufferObject_Type.super.ht_type.tp_dict,
        "CombinedDepthStencil", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type.tp_dict,
        "CombinedDepthStencil", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type,
        (long) QGLFramebufferObject::Depth, "Depth");
    PyDict_SetItemString(SbkQGLFramebufferObject_Type.super.ht_type.tp_dict,
        "Depth", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLFramebufferObject_Attachment_Type.tp_dict,
        "Depth", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLFramebufferObject::Attachment");


    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObject >("QGLFramebufferObject*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObject >(typeid(QGLFramebufferObject).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObject >(typeid(QGLFramebufferObjectWrapper).name());
    PySide::initQtMetaType<QGLFramebufferObject* >();
}

