/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglframebufferobjectformat_wrapper.h"

// Extra includes
#include <qglframebufferobject.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGLFramebufferObjectFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLFramebufferObjectFormat >()))
        return -1;

    QGLFramebufferObjectFormat* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGLFramebufferObjectFormat", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QGLFramebufferObjectFormat()
    // 1: QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
    if (numArgs == 0) {
        overloadId = 0; // QGLFramebufferObjectFormat()
    } else if (numArgs == 1 && Shiboken::Converter<const QGLFramebufferObjectFormat & >::isConvertible(arg)) {
        overloadId = 1; // QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLFramebufferObjectFormat()
            {

                if(!PyErr_Occurred()) {
                // QGLFramebufferObjectFormat()
                cptr = new QGLFramebufferObjectFormat();
                }
                break;
            }
            case 1: // QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QGLFramebufferObjectFormat* cpp_arg0 = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
                cptr = new QGLFramebufferObjectFormat(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGLFramebufferObjectFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGLFramebufferObjectFormat_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQGLFramebufferObjectFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtOpenGL.QGLFramebufferObjectFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObjectFormat", overloads);
        return -1;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_attachment(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // attachment()const
            QGLFramebufferObject::Attachment cppResult = cppSelf->QGLFramebufferObjectFormat::attachment();
            pyResult = Shiboken::Converter<QGLFramebufferObject::Attachment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_internalTextureFormat(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // internalTextureFormat()const
            unsigned int cppResult = cppSelf->QGLFramebufferObjectFormat::internalTextureFormat();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_samples(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // samples()const
            int cppResult = cppSelf->QGLFramebufferObjectFormat::samples();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_setAttachment(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAttachment(QGLFramebufferObject::Attachment)
    if (Shiboken::Converter<QGLFramebufferObject::Attachment >::isConvertible(arg)) {
        overloadId = 0; // setAttachment(QGLFramebufferObject::Attachment)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFormatFunc_setAttachment_TypeError;

    // Call function/method
    {
        {
            QGLFramebufferObject::Attachment cpp_arg0 = Shiboken::Converter<QGLFramebufferObject::Attachment >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAttachment(QGLFramebufferObject::Attachment)
            cppSelf->QGLFramebufferObjectFormat::setAttachment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLFramebufferObjectFormatFunc_setAttachment_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFramebufferObject.Attachment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setAttachment", overloads);
        return 0;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_setInternalTextureFormat(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInternalTextureFormat(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setInternalTextureFormat(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFormatFunc_setInternalTextureFormat_TypeError;

    // Call function/method
    {
        {
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInternalTextureFormat(uint)
            cppSelf->QGLFramebufferObjectFormat::setInternalTextureFormat(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLFramebufferObjectFormatFunc_setInternalTextureFormat_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setInternalTextureFormat", overloads);
        return 0;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_setSamples(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSamples(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFormatFunc_setSamples_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSamples(int)
            cppSelf->QGLFramebufferObjectFormat::setSamples(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLFramebufferObjectFormatFunc_setSamples_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setSamples", overloads);
        return 0;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_setTextureTarget(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextureTarget(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextureTarget(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLFramebufferObjectFormatFunc_setTextureTarget_TypeError;

    // Call function/method
    {
        {
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextureTarget(uint)
            cppSelf->QGLFramebufferObjectFormat::setTextureTarget(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLFramebufferObjectFormatFunc_setTextureTarget_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setTextureTarget", overloads);
        return 0;
}

static PyObject* SbkQGLFramebufferObjectFormatFunc_textureTarget(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textureTarget()const
            unsigned int cppResult = cppSelf->QGLFramebufferObjectFormat::textureTarget();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGLFramebufferObjectFormat_methods[] = {
    {"attachment", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_attachment, METH_NOARGS},
    {"internalTextureFormat", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_internalTextureFormat, METH_NOARGS},
    {"samples", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_samples, METH_NOARGS},
    {"setAttachment", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_setAttachment, METH_O},
    {"setInternalTextureFormat", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_setInternalTextureFormat, METH_O},
    {"setSamples", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_setSamples, METH_O},
    {"setTextureTarget", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_setTextureTarget, METH_O},
    {"textureTarget", (PyCFunction)SbkQGLFramebufferObjectFormatFunc_textureTarget, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQGLFramebufferObjectFormat_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QGLFramebufferObjectFormat& cpp_self = *Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QGLFramebufferObjectFormat & >::isConvertible(other)) {
                // operator!=(const QGLFramebufferObjectFormat & other) const
                QGLFramebufferObjectFormat* cpp_other = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QGLFramebufferObjectFormat  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQGLFramebufferObjectFormat_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QGLFramebufferObjectFormat & >::isConvertible(other)) {
                // operator==(const QGLFramebufferObjectFormat & other) const
                QGLFramebufferObjectFormat* cpp_other = Shiboken::Converter<QGLFramebufferObjectFormat* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QGLFramebufferObjectFormat  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQGLFramebufferObjectFormat_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQGLFramebufferObjectFormat_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGLFramebufferObjectFormat_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLFramebufferObjectFormat",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQGLFramebufferObjectFormat_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGLFramebufferObjectFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGLFramebufferObjectFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGLFramebufferObjectFormat >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGLFramebufferObjectFormat",
    /*user_data*/           0
};
} //extern


void init_QGLFramebufferObjectFormat(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECTFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGLFramebufferObjectFormat_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGLFramebufferObjectFormat_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGLFramebufferObjectFormat_Type));
    PyModule_AddObject(module, "QGLFramebufferObjectFormat",
        ((PyObject*)&SbkQGLFramebufferObjectFormat_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QGLFramebufferObjectFormat >("QGLFramebufferObjectFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObjectFormat >("QGLFramebufferObjectFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QGLFramebufferObjectFormat >(typeid(QGLFramebufferObjectFormat).name());
    PySide::initQtMetaType<QGLFramebufferObjectFormat >();
}

