/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtopengl_python.h"

#include "qglshader_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qgl.h>
#include <qglshaderprogram.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGLShaderWrapper::QGLShaderWrapper(QFlags<QGLShader::ShaderTypeBit> type, QObject * parent) : QGLShader(type, parent), m_metaObject(0) {
    // ... middle
}

QGLShaderWrapper::QGLShaderWrapper(QFlags<QGLShader::ShaderTypeBit> type, const QGLContext * context, QObject * parent) : QGLShader(type, context, parent), m_metaObject(0) {
    // ... middle
}

void QGLShaderWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGLShaderWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGLShaderWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShader.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGLShaderWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShader.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGLShaderWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGLShaderWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGLShader::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGLShaderWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGLShader::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGLShaderWrapper::~QGLShaderWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGLShader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLShader >()))
        return -1;

    QGLShaderWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShader(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QGLShader", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
    // 1: QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
    if (Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
        } else if (Shiboken::Converter< QGLContext * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
            } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[2])) {
                overloadId = 1; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
            }
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QFlags<QGLShader::ShaderTypeBit> cpp_arg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QGLShader(QFlags<QGLShader::ShaderTypeBit>,QObject*)
                cptr = new QGLShaderWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QFlags<QGLShader::ShaderTypeBit> cpp_arg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QGLContext* cpp_arg1 = Shiboken::Converter<QGLContext* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return -1;
                QObject* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QObject* >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // QGLShader(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*,QObject*)
                cptr = new QGLShaderWrapper(cpp_arg0, cpp_arg1, cpp_arg2);
                Shiboken::setParent(pyargs[2], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGLShader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGLShader_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGLShader_Init_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtCore.QObject = None", "PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtOpenGL.QGLContext, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShader", overloads);
        return -1;
}

static PyObject* SbkQGLShaderFunc_compileSourceCode(PyObject* self, PyObject* arg)
{
    QGLShader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: compileSourceCode(QByteArray)
    // 1: compileSourceCode(QString)
    // 2: compileSourceCode(const char*)
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 2; // compileSourceCode(const char*)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // compileSourceCode(QString)
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // compileSourceCode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderFunc_compileSourceCode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // compileSourceCode(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // compileSourceCode(QByteArray)
                bool cppResult = cppSelf->QGLShader::compileSourceCode(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // compileSourceCode(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // compileSourceCode(QString)
                bool cppResult = cppSelf->QGLShader::compileSourceCode(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // compileSourceCode(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // compileSourceCode(const char*)
                bool cppResult = cppSelf->QGLShader::compileSourceCode(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderFunc_compileSourceCode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShader.compileSourceCode", overloads);
        return 0;
}

static PyObject* SbkQGLShaderFunc_compileSourceFile(PyObject* self, PyObject* arg)
{
    QGLShader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: compileSourceFile(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // compileSourceFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderFunc_compileSourceFile_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // compileSourceFile(QString)
            bool cppResult = cppSelf->QGLShader::compileSourceFile(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderFunc_compileSourceFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShader.compileSourceFile", overloads);
        return 0;
}

static PyObject* SbkQGLShaderFunc_hasOpenGLShaders(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "context" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShader.hasOpenGLShaders(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShader.hasOpenGLShaders(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShader.hasOpenGLShaders(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:hasOpenGLShaders", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hasOpenGLShaders(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*)
    if (Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // hasOpenGLShaders(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*)
        } else if (Shiboken::Converter< QGLContext * >::isConvertible(pyargs[1])) {
            overloadId = 0; // hasOpenGLShaders(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderFunc_hasOpenGLShaders_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "context");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "context";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShader.hasOpenGLShaders(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QGLShader::ShaderTypeBit> cpp_arg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QGLContext* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QGLContext* >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // hasOpenGLShaders(QFlags<QGLShader::ShaderTypeBit>,const QGLContext*)
            bool cppResult = QGLShader::hasOpenGLShaders(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderFunc_hasOpenGLShaders_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShader.hasOpenGLShaders", overloads);
        return 0;
}

static PyObject* SbkQGLShaderFunc_isCompiled(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCompiled()const
            bool cppResult = cppSelf->QGLShader::isCompiled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderFunc_log(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // log()const
            QString cppResult = cppSelf->QGLShader::log();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderFunc_shaderId(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shaderId()const
            unsigned int cppResult = cppSelf->QGLShader::shaderId();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderFunc_shaderType(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shaderType()const
            QFlags<QGLShader::ShaderTypeBit> cppResult = cppSelf->QGLShader::shaderType();
            pyResult = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderFunc_sourceCode(PyObject* self)
{
    QGLShader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sourceCode()const
            QByteArray cppResult = cppSelf->QGLShader::sourceCode();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGLShader_methods[] = {
    {"compileSourceCode", (PyCFunction)SbkQGLShaderFunc_compileSourceCode, METH_O},
    {"compileSourceFile", (PyCFunction)SbkQGLShaderFunc_compileSourceFile, METH_O},
    {"hasOpenGLShaders", (PyCFunction)SbkQGLShaderFunc_hasOpenGLShaders, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"isCompiled", (PyCFunction)SbkQGLShaderFunc_isCompiled, METH_NOARGS},
    {"log", (PyCFunction)SbkQGLShaderFunc_log, METH_NOARGS},
    {"shaderId", (PyCFunction)SbkQGLShaderFunc_shaderId, METH_NOARGS},
    {"shaderType", (PyCFunction)SbkQGLShaderFunc_shaderType, METH_NOARGS},
    {"sourceCode", (PyCFunction)SbkQGLShaderFunc_sourceCode, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGLShader_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLShader",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGLShader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGLShader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGLShader >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGLShader*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGLShader_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGLShader*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGLShader_Type;
    return 0;
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGLShader::ShaderType >::checkType(self) && Shiboken::Converter<QGLShader::ShaderType >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        Shiboken::Converter<QGLShader::ShaderType>::toCpp(self)
        & Shiboken::Converter< QGLShader::ShaderType >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGLShader::ShaderType >::checkType(self) && Shiboken::Converter<QGLShader::ShaderType >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        Shiboken::Converter<QGLShader::ShaderType>::toCpp(self)
        | Shiboken::Converter< QGLShader::ShaderType >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGLShader::ShaderType >::checkType(self) && Shiboken::Converter<QGLShader::ShaderType >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        Shiboken::Converter<QGLShader::ShaderType>::toCpp(self)
        ^ Shiboken::Converter< QGLShader::ShaderType >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLShader::ShaderType >::toPython(
        ~Shiboken::Converter<QGLShader::ShaderType >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ShaderTypeBit",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtOpenGL_QGLShader_ShaderType_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ShaderType",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGLShader(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLSHADER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGLShader_Type);

    SbkQGLShader_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQGLShader_Type.type_discovery = &SbkQGLShader_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQGLShader_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGLShader_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGLShader_Type));
    PyModule_AddObject(module, "QGLShader",
        ((PyObject*)&SbkQGLShader_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ShaderTypeBit
    SbkPySide_QtOpenGLTypes[SBK_QGLSHADER_SHADERTYPEBIT_IDX] = &SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type);
    PyDict_SetItemString(SbkQGLShader_Type.super.ht_type.tp_dict,
            "ShaderTypeBit",((PyObject*)&SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type));

    // init flags class: QFlags<QGLShader::ShaderTypeBit>
    SbkPySide_QtOpenGLTypes[SBK_QFLAGS_QGLSHADER_SHADERTYPEBIT__IDX] = &SbkPySide_QtOpenGL_QGLShader_ShaderType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLShader_ShaderType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtOpenGL_QGLShader_ShaderType_Type);
    PyDict_SetItemString(SbkQGLShader_Type.super.ht_type.tp_dict,
            "ShaderType",((PyObject*)&SbkPySide_QtOpenGL_QGLShader_ShaderType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type,
        (long) QGLShader::Vertex, "Vertex");
    PyDict_SetItemString(SbkQGLShader_Type.super.ht_type.tp_dict,
        "Vertex", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type.tp_dict,
        "Vertex", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type,
        (long) QGLShader::Fragment, "Fragment");
    PyDict_SetItemString(SbkQGLShader_Type.super.ht_type.tp_dict,
        "Fragment", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type.tp_dict,
        "Fragment", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type,
        (long) QGLShader::Geometry, "Geometry");
    PyDict_SetItemString(SbkQGLShader_Type.super.ht_type.tp_dict,
        "Geometry", enum_item);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLShader_ShaderTypeBit_Type.tp_dict,
        "Geometry", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLShader::ShaderTypeBit");


    Shiboken::TypeResolver::createObjectTypeResolver<QGLShader >("QGLShader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShader >(typeid(QGLShader).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShader >(typeid(QGLShaderWrapper).name());
    PySide::initQtMetaType<QGLShader* >();
}

