/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtopengl_python.h"

#include "qglshaderprogram_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qgenericmatrix.h>
#include <qgl.h>
#include <qglshaderprogram.h>
#include <qmatrix4x4.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qthread.h>
#include <qtransform.h>
#include <qvector2d.h>
#include <qvector3d.h>
#include <qvector4d.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGLShaderProgramWrapper::QGLShaderProgramWrapper(QObject * parent) : QGLShaderProgram(parent), m_metaObject(0) {
    // ... middle
}

QGLShaderProgramWrapper::QGLShaderProgramWrapper(const QGLContext * context, QObject * parent) : QGLShaderProgram(context, parent), m_metaObject(0) {
    // ... middle
}

void QGLShaderProgramWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderProgramWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGLShaderProgramWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGLShaderProgramWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGLShaderProgramWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGLShaderProgramWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QGLShaderProgramWrapper::link()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "link"));
    if (py_override.isNull()) {
        return this->QGLShaderProgram::link();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLShaderProgram.link", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QGLShaderProgramWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGLShaderProgramWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGLShaderProgram::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGLShaderProgramWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGLShaderProgram::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGLShaderProgramWrapper::~QGLShaderProgramWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGLShaderProgram_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLShaderProgram >()))
        return -1;

    QGLShaderProgramWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QGLShaderProgram", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGLShaderProgram(QObject*)
    // 1: QGLShaderProgram(const QGLContext*,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGLShaderProgram(QObject*)
    } else if (Shiboken::Converter< QGLContext * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGLShaderProgram(const QGLContext*,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGLShaderProgram(const QGLContext*,QObject*)
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGLShaderProgram(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgram_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLShaderProgram(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QGLShaderProgram(QObject*)
                cptr = new QGLShaderProgramWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QGLShaderProgram(const QGLContext*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QGLContext* cpp_arg0 = Shiboken::Converter<QGLContext* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QGLShaderProgram(const QGLContext*,QObject*)
                cptr = new QGLShaderProgramWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGLShaderProgram >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGLShaderProgram_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGLShaderProgram_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "PySide.QtOpenGL.QGLContext, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram", overloads);
        return -1;
}

static PyObject* SbkQGLShaderProgramFunc_addShader(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addShader(QGLShader*)
    if (Shiboken::Converter<QGLShader * >::isConvertible(arg)) {
        overloadId = 0; // addShader(QGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_addShader_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGLShader* cpp_arg0 = Shiboken::Converter<QGLShader* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addShader(QGLShader*)
            bool cppResult = cppSelf->QGLShaderProgram::addShader(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderProgramFunc_addShader_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.addShader", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_addShaderFromSourceCode(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addShaderFromSourceCode", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
    // 1: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
    // 2: addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
    if (Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 2; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
        } else if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 0; // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_addShaderFromSourceCode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
            {
                QFlags<QGLShader::ShaderTypeBit> cpp_arg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QByteArray)
                bool cppResult = cppSelf->QGLShaderProgram::addShaderFromSourceCode(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
            {
                QFlags<QGLShader::ShaderTypeBit> cpp_arg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,QString)
                bool cppResult = cppSelf->QGLShaderProgram::addShaderFromSourceCode(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
            {
                QFlags<QGLShader::ShaderTypeBit> cpp_arg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // addShaderFromSourceCode(QFlags<QGLShader::ShaderTypeBit>,const char*)
                bool cppResult = cppSelf->QGLShaderProgram::addShaderFromSourceCode(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderProgramFunc_addShaderFromSourceCode_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, PySide.QtCore.QByteArray", "PySide.QtOpenGL.QGLShader.ShaderType, QString", "PySide.QtOpenGL.QGLShader.ShaderType, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.addShaderFromSourceCode", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_addShaderFromSourceFile(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addShaderFromSourceFile", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
    if (numArgs == 2 && Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_addShaderFromSourceFile_TypeError;

    // Call function/method
    {
        {
            QFlags<QGLShader::ShaderTypeBit> cpp_arg0 = Shiboken::Converter<QFlags<QGLShader::ShaderTypeBit> >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // addShaderFromSourceFile(QFlags<QGLShader::ShaderTypeBit>,QString)
            bool cppResult = cppSelf->QGLShaderProgram::addShaderFromSourceFile(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderProgramFunc_addShaderFromSourceFile_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader.ShaderType, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.addShaderFromSourceFile", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_attributeLocation(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: attributeLocation(QByteArray)const
    // 1: attributeLocation(QString)const
    // 2: attributeLocation(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 2; // attributeLocation(const char*)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // attributeLocation(QString)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // attributeLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_attributeLocation_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // attributeLocation(QByteArray)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // attributeLocation(QByteArray)const
                int cppResult = cppSelf->QGLShaderProgram::attributeLocation(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // attributeLocation(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // attributeLocation(QString)const
                int cppResult = cppSelf->QGLShaderProgram::attributeLocation(cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 2: // attributeLocation(const char*)const
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // attributeLocation(const char*)const
                int cppResult = cppSelf->QGLShaderProgram::attributeLocation(cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderProgramFunc_attributeLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.attributeLocation", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_bind(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bind()
            bool cppResult = cppSelf->QGLShaderProgram::bind();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_bindAttributeLocation(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "bindAttributeLocation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bindAttributeLocation(QByteArray,int)
    // 1: bindAttributeLocation(QString,int)
    // 2: bindAttributeLocation(const char*,int)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // bindAttributeLocation(const char*,int)
    } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // bindAttributeLocation(QString,int)
    } else if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // bindAttributeLocation(QByteArray,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_bindAttributeLocation_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindAttributeLocation(QByteArray,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // bindAttributeLocation(QByteArray,int)
                cppSelf->QGLShaderProgram::bindAttributeLocation(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // bindAttributeLocation(QString,int)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // bindAttributeLocation(QString,int)
                cppSelf->QGLShaderProgram::bindAttributeLocation(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // bindAttributeLocation(const char*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // bindAttributeLocation(const char*,int)
                cppSelf->QGLShaderProgram::bindAttributeLocation(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_bindAttributeLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int", "QString, int", "str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.bindAttributeLocation", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_disableAttributeArray(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: disableAttributeArray(const char*)
    // 1: disableAttributeArray(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // disableAttributeArray(int)
    } else if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // disableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_disableAttributeArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // disableAttributeArray(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // disableAttributeArray(const char*)
                cppSelf->QGLShaderProgram::disableAttributeArray(cpp_arg0);
                }
                break;
            }
            case 1: // disableAttributeArray(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // disableAttributeArray(int)
                cppSelf->QGLShaderProgram::disableAttributeArray(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_disableAttributeArray_TypeError:
        const char* overloads[] = {"str", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.disableAttributeArray", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_enableAttributeArray(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: enableAttributeArray(const char*)
    // 1: enableAttributeArray(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // enableAttributeArray(int)
    } else if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // enableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_enableAttributeArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // enableAttributeArray(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // enableAttributeArray(const char*)
                cppSelf->QGLShaderProgram::enableAttributeArray(cpp_arg0);
                }
                break;
            }
            case 1: // enableAttributeArray(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // enableAttributeArray(int)
                cppSelf->QGLShaderProgram::enableAttributeArray(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_enableAttributeArray_TypeError:
        const char* overloads[] = {"str", "int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.enableAttributeArray", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_geometryInputType(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // geometryInputType()const
            unsigned int cppResult = cppSelf->QGLShaderProgram::geometryInputType();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_geometryOutputType(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // geometryOutputType()const
            unsigned int cppResult = cppSelf->QGLShaderProgram::geometryOutputType();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_geometryOutputVertexCount(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // geometryOutputVertexCount()const
            int cppResult = cppSelf->QGLShaderProgram::geometryOutputVertexCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_hasOpenGLShaderPrograms(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "context" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:hasOpenGLShaderPrograms", &arg))
        return 0;


    // Overloaded function decisor
    // 0: hasOpenGLShaderPrograms(const QGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // hasOpenGLShaderPrograms(const QGLContext*)
    } else if (Shiboken::Converter< QGLContext * >::isConvertible(arg)) {
        overloadId = 0; // hasOpenGLShaderPrograms(const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "context");
                if (value) {
                    if (arg)
                        errorArgName = "context";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGLContext* cpp_arg0 = arg ? Shiboken::Converter<QGLContext* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // hasOpenGLShaderPrograms(const QGLContext*)
            bool cppResult = QGLShaderProgram::hasOpenGLShaderPrograms(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderProgramFunc_hasOpenGLShaderPrograms_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.hasOpenGLShaderPrograms", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_isLinked(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isLinked()const
            bool cppResult = cppSelf->QGLShaderProgram::isLinked();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_link(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // link()
            bool cppResult = cppSelf->QGLShaderProgram::link();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_log(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // log()const
            QString cppResult = cppSelf->QGLShaderProgram::log();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_maxGeometryOutputVertices(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maxGeometryOutputVertices()const
            int cppResult = cppSelf->QGLShaderProgram::maxGeometryOutputVertices();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_programId(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // programId()const
            unsigned int cppResult = cppSelf->QGLShaderProgram::programId();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_release(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // release()
            cppSelf->QGLShaderProgram::release();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGLShaderProgramFunc_removeAllShaders(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // removeAllShaders()
            cppSelf->QGLShaderProgram::removeAllShaders();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGLShaderProgramFunc_removeShader(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeShader(QGLShader*)
    if (Shiboken::Converter<QGLShader * >::isConvertible(arg)) {
        overloadId = 0; // removeShader(QGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_removeShader_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGLShader* cpp_arg0 = Shiboken::Converter<QGLShader* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeShader(QGLShader*)
            cppSelf->QGLShaderProgram::removeShader(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_removeShader_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLShader", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.removeShader", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setAttributeArray(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "stride" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setAttributeArray", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeArray(const char*,const QVector2D*,int)
    // 1: setAttributeArray(const char*,const QVector3D*,int)
    // 2: setAttributeArray(const char*,const QVector4D*,int)
    // 3: setAttributeArray(const char*,const float*,int,int)
    // 4: setAttributeArray(int,const QVector2D*,int)
    // 5: setAttributeArray(int,const QVector3D*,int)
    // 6: setAttributeArray(int,const QVector4D*,int)
    // 7: setAttributeArray(int,const float*,int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs >= 3 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 7; // setAttributeArray(int,const float*,int,int)
            } else if (SbkNumber_Check(pyargs[3])) {
                overloadId = 7; // setAttributeArray(int,const float*,int,int)
            }
        } else if (Shiboken::Converter<const QVector2D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // setAttributeArray(int,const QVector2D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 4; // setAttributeArray(int,const QVector2D*,int)
            }
        } else if (Shiboken::Converter<const QVector3D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 5; // setAttributeArray(int,const QVector3D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 5; // setAttributeArray(int,const QVector3D*,int)
            }
        } else if (Shiboken::Converter<const QVector4D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 6; // setAttributeArray(int,const QVector4D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 6; // setAttributeArray(int,const QVector4D*,int)
            }
        }
    } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs >= 3 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // setAttributeArray(const char*,const float*,int,int)
            } else if (SbkNumber_Check(pyargs[3])) {
                overloadId = 3; // setAttributeArray(const char*,const float*,int,int)
            }
        } else if (Shiboken::Converter<const QVector2D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setAttributeArray(const char*,const QVector2D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // setAttributeArray(const char*,const QVector2D*,int)
            }
        } else if (Shiboken::Converter<const QVector3D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // setAttributeArray(const char*,const QVector3D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // setAttributeArray(const char*,const QVector3D*,int)
            }
        } else if (Shiboken::Converter<const QVector4D * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // setAttributeArray(const char*,const QVector4D*,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 2; // setAttributeArray(const char*,const QVector4D*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setAttributeArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeArray(const char*,const QVector2D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const QVector2D*,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // setAttributeArray(const char*,const QVector3D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const QVector3D*,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // setAttributeArray(const char*,const QVector4D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const QVector4D*,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 3: // setAttributeArray(const char*,const float*,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "stride";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float * cpp_arg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(const char*,const float*,int,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 4: // setAttributeArray(int,const QVector2D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(int,const QVector2D*,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 5: // setAttributeArray(int,const QVector3D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(int,const QVector3D*,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 6: // setAttributeArray(int,const QVector4D*,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "stride";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(int,const QVector4D*,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 7: // setAttributeArray(int,const float*,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "stride";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float * cpp_arg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeArray(int,const float*,int,int)
                cppSelf->QGLShaderProgram::setAttributeArray(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setAttributeArray_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QVector2D, int = 0", "str, PySide.QtGui.QVector3D, int = 0", "str, PySide.QtGui.QVector4D, int = 0", "str, float, int, int = 0", "int, PySide.QtGui.QVector2D, int = 0", "int, PySide.QtGui.QVector3D, int = 0", "int, PySide.QtGui.QVector4D, int = 0", "int, float, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeArray", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setAttributeBuffer(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "stride" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:setAttributeBuffer", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeBuffer(const char*,uint,int,int,int)
    // 1: setAttributeBuffer(int,uint,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        }
    } else if (numArgs >= 4 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setAttributeBuffer_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeBuffer(const char*,uint,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "stride";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeBuffer(const char*,uint,int,int,int)
                cppSelf->QGLShaderProgram::setAttributeBuffer(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 1: // setAttributeBuffer(int,uint,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "stride");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "stride";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 0;

                if(!PyErr_Occurred()) {
                // setAttributeBuffer(int,uint,int,int,int)
                cppSelf->QGLShaderProgram::setAttributeBuffer(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setAttributeBuffer_TypeError:
        const char* overloads[] = {"str, unsigned int, int, int, int = 0", "int, unsigned int, int, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeBuffer", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setAttributeValue(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttributeValue", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeValue(const char*,QColor)
    // 1: setAttributeValue(const char*,QVector2D)
    // 2: setAttributeValue(const char*,QVector3D)
    // 3: setAttributeValue(const char*,QVector4D)
    // 4: setAttributeValue(const char*,float)
    // 5: setAttributeValue(const char*,float,float)
    // 6: setAttributeValue(const char*,float,float,float)
    // 7: setAttributeValue(const char*,float,float,float,float)
    // 8: setAttributeValue(int,QColor)
    // 9: setAttributeValue(int,QVector2D)
    // 10: setAttributeValue(int,QVector3D)
    // 11: setAttributeValue(int,QVector4D)
    // 12: setAttributeValue(int,float)
    // 13: setAttributeValue(int,float,float)
    // 14: setAttributeValue(int,float,float,float)
    // 15: setAttributeValue(int,float,float,float,float)
    if (SbkNumber_Check(pyargs[0])) {
        if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 12; // setAttributeValue(int,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 13; // setAttributeValue(int,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 14; // setAttributeValue(int,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 15; // setAttributeValue(int,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && Shiboken::Converter<const QVector2D & >::isConvertible(pyargs[1])) {
            overloadId = 9; // setAttributeValue(int,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[1])) {
            overloadId = 10; // setAttributeValue(int,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[1])) {
            overloadId = 11; // setAttributeValue(int,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[1])) {
            overloadId = 8; // setAttributeValue(int,QColor)
        }
    } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // setAttributeValue(const char*,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 5; // setAttributeValue(const char*,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 6; // setAttributeValue(const char*,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 7; // setAttributeValue(const char*,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && Shiboken::Converter<const QVector2D & >::isConvertible(pyargs[1])) {
            overloadId = 1; // setAttributeValue(const char*,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[1])) {
            overloadId = 2; // setAttributeValue(const char*,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[1])) {
            overloadId = 3; // setAttributeValue(const char*,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[1])) {
            overloadId = 0; // setAttributeValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setAttributeValue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeValue(const char*,QColor)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg1_auto_ptr;
                QColor* cpp_arg1 = Shiboken::Converter<QColor* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QColor >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QColor)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // setAttributeValue(const char*,QVector2D)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QVector2D)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // setAttributeValue(const char*,QVector3D)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QVector3D)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // setAttributeValue(const char*,QVector4D)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,QVector4D)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // setAttributeValue(const char*,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 5: // setAttributeValue(const char*,float,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 6: // setAttributeValue(const char*,float,float,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float,float,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 7: // setAttributeValue(const char*,float,float,float,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cpp_arg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(const char*,float,float,float,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 8: // setAttributeValue(int,QColor)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg1_auto_ptr;
                QColor* cpp_arg1 = Shiboken::Converter<QColor* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QColor >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,QColor)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 9: // setAttributeValue(int,QVector2D)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,QVector2D)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 10: // setAttributeValue(int,QVector3D)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,QVector3D)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 11: // setAttributeValue(int,QVector4D)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,QVector4D)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 12: // setAttributeValue(int,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 13: // setAttributeValue(int,float,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,float,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 14: // setAttributeValue(int,float,float,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,float,float,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 15: // setAttributeValue(int,float,float,float,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cpp_arg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // setAttributeValue(int,float,float,float,float)
                cppSelf->QGLShaderProgram::setAttributeValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setAttributeValue_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QColor", "str, PySide.QtGui.QVector2D", "str, PySide.QtGui.QVector3D", "str, PySide.QtGui.QVector4D", "str, float", "str, float, float", "str, float, float, float", "str, float, float, float, float", "int, PySide.QtGui.QColor", "int, PySide.QtGui.QVector2D", "int, PySide.QtGui.QVector3D", "int, PySide.QtGui.QVector4D", "int, float", "int, float, float", "int, float, float, float", "int, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setAttributeValue", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setGeometryInputType(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryInputType(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGeometryInputType(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setGeometryInputType_TypeError;

    // Call function/method
    {
        {
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGeometryInputType(uint)
            cppSelf->QGLShaderProgram::setGeometryInputType(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setGeometryInputType_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryInputType", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setGeometryOutputType(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryOutputType(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGeometryOutputType(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setGeometryOutputType_TypeError;

    // Call function/method
    {
        {
            unsigned int cpp_arg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGeometryOutputType(uint)
            cppSelf->QGLShaderProgram::setGeometryOutputType(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setGeometryOutputType_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryOutputType", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setGeometryOutputVertexCount(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometryOutputVertexCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGeometryOutputVertexCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setGeometryOutputVertexCount_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGeometryOutputVertexCount(int)
            cppSelf->QGLShaderProgram::setGeometryOutputVertexCount(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setGeometryOutputVertexCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.setGeometryOutputVertexCount", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setUniformValue(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValue", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValue(const char*,QColor)
    // 1: setUniformValue(const char*,QMatrix2x2)
    // 2: setUniformValue(const char*,QMatrix2x3)
    // 3: setUniformValue(const char*,QMatrix2x4)
    // 4: setUniformValue(const char*,QMatrix3x2)
    // 5: setUniformValue(const char*,QMatrix3x3)
    // 6: setUniformValue(const char*,QMatrix3x4)
    // 7: setUniformValue(const char*,QMatrix4x2)
    // 8: setUniformValue(const char*,QMatrix4x3)
    // 9: setUniformValue(const char*,QMatrix4x4)
    // 10: setUniformValue(const char*,QPoint)
    // 11: setUniformValue(const char*,QPointF)
    // 12: setUniformValue(const char*,QSize)
    // 13: setUniformValue(const char*,QSizeF)
    // 14: setUniformValue(const char*,QTransform)
    // 15: setUniformValue(const char*,QVector2D)
    // 16: setUniformValue(const char*,QVector3D)
    // 17: setUniformValue(const char*,QVector4D)
    // 18: setUniformValue(const char*,float)
    // 19: setUniformValue(const char*,float,float)
    // 20: setUniformValue(const char*,float,float,float)
    // 21: setUniformValue(const char*,float,float,float,float)
    // 22: setUniformValue(const char*,int)
    // 23: setUniformValue(const char*,uint)
    // 24: setUniformValue(int,QColor)
    // 25: setUniformValue(int,QMatrix2x2)
    // 26: setUniformValue(int,QMatrix2x3)
    // 27: setUniformValue(int,QMatrix2x4)
    // 28: setUniformValue(int,QMatrix3x2)
    // 29: setUniformValue(int,QMatrix3x3)
    // 30: setUniformValue(int,QMatrix3x4)
    // 31: setUniformValue(int,QMatrix4x2)
    // 32: setUniformValue(int,QMatrix4x3)
    // 33: setUniformValue(int,QMatrix4x4)
    // 34: setUniformValue(int,QPoint)
    // 35: setUniformValue(int,QPointF)
    // 36: setUniformValue(int,QSize)
    // 37: setUniformValue(int,QSizeF)
    // 38: setUniformValue(int,QTransform)
    // 39: setUniformValue(int,QVector2D)
    // 40: setUniformValue(int,QVector3D)
    // 41: setUniformValue(int,QVector4D)
    // 42: setUniformValue(int,float)
    // 43: setUniformValue(int,float,float)
    // 44: setUniformValue(int,float,float,float)
    // 45: setUniformValue(int,float,float,float,float)
    // 46: setUniformValue(int,int)
    // 47: setUniformValue(int,uint)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 47; // setUniformValue(int,uint)
        } else if (PyFloat_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 42; // setUniformValue(int,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 43; // setUniformValue(int,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 44; // setUniformValue(int,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 45; // setUniformValue(int,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 46; // setUniformValue(int,int)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector2D & >::isConvertible(pyargs[1])) {
            overloadId = 39; // setUniformValue(int,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[1])) {
            overloadId = 40; // setUniformValue(int,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[1])) {
            overloadId = 41; // setUniformValue(int,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[1])) {
            overloadId = 38; // setUniformValue(int,QTransform)
        } else if (numArgs == 2 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[1])) {
            overloadId = 36; // setUniformValue(int,QSize)
        } else if (numArgs == 2 && Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[1])) {
            overloadId = 37; // setUniformValue(int,QSizeF)
        } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
            overloadId = 34; // setUniformValue(int,QPoint)
        } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
            overloadId = 35; // setUniformValue(int,QPointF)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(pyargs[1])) {
            overloadId = 33; // setUniformValue(int,QMatrix4x4)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix4x3 & >::isConvertible(pyargs[1])) {
            overloadId = 32; // setUniformValue(int,QMatrix4x3)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix4x2 & >::isConvertible(pyargs[1])) {
            overloadId = 31; // setUniformValue(int,QMatrix4x2)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix3x4 & >::isConvertible(pyargs[1])) {
            overloadId = 30; // setUniformValue(int,QMatrix3x4)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix3x3 & >::isConvertible(pyargs[1])) {
            overloadId = 29; // setUniformValue(int,QMatrix3x3)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix3x2 & >::isConvertible(pyargs[1])) {
            overloadId = 28; // setUniformValue(int,QMatrix3x2)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix2x4 & >::isConvertible(pyargs[1])) {
            overloadId = 27; // setUniformValue(int,QMatrix2x4)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix2x3 & >::isConvertible(pyargs[1])) {
            overloadId = 26; // setUniformValue(int,QMatrix2x3)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix2x2 & >::isConvertible(pyargs[1])) {
            overloadId = 25; // setUniformValue(int,QMatrix2x2)
        } else if (numArgs == 2 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[1])) {
            overloadId = 24; // setUniformValue(int,QColor)
        }
    } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 23; // setUniformValue(const char*,uint)
        } else if (PyFloat_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 18; // setUniformValue(const char*,float)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 19; // setUniformValue(const char*,float,float)
                } else if (SbkNumber_Check(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 20; // setUniformValue(const char*,float,float,float)
                    } else if (numArgs == 5 && SbkNumber_Check(pyargs[4])) {
                        overloadId = 21; // setUniformValue(const char*,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 22; // setUniformValue(const char*,int)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector2D & >::isConvertible(pyargs[1])) {
            overloadId = 15; // setUniformValue(const char*,QVector2D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector3D & >::isConvertible(pyargs[1])) {
            overloadId = 16; // setUniformValue(const char*,QVector3D)
        } else if (numArgs == 2 && Shiboken::Converter<const QVector4D & >::isConvertible(pyargs[1])) {
            overloadId = 17; // setUniformValue(const char*,QVector4D)
        } else if (numArgs == 2 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[1])) {
            overloadId = 14; // setUniformValue(const char*,QTransform)
        } else if (numArgs == 2 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[1])) {
            overloadId = 12; // setUniformValue(const char*,QSize)
        } else if (numArgs == 2 && Shiboken::Converter<const QSizeF & >::isConvertible(pyargs[1])) {
            overloadId = 13; // setUniformValue(const char*,QSizeF)
        } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
            overloadId = 10; // setUniformValue(const char*,QPoint)
        } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
            overloadId = 11; // setUniformValue(const char*,QPointF)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix4x4 & >::isConvertible(pyargs[1])) {
            overloadId = 9; // setUniformValue(const char*,QMatrix4x4)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix4x3 & >::isConvertible(pyargs[1])) {
            overloadId = 8; // setUniformValue(const char*,QMatrix4x3)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix4x2 & >::isConvertible(pyargs[1])) {
            overloadId = 7; // setUniformValue(const char*,QMatrix4x2)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix3x4 & >::isConvertible(pyargs[1])) {
            overloadId = 6; // setUniformValue(const char*,QMatrix3x4)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix3x3 & >::isConvertible(pyargs[1])) {
            overloadId = 5; // setUniformValue(const char*,QMatrix3x3)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix3x2 & >::isConvertible(pyargs[1])) {
            overloadId = 4; // setUniformValue(const char*,QMatrix3x2)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix2x4 & >::isConvertible(pyargs[1])) {
            overloadId = 3; // setUniformValue(const char*,QMatrix2x4)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix2x3 & >::isConvertible(pyargs[1])) {
            overloadId = 2; // setUniformValue(const char*,QMatrix2x3)
        } else if (numArgs == 2 && Shiboken::Converter<const QMatrix2x2 & >::isConvertible(pyargs[1])) {
            overloadId = 1; // setUniformValue(const char*,QMatrix2x2)
        } else if (numArgs == 2 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[1])) {
            overloadId = 0; // setUniformValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setUniformValue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setUniformValue(const char*,QColor)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg1_auto_ptr;
                QColor* cpp_arg1 = Shiboken::Converter<QColor* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QColor >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QColor)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // setUniformValue(const char*,QMatrix2x2)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x2* cpp_arg1 = Shiboken::Converter<QMatrix2x2* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix2x2)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // setUniformValue(const char*,QMatrix2x3)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x3* cpp_arg1 = Shiboken::Converter<QMatrix2x3* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix2x3)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // setUniformValue(const char*,QMatrix2x4)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x4* cpp_arg1 = Shiboken::Converter<QMatrix2x4* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix2x4)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // setUniformValue(const char*,QMatrix3x2)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x2* cpp_arg1 = Shiboken::Converter<QMatrix3x2* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix3x2)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 5: // setUniformValue(const char*,QMatrix3x3)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x3* cpp_arg1 = Shiboken::Converter<QMatrix3x3* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix3x3)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 6: // setUniformValue(const char*,QMatrix3x4)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x4* cpp_arg1 = Shiboken::Converter<QMatrix3x4* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix3x4)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 7: // setUniformValue(const char*,QMatrix4x2)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x2* cpp_arg1 = Shiboken::Converter<QMatrix4x2* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix4x2)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 8: // setUniformValue(const char*,QMatrix4x3)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x3* cpp_arg1 = Shiboken::Converter<QMatrix4x3* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix4x3)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 9: // setUniformValue(const char*,QMatrix4x4)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_arg1_auto_ptr;
                QMatrix4x4* cpp_arg1 = Shiboken::Converter<QMatrix4x4* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QMatrix4x4)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 10: // setUniformValue(const char*,QPoint)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QPoint)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 11: // setUniformValue(const char*,QPointF)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QPointF)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 12: // setUniformValue(const char*,QSize)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QSize* cpp_arg1 = Shiboken::Converter<QSize* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QSize)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 13: // setUniformValue(const char*,QSizeF)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QSizeF > cpp_arg1_auto_ptr;
                QSizeF* cpp_arg1 = Shiboken::Converter<QSizeF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QSizeF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QSizeF)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 14: // setUniformValue(const char*,QTransform)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTransform* cpp_arg1 = Shiboken::Converter<QTransform* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QTransform)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 15: // setUniformValue(const char*,QVector2D)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QVector2D)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 16: // setUniformValue(const char*,QVector3D)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QVector3D)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 17: // setUniformValue(const char*,QVector4D)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,QVector4D)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 18: // setUniformValue(const char*,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 19: // setUniformValue(const char*,float,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 20: // setUniformValue(const char*,float,float,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float,float,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 21: // setUniformValue(const char*,float,float,float,float)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cpp_arg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,float,float,float,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 22: // setUniformValue(const char*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,int)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 23: // setUniformValue(const char*,uint)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(const char*,uint)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 24: // setUniformValue(int,QColor)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg1_auto_ptr;
                QColor* cpp_arg1 = Shiboken::Converter<QColor* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QColor >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QColor)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 25: // setUniformValue(int,QMatrix2x2)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x2* cpp_arg1 = Shiboken::Converter<QMatrix2x2* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix2x2)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 26: // setUniformValue(int,QMatrix2x3)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x3* cpp_arg1 = Shiboken::Converter<QMatrix2x3* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix2x3)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 27: // setUniformValue(int,QMatrix2x4)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x4* cpp_arg1 = Shiboken::Converter<QMatrix2x4* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix2x4)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 28: // setUniformValue(int,QMatrix3x2)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x2* cpp_arg1 = Shiboken::Converter<QMatrix3x2* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix3x2)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 29: // setUniformValue(int,QMatrix3x3)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x3* cpp_arg1 = Shiboken::Converter<QMatrix3x3* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix3x3)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 30: // setUniformValue(int,QMatrix3x4)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x4* cpp_arg1 = Shiboken::Converter<QMatrix3x4* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix3x4)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 31: // setUniformValue(int,QMatrix4x2)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x2* cpp_arg1 = Shiboken::Converter<QMatrix4x2* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix4x2)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 32: // setUniformValue(int,QMatrix4x3)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x3* cpp_arg1 = Shiboken::Converter<QMatrix4x3* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix4x3)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 33: // setUniformValue(int,QMatrix4x4)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_arg1_auto_ptr;
                QMatrix4x4* cpp_arg1 = Shiboken::Converter<QMatrix4x4* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QMatrix4x4)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 34: // setUniformValue(int,QPoint)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QPoint)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 35: // setUniformValue(int,QPointF)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QPointF)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 36: // setUniformValue(int,QSize)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QSize* cpp_arg1 = Shiboken::Converter<QSize* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QSize)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 37: // setUniformValue(int,QSizeF)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QSizeF > cpp_arg1_auto_ptr;
                QSizeF* cpp_arg1 = Shiboken::Converter<QSizeF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QSizeF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QSizeF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QSizeF)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 38: // setUniformValue(int,QTransform)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTransform* cpp_arg1 = Shiboken::Converter<QTransform* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QTransform)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 39: // setUniformValue(int,QVector2D)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QVector2D)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 40: // setUniformValue(int,QVector3D)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QVector3D)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 41: // setUniformValue(int,QVector4D)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,QVector4D)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 42: // setUniformValue(int,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 43: // setUniformValue(int,float,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,float,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 44: // setUniformValue(int,float,float,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,float,float,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 45: // setUniformValue(int,float,float,float,float)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);
                float cpp_arg2 = Shiboken::Converter<float >::toCpp(pyargs[2]);
                float cpp_arg3 = Shiboken::Converter<float >::toCpp(pyargs[3]);
                float cpp_arg4 = Shiboken::Converter<float >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,float,float,float,float)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 46: // setUniformValue(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,int)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 47: // setUniformValue(int,uint)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                unsigned int cpp_arg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setUniformValue(int,uint)
                cppSelf->QGLShaderProgram::setUniformValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setUniformValue_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QColor", "str, PySide.QtGui.QMatrix2x2", "str, PySide.QtGui.QMatrix2x3", "str, PySide.QtGui.QMatrix2x4", "str, PySide.QtGui.QMatrix3x2", "str, PySide.QtGui.QMatrix3x3", "str, PySide.QtGui.QMatrix3x4", "str, PySide.QtGui.QMatrix4x2", "str, PySide.QtGui.QMatrix4x3", "str, PySide.QtGui.QMatrix4x4", "str, PySide.QtCore.QPoint", "str, PySide.QtCore.QPointF", "str, PySide.QtCore.QSize", "str, PySide.QtCore.QSizeF", "str, PySide.QtGui.QTransform", "str, PySide.QtGui.QVector2D", "str, PySide.QtGui.QVector3D", "str, PySide.QtGui.QVector4D", "str, float", "str, float, float", "str, float, float, float", "str, float, float, float, float", "str, int", "str, unsigned int", "int, PySide.QtGui.QColor", "int, PySide.QtGui.QMatrix2x2", "int, PySide.QtGui.QMatrix2x3", "int, PySide.QtGui.QMatrix2x4", "int, PySide.QtGui.QMatrix3x2", "int, PySide.QtGui.QMatrix3x3", "int, PySide.QtGui.QMatrix3x4", "int, PySide.QtGui.QMatrix4x2", "int, PySide.QtGui.QMatrix4x3", "int, PySide.QtGui.QMatrix4x4", "int, PySide.QtCore.QPoint", "int, PySide.QtCore.QPointF", "int, PySide.QtCore.QSize", "int, PySide.QtCore.QSizeF", "int, PySide.QtGui.QTransform", "int, PySide.QtGui.QVector2D", "int, PySide.QtGui.QVector3D", "int, PySide.QtGui.QVector4D", "int, float", "int, float, float", "int, float, float, float", "int, float, float, float, float", "int, int", "int, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValue", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_setUniformValueArray(PyObject* self, PyObject* args)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUniformValueArray", 3, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setUniformValueArray(const char*,const QMatrix2x2*,int)
    // 1: setUniformValueArray(const char*,const QMatrix2x3*,int)
    // 2: setUniformValueArray(const char*,const QMatrix2x4*,int)
    // 3: setUniformValueArray(const char*,const QMatrix3x2*,int)
    // 4: setUniformValueArray(const char*,const QMatrix3x3*,int)
    // 5: setUniformValueArray(const char*,const QMatrix3x4*,int)
    // 6: setUniformValueArray(const char*,const QMatrix4x2*,int)
    // 7: setUniformValueArray(const char*,const QMatrix4x3*,int)
    // 8: setUniformValueArray(const char*,const QMatrix4x4*,int)
    // 9: setUniformValueArray(const char*,const QVector2D*,int)
    // 10: setUniformValueArray(const char*,const QVector3D*,int)
    // 11: setUniformValueArray(const char*,const QVector4D*,int)
    // 12: setUniformValueArray(const char*,const float*,int,int)
    // 13: setUniformValueArray(const char*,const int*,int)
    // 14: setUniformValueArray(const char*,const uint*,int)
    // 15: setUniformValueArray(int,const QMatrix2x2*,int)
    // 16: setUniformValueArray(int,const QMatrix2x3*,int)
    // 17: setUniformValueArray(int,const QMatrix2x4*,int)
    // 18: setUniformValueArray(int,const QMatrix3x2*,int)
    // 19: setUniformValueArray(int,const QMatrix3x3*,int)
    // 20: setUniformValueArray(int,const QMatrix3x4*,int)
    // 21: setUniformValueArray(int,const QMatrix4x2*,int)
    // 22: setUniformValueArray(int,const QMatrix4x3*,int)
    // 23: setUniformValueArray(int,const QMatrix4x4*,int)
    // 24: setUniformValueArray(int,const QVector2D*,int)
    // 25: setUniformValueArray(int,const QVector3D*,int)
    // 26: setUniformValueArray(int,const QVector4D*,int)
    // 27: setUniformValueArray(int,const float*,int,int)
    // 28: setUniformValueArray(int,const int*,int)
    // 29: setUniformValueArray(int,const uint*,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 29; // setUniformValueArray(int,const uint*,int)
        } else if (numArgs == 4 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 27; // setUniformValueArray(int,const float*,int,int)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 28; // setUniformValueArray(int,const int*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QVector2D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 24; // setUniformValueArray(int,const QVector2D*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QVector3D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 25; // setUniformValueArray(int,const QVector3D*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QVector4D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 26; // setUniformValueArray(int,const QVector4D*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix4x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 23; // setUniformValueArray(int,const QMatrix4x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix4x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 22; // setUniformValueArray(int,const QMatrix4x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix4x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 21; // setUniformValueArray(int,const QMatrix4x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix3x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 20; // setUniformValueArray(int,const QMatrix3x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix3x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 19; // setUniformValueArray(int,const QMatrix3x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix3x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 18; // setUniformValueArray(int,const QMatrix3x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix2x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 17; // setUniformValueArray(int,const QMatrix2x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix2x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 16; // setUniformValueArray(int,const QMatrix2x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix2x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 15; // setUniformValueArray(int,const QMatrix2x2*,int)
        }
    } else if (Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 14; // setUniformValueArray(const char*,const uint*,int)
        } else if (numArgs == 4 && PyFloat_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 12; // setUniformValueArray(const char*,const float*,int,int)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 13; // setUniformValueArray(const char*,const int*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QVector2D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 9; // setUniformValueArray(const char*,const QVector2D*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QVector3D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 10; // setUniformValueArray(const char*,const QVector3D*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QVector4D * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 11; // setUniformValueArray(const char*,const QVector4D*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix4x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 8; // setUniformValueArray(const char*,const QMatrix4x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix4x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 7; // setUniformValueArray(const char*,const QMatrix4x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix4x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 6; // setUniformValueArray(const char*,const QMatrix4x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix3x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 5; // setUniformValueArray(const char*,const QMatrix3x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix3x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 4; // setUniformValueArray(const char*,const QMatrix3x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix3x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 3; // setUniformValueArray(const char*,const QMatrix3x2*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix2x4 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 2; // setUniformValueArray(const char*,const QMatrix2x4*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix2x3 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // setUniformValueArray(const char*,const QMatrix2x3*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QMatrix2x2 * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // setUniformValueArray(const char*,const QMatrix2x2*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_setUniformValueArray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setUniformValueArray(const char*,const QMatrix2x2*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x2* cpp_arg1 = Shiboken::Converter<QMatrix2x2* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix2x2*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // setUniformValueArray(const char*,const QMatrix2x3*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x3* cpp_arg1 = Shiboken::Converter<QMatrix2x3* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix2x3*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // setUniformValueArray(const char*,const QMatrix2x4*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x4* cpp_arg1 = Shiboken::Converter<QMatrix2x4* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix2x4*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 3: // setUniformValueArray(const char*,const QMatrix3x2*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x2* cpp_arg1 = Shiboken::Converter<QMatrix3x2* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix3x2*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 4: // setUniformValueArray(const char*,const QMatrix3x3*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x3* cpp_arg1 = Shiboken::Converter<QMatrix3x3* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix3x3*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 5: // setUniformValueArray(const char*,const QMatrix3x4*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x4* cpp_arg1 = Shiboken::Converter<QMatrix3x4* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix3x4*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 6: // setUniformValueArray(const char*,const QMatrix4x2*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x2* cpp_arg1 = Shiboken::Converter<QMatrix4x2* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix4x2*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 7: // setUniformValueArray(const char*,const QMatrix4x3*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x3* cpp_arg1 = Shiboken::Converter<QMatrix4x3* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix4x3*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 8: // setUniformValueArray(const char*,const QMatrix4x4*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_arg1_auto_ptr;
                QMatrix4x4* cpp_arg1 = Shiboken::Converter<QMatrix4x4* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg1);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QMatrix4x4*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 9: // setUniformValueArray(const char*,const QVector2D*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QVector2D*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 10: // setUniformValueArray(const char*,const QVector3D*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QVector3D*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 11: // setUniformValueArray(const char*,const QVector4D*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const QVector4D*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 12: // setUniformValueArray(const char*,const float*,int,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                float * cpp_arg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const float*,int,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 13: // setUniformValueArray(const char*,const int*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int * cpp_arg1 = Shiboken::Converter<int * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const int*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 14: // setUniformValueArray(const char*,const uint*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                unsigned int * cpp_arg1 = Shiboken::Converter<unsigned int * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(const char*,const uint*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 15: // setUniformValueArray(int,const QMatrix2x2*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x2* cpp_arg1 = Shiboken::Converter<QMatrix2x2* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix2x2*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 16: // setUniformValueArray(int,const QMatrix2x3*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x3* cpp_arg1 = Shiboken::Converter<QMatrix2x3* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix2x3*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 17: // setUniformValueArray(int,const QMatrix2x4*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix2x4* cpp_arg1 = Shiboken::Converter<QMatrix2x4* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix2x4*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 18: // setUniformValueArray(int,const QMatrix3x2*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x2* cpp_arg1 = Shiboken::Converter<QMatrix3x2* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix3x2*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 19: // setUniformValueArray(int,const QMatrix3x3*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x3* cpp_arg1 = Shiboken::Converter<QMatrix3x3* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix3x3*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 20: // setUniformValueArray(int,const QMatrix3x4*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix3x4* cpp_arg1 = Shiboken::Converter<QMatrix3x4* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix3x4*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 21: // setUniformValueArray(int,const QMatrix4x2*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x2* cpp_arg1 = Shiboken::Converter<QMatrix4x2* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix4x2*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 22: // setUniformValueArray(int,const QMatrix4x3*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QMatrix4x3* cpp_arg1 = Shiboken::Converter<QMatrix4x3* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix4x3*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 23: // setUniformValueArray(int,const QMatrix4x4*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QMatrix4x4 > cpp_arg1_auto_ptr;
                QMatrix4x4* cpp_arg1 = Shiboken::Converter<QMatrix4x4* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QMatrix4x4 >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QMatrix4x4 >(cpp_arg1);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QMatrix4x4*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 24: // setUniformValueArray(int,const QVector2D*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QVector2D* cpp_arg1 = Shiboken::Converter<QVector2D* >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QVector2D*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 25: // setUniformValueArray(int,const QVector3D*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector3D > cpp_arg1_auto_ptr;
                QVector3D* cpp_arg1 = Shiboken::Converter<QVector3D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector3D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector3D >(cpp_arg1);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QVector3D*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 26: // setUniformValueArray(int,const QVector4D*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QVector4D > cpp_arg1_auto_ptr;
                QVector4D* cpp_arg1 = Shiboken::Converter<QVector4D* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QVector4D >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QVector4D >(cpp_arg1);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const QVector4D*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 27: // setUniformValueArray(int,const float*,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                float * cpp_arg1 = Shiboken::Converter<float * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const float*,int,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 28: // setUniformValueArray(int,const int*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int * cpp_arg1 = Shiboken::Converter<int * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const int*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 29: // setUniformValueArray(int,const uint*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                unsigned int * cpp_arg1 = Shiboken::Converter<unsigned int * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setUniformValueArray(int,const uint*,int)
                cppSelf->QGLShaderProgram::setUniformValueArray(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGLShaderProgramFunc_setUniformValueArray_TypeError:
        const char* overloads[] = {"str, PySide.QtGui.QMatrix2x2, int", "str, PySide.QtGui.QMatrix2x3, int", "str, PySide.QtGui.QMatrix2x4, int", "str, PySide.QtGui.QMatrix3x2, int", "str, PySide.QtGui.QMatrix3x3, int", "str, PySide.QtGui.QMatrix3x4, int", "str, PySide.QtGui.QMatrix4x2, int", "str, PySide.QtGui.QMatrix4x3, int", "str, PySide.QtGui.QMatrix4x4, int", "str, PySide.QtGui.QVector2D, int", "str, PySide.QtGui.QVector3D, int", "str, PySide.QtGui.QVector4D, int", "str, float, int, int", "str, int, int", "str, unsigned int, int", "int, PySide.QtGui.QMatrix2x2, int", "int, PySide.QtGui.QMatrix2x3, int", "int, PySide.QtGui.QMatrix2x4, int", "int, PySide.QtGui.QMatrix3x2, int", "int, PySide.QtGui.QMatrix3x3, int", "int, PySide.QtGui.QMatrix3x4, int", "int, PySide.QtGui.QMatrix4x2, int", "int, PySide.QtGui.QMatrix4x3, int", "int, PySide.QtGui.QMatrix4x4, int", "int, PySide.QtGui.QVector2D, int", "int, PySide.QtGui.QVector3D, int", "int, PySide.QtGui.QVector4D, int", "int, float, int, int", "int, int, int", "int, unsigned int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLShaderProgram.setUniformValueArray", overloads);
        return 0;
}

static PyObject* SbkQGLShaderProgramFunc_shaders(PyObject* self)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // shaders()const
            QList<QGLShader * > cppResult = cppSelf->QGLShaderProgram::shaders();
            pyResult = Shiboken::Converter<QList<QGLShader * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGLShaderProgramFunc_uniformLocation(PyObject* self, PyObject* arg)
{
    QGLShaderProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGLShaderProgram* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: uniformLocation(QByteArray)const
    // 1: uniformLocation(QString)const
    // 2: uniformLocation(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 2; // uniformLocation(const char*)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // uniformLocation(QString)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // uniformLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGLShaderProgramFunc_uniformLocation_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // uniformLocation(QByteArray)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // uniformLocation(QByteArray)const
                int cppResult = cppSelf->QGLShaderProgram::uniformLocation(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // uniformLocation(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // uniformLocation(QString)const
                int cppResult = cppSelf->QGLShaderProgram::uniformLocation(cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 2: // uniformLocation(const char*)const
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // uniformLocation(const char*)const
                int cppResult = cppSelf->QGLShaderProgram::uniformLocation(cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGLShaderProgramFunc_uniformLocation_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLShaderProgram.uniformLocation", overloads);
        return 0;
}

static PyMethodDef SbkQGLShaderProgram_methods[] = {
    {"addShader", (PyCFunction)SbkQGLShaderProgramFunc_addShader, METH_O},
    {"addShaderFromSourceCode", (PyCFunction)SbkQGLShaderProgramFunc_addShaderFromSourceCode, METH_VARARGS},
    {"addShaderFromSourceFile", (PyCFunction)SbkQGLShaderProgramFunc_addShaderFromSourceFile, METH_VARARGS},
    {"attributeLocation", (PyCFunction)SbkQGLShaderProgramFunc_attributeLocation, METH_O},
    {"bind", (PyCFunction)SbkQGLShaderProgramFunc_bind, METH_NOARGS},
    {"bindAttributeLocation", (PyCFunction)SbkQGLShaderProgramFunc_bindAttributeLocation, METH_VARARGS},
    {"disableAttributeArray", (PyCFunction)SbkQGLShaderProgramFunc_disableAttributeArray, METH_O},
    {"enableAttributeArray", (PyCFunction)SbkQGLShaderProgramFunc_enableAttributeArray, METH_O},
    {"geometryInputType", (PyCFunction)SbkQGLShaderProgramFunc_geometryInputType, METH_NOARGS},
    {"geometryOutputType", (PyCFunction)SbkQGLShaderProgramFunc_geometryOutputType, METH_NOARGS},
    {"geometryOutputVertexCount", (PyCFunction)SbkQGLShaderProgramFunc_geometryOutputVertexCount, METH_NOARGS},
    {"hasOpenGLShaderPrograms", (PyCFunction)SbkQGLShaderProgramFunc_hasOpenGLShaderPrograms, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"isLinked", (PyCFunction)SbkQGLShaderProgramFunc_isLinked, METH_NOARGS},
    {"link", (PyCFunction)SbkQGLShaderProgramFunc_link, METH_NOARGS},
    {"log", (PyCFunction)SbkQGLShaderProgramFunc_log, METH_NOARGS},
    {"maxGeometryOutputVertices", (PyCFunction)SbkQGLShaderProgramFunc_maxGeometryOutputVertices, METH_NOARGS},
    {"programId", (PyCFunction)SbkQGLShaderProgramFunc_programId, METH_NOARGS},
    {"release", (PyCFunction)SbkQGLShaderProgramFunc_release, METH_NOARGS},
    {"removeAllShaders", (PyCFunction)SbkQGLShaderProgramFunc_removeAllShaders, METH_NOARGS},
    {"removeShader", (PyCFunction)SbkQGLShaderProgramFunc_removeShader, METH_O},
    {"setAttributeArray", (PyCFunction)SbkQGLShaderProgramFunc_setAttributeArray, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeBuffer", (PyCFunction)SbkQGLShaderProgramFunc_setAttributeBuffer, METH_VARARGS|METH_KEYWORDS},
    {"setAttributeValue", (PyCFunction)SbkQGLShaderProgramFunc_setAttributeValue, METH_VARARGS},
    {"setGeometryInputType", (PyCFunction)SbkQGLShaderProgramFunc_setGeometryInputType, METH_O},
    {"setGeometryOutputType", (PyCFunction)SbkQGLShaderProgramFunc_setGeometryOutputType, METH_O},
    {"setGeometryOutputVertexCount", (PyCFunction)SbkQGLShaderProgramFunc_setGeometryOutputVertexCount, METH_O},
    {"setUniformValue", (PyCFunction)SbkQGLShaderProgramFunc_setUniformValue, METH_VARARGS},
    {"setUniformValueArray", (PyCFunction)SbkQGLShaderProgramFunc_setUniformValueArray, METH_VARARGS},
    {"shaders", (PyCFunction)SbkQGLShaderProgramFunc_shaders, METH_NOARGS},
    {"uniformLocation", (PyCFunction)SbkQGLShaderProgramFunc_uniformLocation, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGLShaderProgram_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLShaderProgram",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGLShaderProgram_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGLShaderProgram_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGLShaderProgram >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGLShaderProgram*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGLShaderProgram_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGLShaderProgram*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGLShaderProgram_Type;
    return 0;
}


void init_QGLShaderProgram(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLSHADERPROGRAM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGLShaderProgram_Type);

    SbkQGLShaderProgram_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQGLShaderProgram_Type.type_discovery = &SbkQGLShaderProgram_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQGLShaderProgram_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGLShaderProgram_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGLShaderProgram_Type));
    PyModule_AddObject(module, "QGLShaderProgram",
        ((PyObject*)&SbkQGLShaderProgram_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGLShaderProgram >("QGLShaderProgram*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShaderProgram >(typeid(QGLShaderProgram).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLShaderProgram >(typeid(QGLShaderProgramWrapper).name());
    PySide::initQtMetaType<QGLShaderProgram* >();
}

