/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptclasspropertyiterator_wrapper.h"

// Extra includes
#include <qscriptclasspropertyiterator.h>
#include <qscriptstring.h>
#include <qscriptvalue.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QScriptClassPropertyIteratorWrapper::QScriptClassPropertyIteratorWrapper(const QScriptValue & object) : QScriptClassPropertyIterator(object) {
    // ... middle
}

QFlags<QScriptValue::PropertyFlag> QScriptClassPropertyIteratorWrapper::flags() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "flags"));
    if (py_override.isNull()) {
        return this->QScriptClassPropertyIterator::flags();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QScriptValue::PropertyFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QFlags<QScriptValue::PropertyFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.flags", SbkType<QFlags<QScriptValue::PropertyFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QScriptValue::PropertyFlag>();
    }
    QFlags<QScriptValue::PropertyFlag> cppResult(Shiboken::Converter<QFlags<QScriptValue::PropertyFlag> >::toCpp(pyResult));
    return cppResult;
}

bool QScriptClassPropertyIteratorWrapper::hasNext() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasNext"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasNext()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.hasNext", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QScriptClassPropertyIteratorWrapper::hasPrevious() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasPrevious"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasPrevious()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.hasPrevious", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

uint QScriptClassPropertyIteratorWrapper::id() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "id"));
    if (py_override.isNull()) {
        return this->QScriptClassPropertyIterator::id();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return uint(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.id", "uint", pyResult->ob_type->tp_name);
        return uint(0);
    }
    uint cppResult(Shiboken::Converter<unsigned int >::toCpp(pyResult));
    return cppResult;
}

QScriptString QScriptClassPropertyIteratorWrapper::name() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "name"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.name()' not implemented.");
        return QScriptString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QScriptString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QScriptString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptClassPropertyIterator.name", SbkType<QScriptString >()->tp_name, pyResult->ob_type->tp_name);
        return QScriptString();
    }
    QScriptString cppResult(Shiboken::Converter<QScriptString >::toCpp(pyResult));
    return cppResult;
}

void QScriptClassPropertyIteratorWrapper::next()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "next"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.next()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptClassPropertyIteratorWrapper::previous()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "previous"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.previous()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptClassPropertyIteratorWrapper::toBack()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "toBack"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toBack()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptClassPropertyIteratorWrapper::toFront()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "toFront"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toFront()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QScriptClassPropertyIteratorWrapper::~QScriptClassPropertyIteratorWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQScriptClassPropertyIterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptClassPropertyIterator >()))
        return -1;

    QScriptClassPropertyIteratorWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtScriptTypes[SBK_QSCRIPTCLASSPROPERTYITERATOR_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QScriptClassPropertyIterator' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptClassPropertyIterator", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QScriptClassPropertyIterator(QScriptValue)
    if (numArgs == 1 && Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // QScriptClassPropertyIterator(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptClassPropertyIterator_Init_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // QScriptClassPropertyIterator(QScriptValue)
            cptr = new QScriptClassPropertyIteratorWrapper(*cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptClassPropertyIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQScriptClassPropertyIterator_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQScriptClassPropertyIterator_Init_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptClassPropertyIterator", overloads);
        return -1;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_flags(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flags()const
            QFlags<QScriptValue::PropertyFlag> cppResult = cppSelf->QScriptClassPropertyIterator::flags();
            pyResult = Shiboken::Converter<QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_hasNext(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasNext()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasNext()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->hasNext();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_hasPrevious(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasPrevious()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.hasPrevious()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->hasPrevious();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_id(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // id()const
            uint cppResult = cppSelf->QScriptClassPropertyIterator::id();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_name(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.name()' not implemented.");
                return 0;
            }
            QScriptString cppResult = cppSelf->name();
            pyResult = Shiboken::Converter<QScriptString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_next(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // next()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.next()' not implemented.");
                return 0;
            }
            cppSelf->next();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_object(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // object()const
            QScriptValue cppResult = cppSelf->QScriptClassPropertyIterator::object();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_previous(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // previous()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.previous()' not implemented.");
                return 0;
            }
            cppSelf->previous();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_toBack(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toBack()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toBack()' not implemented.");
                return 0;
            }
            cppSelf->toBack();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptClassPropertyIteratorFunc_toFront(PyObject* self)
{
    QScriptClassPropertyIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptClassPropertyIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toFront()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QScriptClassPropertyIterator.toFront()' not implemented.");
                return 0;
            }
            cppSelf->toFront();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef SbkQScriptClassPropertyIterator_methods[] = {
    {"flags", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_flags, METH_NOARGS},
    {"hasNext", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_hasNext, METH_NOARGS},
    {"hasPrevious", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_hasPrevious, METH_NOARGS},
    {"id", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_id, METH_NOARGS},
    {"name", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_name, METH_NOARGS},
    {"next", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_next, METH_NOARGS},
    {"object", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_object, METH_NOARGS},
    {"previous", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_previous, METH_NOARGS},
    {"toBack", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_toBack, METH_NOARGS},
    {"toFront", (PyCFunction)SbkQScriptClassPropertyIteratorFunc_toFront, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQScriptClassPropertyIterator_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptClassPropertyIterator",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQScriptClassPropertyIterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQScriptClassPropertyIterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QScriptClassPropertyIterator >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QScriptClassPropertyIterator*",
    /*user_data*/           0
};
} //extern


void init_QScriptClassPropertyIterator(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTCLASSPROPERTYITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQScriptClassPropertyIterator_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQScriptClassPropertyIterator_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQScriptClassPropertyIterator_Type));
    PyModule_AddObject(module, "QScriptClassPropertyIterator",
        ((PyObject*)&SbkQScriptClassPropertyIterator_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptClassPropertyIterator >("QScriptClassPropertyIterator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptClassPropertyIterator >(typeid(QScriptClassPropertyIterator).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptClassPropertyIterator >(typeid(QScriptClassPropertyIteratorWrapper).name());
    PySide::initQtMetaType<QScriptClassPropertyIterator* >();
}

