/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtscript_python.h"

#include "qscriptengine_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregexp.h>
#include <qscriptclass.h>
#include <qscriptcontext.h>
#include <qscriptengine.h>
#include <qscriptengineagent.h>
#include <qscriptprogram.h>
#include <qscriptstring.h>
#include <qscriptvalue.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QScriptEngineWrapper::QScriptEngineWrapper() : QScriptEngine(), m_metaObject(0) {
    // ... middle
}

QScriptEngineWrapper::QScriptEngineWrapper(QObject * parent) : QScriptEngine(parent), m_metaObject(0) {
    // ... middle
}

void QScriptEngineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QScriptEngineWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QScriptEngineWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QScriptEngineWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QScriptEngineWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QScriptEngine::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QScriptEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QScriptEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QScriptEngineWrapper::~QScriptEngineWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQScriptEngine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptEngine >()))
        return -1;

    QScriptEngineWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
                propertyKeys.push_back(argName);
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptEngine", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QScriptEngine()
    // 1: QScriptEngine(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QScriptEngine()
    } else if (numArgs == 1 && Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 1; // QScriptEngine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngine_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QScriptEngine()
            {

                if(!PyErr_Occurred()) {
                // QScriptEngine()
                cptr = new QScriptEngineWrapper();
                }
                break;
            }
            case 1: // QScriptEngine(QObject*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QScriptEngine(QObject*)
                cptr = new QScriptEngineWrapper(cpp_arg0);
                Shiboken::setParent(arg, self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQScriptEngine_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQScriptEngine_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine", overloads);
        return -1;
}

static PyObject* SbkQScriptEngineFunc_abortEvaluation(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "result" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.abortEvaluation(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.abortEvaluation(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:abortEvaluation", &arg))
        return 0;


    // Overloaded function decisor
    // 0: abortEvaluation(QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // abortEvaluation(QScriptValue)
    } else if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // abortEvaluation(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_abortEvaluation_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "result");
                if (value) {
                    if (arg)
                        errorArgName = "result";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.abortEvaluation(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue cpp_arg0_tmp = QScriptValue();
            QScriptValue* cpp_arg0 = arg ? Shiboken::Converter<QScriptValue* >::toCpp(arg) : &cpp_arg0_tmp;
            if (arg && !Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // abortEvaluation(QScriptValue)
            cppSelf->QScriptEngine::abortEvaluation(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineFunc_abortEvaluation_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.abortEvaluation", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_agent(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // agent()const
            QScriptEngineAgent * cppResult = cppSelf->QScriptEngine::agent();
            pyResult = Shiboken::Converter<QScriptEngineAgent * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_availableExtensions(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // availableExtensions()const
            QStringList cppResult = cppSelf->QScriptEngine::availableExtensions();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_canEvaluate(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: canEvaluate(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // canEvaluate(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_canEvaluate_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // canEvaluate(QString)const
            bool cppResult = cppSelf->QScriptEngine::canEvaluate(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_canEvaluate_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.canEvaluate", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_clearExceptions(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearExceptions()
            cppSelf->QScriptEngine::clearExceptions();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptEngineFunc_collectGarbage(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // collectGarbage()
            cppSelf->QScriptEngine::collectGarbage();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptEngineFunc_currentContext(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentContext()const
            QScriptContext * cppResult = cppSelf->QScriptEngine::currentContext();
            pyResult = Shiboken::Converter<QScriptContext * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_defaultPrototype(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: defaultPrototype(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // defaultPrototype(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_defaultPrototype_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // defaultPrototype(int)const
            QScriptValue cppResult = cppSelf->QScriptEngine::defaultPrototype(cpp_arg0);
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_defaultPrototype_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.defaultPrototype", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_evaluate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fileName", "lineNumber" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.evaluate(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.evaluate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.evaluate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:evaluate", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: evaluate(QScriptProgram)
    // 1: evaluate(QString,QString,int)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // evaluate(QString,QString,int)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // evaluate(QString,QString,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // evaluate(QString,QString,int)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< QScriptProgram & >::isConvertible(pyargs[0])) {
        overloadId = 0; // evaluate(QScriptProgram)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_evaluate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // evaluate(QScriptProgram)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QScriptProgram* cpp_arg0 = Shiboken::Converter<QScriptProgram* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // evaluate(QScriptProgram)
                QScriptValue cppResult = cppSelf->QScriptEngine::evaluate(*cpp_arg0);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // evaluate(QString,QString,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fileName");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fileName";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "lineNumber");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "lineNumber";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.evaluate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 1;

                if(!PyErr_Occurred()) {
                // evaluate(QString,QString,int)
                QScriptValue cppResult = cppSelf->QScriptEngine::evaluate(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_evaluate_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptProgram", "QString, QString = QString(), int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.evaluate", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_globalObject(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // globalObject()const
            QScriptValue cppResult = cppSelf->QScriptEngine::globalObject();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_hasUncaughtException(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasUncaughtException()const
            bool cppResult = cppSelf->QScriptEngine::hasUncaughtException();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_importExtension(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: importExtension(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // importExtension(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_importExtension_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // importExtension(QString)
            QScriptValue cppResult = cppSelf->QScriptEngine::importExtension(cpp_arg0);
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_importExtension_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.importExtension", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_importedExtensions(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // importedExtensions()const
            QStringList cppResult = cppSelf->QScriptEngine::importedExtensions();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_installTranslatorFunctions(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "object" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.installTranslatorFunctions(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.installTranslatorFunctions(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:installTranslatorFunctions", &arg))
        return 0;


    // Overloaded function decisor
    // 0: installTranslatorFunctions(QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // installTranslatorFunctions(QScriptValue)
    } else if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // installTranslatorFunctions(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_installTranslatorFunctions_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "object");
                if (value) {
                    if (arg)
                        errorArgName = "object";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.installTranslatorFunctions(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue cpp_arg0_tmp = QScriptValue();
            QScriptValue* cpp_arg0 = arg ? Shiboken::Converter<QScriptValue* >::toCpp(arg) : &cpp_arg0_tmp;
            if (arg && !Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // installTranslatorFunctions(QScriptValue)
            cppSelf->QScriptEngine::installTranslatorFunctions(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineFunc_installTranslatorFunctions_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.installTranslatorFunctions", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_isEvaluating(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEvaluating()const
            bool cppResult = cppSelf->QScriptEngine::isEvaluating();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_newActivationObject(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // newActivationObject()
            QScriptValue cppResult = cppSelf->QScriptEngine::newActivationObject();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_newArray(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "length" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newArray(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newArray(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:newArray", &arg))
        return 0;


    // Overloaded function decisor
    // 0: newArray(uint)
    if (numArgs == 0) {
        overloadId = 0; // newArray(uint)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // newArray(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_newArray_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "length");
                if (value) {
                    if (arg)
                        errorArgName = "length";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newArray(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            uint cpp_arg0 = arg ? Shiboken::Converter<uint >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // newArray(uint)
            QScriptValue cppResult = cppSelf->QScriptEngine::newArray(cpp_arg0);
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_newArray_TypeError:
        const char* overloads[] = {"unsigned int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.newArray", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_newDate(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: newDate(QDateTime)
    // 1: newDate(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 1; // newDate(double)
    } else if (Shiboken::Converter<const QDateTime & >::isConvertible(arg)) {
        overloadId = 0; // newDate(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_newDate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newDate(QDateTime)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QDateTime* cpp_arg0 = Shiboken::Converter<QDateTime* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // newDate(QDateTime)
                QScriptValue cppResult = cppSelf->QScriptEngine::newDate(*cpp_arg0);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newDate(double)
            {
                double cpp_arg0 = Shiboken::Converter<double >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // newDate(double)
                QScriptValue cppResult = cppSelf->QScriptEngine::newDate(cpp_arg0);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_newDate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDateTime", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.newDate", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_newObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "data" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newObject(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newObject(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:newObject", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newObject()
    // 1: newObject(QScriptClass*,QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // newObject()
    } else if (Shiboken::Converter<QScriptClass * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // newObject(QScriptClass*,QScriptValue)
        } else if (Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
            overloadId = 1; // newObject(QScriptClass*,QScriptValue)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_newObject_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newObject()
            {

                if(!PyErr_Occurred()) {
                // newObject()
                QScriptValue cppResult = cppSelf->QScriptEngine::newObject();
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newObject(QScriptClass*,QScriptValue)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "data");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "data";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QScriptClass* cpp_arg0 = Shiboken::Converter<QScriptClass* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
                QScriptValue cpp_arg1_tmp = QScriptValue();
                QScriptValue* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // newObject(QScriptClass*,QScriptValue)
                QScriptValue cppResult = cppSelf->QScriptEngine::newObject(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_newObject_TypeError:
        const char* overloads[] = {"", "PySide.QtScript.QScriptClass, PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newObject", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_newQMetaObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "ctor" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQMetaObject(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQMetaObject(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQMetaObject(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:newQMetaObject", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newQMetaObject(const QMetaObject*,QScriptValue)
    if (Shiboken::Converter< QMetaObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // newQMetaObject(const QMetaObject*,QScriptValue)
        } else if (Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
            overloadId = 0; // newQMetaObject(const QMetaObject*,QScriptValue)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_newQMetaObject_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "ctor");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "ctor";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQMetaObject(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QMetaObject* cpp_arg0 = Shiboken::Converter<QMetaObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
            QScriptValue cpp_arg1_tmp = QScriptValue();
            QScriptValue* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // newQMetaObject(const QMetaObject*,QScriptValue)
            QScriptValue cppResult = cppSelf->QScriptEngine::newQMetaObject(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_newQMetaObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMetaObject, PySide.QtScript.QScriptValue = QScriptValue()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newQMetaObject", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_newQObject(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "options", "ownership" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:newQObject", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
    // 1: newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
    if (numArgs >= 2 && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
        } else if (Shiboken::Converter<QScriptEngine::ValueOwnership >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            } else if (Shiboken::Converter<const QFlags<QScriptEngine::QObjectWrapOption> & >::isConvertible(pyargs[3])) {
                overloadId = 1; // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            }
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
        } else if (Shiboken::Converter<QScriptEngine::ValueOwnership >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            } else if (Shiboken::Converter<const QFlags<QScriptEngine::QObjectWrapOption> & >::isConvertible(pyargs[2])) {
                overloadId = 0; // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_newQObject_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "ownership");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "ownership";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
                QScriptEngine::ValueOwnership cpp_arg1 = pyargs[1] ? Shiboken::Converter<QScriptEngine::ValueOwnership >::toCpp(pyargs[1]) : QScriptEngine::QtOwnership;
                const QFlags<QScriptEngine::QObjectWrapOption> & cpp_arg2 = pyargs[2] ? Shiboken::Converter<const QFlags<QScriptEngine::QObjectWrapOption> & >::toCpp(pyargs[2]) : QFlags<QScriptEngine::QObjectWrapOption> (0);

                if(!PyErr_Occurred()) {
                // newQObject(QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
                QScriptValue cppResult = cppSelf->QScriptEngine::newQObject(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "ownership");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "ownership";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "options";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngine.newQObject(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
                QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);
                QScriptEngine::ValueOwnership cpp_arg2 = pyargs[2] ? Shiboken::Converter<QScriptEngine::ValueOwnership >::toCpp(pyargs[2]) : QScriptEngine::QtOwnership;
                const QFlags<QScriptEngine::QObjectWrapOption> & cpp_arg3 = pyargs[3] ? Shiboken::Converter<const QFlags<QScriptEngine::QObjectWrapOption> & >::toCpp(pyargs[3]) : QFlags<QScriptEngine::QObjectWrapOption> (0);

                if(!PyErr_Occurred()) {
                // newQObject(QScriptValue,QObject*,QScriptEngine::ValueOwnership,QFlags<QScriptEngine::QObjectWrapOption>)
                QScriptValue cppResult = cppSelf->QScriptEngine::newQObject(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_newQObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtScript.QScriptEngine.ValueOwnership = QtOwnership, PySide.QtScript.QScriptEngine.QObjectWrapOptions = 0", "PySide.QtScript.QScriptValue, PySide.QtCore.QObject, PySide.QtScript.QScriptEngine.ValueOwnership = QtOwnership, PySide.QtScript.QScriptEngine.QObjectWrapOptions = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newQObject", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_newRegExp(PyObject* self, PyObject* args)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "newRegExp", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newRegExp(QRegExp)
    // 1: newRegExp(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // newRegExp(QString,QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QRegExp & >::isConvertible(pyargs[0])) {
        overloadId = 0; // newRegExp(QRegExp)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_newRegExp_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newRegExp(QRegExp)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRegExp* cpp_arg0 = Shiboken::Converter<QRegExp* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // newRegExp(QRegExp)
                QScriptValue cppResult = cppSelf->QScriptEngine::newRegExp(*cpp_arg0);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newRegExp(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // newRegExp(QString,QString)
                QScriptValue cppResult = cppSelf->QScriptEngine::newRegExp(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_newRegExp_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newRegExp", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_newVariant(PyObject* self, PyObject* args)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "newVariant", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: newVariant(QScriptValue,QVariant)
    // 1: newVariant(QVariant)
    if (numArgs == 1 && Shiboken::Converter<QVariant >::isConvertible(pyargs[0])) {
        overloadId = 1; // newVariant(QVariant)
    } else if (numArgs == 2 && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[0]) && Shiboken::Converter<QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // newVariant(QScriptValue,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_newVariant_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // newVariant(QScriptValue,QVariant)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
                QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);
                QVariant cpp_arg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // newVariant(QScriptValue,QVariant)
                QScriptValue cppResult = cppSelf->QScriptEngine::newVariant(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // newVariant(QVariant)
            {
                QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // newVariant(QVariant)
                QScriptValue cppResult = cppSelf->QScriptEngine::newVariant(cpp_arg0);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_newVariant_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue, QVariant", "QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.newVariant", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_nullValue(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nullValue()
            QScriptValue cppResult = cppSelf->QScriptEngine::nullValue();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_objectById(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectById(qint64)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // objectById(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_objectById_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // objectById(qint64)const
            QScriptValue cppResult = cppSelf->QScriptEngine::objectById(cpp_arg0);
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_objectById_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.objectById", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_popContext(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // popContext()
            cppSelf->QScriptEngine::popContext();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptEngineFunc_processEventsInterval(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // processEventsInterval()const
            int cppResult = cppSelf->QScriptEngine::processEventsInterval();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_pushContext(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pushContext()
            QScriptContext * cppResult = cppSelf->QScriptEngine::pushContext();
            pyResult = Shiboken::Converter<QScriptContext * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_reportAdditionalMemoryCost(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reportAdditionalMemoryCost(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // reportAdditionalMemoryCost(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_reportAdditionalMemoryCost_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // reportAdditionalMemoryCost(int)
            cppSelf->QScriptEngine::reportAdditionalMemoryCost(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineFunc_reportAdditionalMemoryCost_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.reportAdditionalMemoryCost", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_setAgent(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAgent(QScriptEngineAgent*)
    if (Shiboken::Converter<QScriptEngineAgent * >::isConvertible(arg)) {
        overloadId = 0; // setAgent(QScriptEngineAgent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_setAgent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QScriptEngineAgent* cpp_arg0 = Shiboken::Converter<QScriptEngineAgent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAgent(QScriptEngineAgent*)
            cppSelf->QScriptEngine::setAgent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineFunc_setAgent_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngineAgent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.setAgent", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_setDefaultPrototype(PyObject* self, PyObject* args)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDefaultPrototype", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setDefaultPrototype(int,QScriptValue)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setDefaultPrototype(int,QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_setDefaultPrototype_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
            QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setDefaultPrototype(int,QScriptValue)
            cppSelf->QScriptEngine::setDefaultPrototype(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineFunc_setDefaultPrototype_TypeError:
        const char* overloads[] = {"int, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngine.setDefaultPrototype", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_setGlobalObject(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGlobalObject(QScriptValue)
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // setGlobalObject(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_setGlobalObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setGlobalObject(QScriptValue)
            cppSelf->QScriptEngine::setGlobalObject(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineFunc_setGlobalObject_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.setGlobalObject", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_setProcessEventsInterval(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessEventsInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setProcessEventsInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_setProcessEventsInterval_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setProcessEventsInterval(int)
            cppSelf->QScriptEngine::setProcessEventsInterval(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineFunc_setProcessEventsInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.setProcessEventsInterval", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_toObject(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toObject(QScriptValue)
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // toObject(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_toObject_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // toObject(QScriptValue)
            QScriptValue cppResult = cppSelf->QScriptEngine::toObject(*cpp_arg0);
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_toObject_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.toObject", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_toStringHandle(PyObject* self, PyObject* arg)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toStringHandle(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // toStringHandle(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineFunc_toStringHandle_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toStringHandle(QString)
            QScriptString cppResult = cppSelf->QScriptEngine::toStringHandle(cpp_arg0);
            pyResult = Shiboken::Converter<QScriptString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineFunc_toStringHandle_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngine.toStringHandle", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineFunc_uncaughtException(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // uncaughtException()const
            QScriptValue cppResult = cppSelf->QScriptEngine::uncaughtException();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_uncaughtExceptionBacktrace(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // uncaughtExceptionBacktrace()const
            QStringList cppResult = cppSelf->QScriptEngine::uncaughtExceptionBacktrace();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_uncaughtExceptionLineNumber(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // uncaughtExceptionLineNumber()const
            int cppResult = cppSelf->QScriptEngine::uncaughtExceptionLineNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineFunc_undefinedValue(PyObject* self)
{
    QScriptEngine* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // undefinedValue()
            QScriptValue cppResult = cppSelf->QScriptEngine::undefinedValue();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQScriptEngine_methods[] = {
    {"abortEvaluation", (PyCFunction)SbkQScriptEngineFunc_abortEvaluation, METH_VARARGS|METH_KEYWORDS},
    {"agent", (PyCFunction)SbkQScriptEngineFunc_agent, METH_NOARGS},
    {"availableExtensions", (PyCFunction)SbkQScriptEngineFunc_availableExtensions, METH_NOARGS},
    {"canEvaluate", (PyCFunction)SbkQScriptEngineFunc_canEvaluate, METH_O},
    {"clearExceptions", (PyCFunction)SbkQScriptEngineFunc_clearExceptions, METH_NOARGS},
    {"collectGarbage", (PyCFunction)SbkQScriptEngineFunc_collectGarbage, METH_NOARGS},
    {"currentContext", (PyCFunction)SbkQScriptEngineFunc_currentContext, METH_NOARGS},
    {"defaultPrototype", (PyCFunction)SbkQScriptEngineFunc_defaultPrototype, METH_O},
    {"evaluate", (PyCFunction)SbkQScriptEngineFunc_evaluate, METH_VARARGS|METH_KEYWORDS},
    {"globalObject", (PyCFunction)SbkQScriptEngineFunc_globalObject, METH_NOARGS},
    {"hasUncaughtException", (PyCFunction)SbkQScriptEngineFunc_hasUncaughtException, METH_NOARGS},
    {"importExtension", (PyCFunction)SbkQScriptEngineFunc_importExtension, METH_O},
    {"importedExtensions", (PyCFunction)SbkQScriptEngineFunc_importedExtensions, METH_NOARGS},
    {"installTranslatorFunctions", (PyCFunction)SbkQScriptEngineFunc_installTranslatorFunctions, METH_VARARGS|METH_KEYWORDS},
    {"isEvaluating", (PyCFunction)SbkQScriptEngineFunc_isEvaluating, METH_NOARGS},
    {"newActivationObject", (PyCFunction)SbkQScriptEngineFunc_newActivationObject, METH_NOARGS},
    {"newArray", (PyCFunction)SbkQScriptEngineFunc_newArray, METH_VARARGS|METH_KEYWORDS},
    {"newDate", (PyCFunction)SbkQScriptEngineFunc_newDate, METH_O},
    {"newObject", (PyCFunction)SbkQScriptEngineFunc_newObject, METH_VARARGS|METH_KEYWORDS},
    {"newQMetaObject", (PyCFunction)SbkQScriptEngineFunc_newQMetaObject, METH_VARARGS|METH_KEYWORDS},
    {"newQObject", (PyCFunction)SbkQScriptEngineFunc_newQObject, METH_VARARGS|METH_KEYWORDS},
    {"newRegExp", (PyCFunction)SbkQScriptEngineFunc_newRegExp, METH_VARARGS},
    {"newVariant", (PyCFunction)SbkQScriptEngineFunc_newVariant, METH_VARARGS},
    {"nullValue", (PyCFunction)SbkQScriptEngineFunc_nullValue, METH_NOARGS},
    {"objectById", (PyCFunction)SbkQScriptEngineFunc_objectById, METH_O},
    {"popContext", (PyCFunction)SbkQScriptEngineFunc_popContext, METH_NOARGS},
    {"processEventsInterval", (PyCFunction)SbkQScriptEngineFunc_processEventsInterval, METH_NOARGS},
    {"pushContext", (PyCFunction)SbkQScriptEngineFunc_pushContext, METH_NOARGS},
    {"reportAdditionalMemoryCost", (PyCFunction)SbkQScriptEngineFunc_reportAdditionalMemoryCost, METH_O},
    {"setAgent", (PyCFunction)SbkQScriptEngineFunc_setAgent, METH_O},
    {"setDefaultPrototype", (PyCFunction)SbkQScriptEngineFunc_setDefaultPrototype, METH_VARARGS},
    {"setGlobalObject", (PyCFunction)SbkQScriptEngineFunc_setGlobalObject, METH_O},
    {"setProcessEventsInterval", (PyCFunction)SbkQScriptEngineFunc_setProcessEventsInterval, METH_O},
    {"toObject", (PyCFunction)SbkQScriptEngineFunc_toObject, METH_O},
    {"toStringHandle", (PyCFunction)SbkQScriptEngineFunc_toStringHandle, METH_O},
    {"uncaughtException", (PyCFunction)SbkQScriptEngineFunc_uncaughtException, METH_NOARGS},
    {"uncaughtExceptionBacktrace", (PyCFunction)SbkQScriptEngineFunc_uncaughtExceptionBacktrace, METH_NOARGS},
    {"uncaughtExceptionLineNumber", (PyCFunction)SbkQScriptEngineFunc_uncaughtExceptionLineNumber, METH_NOARGS},
    {"undefinedValue", (PyCFunction)SbkQScriptEngineFunc_undefinedValue, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQScriptEngine_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptEngine",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQScriptEngine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQScriptEngine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QScriptEngine >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QScriptEngine*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQScriptEngine_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QScriptEngine*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQScriptEngine_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtScript_QScriptEngine_ValueOwnership_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScript_QScriptEngine_ValueOwnership_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ValueOwnership",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScript_QScriptEngine_ValueOwnership_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScript_QScriptEngine_ValueOwnership_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScript_QScriptEngine_ValueOwnership_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::checkType(self) && Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        Shiboken::Converter<QScriptEngine::QObjectWrapOptions>::toCpp(self)
        & Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::checkType(self) && Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        Shiboken::Converter<QScriptEngine::QObjectWrapOptions>::toCpp(self)
        | Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::checkType(self) && Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        Shiboken::Converter<QScriptEngine::QObjectWrapOptions>::toCpp(self)
        ^ Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QScriptEngine::QObjectWrapOptions >::toPython(
        ~Shiboken::Converter<QScriptEngine::QObjectWrapOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtScript_QScriptEngine_QObjectWrapOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QObjectWrapOption",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QObjectWrapOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QScriptEngine(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQScriptEngine_Type);

    SbkQScriptEngine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQScriptEngine_Type.type_discovery = &SbkQScriptEngine_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQScriptEngine_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQScriptEngine_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQScriptEngine_Type));
    PyModule_AddObject(module, "QScriptEngine",
        ((PyObject*)&SbkQScriptEngine_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ValueOwnership
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINE_VALUEOWNERSHIP_IDX] = &SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type);
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
            "ValueOwnership",((PyObject*)&SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type,
        (long) QScriptEngine::QtOwnership, "QtOwnership");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "QtOwnership", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type.tp_dict,
        "QtOwnership", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type,
        (long) QScriptEngine::ScriptOwnership, "ScriptOwnership");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "ScriptOwnership", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type.tp_dict,
        "ScriptOwnership", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type,
        (long) QScriptEngine::AutoOwnership, "AutoOwnership");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "AutoOwnership", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_ValueOwnership_Type.tp_dict,
        "AutoOwnership", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngine::ValueOwnership");

    // init enum class: QObjectWrapOption
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINE_QOBJECTWRAPOPTION_IDX] = &SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type);
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
            "QObjectWrapOption",((PyObject*)&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type));

    // init flags class: QFlags<QScriptEngine::QObjectWrapOption>
    SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTENGINE_QOBJECTWRAPOPTION__IDX] = &SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type);
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
            "QObjectWrapOptions",((PyObject*)&SbkPySide_QtScript_QScriptEngine_QObjectWrapOptions_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::ExcludeChildObjects, "ExcludeChildObjects");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "ExcludeChildObjects", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "ExcludeChildObjects", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::ExcludeSuperClassMethods, "ExcludeSuperClassMethods");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "ExcludeSuperClassMethods", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "ExcludeSuperClassMethods", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::ExcludeSuperClassProperties, "ExcludeSuperClassProperties");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "ExcludeSuperClassProperties", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "ExcludeSuperClassProperties", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::ExcludeSuperClassContents, "ExcludeSuperClassContents");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "ExcludeSuperClassContents", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "ExcludeSuperClassContents", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::SkipMethodsInEnumeration, "SkipMethodsInEnumeration");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "SkipMethodsInEnumeration", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "SkipMethodsInEnumeration", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::ExcludeDeleteLater, "ExcludeDeleteLater");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "ExcludeDeleteLater", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "ExcludeDeleteLater", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::ExcludeSlots, "ExcludeSlots");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "ExcludeSlots", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "ExcludeSlots", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::AutoCreateDynamicProperties, "AutoCreateDynamicProperties");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "AutoCreateDynamicProperties", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "AutoCreateDynamicProperties", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type,
        (long) QScriptEngine::PreferExistingWrapperObject, "PreferExistingWrapperObject");
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict,
        "PreferExistingWrapperObject", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngine_QObjectWrapOption_Type.tp_dict,
        "PreferExistingWrapperObject", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngine::QObjectWrapOption");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("signalHandlerException", "const QScriptValue&", NULL);
    PyDict_SetItemString(SbkQScriptEngine_Type.super.ht_type.tp_dict, "signalHandlerException", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngine >("QScriptEngine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngine >(typeid(QScriptEngine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngine >(typeid(QScriptEngineWrapper).name());
    PySide::initQtMetaType<QScriptEngine* >();
}

