/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptprogram_wrapper.h"

// Extra includes
#include <qscriptprogram.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQScriptProgram_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptProgram >()))
        return -1;

    QScriptProgram* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fileName", "firstLineNumber" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptProgram(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptProgram(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QScriptProgram", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptProgram()
    // 1: QScriptProgram(QScriptProgram)
    // 2: QScriptProgram(QString,QString,int)
    if (numArgs == 0) {
        overloadId = 0; // QScriptProgram()
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QScriptProgram(QString,QString,int)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QScriptProgram(QString,QString,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 2; // QScriptProgram(QString,QString,int)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< QScriptProgram & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QScriptProgram(QScriptProgram)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptProgram_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QScriptProgram()
            {

                if(!PyErr_Occurred()) {
                // QScriptProgram()
                cptr = new QScriptProgram();
                }
                break;
            }
            case 1: // QScriptProgram(QScriptProgram)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptProgram* cpp_arg0 = Shiboken::Converter<QScriptProgram* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptProgram(QScriptProgram)
                cptr = new QScriptProgram(*cpp_arg0);
                }
                break;
            }
            case 2: // QScriptProgram(QString,QString,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fileName");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fileName";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "firstLineNumber");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "firstLineNumber";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptProgram(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 1;

                if(!PyErr_Occurred()) {
                // QScriptProgram(QString,QString,int)
                cptr = new QScriptProgram(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptProgram >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQScriptProgram_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQScriptProgram_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtScript.QScriptProgram", "QString, QString = QString(), int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptProgram", overloads);
        return -1;
}

static PyObject* SbkQScriptProgramFunc_fileName(PyObject* self)
{
    QScriptProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->QScriptProgram::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptProgramFunc_firstLineNumber(PyObject* self)
{
    QScriptProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // firstLineNumber()const
            int cppResult = cppSelf->QScriptProgram::firstLineNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptProgramFunc_isNull(PyObject* self)
{
    QScriptProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QScriptProgram::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptProgramFunc_sourceCode(PyObject* self)
{
    QScriptProgram* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptProgram* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sourceCode()const
            QString cppResult = cppSelf->QScriptProgram::sourceCode();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQScriptProgram_methods[] = {
    {"fileName", (PyCFunction)SbkQScriptProgramFunc_fileName, METH_NOARGS},
    {"firstLineNumber", (PyCFunction)SbkQScriptProgramFunc_firstLineNumber, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQScriptProgramFunc_isNull, METH_NOARGS},
    {"sourceCode", (PyCFunction)SbkQScriptProgramFunc_sourceCode, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQScriptProgram_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QScriptProgram& cpp_self = *Shiboken::Converter<QScriptProgram* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< QScriptProgram & >::isConvertible(other)) {
                // operator!=(const QScriptProgram & other) const
                const QScriptProgram & cpp_other = Shiboken::Converter< QScriptProgram & >::toCpp(other);
                result = (cpp_self != cpp_other);
            } else if (Shiboken::Converter<QScriptProgram* >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                QScriptProgram* cpp_other = Shiboken::Converter<QScriptProgram* >::toCpp(other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQScriptProgram_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< QScriptProgram & >::isConvertible(other)) {
                // operator==(const QScriptProgram & other) const
                const QScriptProgram & cpp_other = Shiboken::Converter< QScriptProgram & >::toCpp(other);
                result = (cpp_self == cpp_other);
            } else if (Shiboken::Converter<QScriptProgram* >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                QScriptProgram* cpp_other = Shiboken::Converter<QScriptProgram* >::toCpp(other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQScriptProgram_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQScriptProgram_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQScriptProgram_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptProgram",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQScriptProgram_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQScriptProgram_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQScriptProgram_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QScriptProgram >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QScriptProgram*",
    /*user_data*/           0
};
} //extern


void init_QScriptProgram(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTPROGRAM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQScriptProgram_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQScriptProgram_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQScriptProgram_Type));
    PyModule_AddObject(module, "QScriptProgram",
        ((PyObject*)&SbkQScriptProgram_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptProgram >("QScriptProgram*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptProgram >(typeid(QScriptProgram).name());
    PySide::initQtMetaType<QScriptProgram* >();
}

