/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptvalue_wrapper.h"

// Extra includes
#include <QList>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qregexp.h>
#include <qscriptclass.h>
#include <qscriptengine.h>
#include <qscriptstring.h>
#include <qscriptvalue.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQScriptValue_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptValue >()))
        return -1;

    QScriptValue* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptValue", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptValue()
    // 1: QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
    // 2: QScriptValue(QScriptEngine*,bool)
    // 3: QScriptValue(QScriptEngine*,QString)
    // 4: QScriptValue(QScriptEngine*,const char*)
    // 5: QScriptValue(QScriptEngine*,double)
    // 6: QScriptValue(QScriptEngine*,int)
    // 7: QScriptValue(QScriptEngine*,uint)
    // 8: QScriptValue(QScriptValue::SpecialValue)
    // 9: QScriptValue(bool)
    // 10: QScriptValue(QScriptValue)
    // 11: QScriptValue(QString)
    // 12: QScriptValue(const char*)
    // 13: QScriptValue(double)
    // 14: QScriptValue(int)
    // 15: QScriptValue(uint)
    if (numArgs == 0) {
        overloadId = 0; // QScriptValue()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 11; // QScriptValue(QString)
    } else if (numArgs == 1 && Shiboken::Converter<QScriptValue::SpecialValue >::isConvertible(pyargs[0])) {
        overloadId = 8; // QScriptValue(QScriptValue::SpecialValue)
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 15; // QScriptValue(uint)
    } else if (numArgs == 1 && PyFloat_Check(pyargs[0])) {
        overloadId = 13; // QScriptValue(double)
    } else if (numArgs == 1 && Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        overloadId = 12; // QScriptValue(const char*)
    } else if (numArgs == 1 && PyBool_Check(pyargs[0])) {
        overloadId = 9; // QScriptValue(bool)
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 14; // QScriptValue(int)
    } else if (numArgs == 1 && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[0])) {
        overloadId = 10; // QScriptValue(QScriptValue)
    } else if (Shiboken::Converter<QScriptEngine * >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 3; // QScriptValue(QScriptEngine*,QString)
        } else if (numArgs == 2 && Shiboken::Converter<QScriptValue::SpecialValue >::isConvertible(pyargs[1])) {
            overloadId = 1; // QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 7; // QScriptValue(QScriptEngine*,uint)
        } else if (numArgs == 2 && PyFloat_Check(pyargs[1])) {
            overloadId = 5; // QScriptValue(QScriptEngine*,double)
        } else if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[1])) {
            overloadId = 4; // QScriptValue(QScriptEngine*,const char*)
        } else if (numArgs == 2 && PyBool_Check(pyargs[1])) {
            overloadId = 2; // QScriptValue(QScriptEngine*,bool)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 6; // QScriptValue(QScriptEngine*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValue_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QScriptValue()
            {

                if(!PyErr_Occurred()) {
                // QScriptValue()
                cptr = new QScriptValue();
                }
                break;
            }
            case 1: // QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(pyargs[0]);
                QScriptValue::SpecialValue cpp_arg1 = Shiboken::Converter<QScriptValue::SpecialValue >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,QScriptValue::SpecialValue)
                cptr = new QScriptValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // QScriptValue(QScriptEngine*,bool)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(pyargs[0]);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,bool)
                cptr = new QScriptValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // QScriptValue(QScriptEngine*,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,QString)
                cptr = new QScriptValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 4: // QScriptValue(QScriptEngine*,const char*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,const char*)
                cptr = new QScriptValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 5: // QScriptValue(QScriptEngine*,double)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(pyargs[0]);
                double cpp_arg1 = Shiboken::Converter<double >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,double)
                cptr = new QScriptValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 6: // QScriptValue(QScriptEngine*,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,int)
                cptr = new QScriptValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 7: // QScriptValue(QScriptEngine*,uint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(pyargs[0]);
                uint cpp_arg1 = Shiboken::Converter<uint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptEngine*,uint)
                cptr = new QScriptValue(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 8: // QScriptValue(QScriptValue::SpecialValue)
            {
                QScriptValue::SpecialValue cpp_arg0 = Shiboken::Converter<QScriptValue::SpecialValue >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptValue::SpecialValue)
                cptr = new QScriptValue(cpp_arg0);
                }
                break;
            }
            case 9: // QScriptValue(bool)
            {
                bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptValue(bool)
                cptr = new QScriptValue(cpp_arg0);
                }
                break;
            }
            case 10: // QScriptValue(QScriptValue)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
                QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QScriptValue(QScriptValue)
                cptr = new QScriptValue(*cpp_arg0);
                }
                break;
            }
            case 11: // QScriptValue(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptValue(QString)
                cptr = new QScriptValue(cpp_arg0);
                }
                break;
            }
            case 12: // QScriptValue(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptValue(const char*)
                cptr = new QScriptValue(cpp_arg0);
                }
                break;
            }
            case 13: // QScriptValue(double)
            {
                double cpp_arg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptValue(double)
                cptr = new QScriptValue(cpp_arg0);
                }
                break;
            }
            case 14: // QScriptValue(int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptValue(int)
                cptr = new QScriptValue(cpp_arg0);
                }
                break;
            }
            case 15: // QScriptValue(uint)
            {
                uint cpp_arg0 = Shiboken::Converter<uint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QScriptValue(uint)
                cptr = new QScriptValue(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQScriptValue_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQScriptValue_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtScript.QScriptEngine, PySide.QtScript.QScriptValue.SpecialValue", "PySide.QtScript.QScriptEngine, bool", "PySide.QtScript.QScriptEngine, QString", "PySide.QtScript.QScriptEngine, str", "PySide.QtScript.QScriptEngine, float", "PySide.QtScript.QScriptEngine, int", "PySide.QtScript.QScriptEngine, unsigned int", "PySide.QtScript.QScriptValue.SpecialValue", "bool", "PySide.QtScript.QScriptValue", "QString", "str", "float", "int", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue", overloads);
        return -1;
}

static PyObject* SbkQScriptValueFunc_call(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "args", "thisObject" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.call(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.call(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:call", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: call(QScriptValue,QList<QScriptValue>)
    // 1: call(QScriptValue,QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // call(QScriptValue,QList<QScriptValue>)
    } else if (Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // call(QScriptValue,QList<QScriptValue>)
        } else if (numArgs == 2 && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
            overloadId = 1; // call(QScriptValue,QScriptValue)
        } else if (Shiboken::Converter< QList<QScriptValue >  >::isConvertible(pyargs[1])) {
            overloadId = 0; // call(QScriptValue,QList<QScriptValue>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_call_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // call(QScriptValue,QList<QScriptValue>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "thisObject");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "thisObject";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "args");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "args";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.call(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
                QScriptValue cpp_arg0_tmp = QScriptValue();
                QScriptValue* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QScriptValue* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
                if (pyargs[0] && !Shiboken::Converter<QScriptValue >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);
                QList<QScriptValue > cpp_arg1 = pyargs[1] ? Shiboken::Converter<QList<QScriptValue > >::toCpp(pyargs[1]) : QScriptValueList();

                if(!PyErr_Occurred()) {
                // call(QScriptValue,QList<QScriptValue>)
                QScriptValue cppResult = cppSelf->QScriptValue::call(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // call(QScriptValue,QScriptValue)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
                QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
                QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // call(QScriptValue,QScriptValue)
                QScriptValue cppResult = cppSelf->QScriptValue::call(*cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_call_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue = QScriptValue(), list = QScriptValueList()", "PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.call", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_construct(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "args" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.construct(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.construct(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:construct", &arg))
        return 0;


    // Overloaded function decisor
    // 0: construct(QList<QScriptValue>)
    // 1: construct(QScriptValue)
    if (numArgs == 0) {
        overloadId = 0; // construct(QList<QScriptValue>)
    } else if (numArgs == 1 && Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 1; // construct(QScriptValue)
    } else if (Shiboken::Converter< QList<QScriptValue >  >::isConvertible(arg)) {
        overloadId = 0; // construct(QList<QScriptValue>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_construct_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // construct(QList<QScriptValue>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "args");
                    if (value) {
                        if (arg)
                            errorArgName = "args";
                        else
                            arg = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.construct(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QList<QScriptValue > cpp_arg0 = arg ? Shiboken::Converter<QList<QScriptValue > >::toCpp(arg) : QScriptValueList();

                if(!PyErr_Occurred()) {
                // construct(QList<QScriptValue>)
                QScriptValue cppResult = cppSelf->QScriptValue::construct(cpp_arg0);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // construct(QScriptValue)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
                QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
                if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // construct(QScriptValue)
                QScriptValue cppResult = cppSelf->QScriptValue::construct(*cpp_arg0);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_construct_TypeError:
        const char* overloads[] = {"list = QScriptValueList()", "PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.construct", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_data(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // data()const
            QScriptValue cppResult = cppSelf->QScriptValue::data();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_engine(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // engine()const
            QScriptEngine * cppResult = cppSelf->QScriptValue::engine();
            pyResult = Shiboken::Converter<QScriptEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_equals(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: equals(QScriptValue)const
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // equals(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_equals_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // equals(QScriptValue)const
            bool cppResult = cppSelf->QScriptValue::equals(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_equals_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.equals", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_instanceOf(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: instanceOf(QScriptValue)const
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // instanceOf(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_instanceOf_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // instanceOf(QScriptValue)const
            bool cppResult = cppSelf->QScriptValue::instanceOf(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_instanceOf_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.instanceOf", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_isArray(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isArray()const
            bool cppResult = cppSelf->QScriptValue::isArray();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isBool(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isBool()const
            bool cppResult = cppSelf->QScriptValue::isBool();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isBoolean(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isBoolean()const
            bool cppResult = cppSelf->QScriptValue::isBoolean();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isDate(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDate()const
            bool cppResult = cppSelf->QScriptValue::isDate();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isError(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isError()const
            bool cppResult = cppSelf->QScriptValue::isError();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isFunction(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isFunction()const
            bool cppResult = cppSelf->QScriptValue::isFunction();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isNull(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QScriptValue::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isNumber(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNumber()const
            bool cppResult = cppSelf->QScriptValue::isNumber();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isObject(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isObject()const
            bool cppResult = cppSelf->QScriptValue::isObject();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isQMetaObject(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isQMetaObject()const
            bool cppResult = cppSelf->QScriptValue::isQMetaObject();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isQObject(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isQObject()const
            bool cppResult = cppSelf->QScriptValue::isQObject();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isRegExp(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRegExp()const
            bool cppResult = cppSelf->QScriptValue::isRegExp();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isString(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isString()const
            bool cppResult = cppSelf->QScriptValue::isString();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isUndefined(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isUndefined()const
            bool cppResult = cppSelf->QScriptValue::isUndefined();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isValid(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QScriptValue::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_isVariant(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isVariant()const
            bool cppResult = cppSelf->QScriptValue::isVariant();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_lessThan(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: lessThan(QScriptValue)const
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // lessThan(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_lessThan_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // lessThan(QScriptValue)const
            bool cppResult = cppSelf->QScriptValue::lessThan(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_lessThan_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.lessThan", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_objectId(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // objectId()const
            qint64 cppResult = cppSelf->QScriptValue::objectId();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_property(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:property", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
    // 1: property(QString,QFlags<QScriptValue::ResolveFlag>)const
    // 2: property(quint32,QFlags<QScriptValue::ResolveFlag>)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::isConvertible(pyargs[1])) {
            overloadId = 2; // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
        }
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // property(QString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::isConvertible(pyargs[1])) {
            overloadId = 1; // property(QString,QFlags<QScriptValue::ResolveFlag>)const
        }
    } else if (Shiboken::Converter<const QScriptString & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::isConvertible(pyargs[1])) {
            overloadId = 0; // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_property_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QScriptString* cpp_arg0 = Shiboken::Converter<QScriptString* >::toCpp(pyargs[0]);
                const QFlags<QScriptValue::ResolveFlag> & cpp_arg1 = pyargs[1] ? Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::toCpp(pyargs[1]) : QScriptValue::ResolvePrototype;

                if(!PyErr_Occurred()) {
                // property(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
                QScriptValue cppResult = cppSelf->QScriptValue::property(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 1: // property(QString,QFlags<QScriptValue::ResolveFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const QFlags<QScriptValue::ResolveFlag> & cpp_arg1 = pyargs[1] ? Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::toCpp(pyargs[1]) : QScriptValue::ResolvePrototype;

                if(!PyErr_Occurred()) {
                // property(QString,QFlags<QScriptValue::ResolveFlag>)const
                QScriptValue cppResult = cppSelf->QScriptValue::property(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
            case 2: // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.property(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                quint32 cpp_arg0 = Shiboken::Converter<quint32 >::toCpp(pyargs[0]);
                const QFlags<QScriptValue::ResolveFlag> & cpp_arg1 = pyargs[1] ? Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::toCpp(pyargs[1]) : QScriptValue::ResolvePrototype;

                if(!PyErr_Occurred()) {
                // property(quint32,QFlags<QScriptValue::ResolveFlag>)const
                QScriptValue cppResult = cppSelf->QScriptValue::property(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_property_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptString, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", "QString, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", "unsigned int, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.property", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_propertyFlags(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:propertyFlags", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
    // 1: propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::isConvertible(pyargs[1])) {
            overloadId = 1; // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
        }
    } else if (Shiboken::Converter<const QScriptString & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        } else if (Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::isConvertible(pyargs[1])) {
            overloadId = 0; // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_propertyFlags_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QScriptString* cpp_arg0 = Shiboken::Converter<QScriptString* >::toCpp(pyargs[0]);
                const QFlags<QScriptValue::ResolveFlag> & cpp_arg1 = pyargs[1] ? Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::toCpp(pyargs[1]) : QScriptValue::ResolvePrototype;

                if(!PyErr_Occurred()) {
                // propertyFlags(QScriptString,QFlags<QScriptValue::ResolveFlag>)const
                QFlags<QScriptValue::PropertyFlag> cppResult = cppSelf->QScriptValue::propertyFlags(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
                }
                break;
            }
            case 1: // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.propertyFlags(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const QFlags<QScriptValue::ResolveFlag> & cpp_arg1 = pyargs[1] ? Shiboken::Converter<const QFlags<QScriptValue::ResolveFlag> & >::toCpp(pyargs[1]) : QScriptValue::ResolvePrototype;

                if(!PyErr_Occurred()) {
                // propertyFlags(QString,QFlags<QScriptValue::ResolveFlag>)const
                QFlags<QScriptValue::PropertyFlag> cppResult = cppSelf->QScriptValue::propertyFlags(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_propertyFlags_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptString, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", "QString, PySide.QtScript.QScriptValue.ResolveFlags = QScriptValue.ResolvePrototype", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.propertyFlags", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_prototype(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prototype()const
            QScriptValue cppResult = cppSelf->QScriptValue::prototype();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_scope(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scope()const
            QScriptValue cppResult = cppSelf->QScriptValue::scope();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_scriptClass(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scriptClass()const
            QScriptClass * cppResult = cppSelf->QScriptValue::scriptClass();
            pyResult = Shiboken::Converter<QScriptClass * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_setData(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setData(QScriptValue)
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // setData(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_setData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setData(QScriptValue)
            cppSelf->QScriptValue::setData(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptValueFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.setData", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_setProperty(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setProperty", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
    // 1: setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
    // 2: setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        } else if (Shiboken::Converter<const QFlags<QScriptValue::PropertyFlag> & >::isConvertible(pyargs[2])) {
            overloadId = 2; // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        } else if (Shiboken::Converter<const QFlags<QScriptValue::PropertyFlag> & >::isConvertible(pyargs[2])) {
            overloadId = 1; // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QScriptString & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QScriptValue & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        } else if (Shiboken::Converter<const QFlags<QScriptValue::PropertyFlag> & >::isConvertible(pyargs[2])) {
            overloadId = 0; // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_setProperty_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QScriptString* cpp_arg0 = Shiboken::Converter<QScriptString* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
                QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);
                const QFlags<QScriptValue::PropertyFlag> & cpp_arg2 = pyargs[2] ? Shiboken::Converter<const QFlags<QScriptValue::PropertyFlag> & >::toCpp(pyargs[2]) : QScriptValue::KeepExistingFlags;

                if(!PyErr_Occurred()) {
                // setProperty(QScriptString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
                cppSelf->QScriptValue::setProperty(*cpp_arg0, *cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
                QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);
                const QFlags<QScriptValue::PropertyFlag> & cpp_arg2 = pyargs[2] ? Shiboken::Converter<const QFlags<QScriptValue::PropertyFlag> & >::toCpp(pyargs[2]) : QScriptValue::KeepExistingFlags;

                if(!PyErr_Occurred()) {
                // setProperty(QString,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
                cppSelf->QScriptValue::setProperty(cpp_arg0, *cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptValue.setProperty(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                quint32 cpp_arg0 = Shiboken::Converter<quint32 >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QScriptValue > cpp_arg1_auto_ptr;
                QScriptValue* cpp_arg1 = Shiboken::Converter<QScriptValue* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QScriptValue >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg1);
                const QFlags<QScriptValue::PropertyFlag> & cpp_arg2 = pyargs[2] ? Shiboken::Converter<const QFlags<QScriptValue::PropertyFlag> & >::toCpp(pyargs[2]) : QScriptValue::KeepExistingFlags;

                if(!PyErr_Occurred()) {
                // setProperty(quint32,QScriptValue,QFlags<QScriptValue::PropertyFlag>)
                cppSelf->QScriptValue::setProperty(cpp_arg0, *cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptValueFunc_setProperty_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptString, PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue.PropertyFlags = QScriptValue.KeepExistingFlags", "QString, PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue.PropertyFlags = QScriptValue.KeepExistingFlags", "unsigned int, PySide.QtScript.QScriptValue, PySide.QtScript.QScriptValue.PropertyFlags = QScriptValue.KeepExistingFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValue.setProperty", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_setPrototype(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrototype(QScriptValue)
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // setPrototype(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_setPrototype_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPrototype(QScriptValue)
            cppSelf->QScriptValue::setPrototype(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptValueFunc_setPrototype_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.setPrototype", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_setScope(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScope(QScriptValue)
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // setScope(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_setScope_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setScope(QScriptValue)
            cppSelf->QScriptValue::setScope(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptValueFunc_setScope_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.setScope", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_setScriptClass(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScriptClass(QScriptClass*)
    if (Shiboken::Converter<QScriptClass * >::isConvertible(arg)) {
        overloadId = 0; // setScriptClass(QScriptClass*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_setScriptClass_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QScriptClass* cpp_arg0 = Shiboken::Converter<QScriptClass* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScriptClass(QScriptClass*)
            cppSelf->QScriptValue::setScriptClass(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptValueFunc_setScriptClass_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptClass", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.setScriptClass", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_strictlyEquals(PyObject* self, PyObject* arg)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: strictlyEquals(QScriptValue)const
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // strictlyEquals(QScriptValue)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueFunc_strictlyEquals_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // strictlyEquals(QScriptValue)const
            bool cppResult = cppSelf->QScriptValue::strictlyEquals(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptValueFunc_strictlyEquals_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValue.strictlyEquals", overloads);
        return 0;
}

static PyObject* SbkQScriptValueFunc_toBool(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toBool()const
            bool cppResult = cppSelf->QScriptValue::toBool();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toBoolean(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toBoolean()const
            bool cppResult = cppSelf->QScriptValue::toBoolean();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toDateTime(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toDateTime()const
            QDateTime cppResult = cppSelf->QScriptValue::toDateTime();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toInt32(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toInt32()const
            qint32 cppResult = cppSelf->QScriptValue::toInt32();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toInteger(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toInteger()const
            double cppResult = cppSelf->QScriptValue::toInteger();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toNumber(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toNumber()const
            double cppResult = cppSelf->QScriptValue::toNumber();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toObject(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toObject()const
            QScriptValue cppResult = cppSelf->QScriptValue::toObject();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toQMetaObject(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toQMetaObject()const
            const QMetaObject * cppResult = cppSelf->QScriptValue::toQMetaObject();
            pyResult = Shiboken::Converter< QMetaObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toQObject(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toQObject()const
            QObject * cppResult = cppSelf->QScriptValue::toQObject();
            pyResult = Shiboken::Converter<QObject * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toRegExp(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toRegExp()const
            QRegExp cppResult = cppSelf->QScriptValue::toRegExp();
            pyResult = Shiboken::Converter<QRegExp >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toString(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toString()const
            QString cppResult = cppSelf->QScriptValue::toString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toUInt16(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toUInt16()const
            quint16 cppResult = cppSelf->QScriptValue::toUInt16();
            pyResult = Shiboken::Converter<unsigned short >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toUInt32(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toUInt32()const
            quint32 cppResult = cppSelf->QScriptValue::toUInt32();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueFunc_toVariant(PyObject* self)
{
    QScriptValue* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValue* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toVariant()const
            QVariant cppResult = cppSelf->QScriptValue::toVariant();
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQScriptValue_methods[] = {
    {"call", (PyCFunction)SbkQScriptValueFunc_call, METH_VARARGS|METH_KEYWORDS},
    {"construct", (PyCFunction)SbkQScriptValueFunc_construct, METH_VARARGS|METH_KEYWORDS},
    {"data", (PyCFunction)SbkQScriptValueFunc_data, METH_NOARGS},
    {"engine", (PyCFunction)SbkQScriptValueFunc_engine, METH_NOARGS},
    {"equals", (PyCFunction)SbkQScriptValueFunc_equals, METH_O},
    {"instanceOf", (PyCFunction)SbkQScriptValueFunc_instanceOf, METH_O},
    {"isArray", (PyCFunction)SbkQScriptValueFunc_isArray, METH_NOARGS},
    {"isBool", (PyCFunction)SbkQScriptValueFunc_isBool, METH_NOARGS},
    {"isBoolean", (PyCFunction)SbkQScriptValueFunc_isBoolean, METH_NOARGS},
    {"isDate", (PyCFunction)SbkQScriptValueFunc_isDate, METH_NOARGS},
    {"isError", (PyCFunction)SbkQScriptValueFunc_isError, METH_NOARGS},
    {"isFunction", (PyCFunction)SbkQScriptValueFunc_isFunction, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQScriptValueFunc_isNull, METH_NOARGS},
    {"isNumber", (PyCFunction)SbkQScriptValueFunc_isNumber, METH_NOARGS},
    {"isObject", (PyCFunction)SbkQScriptValueFunc_isObject, METH_NOARGS},
    {"isQMetaObject", (PyCFunction)SbkQScriptValueFunc_isQMetaObject, METH_NOARGS},
    {"isQObject", (PyCFunction)SbkQScriptValueFunc_isQObject, METH_NOARGS},
    {"isRegExp", (PyCFunction)SbkQScriptValueFunc_isRegExp, METH_NOARGS},
    {"isString", (PyCFunction)SbkQScriptValueFunc_isString, METH_NOARGS},
    {"isUndefined", (PyCFunction)SbkQScriptValueFunc_isUndefined, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQScriptValueFunc_isValid, METH_NOARGS},
    {"isVariant", (PyCFunction)SbkQScriptValueFunc_isVariant, METH_NOARGS},
    {"lessThan", (PyCFunction)SbkQScriptValueFunc_lessThan, METH_O},
    {"objectId", (PyCFunction)SbkQScriptValueFunc_objectId, METH_NOARGS},
    {"property", (PyCFunction)SbkQScriptValueFunc_property, METH_VARARGS|METH_KEYWORDS},
    {"propertyFlags", (PyCFunction)SbkQScriptValueFunc_propertyFlags, METH_VARARGS|METH_KEYWORDS},
    {"prototype", (PyCFunction)SbkQScriptValueFunc_prototype, METH_NOARGS},
    {"scope", (PyCFunction)SbkQScriptValueFunc_scope, METH_NOARGS},
    {"scriptClass", (PyCFunction)SbkQScriptValueFunc_scriptClass, METH_NOARGS},
    {"setData", (PyCFunction)SbkQScriptValueFunc_setData, METH_O},
    {"setProperty", (PyCFunction)SbkQScriptValueFunc_setProperty, METH_VARARGS|METH_KEYWORDS},
    {"setPrototype", (PyCFunction)SbkQScriptValueFunc_setPrototype, METH_O},
    {"setScope", (PyCFunction)SbkQScriptValueFunc_setScope, METH_O},
    {"setScriptClass", (PyCFunction)SbkQScriptValueFunc_setScriptClass, METH_O},
    {"strictlyEquals", (PyCFunction)SbkQScriptValueFunc_strictlyEquals, METH_O},
    {"toBool", (PyCFunction)SbkQScriptValueFunc_toBool, METH_NOARGS},
    {"toBoolean", (PyCFunction)SbkQScriptValueFunc_toBoolean, METH_NOARGS},
    {"toDateTime", (PyCFunction)SbkQScriptValueFunc_toDateTime, METH_NOARGS},
    {"toInt32", (PyCFunction)SbkQScriptValueFunc_toInt32, METH_NOARGS},
    {"toInteger", (PyCFunction)SbkQScriptValueFunc_toInteger, METH_NOARGS},
    {"toNumber", (PyCFunction)SbkQScriptValueFunc_toNumber, METH_NOARGS},
    {"toObject", (PyCFunction)SbkQScriptValueFunc_toObject, METH_NOARGS},
    {"toQMetaObject", (PyCFunction)SbkQScriptValueFunc_toQMetaObject, METH_NOARGS},
    {"toQObject", (PyCFunction)SbkQScriptValueFunc_toQObject, METH_NOARGS},
    {"toRegExp", (PyCFunction)SbkQScriptValueFunc_toRegExp, METH_NOARGS},
    {"toString", (PyCFunction)SbkQScriptValueFunc_toString, METH_NOARGS},
    {"toUInt16", (PyCFunction)SbkQScriptValueFunc_toUInt16, METH_NOARGS},
    {"toUInt32", (PyCFunction)SbkQScriptValueFunc_toUInt32, METH_NOARGS},
    {"toVariant", (PyCFunction)SbkQScriptValueFunc_toVariant, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQScriptValue_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptValue",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQScriptValue_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQScriptValue_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QScriptValue >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QScriptValue",
    /*user_data*/           0
};
} //extern

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptValue::ResolveFlags >::checkType(self) && Shiboken::Converter<QScriptValue::ResolveFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptValue::ResolveFlags >::toPython(
        Shiboken::Converter<QScriptValue::ResolveFlags>::toCpp(self)
        & Shiboken::Converter< QScriptValue::ResolveFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptValue::ResolveFlags >::checkType(self) && Shiboken::Converter<QScriptValue::ResolveFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptValue::ResolveFlags >::toPython(
        Shiboken::Converter<QScriptValue::ResolveFlags>::toCpp(self)
        | Shiboken::Converter< QScriptValue::ResolveFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptValue::ResolveFlags >::checkType(self) && Shiboken::Converter<QScriptValue::ResolveFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptValue::ResolveFlags >::toPython(
        Shiboken::Converter<QScriptValue::ResolveFlags>::toCpp(self)
        ^ Shiboken::Converter< QScriptValue::ResolveFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QScriptValue::ResolveFlags >::toPython(
        ~Shiboken::Converter<QScriptValue::ResolveFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtScript_QScriptValue_ResolveFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtScript_QScriptValue_ResolveFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtScript_QScriptValue_ResolveFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScript_QScriptValue_ResolveFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ResolveFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtScript_QScriptValue_ResolveFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScript_QScriptValue_ResolveFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScript_QScriptValue_ResolveFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScript_QScriptValue_ResolveFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtScript_QScriptValue_ResolveFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ResolveFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtScript_QScriptValue_ResolveFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptValue::PropertyFlags >::checkType(self) && Shiboken::Converter<QScriptValue::PropertyFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptValue::PropertyFlags >::toPython(
        Shiboken::Converter<QScriptValue::PropertyFlags>::toCpp(self)
        & Shiboken::Converter< QScriptValue::PropertyFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptValue::PropertyFlags >::checkType(self) && Shiboken::Converter<QScriptValue::PropertyFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptValue::PropertyFlags >::toPython(
        Shiboken::Converter<QScriptValue::PropertyFlags>::toCpp(self)
        | Shiboken::Converter< QScriptValue::PropertyFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QScriptValue::PropertyFlags >::checkType(self) && Shiboken::Converter<QScriptValue::PropertyFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QScriptValue::PropertyFlags >::toPython(
        Shiboken::Converter<QScriptValue::PropertyFlags>::toCpp(self)
        ^ Shiboken::Converter< QScriptValue::PropertyFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QScriptValue::PropertyFlags >::toPython(
        ~Shiboken::Converter<QScriptValue::PropertyFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtScript_QScriptValue_PropertyFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtScript_QScriptValue_PropertyFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtScript_QScriptValue_PropertyFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScript_QScriptValue_PropertyFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PropertyFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtScript_QScriptValue_PropertyFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScript_QScriptValue_PropertyFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScript_QScriptValue_PropertyFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScript_QScriptValue_PropertyFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtScript_QScriptValue_PropertyFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PropertyFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtScript_QScriptValue_SpecialValue_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScript_QScriptValue_SpecialValue_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScript_QScriptValue_SpecialValue_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SpecialValue",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScript_QScriptValue_SpecialValue_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScript_QScriptValue_SpecialValue_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScript_QScriptValue_SpecialValue_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QScriptValue(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQScriptValue_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQScriptValue_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQScriptValue_Type));
    PyModule_AddObject(module, "QScriptValue",
        ((PyObject*)&SbkQScriptValue_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ResolveFlag
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_RESOLVEFLAG_IDX] = &SbkPySide_QtScript_QScriptValue_ResolveFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptValue_ResolveFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptValue_ResolveFlag_Type);
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
            "ResolveFlag",((PyObject*)&SbkPySide_QtScript_QScriptValue_ResolveFlag_Type));

    // init flags class: QFlags<QScriptValue::ResolveFlag>
    SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTVALUE_RESOLVEFLAG__IDX] = &SbkPySide_QtScript_QScriptValue_ResolveFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptValue_ResolveFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptValue_ResolveFlags_Type);
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
            "ResolveFlags",((PyObject*)&SbkPySide_QtScript_QScriptValue_ResolveFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_ResolveFlag_Type,
        (long) QScriptValue::ResolveLocal, "ResolveLocal");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "ResolveLocal", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_ResolveFlag_Type.tp_dict,
        "ResolveLocal", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_ResolveFlag_Type,
        (long) QScriptValue::ResolvePrototype, "ResolvePrototype");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "ResolvePrototype", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_ResolveFlag_Type.tp_dict,
        "ResolvePrototype", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_ResolveFlag_Type,
        (long) QScriptValue::ResolveScope, "ResolveScope");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "ResolveScope", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_ResolveFlag_Type.tp_dict,
        "ResolveScope", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_ResolveFlag_Type,
        (long) QScriptValue::ResolveFull, "ResolveFull");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "ResolveFull", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_ResolveFlag_Type.tp_dict,
        "ResolveFull", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptValue::ResolveFlag");

    // init enum class: PropertyFlag
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_PROPERTYFLAG_IDX] = &SbkPySide_QtScript_QScriptValue_PropertyFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type);
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
            "PropertyFlag",((PyObject*)&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type));

    // init flags class: QFlags<QScriptValue::PropertyFlag>
    SbkPySide_QtScriptTypes[SBK_QFLAGS_QSCRIPTVALUE_PROPERTYFLAG__IDX] = &SbkPySide_QtScript_QScriptValue_PropertyFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptValue_PropertyFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptValue_PropertyFlags_Type);
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
            "PropertyFlags",((PyObject*)&SbkPySide_QtScript_QScriptValue_PropertyFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::ReadOnly, "ReadOnly");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "ReadOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "ReadOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::Undeletable, "Undeletable");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "Undeletable", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "Undeletable", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::SkipInEnumeration, "SkipInEnumeration");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "SkipInEnumeration", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "SkipInEnumeration", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::PropertyGetter, "PropertyGetter");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "PropertyGetter", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "PropertyGetter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::PropertySetter, "PropertySetter");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "PropertySetter", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "PropertySetter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::QObjectMember, "QObjectMember");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "QObjectMember", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "QObjectMember", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::KeepExistingFlags, "KeepExistingFlags");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "KeepExistingFlags", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "KeepExistingFlags", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_PropertyFlag_Type,
        (long) QScriptValue::UserRange, "UserRange");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "UserRange", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_PropertyFlag_Type.tp_dict,
        "UserRange", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptValue::PropertyFlag");

    // init enum class: SpecialValue
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUE_SPECIALVALUE_IDX] = &SbkPySide_QtScript_QScriptValue_SpecialValue_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScript_QScriptValue_SpecialValue_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScript_QScriptValue_SpecialValue_Type);
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
            "SpecialValue",((PyObject*)&SbkPySide_QtScript_QScriptValue_SpecialValue_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_SpecialValue_Type,
        (long) QScriptValue::NullValue, "NullValue");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "NullValue", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_SpecialValue_Type.tp_dict,
        "NullValue", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScript_QScriptValue_SpecialValue_Type,
        (long) QScriptValue::UndefinedValue, "UndefinedValue");
    PyDict_SetItemString(SbkQScriptValue_Type.super.ht_type.tp_dict,
        "UndefinedValue", enum_item);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptValue_SpecialValue_Type.tp_dict,
        "UndefinedValue", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptValue::SpecialValue");


    Shiboken::TypeResolver::createValueTypeResolver<QScriptValue >("QScriptValue");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptValue >("QScriptValue*");
    Shiboken::TypeResolver::createValueTypeResolver<QScriptValue >(typeid(QScriptValue).name());
    PySide::initQtMetaType<QScriptValue >();
}

