/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptvalueiterator_wrapper.h"

// Extra includes
#include <qscriptstring.h>
#include <qscriptvalue.h>
#include <qscriptvalueiterator.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQScriptValueIterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptValueIterator >()))
        return -1;

    QScriptValueIterator* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptValueIterator", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QScriptValueIterator(QScriptValue)
    if (numArgs == 1 && Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // QScriptValueIterator(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueIterator_Init_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // QScriptValueIterator(QScriptValue)
            cptr = new QScriptValueIterator(*cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptValueIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQScriptValueIterator_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQScriptValueIterator_Init_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValueIterator", overloads);
        return -1;
}

static PyObject* SbkQScriptValueIteratorFunc_flags(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // flags()const
            QFlags<QScriptValue::PropertyFlag> cppResult = cppSelf->QScriptValueIterator::flags();
            pyResult = Shiboken::Converter<QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueIteratorFunc_hasNext(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasNext()const
            bool cppResult = cppSelf->QScriptValueIterator::hasNext();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueIteratorFunc_hasPrevious(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasPrevious()const
            bool cppResult = cppSelf->QScriptValueIterator::hasPrevious();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueIteratorFunc_name(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QScriptValueIterator::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueIteratorFunc_next(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // next()
            cppSelf->QScriptValueIterator::next();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptValueIteratorFunc_previous(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // previous()
            cppSelf->QScriptValueIterator::previous();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptValueIteratorFunc_remove(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // remove()
            cppSelf->QScriptValueIterator::remove();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptValueIteratorFunc_scriptName(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scriptName()const
            QScriptString cppResult = cppSelf->QScriptValueIterator::scriptName();
            pyResult = Shiboken::Converter<QScriptString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptValueIteratorFunc_setValue(PyObject* self, PyObject* arg)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setValue(QScriptValue)
    if (Shiboken::Converter<const QScriptValue & >::isConvertible(arg)) {
        overloadId = 0; // setValue(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptValueIteratorFunc_setValue_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QScriptValue > cpp_arg0_auto_ptr;
            QScriptValue* cpp_arg0 = Shiboken::Converter<QScriptValue* >::toCpp(arg);
            if (!Shiboken::Converter<QScriptValue >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QScriptValue >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setValue(QScriptValue)
            cppSelf->QScriptValueIterator::setValue(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptValueIteratorFunc_setValue_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValueIterator.setValue", overloads);
        return 0;
}

static PyObject* SbkQScriptValueIteratorFunc_toBack(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toBack()
            cppSelf->QScriptValueIterator::toBack();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptValueIteratorFunc_toFront(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toFront()
            cppSelf->QScriptValueIterator::toFront();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQScriptValueIteratorFunc_value(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // value()const
            QScriptValue cppResult = cppSelf->QScriptValueIterator::value();
            pyResult = Shiboken::Converter<QScriptValue >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQScriptValueIterator_methods[] = {
    {"flags", (PyCFunction)SbkQScriptValueIteratorFunc_flags, METH_NOARGS},
    {"hasNext", (PyCFunction)SbkQScriptValueIteratorFunc_hasNext, METH_NOARGS},
    {"hasPrevious", (PyCFunction)SbkQScriptValueIteratorFunc_hasPrevious, METH_NOARGS},
    {"name", (PyCFunction)SbkQScriptValueIteratorFunc_name, METH_NOARGS},
    {"next", (PyCFunction)SbkQScriptValueIteratorFunc_next, METH_NOARGS},
    {"previous", (PyCFunction)SbkQScriptValueIteratorFunc_previous, METH_NOARGS},
    {"remove", (PyCFunction)SbkQScriptValueIteratorFunc_remove, METH_NOARGS},
    {"scriptName", (PyCFunction)SbkQScriptValueIteratorFunc_scriptName, METH_NOARGS},
    {"setValue", (PyCFunction)SbkQScriptValueIteratorFunc_setValue, METH_O},
    {"toBack", (PyCFunction)SbkQScriptValueIteratorFunc_toBack, METH_NOARGS},
    {"toFront", (PyCFunction)SbkQScriptValueIteratorFunc_toFront, METH_NOARGS},
    {"value", (PyCFunction)SbkQScriptValueIteratorFunc_value, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQScriptValueIterator_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptValueIterator",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQScriptValueIterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQScriptValueIterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QScriptValueIterator >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QScriptValueIterator*",
    /*user_data*/           0
};
} //extern


void init_QScriptValueIterator(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUEITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQScriptValueIterator_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQScriptValueIterator_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQScriptValueIterator_Type));
    PyModule_AddObject(module, "QScriptValueIterator",
        ((PyObject*)&SbkQScriptValueIterator_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptValueIterator >("QScriptValueIterator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptValueIterator >(typeid(QScriptValueIterator).name());
    PySide::initQtMetaType<QScriptValueIterator* >();
}

