/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtscripttools_python.h"

#include "qscriptenginedebugger_wrapper.h"

// Extra includes
#include <QList>
#include <QScriptEngine>
#include <qaction.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmainwindow.h>
#include <qmenu.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qscriptengine.h>
#include <qscriptenginedebugger.h>
#include <qthread.h>
#include <qtoolbar.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QScriptEngineDebuggerWrapper::QScriptEngineDebuggerWrapper(QObject * parent) : QScriptEngineDebugger(parent), m_metaObject(0) {
    // ... middle
}

void QScriptEngineDebuggerWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineDebuggerWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QScriptEngineDebuggerWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QScriptEngineDebuggerWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QScriptEngineDebuggerWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineDebugger.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QScriptEngineDebuggerWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineDebugger.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QScriptEngineDebuggerWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QScriptEngineDebuggerWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QScriptEngineDebugger::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QScriptEngineDebuggerWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QScriptEngineDebugger::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QScriptEngineDebuggerWrapper::~QScriptEngineDebuggerWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQScriptEngineDebugger_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptEngineDebugger >()))
        return -1;

    QScriptEngineDebuggerWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QScriptEngineDebugger", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QScriptEngineDebugger(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QScriptEngineDebugger(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QScriptEngineDebugger(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineDebugger_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QScriptEngineDebugger(QObject*)
            cptr = new QScriptEngineDebuggerWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptEngineDebugger >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQScriptEngineDebugger_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQScriptEngineDebugger_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScriptTools.QScriptEngineDebugger", overloads);
        return -1;
}

static PyObject* SbkQScriptEngineDebuggerFunc_action(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: action(QScriptEngineDebugger::DebuggerAction)const
    if (Shiboken::Converter<QScriptEngineDebugger::DebuggerAction >::isConvertible(arg)) {
        overloadId = 0; // action(QScriptEngineDebugger::DebuggerAction)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineDebuggerFunc_action_TypeError;

    // Call function/method
    {
        {
            QScriptEngineDebugger::DebuggerAction cpp_arg0 = Shiboken::Converter<QScriptEngineDebugger::DebuggerAction >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // action(QScriptEngineDebugger::DebuggerAction)const
            QAction * cppResult = cppSelf->QScriptEngineDebugger::action(cpp_arg0);
            pyResult = Shiboken::Converter<QAction * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineDebuggerFunc_action_TypeError:
        const char* overloads[] = {"PySide.QtScriptTools.QScriptEngineDebugger.DebuggerAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.action", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineDebuggerFunc_attachTo(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: attachTo(QScriptEngine*)
    if (Shiboken::Converter<QScriptEngine * >::isConvertible(arg)) {
        overloadId = 0; // attachTo(QScriptEngine*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineDebuggerFunc_attachTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QScriptEngine* cpp_arg0 = Shiboken::Converter<QScriptEngine* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // attachTo(QScriptEngine*)
            cppSelf->QScriptEngineDebugger::attachTo(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineDebuggerFunc_attachTo_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngine", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.attachTo", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineDebuggerFunc_autoShowStandardWindow(PyObject* self)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoShowStandardWindow()const
            bool cppResult = cppSelf->QScriptEngineDebugger::autoShowStandardWindow();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineDebuggerFunc_createStandardMenu(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardMenu(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardMenu(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createStandardMenu", &arg))
        return 0;


    // Overloaded function decisor
    // 0: createStandardMenu(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // createStandardMenu(QWidget*)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // createStandardMenu(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineDebuggerFunc_createStandardMenu_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardMenu(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = arg ? Shiboken::Converter<QWidget* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // createStandardMenu(QWidget*)
            QMenu * cppResult = cppSelf->QScriptEngineDebugger::createStandardMenu(cpp_arg0);
            pyResult = Shiboken::Converter<QMenu * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineDebuggerFunc_createStandardMenu_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardMenu", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineDebuggerFunc_createStandardToolBar(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardToolBar(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardToolBar(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createStandardToolBar", &arg))
        return 0;


    // Overloaded function decisor
    // 0: createStandardToolBar(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // createStandardToolBar(QWidget*)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // createStandardToolBar(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineDebuggerFunc_createStandardToolBar_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardToolBar(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = arg ? Shiboken::Converter<QWidget* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // createStandardToolBar(QWidget*)
            QToolBar * cppResult = cppSelf->QScriptEngineDebugger::createStandardToolBar(cpp_arg0);
            pyResult = Shiboken::Converter<QToolBar * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineDebuggerFunc_createStandardToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.createStandardToolBar", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineDebuggerFunc_setAutoShowStandardWindow(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoShowStandardWindow(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoShowStandardWindow(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineDebuggerFunc_setAutoShowStandardWindow_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoShowStandardWindow(bool)
            cppSelf->QScriptEngineDebugger::setAutoShowStandardWindow(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQScriptEngineDebuggerFunc_setAutoShowStandardWindow_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.setAutoShowStandardWindow", overloads);
        return 0;
}

static PyObject* SbkQScriptEngineDebuggerFunc_standardWindow(PyObject* self)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // standardWindow()const
            QMainWindow * cppResult = cppSelf->QScriptEngineDebugger::standardWindow();
            pyResult = Shiboken::Converter<QMainWindow * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineDebuggerFunc_state(PyObject* self)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QScriptEngineDebugger::DebuggerState cppResult = cppSelf->QScriptEngineDebugger::state();
            pyResult = Shiboken::Converter<QScriptEngineDebugger::DebuggerState >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQScriptEngineDebuggerFunc_widget(PyObject* self, PyObject* arg)
{
    QScriptEngineDebugger* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QScriptEngineDebugger* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: widget(QScriptEngineDebugger::DebuggerWidget)const
    if (Shiboken::Converter<QScriptEngineDebugger::DebuggerWidget >::isConvertible(arg)) {
        overloadId = 0; // widget(QScriptEngineDebugger::DebuggerWidget)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQScriptEngineDebuggerFunc_widget_TypeError;

    // Call function/method
    {
        {
            QScriptEngineDebugger::DebuggerWidget cpp_arg0 = Shiboken::Converter<QScriptEngineDebugger::DebuggerWidget >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // widget(QScriptEngineDebugger::DebuggerWidget)const
            QWidget * cppResult = cppSelf->QScriptEngineDebugger::widget(cpp_arg0);
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQScriptEngineDebuggerFunc_widget_TypeError:
        const char* overloads[] = {"PySide.QtScriptTools.QScriptEngineDebugger.DebuggerWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScriptTools.QScriptEngineDebugger.widget", overloads);
        return 0;
}

static PyMethodDef SbkQScriptEngineDebugger_methods[] = {
    {"action", (PyCFunction)SbkQScriptEngineDebuggerFunc_action, METH_O},
    {"attachTo", (PyCFunction)SbkQScriptEngineDebuggerFunc_attachTo, METH_O},
    {"autoShowStandardWindow", (PyCFunction)SbkQScriptEngineDebuggerFunc_autoShowStandardWindow, METH_NOARGS},
    {"createStandardMenu", (PyCFunction)SbkQScriptEngineDebuggerFunc_createStandardMenu, METH_VARARGS|METH_KEYWORDS},
    {"createStandardToolBar", (PyCFunction)SbkQScriptEngineDebuggerFunc_createStandardToolBar, METH_VARARGS|METH_KEYWORDS},
    {"setAutoShowStandardWindow", (PyCFunction)SbkQScriptEngineDebuggerFunc_setAutoShowStandardWindow, METH_O},
    {"standardWindow", (PyCFunction)SbkQScriptEngineDebuggerFunc_standardWindow, METH_NOARGS},
    {"state", (PyCFunction)SbkQScriptEngineDebuggerFunc_state, METH_NOARGS},
    {"widget", (PyCFunction)SbkQScriptEngineDebuggerFunc_widget, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQScriptEngineDebugger_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScriptTools.QScriptEngineDebugger",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQScriptEngineDebugger_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQScriptEngineDebugger_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QScriptEngineDebugger >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QScriptEngineDebugger*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQScriptEngineDebugger_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QScriptEngineDebugger*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQScriptEngineDebugger_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DebuggerWidget",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DebuggerAction",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DebuggerState",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QScriptEngineDebugger(PyObject* module)
{
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQScriptEngineDebugger_Type);

    SbkQScriptEngineDebugger_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQScriptEngineDebugger_Type.type_discovery = &SbkQScriptEngineDebugger_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQScriptEngineDebugger_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQScriptEngineDebugger_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQScriptEngineDebugger_Type));
    PyModule_AddObject(module, "QScriptEngineDebugger",
        ((PyObject*)&SbkQScriptEngineDebugger_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: DebuggerWidget
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERWIDGET_IDX] = &SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type);
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
            "DebuggerWidget",((PyObject*)&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::ConsoleWidget, "ConsoleWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ConsoleWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "ConsoleWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::StackWidget, "StackWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "StackWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "StackWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::ScriptsWidget, "ScriptsWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ScriptsWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "ScriptsWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::LocalsWidget, "LocalsWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "LocalsWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "LocalsWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::CodeWidget, "CodeWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "CodeWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "CodeWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::CodeFinderWidget, "CodeFinderWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "CodeFinderWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "CodeFinderWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::BreakpointsWidget, "BreakpointsWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "BreakpointsWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "BreakpointsWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::DebugOutputWidget, "DebugOutputWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "DebugOutputWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "DebugOutputWidget", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type,
        (long) QScriptEngineDebugger::ErrorLogWidget, "ErrorLogWidget");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ErrorLogWidget", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerWidget_Type.tp_dict,
        "ErrorLogWidget", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineDebugger::DebuggerWidget");

    // init enum class: DebuggerAction
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERACTION_IDX] = &SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type);
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
            "DebuggerAction",((PyObject*)&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::InterruptAction, "InterruptAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "InterruptAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "InterruptAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::ContinueAction, "ContinueAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ContinueAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "ContinueAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::StepIntoAction, "StepIntoAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "StepIntoAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "StepIntoAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::StepOverAction, "StepOverAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "StepOverAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "StepOverAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::StepOutAction, "StepOutAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "StepOutAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "StepOutAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::RunToCursorAction, "RunToCursorAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "RunToCursorAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "RunToCursorAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::RunToNewScriptAction, "RunToNewScriptAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "RunToNewScriptAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "RunToNewScriptAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::ToggleBreakpointAction, "ToggleBreakpointAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ToggleBreakpointAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "ToggleBreakpointAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::ClearDebugOutputAction, "ClearDebugOutputAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ClearDebugOutputAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "ClearDebugOutputAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::ClearErrorLogAction, "ClearErrorLogAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ClearErrorLogAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "ClearErrorLogAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::ClearConsoleAction, "ClearConsoleAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "ClearConsoleAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "ClearConsoleAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::FindInScriptAction, "FindInScriptAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "FindInScriptAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "FindInScriptAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::FindNextInScriptAction, "FindNextInScriptAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "FindNextInScriptAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "FindNextInScriptAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::FindPreviousInScriptAction, "FindPreviousInScriptAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "FindPreviousInScriptAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "FindPreviousInScriptAction", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type,
        (long) QScriptEngineDebugger::GoToLineAction, "GoToLineAction");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "GoToLineAction", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerAction_Type.tp_dict,
        "GoToLineAction", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineDebugger::DebuggerAction");

    // init enum class: DebuggerState
    SbkPySide_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERSTATE_IDX] = &SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type);
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
            "DebuggerState",((PyObject*)&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type,
        (long) QScriptEngineDebugger::RunningState, "RunningState");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "RunningState", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type.tp_dict,
        "RunningState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type,
        (long) QScriptEngineDebugger::SuspendedState, "SuspendedState");
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict,
        "SuspendedState", enum_item);
    PyDict_SetItemString(SbkPySide_QtScriptTools_QScriptEngineDebugger_DebuggerState_Type.tp_dict,
        "SuspendedState", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineDebugger::DebuggerState");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("evaluationSuspended", "void", NULL);
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict, "evaluationSuspended", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("evaluationResumed", "void", NULL);
    PyDict_SetItemString(SbkQScriptEngineDebugger_Type.super.ht_type.tp_dict, "evaluationResumed", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineDebugger >("QScriptEngineDebugger*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineDebugger >(typeid(QScriptEngineDebugger).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineDebugger >(typeid(QScriptEngineDebuggerWrapper).name());
    PySide::initQtMetaType<QScriptEngineDebugger* >();
}

