/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtsql_python.h"

#include "qsqldatabase_wrapper.h"

// Extra includes
#include <QSize>
#include <QSqlError>
#include <QSqlIndex>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <qsqldatabase.h>
#include <qsqldriver.h>
#include <qsqlerror.h>
#include <qsqlindex.h>
#include <qsqlquery.h>
#include <qsqlrecord.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSqlDatabase_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlDatabase >()))
        return -1;

    QSqlDatabase* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSqlDatabase", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QSqlDatabase()
    // 1: QSqlDatabase(QSqlDriver*)
    // 2: QSqlDatabase(QSqlDatabase)
    // 3: QSqlDatabase(QString)
    if (numArgs == 0) {
        overloadId = 0; // QSqlDatabase()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 3; // QSqlDatabase(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QSqlDatabase & >::isConvertible(arg)) {
        overloadId = 2; // QSqlDatabase(QSqlDatabase)
    } else if (numArgs == 1 && Shiboken::Converter<QSqlDriver * >::isConvertible(arg)) {
        overloadId = 1; // QSqlDatabase(QSqlDriver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabase_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSqlDatabase()
            {

                if(!PyErr_Occurred()) {
                // QSqlDatabase()
                cptr = new QSqlDatabase();
                }
                break;
            }
            case 1: // QSqlDatabase(QSqlDriver*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QSqlDriver* cpp_arg0 = Shiboken::Converter<QSqlDriver* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QSqlDatabase(QSqlDriver*)
                cptr = new QSqlDatabase(cpp_arg0);
                }
                break;
            }
            case 2: // QSqlDatabase(QSqlDatabase)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QSqlDatabase* cpp_arg0 = Shiboken::Converter<QSqlDatabase* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QSqlDatabase(QSqlDatabase)
                cptr = new QSqlDatabase(*cpp_arg0);
                }
                break;
            }
            case 3: // QSqlDatabase(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QSqlDatabase(QString)
                cptr = new QSqlDatabase(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlDatabase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSqlDatabase_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQSqlDatabase_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtSql.QSqlDriver", "PySide.QtSql.QSqlDatabase", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDatabase", overloads);
        return -1;
}

static PyObject* SbkQSqlDatabaseFunc_addDatabase(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "connectionName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.addDatabase(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.addDatabase(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.addDatabase(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addDatabase", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addDatabase(QSqlDriver*,QString)
    // 1: addDatabase(QString,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // addDatabase(QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // addDatabase(QString,QString)
        }
    } else if (Shiboken::Converter<QSqlDriver * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addDatabase(QSqlDriver*,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // addDatabase(QSqlDriver*,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_addDatabase_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addDatabase(QSqlDriver*,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "connectionName");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "connectionName";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.addDatabase(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSqlDriver* cpp_arg0 = Shiboken::Converter<QSqlDriver* >::toCpp(pyargs[0]);
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QLatin1String(QSqlDatabase::defaultConnection);

                if(!PyErr_Occurred()) {
                // addDatabase(QSqlDriver*,QString)
                QSqlDatabase cppResult = QSqlDatabase::addDatabase(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QSqlDatabase >::toPython(cppResult);
                }
                break;
            }
            case 1: // addDatabase(QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "connectionName");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "connectionName";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.addDatabase(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QLatin1String(QSqlDatabase::defaultConnection);

                if(!PyErr_Occurred()) {
                // addDatabase(QString,QString)
                QSqlDatabase cppResult = QSqlDatabase::addDatabase(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QSqlDatabase >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_addDatabase_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlDriver, QString = QLatin1String(defaultConnection)", "QString, QString = QLatin1String(defaultConnection)", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDatabase.addDatabase", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_cloneDatabase(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "cloneDatabase", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: cloneDatabase(QSqlDatabase,QString)
    if (numArgs == 2 && Shiboken::Converter<const QSqlDatabase & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // cloneDatabase(QSqlDatabase,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_cloneDatabase_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QSqlDatabase* cpp_arg0 = Shiboken::Converter<QSqlDatabase* >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // cloneDatabase(QSqlDatabase,QString)
            QSqlDatabase cppResult = QSqlDatabase::cloneDatabase(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QSqlDatabase >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_cloneDatabase_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlDatabase, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDatabase.cloneDatabase", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_close(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // close()
            cppSelf->QSqlDatabase::close();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSqlDatabaseFunc_commit(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // commit()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlDatabase::commit();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_connectOptions(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // connectOptions()const
            QString cppResult = cppSelf->QSqlDatabase::connectOptions();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_connectionName(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // connectionName()const
            QString cppResult = cppSelf->QSqlDatabase::connectionName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_connectionNames(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // connectionNames()
            QStringList cppResult = QSqlDatabase::connectionNames();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_contains(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "connectionName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.contains(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.contains(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:contains", &arg))
        return 0;


    // Overloaded function decisor
    // 0: contains(QString)
    if (numArgs == 0) {
        overloadId = 0; // contains(QString)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // contains(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_contains_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "connectionName");
                if (value) {
                    if (arg)
                        errorArgName = "connectionName";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.contains(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QLatin1String(QSqlDatabase::defaultConnection);

            if(!PyErr_Occurred()) {
            // contains(QString)
            bool cppResult = QSqlDatabase::contains(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_contains_TypeError:
        const char* overloads[] = {"QString = QLatin1String(defaultConnection)", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.contains", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_database(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "connectionName", "open" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.database(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.database(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:database", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: database(QString,bool)
    if (numArgs == 0) {
        overloadId = 0; // database(QString,bool)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // database(QString,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // database(QString,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_database_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "connectionName");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "connectionName";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "open");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "open";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.database(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QLatin1String(QSqlDatabase::defaultConnection);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // database(QString,bool)
            QSqlDatabase cppResult = QSqlDatabase::database(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QSqlDatabase >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_database_TypeError:
        const char* overloads[] = {"QString = QLatin1String(defaultConnection), bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDatabase.database", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_databaseName(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // databaseName()const
            QString cppResult = cppSelf->QSqlDatabase::databaseName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_driver(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // driver()const
            QSqlDriver * cppResult = cppSelf->QSqlDatabase::driver();
            pyResult = Shiboken::Converter<QSqlDriver * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_driverName(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // driverName()const
            QString cppResult = cppSelf->QSqlDatabase::driverName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_drivers(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // drivers()
            QStringList cppResult = QSqlDatabase::drivers();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_exec_(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "query" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.exec_(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.exec_(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:exec_", &arg))
        return 0;


    // Overloaded function decisor
    // 0: exec(QString)const
    if (numArgs == 0) {
        overloadId = 0; // exec(QString)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // exec(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_exec__TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "query");
                if (value) {
                    if (arg)
                        errorArgName = "query";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.exec_(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // exec(QString)const
            threadStateSaver.save();
            QSqlQuery cppResult = cppSelf->QSqlDatabase::exec(cpp_arg0);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<QSqlQuery >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_exec__TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.exec_", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_hostName(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hostName()const
            QString cppResult = cppSelf->QSqlDatabase::hostName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_isDriverAvailable(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isDriverAvailable(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // isDriverAvailable(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_isDriverAvailable_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isDriverAvailable(QString)
            bool cppResult = QSqlDatabase::isDriverAvailable(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_isDriverAvailable_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.isDriverAvailable", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_isOpen(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isOpen()const
            bool cppResult = cppSelf->QSqlDatabase::isOpen();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_isOpenError(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isOpenError()const
            bool cppResult = cppSelf->QSqlDatabase::isOpenError();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_isValid(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QSqlDatabase::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_lastError(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastError()const
            QSqlError cppResult = cppSelf->QSqlDatabase::lastError();
            pyResult = Shiboken::Converter<QSqlError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_numericalPrecisionPolicy(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numericalPrecisionPolicy()const
            QSql::NumericalPrecisionPolicy cppResult = cppSelf->QSqlDatabase::numericalPrecisionPolicy();
            pyResult = Shiboken::Converter<QSql::NumericalPrecisionPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_open(PyObject* self, PyObject* args)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto SbkQSqlDatabaseFunc_open_TypeError;

    if (!PyArg_UnpackTuple(args, "open", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: open()
    // 1: open(QString,QString)
    if (numArgs == 0) {
        overloadId = 0; // open()
    } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // open(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_open_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // open()
            {

                if(!PyErr_Occurred()) {
                // open()
                threadStateSaver.save();
                bool cppResult = cppSelf->QSqlDatabase::open();
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // open(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // open(QString,QString)
                threadStateSaver.save();
                bool cppResult = cppSelf->QSqlDatabase::open(cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_open_TypeError:
        const char* overloads[] = {"", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDatabase.open", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_password(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // password()const
            QString cppResult = cppSelf->QSqlDatabase::password();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_port(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // port()const
            int cppResult = cppSelf->QSqlDatabase::port();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_primaryIndex(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: primaryIndex(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // primaryIndex(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_primaryIndex_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // primaryIndex(QString)const
            QSqlIndex cppResult = cppSelf->QSqlDatabase::primaryIndex(cpp_arg0);
            pyResult = Shiboken::Converter<QSqlIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_primaryIndex_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.primaryIndex", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_record(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: record(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // record(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_record_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // record(QString)const
            QSqlRecord cppResult = cppSelf->QSqlDatabase::record(cpp_arg0);
            pyResult = Shiboken::Converter<QSqlRecord >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_record_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.record", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_registerSqlDriver(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "registerSqlDriver", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: registerSqlDriver(QString,QSqlDriverCreatorBase*)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QSqlDriverCreatorBase * >::isConvertible(pyargs[1])) {
        overloadId = 0; // registerSqlDriver(QString,QSqlDriverCreatorBase*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_registerSqlDriver_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QSqlDriverCreatorBase* cpp_arg1 = Shiboken::Converter<QSqlDriverCreatorBase* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // registerSqlDriver(QString,QSqlDriverCreatorBase*)
            QSqlDatabase::registerSqlDriver(cpp_arg0, cpp_arg1);

            // Ownership transferences.
            BindingManager::instance().transferOwnershipToCpp(pyargs[1]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_registerSqlDriver_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriverCreatorBase", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDatabase.registerSqlDriver", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_removeDatabase(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeDatabase(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeDatabase(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_removeDatabase_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeDatabase(QString)
            QSqlDatabase::removeDatabase(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_removeDatabase_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.removeDatabase", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_rollback(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // rollback()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlDatabase::rollback();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_setConnectOptions(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "options" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.setConnectOptions(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.setConnectOptions(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setConnectOptions", &arg))
        return 0;


    // Overloaded function decisor
    // 0: setConnectOptions(QString)
    if (numArgs == 0) {
        overloadId = 0; // setConnectOptions(QString)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setConnectOptions(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_setConnectOptions_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (arg)
                        errorArgName = "options";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.setConnectOptions(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // setConnectOptions(QString)
            cppSelf->QSqlDatabase::setConnectOptions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_setConnectOptions_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.setConnectOptions", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_setDatabaseName(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDatabaseName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDatabaseName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_setDatabaseName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDatabaseName(QString)
            cppSelf->QSqlDatabase::setDatabaseName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_setDatabaseName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.setDatabaseName", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_setHostName(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHostName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setHostName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_setHostName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHostName(QString)
            cppSelf->QSqlDatabase::setHostName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_setHostName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.setHostName", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_setNumericalPrecisionPolicy(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if (Shiboken::Converter<QSql::NumericalPrecisionPolicy >::isConvertible(arg)) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_setNumericalPrecisionPolicy_TypeError;

    // Call function/method
    {
        {
            QSql::NumericalPrecisionPolicy cpp_arg0 = Shiboken::Converter<QSql::NumericalPrecisionPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
            cppSelf->QSqlDatabase::setNumericalPrecisionPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_setNumericalPrecisionPolicy_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSql.NumericalPrecisionPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.setNumericalPrecisionPolicy", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_setPassword(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPassword(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_setPassword_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPassword(QString)
            cppSelf->QSqlDatabase::setPassword(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_setPassword_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.setPassword", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_setPort(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPort(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPort(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_setPort_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPort(int)
            cppSelf->QSqlDatabase::setPort(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_setPort_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.setPort", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_setUserName(PyObject* self, PyObject* arg)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setUserName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_setUserName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUserName(QString)
            cppSelf->QSqlDatabase::setUserName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDatabaseFunc_setUserName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.setUserName", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_tables(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.tables(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.tables(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:tables", &arg))
        return 0;


    // Overloaded function decisor
    // 0: tables(QSql::TableType)const
    if (numArgs == 0) {
        overloadId = 0; // tables(QSql::TableType)const
    } else if (Shiboken::Converter<QSql::TableType >::isConvertible(arg)) {
        overloadId = 0; // tables(QSql::TableType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDatabaseFunc_tables_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (arg)
                        errorArgName = "type";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDatabase.tables(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QSql::TableType cpp_arg0 = arg ? Shiboken::Converter<QSql::TableType >::toCpp(arg) : QSql::Tables;

            if(!PyErr_Occurred()) {
            // tables(QSql::TableType)const
            QStringList cppResult = cppSelf->QSqlDatabase::tables(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDatabaseFunc_tables_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSql.TableType = QSql.Tables", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDatabase.tables", overloads);
        return 0;
}

static PyObject* SbkQSqlDatabaseFunc_transaction(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // transaction()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlDatabase::transaction();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDatabaseFunc_userName(PyObject* self)
{
    QSqlDatabase* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDatabase* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userName()const
            QString cppResult = cppSelf->QSqlDatabase::userName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQSqlDatabase_methods[] = {
    {"addDatabase", (PyCFunction)SbkQSqlDatabaseFunc_addDatabase, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"cloneDatabase", (PyCFunction)SbkQSqlDatabaseFunc_cloneDatabase, METH_VARARGS|METH_STATIC},
    {"close", (PyCFunction)SbkQSqlDatabaseFunc_close, METH_NOARGS},
    {"commit", (PyCFunction)SbkQSqlDatabaseFunc_commit, METH_NOARGS},
    {"connectOptions", (PyCFunction)SbkQSqlDatabaseFunc_connectOptions, METH_NOARGS},
    {"connectionName", (PyCFunction)SbkQSqlDatabaseFunc_connectionName, METH_NOARGS},
    {"connectionNames", (PyCFunction)SbkQSqlDatabaseFunc_connectionNames, METH_NOARGS|METH_STATIC},
    {"contains", (PyCFunction)SbkQSqlDatabaseFunc_contains, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"database", (PyCFunction)SbkQSqlDatabaseFunc_database, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"databaseName", (PyCFunction)SbkQSqlDatabaseFunc_databaseName, METH_NOARGS},
    {"driver", (PyCFunction)SbkQSqlDatabaseFunc_driver, METH_NOARGS},
    {"driverName", (PyCFunction)SbkQSqlDatabaseFunc_driverName, METH_NOARGS},
    {"drivers", (PyCFunction)SbkQSqlDatabaseFunc_drivers, METH_NOARGS|METH_STATIC},
    {"exec_", (PyCFunction)SbkQSqlDatabaseFunc_exec_, METH_VARARGS|METH_KEYWORDS},
    {"hostName", (PyCFunction)SbkQSqlDatabaseFunc_hostName, METH_NOARGS},
    {"isDriverAvailable", (PyCFunction)SbkQSqlDatabaseFunc_isDriverAvailable, METH_O|METH_STATIC},
    {"isOpen", (PyCFunction)SbkQSqlDatabaseFunc_isOpen, METH_NOARGS},
    {"isOpenError", (PyCFunction)SbkQSqlDatabaseFunc_isOpenError, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQSqlDatabaseFunc_isValid, METH_NOARGS},
    {"lastError", (PyCFunction)SbkQSqlDatabaseFunc_lastError, METH_NOARGS},
    {"numericalPrecisionPolicy", (PyCFunction)SbkQSqlDatabaseFunc_numericalPrecisionPolicy, METH_NOARGS},
    {"open", (PyCFunction)SbkQSqlDatabaseFunc_open, METH_VARARGS},
    {"password", (PyCFunction)SbkQSqlDatabaseFunc_password, METH_NOARGS},
    {"port", (PyCFunction)SbkQSqlDatabaseFunc_port, METH_NOARGS},
    {"primaryIndex", (PyCFunction)SbkQSqlDatabaseFunc_primaryIndex, METH_O},
    {"record", (PyCFunction)SbkQSqlDatabaseFunc_record, METH_O},
    {"registerSqlDriver", (PyCFunction)SbkQSqlDatabaseFunc_registerSqlDriver, METH_VARARGS|METH_STATIC},
    {"removeDatabase", (PyCFunction)SbkQSqlDatabaseFunc_removeDatabase, METH_O|METH_STATIC},
    {"rollback", (PyCFunction)SbkQSqlDatabaseFunc_rollback, METH_NOARGS},
    {"setConnectOptions", (PyCFunction)SbkQSqlDatabaseFunc_setConnectOptions, METH_VARARGS|METH_KEYWORDS},
    {"setDatabaseName", (PyCFunction)SbkQSqlDatabaseFunc_setDatabaseName, METH_O},
    {"setHostName", (PyCFunction)SbkQSqlDatabaseFunc_setHostName, METH_O},
    {"setNumericalPrecisionPolicy", (PyCFunction)SbkQSqlDatabaseFunc_setNumericalPrecisionPolicy, METH_O},
    {"setPassword", (PyCFunction)SbkQSqlDatabaseFunc_setPassword, METH_O},
    {"setPort", (PyCFunction)SbkQSqlDatabaseFunc_setPort, METH_O},
    {"setUserName", (PyCFunction)SbkQSqlDatabaseFunc_setUserName, METH_O},
    {"tables", (PyCFunction)SbkQSqlDatabaseFunc_tables, METH_VARARGS|METH_KEYWORDS},
    {"transaction", (PyCFunction)SbkQSqlDatabaseFunc_transaction, METH_NOARGS},
    {"userName", (PyCFunction)SbkQSqlDatabaseFunc_userName, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSqlDatabase_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlDatabase",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSqlDatabase_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSqlDatabase_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSqlDatabase >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSqlDatabase",
    /*user_data*/           0
};
} //extern


void init_QSqlDatabase(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLDATABASE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSqlDatabase_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSqlDatabase_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSqlDatabase_Type));
    PyModule_AddObject(module, "QSqlDatabase",
        ((PyObject*)&SbkQSqlDatabase_Type));

    PyDict_SetItemString(SbkQSqlDatabase_Type.super.ht_type.tp_dict, "defaultConnection", Shiboken::Converter<const char * >::toPython(QSqlDatabase::defaultConnection));

    Shiboken::TypeResolver::createValueTypeResolver<QSqlDatabase >("QSqlDatabase");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDatabase >("QSqlDatabase*");
    Shiboken::TypeResolver::createValueTypeResolver<QSqlDatabase >(typeid(QSqlDatabase).name());
    PySide::initQtMetaType<QSqlDatabase >();
}

