/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtsql_python.h"

#include "qsqldriver_wrapper.h"

// Extra includes
#include <QList>
#include <QSize>
#include <QSqlError>
#include <QSqlIndex>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsqldriver.h>
#include <qsqlerror.h>
#include <qsqlfield.h>
#include <qsqlindex.h>
#include <qsqlrecord.h>
#include <qsqlresult.h>
#include <qthread.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QSqlDriverWrapper::QSqlDriverWrapper(QObject * parent) : QSqlDriver(parent), m_metaObject(0) {
    // ... middle
}

bool QSqlDriverWrapper::beginTransaction()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "beginTransaction"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QSqlDriver::beginTransaction();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.beginTransaction", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSqlDriverWrapper::close()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.close()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QSqlDriverWrapper::commitTransaction()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "commitTransaction"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QSqlDriver::commitTransaction();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.commitTransaction", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QSqlResult * QSqlDriverWrapper::createResult() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createResult"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.createResult()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSqlResult * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.createResult", SbkType<QSqlResult * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QSqlResult * cppResult(Shiboken::Converter<QSqlResult * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QSqlDriver.createResult");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QSqlDriverWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSqlDriverWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QString QSqlDriverWrapper::escapeIdentifier(const QString & identifier, QSqlDriver::IdentifierType type) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "escapeIdentifier"));
    if (py_override.isNull()) {
        return this->QSqlDriver::escapeIdentifier(identifier, type);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QString >::toPython(identifier),
        Shiboken::Converter<QSqlDriver::IdentifierType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.escapeIdentifier", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QSqlDriverWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QString QSqlDriverWrapper::formatValue(const QSqlField & field, bool trimStrings) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "formatValue"));
    if (py_override.isNull()) {
        return this->QSqlDriver::formatValue(field, trimStrings);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QSqlField & >::toPython(field),
        Shiboken::Converter<bool >::toPython(trimStrings)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.formatValue", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::hasFeature(QSqlDriver::DriverFeature f) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasFeature"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.hasFeature()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QSqlDriver::DriverFeature >::toPython(f)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.hasFeature", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::isOpen() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isOpen"));
    if (py_override.isNull()) {
        return this->QSqlDriver::isOpen();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.isOpen", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::open(const QString & db, const QString & user, const QString & password, const QString & host, int port, const QString & connOpts)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.open()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNNiN)",
        Shiboken::Converter<QString >::toPython(db),
        Shiboken::Converter<QString >::toPython(user),
        Shiboken::Converter<QString >::toPython(password),
        Shiboken::Converter<QString >::toPython(host),
        port,
        Shiboken::Converter<QString >::toPython(connOpts)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QSqlIndex QSqlDriverWrapper::primaryIndex(const QString & tableName) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "primaryIndex"));
    if (py_override.isNull()) {
        return this->QSqlDriver::primaryIndex(tableName);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(tableName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSqlIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSqlIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.primaryIndex", SbkType<QSqlIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QSqlIndex();
    }
    QSqlIndex cppResult(Shiboken::Converter<QSqlIndex >::toCpp(pyResult));
    return cppResult;
}

QSqlRecord QSqlDriverWrapper::record(const QString & tableName) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "record"));
    if (py_override.isNull()) {
        return this->QSqlDriver::record(tableName);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(tableName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSqlRecord();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSqlRecord >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.record", SbkType<QSqlRecord >()->tp_name, pyResult->ob_type->tp_name);
        return QSqlRecord();
    }
    QSqlRecord cppResult(Shiboken::Converter<QSqlRecord >::toCpp(pyResult));
    return cppResult;
}

bool QSqlDriverWrapper::rollbackTransaction()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "rollbackTransaction"));
    if (py_override.isNull()) {
        Shiboken::ThreadStateSaver threadStateSaver;
        threadStateSaver.save();
        return this->QSqlDriver::rollbackTransaction();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.rollbackTransaction", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::setLastError(const QSqlError & e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setLastError"));
    if (py_override.isNull()) {
        return this->QSqlDriver::setLastError(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QSqlError & >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSqlDriverWrapper::setOpen(bool o)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setOpen"));
    if (py_override.isNull()) {
        return this->QSqlDriver::setOpen(o);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(o)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSqlDriverWrapper::setOpenError(bool e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setOpenError"));
    if (py_override.isNull()) {
        return this->QSqlDriver::setOpenError(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QString QSqlDriverWrapper::sqlStatement(QSqlDriver::StatementType type, const QString & tableName, const QSqlRecord & rec, bool preparedStatement) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sqlStatement"));
    if (py_override.isNull()) {
        return this->QSqlDriver::sqlStatement(type, tableName, rec, preparedStatement);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter<QSqlDriver::StatementType >::toPython(type),
        Shiboken::Converter<QString >::toPython(tableName),
        Shiboken::Converter<const QSqlRecord & >::toPython(rec),
        Shiboken::Converter<bool >::toPython(preparedStatement)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.sqlStatement", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

QStringList QSqlDriverWrapper::tables(QSql::TableType tableType) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tables"));
    if (py_override.isNull()) {
        return this->QSqlDriver::tables(tableType);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QSql::TableType >::toPython(tableType)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSqlDriver.tables", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter<QStringList >::toCpp(pyResult));
    return cppResult;
}

void QSqlDriverWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QSqlDriverWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QSqlDriver::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QSqlDriverWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QSqlDriver::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QSqlDriverWrapper::~QSqlDriverWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSqlDriver_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlDriver >()))
        return -1;

    QSqlDriverWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QSqlDriver' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QSqlDriver", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QSqlDriver(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSqlDriver(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // QSqlDriver(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriver_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QSqlDriver(QObject*)
            cptr = new QSqlDriverWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlDriver >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSqlDriver_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQSqlDriver_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver", overloads);
        return -1;
}

static PyObject* SbkQSqlDriverFunc_beginTransaction(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // beginTransaction()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlDriver::beginTransaction();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_close(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // close()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.close()' not implemented.");
                return 0;
            }
            cppSelf->close();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQSqlDriverFunc_commitTransaction(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // commitTransaction()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlDriver::commitTransaction();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_createResult(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // createResult()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.createResult()' not implemented.");
                return 0;
            }
            QSqlResult * cppResult = cppSelf->createResult();
            pyResult = Shiboken::Converter<QSqlResult * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_escapeIdentifier(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "escapeIdentifier", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: escapeIdentifier(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // escapeIdentifier(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_escapeIdentifier_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cpp_arg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // escapeIdentifier(QString,QSqlDriver::IdentifierType)const
            QString cppResult = cppSelf->QSqlDriver::escapeIdentifier(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_escapeIdentifier_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.escapeIdentifier", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_formatValue(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "trimStrings" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver.formatValue(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.formatValue(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.formatValue(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:formatValue", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: formatValue(QSqlField,bool)const
    if (Shiboken::Converter<const QSqlField & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // formatValue(QSqlField,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // formatValue(QSqlField,bool)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_formatValue_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "trimStrings");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "trimStrings";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver.formatValue(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QSqlField* cpp_arg0 = Shiboken::Converter<QSqlField* >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // formatValue(QSqlField,bool)const
            QString cppResult = cppSelf->QSqlDriver::formatValue(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_formatValue_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlField, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.formatValue", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_hasFeature(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasFeature(QSqlDriver::DriverFeature)const
    if (Shiboken::Converter<QSqlDriver::DriverFeature >::isConvertible(arg)) {
        overloadId = 0; // hasFeature(QSqlDriver::DriverFeature)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_hasFeature_TypeError;

    // Call function/method
    {
        {
            QSqlDriver::DriverFeature cpp_arg0 = Shiboken::Converter<QSqlDriver::DriverFeature >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasFeature(QSqlDriver::DriverFeature)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.hasFeature()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->hasFeature(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_hasFeature_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlDriver.DriverFeature", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.hasFeature", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_isIdentifierEscaped(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isIdentifierEscaped", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_isIdentifierEscaped_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cpp_arg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // isIdentifierEscaped(QString,QSqlDriver::IdentifierType)const
            bool cppResult = cppSelf->QSqlDriver::isIdentifierEscaped(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_isIdentifierEscaped_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.isIdentifierEscaped", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_isIdentifierEscapedImplementation(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isIdentifierEscapedImplementation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isIdentifierEscapedImplementation(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // isIdentifierEscapedImplementation(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_isIdentifierEscapedImplementation_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cpp_arg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // isIdentifierEscapedImplementation(QString,QSqlDriver::IdentifierType)const
            bool cppResult = cppSelf->QSqlDriver::isIdentifierEscapedImplementation(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_isIdentifierEscapedImplementation_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.isIdentifierEscapedImplementation", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_isOpen(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isOpen()const
            bool cppResult = cppSelf->QSqlDriver::isOpen();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_isOpenError(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isOpenError()const
            bool cppResult = cppSelf->QSqlDriver::isOpenError();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_lastError(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastError()const
            QSqlError cppResult = cppSelf->QSqlDriver::lastError();
            pyResult = Shiboken::Converter<QSqlError >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_numericalPrecisionPolicy(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // numericalPrecisionPolicy()const
            QSql::NumericalPrecisionPolicy cppResult = cppSelf->QSqlDriver::numericalPrecisionPolicy();
            pyResult = Shiboken::Converter<QSql::NumericalPrecisionPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_open(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "connOpts", "host", "password", "port", "user" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 5, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver.open(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.open(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlDriver.open(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:open", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: open(QString,QString,QString,QString,int,QString)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // open(QString,QString,QString,QString,int,QString)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                    } else if (SbkNumber_Check(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[5])) {
                            overloadId = 0; // open(QString,QString,QString,QString,int,QString)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_open_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "user");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "user";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "password");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "password";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "host");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "host";
                    else
                        pyargs[3] = value;
                }
                value = PyDict_GetItemString(kwds, "port");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "port";
                    else
                        pyargs[4] = value;
                }
                value = PyDict_GetItemString(kwds, "connOpts");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "connOpts";
                    else
                        pyargs[5] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlDriver.open(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
            QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
            int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : -1;
            QString cpp_arg5 = pyargs[5] ? Shiboken::Converter<QString >::toCpp(pyargs[5]) : QString();

            if(!PyErr_Occurred()) {
            // open(QString,QString,QString,QString,int,QString)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QSqlDriver.open()' not implemented.");
                return 0;
            }
            threadStateSaver.save();
            bool cppResult = cppSelf->open(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_open_TypeError:
        const char* overloads[] = {"QString, QString = QString(), QString = QString(), QString = QString(), int = -1, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.open", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_primaryIndex(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: primaryIndex(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // primaryIndex(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_primaryIndex_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // primaryIndex(QString)const
            QSqlIndex cppResult = cppSelf->QSqlDriver::primaryIndex(cpp_arg0);
            pyResult = Shiboken::Converter<QSqlIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_primaryIndex_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.primaryIndex", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_record(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: record(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // record(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_record_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // record(QString)const
            QSqlRecord cppResult = cppSelf->QSqlDriver::record(cpp_arg0);
            pyResult = Shiboken::Converter<QSqlRecord >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_record_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.record", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_rollbackTransaction(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        {

            if(!PyErr_Occurred()) {
            // rollbackTransaction()
            threadStateSaver.save();
            bool cppResult = cppSelf->QSqlDriver::rollbackTransaction();
            threadStateSaver.restore();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_setLastError(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLastError(QSqlError)
    if (Shiboken::Converter<const QSqlError & >::isConvertible(arg)) {
        overloadId = 0; // setLastError(QSqlError)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_setLastError_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSqlError* cpp_arg0 = Shiboken::Converter<QSqlError* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLastError(QSqlError)
            cppSelf->QSqlDriver::setLastError(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDriverFunc_setLastError_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlError", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setLastError", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_setNumericalPrecisionPolicy(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    if (Shiboken::Converter<QSql::NumericalPrecisionPolicy >::isConvertible(arg)) {
        overloadId = 0; // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_setNumericalPrecisionPolicy_TypeError;

    // Call function/method
    {
        {
            QSql::NumericalPrecisionPolicy cpp_arg0 = Shiboken::Converter<QSql::NumericalPrecisionPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy)
            cppSelf->QSqlDriver::setNumericalPrecisionPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDriverFunc_setNumericalPrecisionPolicy_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSql.NumericalPrecisionPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setNumericalPrecisionPolicy", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_setOpen(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpen(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOpen(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_setOpen_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOpen(bool)
            cppSelf->QSqlDriver::setOpen(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDriverFunc_setOpen_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setOpen", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_setOpenError(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpenError(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOpenError(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_setOpenError_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOpenError(bool)
            cppSelf->QSqlDriver::setOpenError(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlDriverFunc_setOpenError_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.setOpenError", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_sqlStatement(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sqlStatement", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
    if (numArgs == 4 && Shiboken::Converter<QSqlDriver::StatementType >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<const QSqlRecord & >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_sqlStatement_TypeError;

    // Call function/method
    {
        {
            QSqlDriver::StatementType cpp_arg0 = Shiboken::Converter<QSqlDriver::StatementType >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QSqlRecord* cpp_arg2 = Shiboken::Converter<QSqlRecord* >::toCpp(pyargs[2]);
            bool cpp_arg3 = Shiboken::Converter<bool >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // sqlStatement(QSqlDriver::StatementType,QString,QSqlRecord,bool)const
            QString cppResult = cppSelf->QSqlDriver::sqlStatement(cpp_arg0, cpp_arg1, *cpp_arg2, cpp_arg3);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_sqlStatement_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlDriver.StatementType, QString, PySide.QtSql.QSqlRecord, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.sqlStatement", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_stripDelimiters(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "stripDelimiters", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: stripDelimiters(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // stripDelimiters(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_stripDelimiters_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cpp_arg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // stripDelimiters(QString,QSqlDriver::IdentifierType)const
            QString cppResult = cppSelf->QSqlDriver::stripDelimiters(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_stripDelimiters_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.stripDelimiters", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_stripDelimitersImplementation(PyObject* self, PyObject* args)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "stripDelimitersImplementation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: stripDelimitersImplementation(QString,QSqlDriver::IdentifierType)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QSqlDriver::IdentifierType >::isConvertible(pyargs[1])) {
        overloadId = 0; // stripDelimitersImplementation(QString,QSqlDriver::IdentifierType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_stripDelimitersImplementation_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QSqlDriver::IdentifierType cpp_arg1 = Shiboken::Converter<QSqlDriver::IdentifierType >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // stripDelimitersImplementation(QString,QSqlDriver::IdentifierType)const
            QString cppResult = cppSelf->QSqlDriver::stripDelimitersImplementation(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_stripDelimitersImplementation_TypeError:
        const char* overloads[] = {"QString, PySide.QtSql.QSqlDriver.IdentifierType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlDriver.stripDelimitersImplementation", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_subscribeToNotification(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subscribeToNotification(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // subscribeToNotification(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_subscribeToNotification_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // subscribeToNotification(QString)
            bool cppResult = cppSelf->QSqlDriver::subscribeToNotification(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_subscribeToNotification_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.subscribeToNotification", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_subscribeToNotificationImplementation(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subscribeToNotificationImplementation(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // subscribeToNotificationImplementation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_subscribeToNotificationImplementation_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // subscribeToNotificationImplementation(QString)
            bool cppResult = cppSelf->QSqlDriver::subscribeToNotificationImplementation(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_subscribeToNotificationImplementation_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.subscribeToNotificationImplementation", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_subscribedToNotifications(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // subscribedToNotifications()const
            QStringList cppResult = cppSelf->QSqlDriver::subscribedToNotifications();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_subscribedToNotificationsImplementation(PyObject* self)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // subscribedToNotificationsImplementation()const
            QStringList cppResult = cppSelf->QSqlDriver::subscribedToNotificationsImplementation();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlDriverFunc_tables(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tables(QSql::TableType)const
    if (Shiboken::Converter<QSql::TableType >::isConvertible(arg)) {
        overloadId = 0; // tables(QSql::TableType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_tables_TypeError;

    // Call function/method
    {
        {
            QSql::TableType cpp_arg0 = Shiboken::Converter<QSql::TableType >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // tables(QSql::TableType)const
            QStringList cppResult = cppSelf->QSqlDriver::tables(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_tables_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSql.TableType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.tables", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_unsubscribeFromNotification(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unsubscribeFromNotification(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // unsubscribeFromNotification(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_unsubscribeFromNotification_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // unsubscribeFromNotification(QString)
            bool cppResult = cppSelf->QSqlDriver::unsubscribeFromNotification(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_unsubscribeFromNotification_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.unsubscribeFromNotification", overloads);
        return 0;
}

static PyObject* SbkQSqlDriverFunc_unsubscribeFromNotificationImplementation(PyObject* self, PyObject* arg)
{
    QSqlDriver* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlDriver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unsubscribeFromNotificationImplementation(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // unsubscribeFromNotificationImplementation(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlDriverFunc_unsubscribeFromNotificationImplementation_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // unsubscribeFromNotificationImplementation(QString)
            bool cppResult = cppSelf->QSqlDriver::unsubscribeFromNotificationImplementation(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlDriverFunc_unsubscribeFromNotificationImplementation_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlDriver.unsubscribeFromNotificationImplementation", overloads);
        return 0;
}

static PyMethodDef SbkQSqlDriver_methods[] = {
    {"beginTransaction", (PyCFunction)SbkQSqlDriverFunc_beginTransaction, METH_NOARGS},
    {"close", (PyCFunction)SbkQSqlDriverFunc_close, METH_NOARGS},
    {"commitTransaction", (PyCFunction)SbkQSqlDriverFunc_commitTransaction, METH_NOARGS},
    {"createResult", (PyCFunction)SbkQSqlDriverFunc_createResult, METH_NOARGS},
    {"escapeIdentifier", (PyCFunction)SbkQSqlDriverFunc_escapeIdentifier, METH_VARARGS},
    {"formatValue", (PyCFunction)SbkQSqlDriverFunc_formatValue, METH_VARARGS|METH_KEYWORDS},
    {"hasFeature", (PyCFunction)SbkQSqlDriverFunc_hasFeature, METH_O},
    {"isIdentifierEscaped", (PyCFunction)SbkQSqlDriverFunc_isIdentifierEscaped, METH_VARARGS},
    {"isIdentifierEscapedImplementation", (PyCFunction)SbkQSqlDriverFunc_isIdentifierEscapedImplementation, METH_VARARGS},
    {"isOpen", (PyCFunction)SbkQSqlDriverFunc_isOpen, METH_NOARGS},
    {"isOpenError", (PyCFunction)SbkQSqlDriverFunc_isOpenError, METH_NOARGS},
    {"lastError", (PyCFunction)SbkQSqlDriverFunc_lastError, METH_NOARGS},
    {"numericalPrecisionPolicy", (PyCFunction)SbkQSqlDriverFunc_numericalPrecisionPolicy, METH_NOARGS},
    {"open", (PyCFunction)SbkQSqlDriverFunc_open, METH_VARARGS|METH_KEYWORDS},
    {"primaryIndex", (PyCFunction)SbkQSqlDriverFunc_primaryIndex, METH_O},
    {"record", (PyCFunction)SbkQSqlDriverFunc_record, METH_O},
    {"rollbackTransaction", (PyCFunction)SbkQSqlDriverFunc_rollbackTransaction, METH_NOARGS},
    {"setLastError", (PyCFunction)SbkQSqlDriverFunc_setLastError, METH_O},
    {"setNumericalPrecisionPolicy", (PyCFunction)SbkQSqlDriverFunc_setNumericalPrecisionPolicy, METH_O},
    {"setOpen", (PyCFunction)SbkQSqlDriverFunc_setOpen, METH_O},
    {"setOpenError", (PyCFunction)SbkQSqlDriverFunc_setOpenError, METH_O},
    {"sqlStatement", (PyCFunction)SbkQSqlDriverFunc_sqlStatement, METH_VARARGS},
    {"stripDelimiters", (PyCFunction)SbkQSqlDriverFunc_stripDelimiters, METH_VARARGS},
    {"stripDelimitersImplementation", (PyCFunction)SbkQSqlDriverFunc_stripDelimitersImplementation, METH_VARARGS},
    {"subscribeToNotification", (PyCFunction)SbkQSqlDriverFunc_subscribeToNotification, METH_O},
    {"subscribeToNotificationImplementation", (PyCFunction)SbkQSqlDriverFunc_subscribeToNotificationImplementation, METH_O},
    {"subscribedToNotifications", (PyCFunction)SbkQSqlDriverFunc_subscribedToNotifications, METH_NOARGS},
    {"subscribedToNotificationsImplementation", (PyCFunction)SbkQSqlDriverFunc_subscribedToNotificationsImplementation, METH_NOARGS},
    {"tables", (PyCFunction)SbkQSqlDriverFunc_tables, METH_O},
    {"unsubscribeFromNotification", (PyCFunction)SbkQSqlDriverFunc_unsubscribeFromNotification, METH_O},
    {"unsubscribeFromNotificationImplementation", (PyCFunction)SbkQSqlDriverFunc_unsubscribeFromNotificationImplementation, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSqlDriver_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlDriver",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSqlDriver_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSqlDriver_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSqlDriver >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSqlDriver*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQSqlDriver_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QSqlDriver*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQSqlDriver_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtSql_QSqlDriver_StatementType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtSql_QSqlDriver_StatementType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtSql_QSqlDriver_StatementType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StatementType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtSql_QSqlDriver_StatementType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtSql_QSqlDriver_StatementType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtSql_QSqlDriver_StatementType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtSql_QSqlDriver_IdentifierType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtSql_QSqlDriver_IdentifierType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtSql_QSqlDriver_IdentifierType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "IdentifierType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtSql_QSqlDriver_IdentifierType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtSql_QSqlDriver_IdentifierType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtSql_QSqlDriver_IdentifierType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtSql_QSqlDriver_DriverFeature_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtSql_QSqlDriver_DriverFeature_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtSql_QSqlDriver_DriverFeature_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DriverFeature",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtSql_QSqlDriver_DriverFeature_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtSql_QSqlDriver_DriverFeature_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtSql_QSqlDriver_DriverFeature_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QSqlDriver(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSqlDriver_Type);

    SbkQSqlDriver_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQSqlDriver_Type.type_discovery = &SbkQSqlDriver_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQSqlDriver_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSqlDriver_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSqlDriver_Type));
    PyModule_AddObject(module, "QSqlDriver",
        ((PyObject*)&SbkQSqlDriver_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: StatementType
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_STATEMENTTYPE_IDX] = &SbkPySide_QtSql_QSqlDriver_StatementType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtSql_QSqlDriver_StatementType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtSql_QSqlDriver_StatementType_Type);
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
            "StatementType",((PyObject*)&SbkPySide_QtSql_QSqlDriver_StatementType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_StatementType_Type,
        (long) QSqlDriver::WhereStatement, "WhereStatement");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "WhereStatement", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType_Type.tp_dict,
        "WhereStatement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_StatementType_Type,
        (long) QSqlDriver::SelectStatement, "SelectStatement");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "SelectStatement", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType_Type.tp_dict,
        "SelectStatement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_StatementType_Type,
        (long) QSqlDriver::UpdateStatement, "UpdateStatement");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "UpdateStatement", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType_Type.tp_dict,
        "UpdateStatement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_StatementType_Type,
        (long) QSqlDriver::InsertStatement, "InsertStatement");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "InsertStatement", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType_Type.tp_dict,
        "InsertStatement", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_StatementType_Type,
        (long) QSqlDriver::DeleteStatement, "DeleteStatement");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "DeleteStatement", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_StatementType_Type.tp_dict,
        "DeleteStatement", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver::StatementType");

    // init enum class: IdentifierType
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_IDENTIFIERTYPE_IDX] = &SbkPySide_QtSql_QSqlDriver_IdentifierType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtSql_QSqlDriver_IdentifierType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtSql_QSqlDriver_IdentifierType_Type);
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
            "IdentifierType",((PyObject*)&SbkPySide_QtSql_QSqlDriver_IdentifierType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_IdentifierType_Type,
        (long) QSqlDriver::FieldName, "FieldName");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "FieldName", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_IdentifierType_Type.tp_dict,
        "FieldName", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_IdentifierType_Type,
        (long) QSqlDriver::TableName, "TableName");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "TableName", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_IdentifierType_Type.tp_dict,
        "TableName", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver::IdentifierType");

    // init enum class: DriverFeature
    SbkPySide_QtSqlTypes[SBK_QSQLDRIVER_DRIVERFEATURE_IDX] = &SbkPySide_QtSql_QSqlDriver_DriverFeature_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type);
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
            "DriverFeature",((PyObject*)&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::Transactions, "Transactions");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "Transactions", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "Transactions", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::QuerySize, "QuerySize");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "QuerySize", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "QuerySize", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::BLOB, "BLOB");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "BLOB", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "BLOB", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::Unicode, "Unicode");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "Unicode", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "Unicode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::PreparedQueries, "PreparedQueries");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "PreparedQueries", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "PreparedQueries", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::NamedPlaceholders, "NamedPlaceholders");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "NamedPlaceholders", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "NamedPlaceholders", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::PositionalPlaceholders, "PositionalPlaceholders");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "PositionalPlaceholders", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "PositionalPlaceholders", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::LastInsertId, "LastInsertId");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "LastInsertId", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "LastInsertId", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::BatchOperations, "BatchOperations");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "BatchOperations", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "BatchOperations", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::SimpleLocking, "SimpleLocking");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "SimpleLocking", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "SimpleLocking", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::LowPrecisionNumbers, "LowPrecisionNumbers");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "LowPrecisionNumbers", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "LowPrecisionNumbers", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::EventNotifications, "EventNotifications");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "EventNotifications", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "EventNotifications", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::FinishQuery, "FinishQuery");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "FinishQuery", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "FinishQuery", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlDriver_DriverFeature_Type,
        (long) QSqlDriver::MultipleResultSets, "MultipleResultSets");
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict,
        "MultipleResultSets", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlDriver_DriverFeature_Type.tp_dict,
        "MultipleResultSets", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlDriver::DriverFeature");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("notification", "const QString&", NULL);
    PyDict_SetItemString(SbkQSqlDriver_Type.super.ht_type.tp_dict, "notification", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDriver >("QSqlDriver*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDriver >(typeid(QSqlDriver).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlDriver >(typeid(QSqlDriverWrapper).name());
    PySide::initQtMetaType<QSqlDriver* >();
}

