/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtsql_python.h"

#include "qsqlerror_wrapper.h"

// Extra includes
#include <qsqlerror.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSqlError_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlError >()))
        return -1;

    QSqlError* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "databaseText", "driverText", "number", "type" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlError(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlError(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QSqlError", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QSqlError(QSqlError)
    // 1: QSqlError(QString,QString,QSqlError::ErrorType,int)
    if (numArgs == 0) {
        overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
            } else if (Shiboken::Converter<QSqlError::ErrorType >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
                } else if (SbkNumber_Check(pyargs[3])) {
                    overloadId = 1; // QSqlError(QString,QString,QSqlError::ErrorType,int)
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QSqlError & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QSqlError(QSqlError)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlError_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSqlError(QSqlError)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSqlError* cpp_arg0 = Shiboken::Converter<QSqlError* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QSqlError(QSqlError)
                cptr = new QSqlError(*cpp_arg0);
                }
                break;
            }
            case 1: // QSqlError(QString,QString,QSqlError::ErrorType,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "driverText");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "driverText";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "databaseText");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "databaseText";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "type";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "number");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "number";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlError(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
                QSqlError::ErrorType cpp_arg2 = pyargs[2] ? Shiboken::Converter<QSqlError::ErrorType >::toCpp(pyargs[2]) : QSqlError::NoError;
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : -1;

                if(!PyErr_Occurred()) {
                // QSqlError(QString,QString,QSqlError::ErrorType,int)
                cptr = new QSqlError(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSqlError_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQSqlError_Init_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlError", "QString = QString(), QString = QString(), PySide.QtSql.QSqlError.ErrorType = NoError, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlError", overloads);
        return -1;
}

static PyObject* SbkQSqlErrorFunc_databaseText(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // databaseText()const
            QString cppResult = cppSelf->QSqlError::databaseText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlErrorFunc_driverText(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // driverText()const
            QString cppResult = cppSelf->QSqlError::driverText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlErrorFunc_isValid(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QSqlError::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlErrorFunc_number(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // number()const
            int cppResult = cppSelf->QSqlError::number();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlErrorFunc_setDatabaseText(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDatabaseText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDatabaseText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlErrorFunc_setDatabaseText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDatabaseText(QString)
            cppSelf->QSqlError::setDatabaseText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlErrorFunc_setDatabaseText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setDatabaseText", overloads);
        return 0;
}

static PyObject* SbkQSqlErrorFunc_setDriverText(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDriverText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDriverText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlErrorFunc_setDriverText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDriverText(QString)
            cppSelf->QSqlError::setDriverText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlErrorFunc_setDriverText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setDriverText", overloads);
        return 0;
}

static PyObject* SbkQSqlErrorFunc_setNumber(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumber(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNumber(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlErrorFunc_setNumber_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNumber(int)
            cppSelf->QSqlError::setNumber(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlErrorFunc_setNumber_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setNumber", overloads);
        return 0;
}

static PyObject* SbkQSqlErrorFunc_setType(PyObject* self, PyObject* arg)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setType(QSqlError::ErrorType)
    if (Shiboken::Converter<QSqlError::ErrorType >::isConvertible(arg)) {
        overloadId = 0; // setType(QSqlError::ErrorType)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlErrorFunc_setType_TypeError;

    // Call function/method
    {
        {
            QSqlError::ErrorType cpp_arg0 = Shiboken::Converter<QSqlError::ErrorType >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setType(QSqlError::ErrorType)
            cppSelf->QSqlError::setType(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlErrorFunc_setType_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlError.ErrorType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlError.setType", overloads);
        return 0;
}

static PyObject* SbkQSqlErrorFunc_text(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QString cppResult = cppSelf->QSqlError::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlErrorFunc_type(PyObject* self)
{
    QSqlError* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlError* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            QSqlError::ErrorType cppResult = cppSelf->QSqlError::type();
            pyResult = Shiboken::Converter<QSqlError::ErrorType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQSqlError_methods[] = {
    {"databaseText", (PyCFunction)SbkQSqlErrorFunc_databaseText, METH_NOARGS},
    {"driverText", (PyCFunction)SbkQSqlErrorFunc_driverText, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQSqlErrorFunc_isValid, METH_NOARGS},
    {"number", (PyCFunction)SbkQSqlErrorFunc_number, METH_NOARGS},
    {"setDatabaseText", (PyCFunction)SbkQSqlErrorFunc_setDatabaseText, METH_O},
    {"setDriverText", (PyCFunction)SbkQSqlErrorFunc_setDriverText, METH_O},
    {"setNumber", (PyCFunction)SbkQSqlErrorFunc_setNumber, METH_O},
    {"setType", (PyCFunction)SbkQSqlErrorFunc_setType, METH_O},
    {"text", (PyCFunction)SbkQSqlErrorFunc_text, METH_NOARGS},
    {"type", (PyCFunction)SbkQSqlErrorFunc_type, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSqlError_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlError",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSqlError_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSqlError_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSqlError >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSqlError",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtSql_QSqlError_ErrorType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtSql_QSqlError_ErrorType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtSql_QSqlError_ErrorType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ErrorType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtSql_QSqlError_ErrorType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtSql_QSqlError_ErrorType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtSql_QSqlError_ErrorType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QSqlError(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLERROR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSqlError_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSqlError_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSqlError_Type));
    PyModule_AddObject(module, "QSqlError",
        ((PyObject*)&SbkQSqlError_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: ErrorType
    SbkPySide_QtSqlTypes[SBK_QSQLERROR_ERRORTYPE_IDX] = &SbkPySide_QtSql_QSqlError_ErrorType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtSql_QSqlError_ErrorType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtSql_QSqlError_ErrorType_Type);
    PyDict_SetItemString(SbkQSqlError_Type.super.ht_type.tp_dict,
            "ErrorType",((PyObject*)&SbkPySide_QtSql_QSqlError_ErrorType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlError_ErrorType_Type,
        (long) QSqlError::NoError, "NoError");
    PyDict_SetItemString(SbkQSqlError_Type.super.ht_type.tp_dict,
        "NoError", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType_Type.tp_dict,
        "NoError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlError_ErrorType_Type,
        (long) QSqlError::ConnectionError, "ConnectionError");
    PyDict_SetItemString(SbkQSqlError_Type.super.ht_type.tp_dict,
        "ConnectionError", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType_Type.tp_dict,
        "ConnectionError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlError_ErrorType_Type,
        (long) QSqlError::StatementError, "StatementError");
    PyDict_SetItemString(SbkQSqlError_Type.super.ht_type.tp_dict,
        "StatementError", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType_Type.tp_dict,
        "StatementError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlError_ErrorType_Type,
        (long) QSqlError::TransactionError, "TransactionError");
    PyDict_SetItemString(SbkQSqlError_Type.super.ht_type.tp_dict,
        "TransactionError", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType_Type.tp_dict,
        "TransactionError", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtSql_QSqlError_ErrorType_Type,
        (long) QSqlError::UnknownError, "UnknownError");
    PyDict_SetItemString(SbkQSqlError_Type.super.ht_type.tp_dict,
        "UnknownError", enum_item);
    PyDict_SetItemString(SbkPySide_QtSql_QSqlError_ErrorType_Type.tp_dict,
        "UnknownError", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSqlError::ErrorType");


    Shiboken::TypeResolver::createValueTypeResolver<QSqlError >("QSqlError");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlError >("QSqlError*");
    Shiboken::TypeResolver::createValueTypeResolver<QSqlError >(typeid(QSqlError).name());
    PySide::initQtMetaType<QSqlError >();
}

