/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtsql_python.h"

#include "qsqlindex_wrapper.h"

// Extra includes
#include <qsqlfield.h>
#include <qsqlindex.h>
#include <qsqlrecord.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSqlIndex_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSqlIndex >()))
        return -1;

    QSqlIndex* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "cursorName", "name" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlIndex(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSql.QSqlIndex(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QSqlIndex", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QSqlIndex(QSqlIndex)
    // 1: QSqlIndex(QString,QString)
    if (numArgs == 0) {
        overloadId = 1; // QSqlIndex(QString,QString)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QSqlIndex(QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // QSqlIndex(QString,QString)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QSqlIndex & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QSqlIndex(QSqlIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlIndex_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSqlIndex(QSqlIndex)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QSqlIndex* cpp_arg0 = Shiboken::Converter<QSqlIndex* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QSqlIndex(QSqlIndex)
                cptr = new QSqlIndex(*cpp_arg0);
                }
                break;
            }
            case 1: // QSqlIndex(QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "cursorName");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "cursorName";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "name");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "name";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSql.QSqlIndex(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

                if(!PyErr_Occurred()) {
                // QSqlIndex(QString,QString)
                cptr = new QSqlIndex(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSqlIndex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSqlIndex_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQSqlIndex_Init_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlIndex", "QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlIndex", overloads);
        return -1;
}

static PyObject* SbkQSqlIndexFunc_append(PyObject* self, PyObject* args)
{
    QSqlIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlIndex* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "append", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: append(QSqlField)
    // 1: append(QSqlField,bool)
    if (Shiboken::Converter<const QSqlField & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // append(QSqlField)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // append(QSqlField,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlIndexFunc_append_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // append(QSqlField)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSqlField* cpp_arg0 = Shiboken::Converter<QSqlField* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // append(QSqlField)
                cppSelf->QSqlIndex::append(*cpp_arg0);
                }
                break;
            }
            case 1: // append(QSqlField,bool)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSqlField* cpp_arg0 = Shiboken::Converter<QSqlField* >::toCpp(pyargs[0]);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // append(QSqlField,bool)
                cppSelf->QSqlIndex::append(*cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlIndexFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtSql.QSqlField", "PySide.QtSql.QSqlField, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlIndex.append", overloads);
        return 0;
}

static PyObject* SbkQSqlIndexFunc_cursorName(PyObject* self)
{
    QSqlIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cursorName()const
            QString cppResult = cppSelf->QSqlIndex::cursorName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlIndexFunc_isDescending(PyObject* self, PyObject* arg)
{
    QSqlIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlIndex* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isDescending(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // isDescending(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlIndexFunc_isDescending_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isDescending(int)const
            bool cppResult = cppSelf->QSqlIndex::isDescending(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSqlIndexFunc_isDescending_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlIndex.isDescending", overloads);
        return 0;
}

static PyObject* SbkQSqlIndexFunc_name(PyObject* self)
{
    QSqlIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QSqlIndex::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSqlIndexFunc_setCursorName(PyObject* self, PyObject* arg)
{
    QSqlIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlIndex* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursorName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setCursorName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlIndexFunc_setCursorName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCursorName(QString)
            cppSelf->QSqlIndex::setCursorName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlIndexFunc_setCursorName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlIndex.setCursorName", overloads);
        return 0;
}

static PyObject* SbkQSqlIndexFunc_setDescending(PyObject* self, PyObject* args)
{
    QSqlIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlIndex* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDescending", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setDescending(int,bool)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setDescending(int,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlIndexFunc_setDescending_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setDescending(int,bool)
            cppSelf->QSqlIndex::setDescending(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlIndexFunc_setDescending_TypeError:
        const char* overloads[] = {"int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSql.QSqlIndex.setDescending", overloads);
        return 0;
}

static PyObject* SbkQSqlIndexFunc_setName(PyObject* self, PyObject* arg)
{
    QSqlIndex* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSqlIndex* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSqlIndexFunc_setName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setName(QString)
            cppSelf->QSqlIndex::setName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSqlIndexFunc_setName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSql.QSqlIndex.setName", overloads);
        return 0;
}

static PyMethodDef SbkQSqlIndex_methods[] = {
    {"append", (PyCFunction)SbkQSqlIndexFunc_append, METH_VARARGS},
    {"cursorName", (PyCFunction)SbkQSqlIndexFunc_cursorName, METH_NOARGS},
    {"isDescending", (PyCFunction)SbkQSqlIndexFunc_isDescending, METH_O},
    {"name", (PyCFunction)SbkQSqlIndexFunc_name, METH_NOARGS},
    {"setCursorName", (PyCFunction)SbkQSqlIndexFunc_setCursorName, METH_O},
    {"setDescending", (PyCFunction)SbkQSqlIndexFunc_setDescending, METH_VARARGS},
    {"setName", (PyCFunction)SbkQSqlIndexFunc_setName, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSqlIndex_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSql.QSqlIndex",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSqlIndex_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSqlIndex_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSqlIndex >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSqlIndex",
    /*user_data*/           0
};
} //extern


void init_QSqlIndex(PyObject* module)
{
    SbkPySide_QtSqlTypes[SBK_QSQLINDEX_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSqlIndex_Type);

    SbkQSqlIndex_Type.super.ht_type.tp_base = SbkPySide_QtSqlTypes[SBK_QSQLRECORD_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQSqlIndex_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSqlIndex_Type));
    PyModule_AddObject(module, "QSqlIndex",
        ((PyObject*)&SbkQSqlIndex_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSqlIndex >("QSqlIndex");
    Shiboken::TypeResolver::createObjectTypeResolver<QSqlIndex >("QSqlIndex*");
    Shiboken::TypeResolver::createValueTypeResolver<QSqlIndex >(typeid(QSqlIndex).name());
    PySide::initQtMetaType<QSqlIndex >();
}

