/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtsvg_python.h"

#include "qsvgrenderer_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmatrix.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>
#include <qxmlstream.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QSvgRendererWrapper::QSvgRendererWrapper(QObject * parent) : QSvgRenderer(parent), m_metaObject(0) {
    // ... middle
}

QSvgRendererWrapper::QSvgRendererWrapper(QXmlStreamReader * contents, QObject * parent) : QSvgRenderer(contents, parent), m_metaObject(0) {
    // ... middle
}

QSvgRendererWrapper::QSvgRendererWrapper(const QByteArray & contents, QObject * parent) : QSvgRenderer(contents, parent), m_metaObject(0) {
    // ... middle
}

QSvgRendererWrapper::QSvgRendererWrapper(const QString & filename, QObject * parent) : QSvgRenderer(filename, parent), m_metaObject(0) {
    // ... middle
}

void QSvgRendererWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSvgRendererWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QSvgRendererWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QSvgRendererWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QSvgRendererWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSvgRenderer.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QSvgRendererWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSvgRenderer.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QSvgRendererWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QSvgRendererWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QSvgRenderer::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QSvgRendererWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QSvgRenderer::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QSvgRendererWrapper::~QSvgRendererWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQSvgRenderer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QSvgRenderer >()))
        return -1;

    QSvgRendererWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QSvgRenderer", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QSvgRenderer(QObject*)
    // 1: QSvgRenderer(QXmlStreamReader*,QObject*)
    // 2: QSvgRenderer(QByteArray,QObject*)
    // 3: QSvgRenderer(QString,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QSvgRenderer(QObject*)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QSvgRenderer(QString,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 3; // QSvgRenderer(QString,QObject*)
        }
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QSvgRenderer(QByteArray,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 2; // QSvgRenderer(QByteArray,QObject*)
        }
    } else if (Shiboken::Converter<QXmlStreamReader * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QSvgRenderer(QXmlStreamReader*,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QSvgRenderer(QXmlStreamReader*,QObject*)
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QSvgRenderer(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRenderer_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSvgRenderer(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QSvgRenderer(QObject*)
                cptr = new QSvgRendererWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QSvgRenderer(QXmlStreamReader*,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QXmlStreamReader* cpp_arg0 = Shiboken::Converter<QXmlStreamReader* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QSvgRenderer(QXmlStreamReader*,QObject*)
                cptr = new QSvgRendererWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 2: // QSvgRenderer(QByteArray,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QSvgRenderer(QByteArray,QObject*)
                cptr = new QSvgRendererWrapper(*cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 3: // QSvgRenderer(QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QSvgRenderer(QString,QObject*)
                cptr = new QSvgRendererWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QSvgRenderer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQSvgRenderer_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQSvgRenderer_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "PySide.QtCore.QXmlStreamReader, PySide.QtCore.QObject = None", "PySide.QtCore.QByteArray, PySide.QtCore.QObject = None", "QString, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSvg.QSvgRenderer", overloads);
        return -1;
}

static PyObject* SbkQSvgRendererFunc_animated(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // animated()const
            bool cppResult = cppSelf->QSvgRenderer::animated();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSvgRendererFunc_animationDuration(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // animationDuration()const
            int cppResult = cppSelf->QSvgRenderer::animationDuration();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSvgRendererFunc_boundsOnElement(PyObject* self, PyObject* arg)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundsOnElement(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // boundsOnElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_boundsOnElement_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // boundsOnElement(QString)const
            QRectF cppResult = cppSelf->QSvgRenderer::boundsOnElement(cpp_arg0);
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSvgRendererFunc_boundsOnElement_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSvg.QSvgRenderer.boundsOnElement", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_currentFrame(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentFrame()const
            int cppResult = cppSelf->QSvgRenderer::currentFrame();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSvgRendererFunc_defaultSize(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultSize()const
            QSize cppResult = cppSelf->QSvgRenderer::defaultSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSvgRendererFunc_elementExists(PyObject* self, PyObject* arg)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementExists(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // elementExists(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_elementExists_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // elementExists(QString)const
            bool cppResult = cppSelf->QSvgRenderer::elementExists(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSvgRendererFunc_elementExists_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSvg.QSvgRenderer.elementExists", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_framesPerSecond(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // framesPerSecond()const
            int cppResult = cppSelf->QSvgRenderer::framesPerSecond();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSvgRendererFunc_isValid(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QSvgRenderer::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSvgRendererFunc_load(PyObject* self, PyObject* arg)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: load(QXmlStreamReader*)
    // 1: load(QByteArray)
    // 2: load(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 2; // load(QString)
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 1; // load(QByteArray)
    } else if (Shiboken::Converter<QXmlStreamReader * >::isConvertible(arg)) {
        overloadId = 0; // load(QXmlStreamReader*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_load_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // load(QXmlStreamReader*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QXmlStreamReader* cpp_arg0 = Shiboken::Converter<QXmlStreamReader* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // load(QXmlStreamReader*)
                bool cppResult = cppSelf->QSvgRenderer::load(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // load(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // load(QByteArray)
                bool cppResult = cppSelf->QSvgRenderer::load(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // load(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // load(QString)
                bool cppResult = cppSelf->QSvgRenderer::load(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSvgRendererFunc_load_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamReader", "PySide.QtCore.QByteArray", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSvg.QSvgRenderer.load", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_matrixForElement(PyObject* self, PyObject* arg)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: matrixForElement(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // matrixForElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_matrixForElement_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // matrixForElement(QString)const
            QMatrix cppResult = cppSelf->QSvgRenderer::matrixForElement(cpp_arg0);
            pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQSvgRendererFunc_matrixForElement_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSvg.QSvgRenderer.matrixForElement", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "bounds" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer.render(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPainter*)
    // 1: render(QPainter*,QRectF)
    // 2: render(QPainter*,QString,QRectF)
    if (Shiboken::Converter<QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // render(QPainter*,QString,QRectF)
            } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[2])) {
                overloadId = 2; // render(QPainter*,QString,QRectF)
            }
        } else if (numArgs == 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            overloadId = 1; // render(QPainter*,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_render_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // render(QPainter*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // render(QPainter*)
                cppSelf->QSvgRenderer::render(cpp_arg0);
                }
                break;
            }
            case 1: // render(QPainter*,QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
                QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // render(QPainter*,QRectF)
                cppSelf->QSvgRenderer::render(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // render(QPainter*,QString,QRectF)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "bounds");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "bounds";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtSvg.QSvgRenderer.render(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg2_auto_ptr;
                QRectF cpp_arg2_tmp = QRectF();
                QRectF* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QRectF >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRectF >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // render(QPainter*,QString,QRectF)
                cppSelf->QSvgRenderer::render(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSvgRendererFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter", "PySide.QtGui.QPainter, PySide.QtCore.QRectF", "PySide.QtGui.QPainter, QString, PySide.QtCore.QRectF = QRectF()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtSvg.QSvgRenderer.render", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_setCurrentFrame(PyObject* self, PyObject* arg)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentFrame(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentFrame(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_setCurrentFrame_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentFrame(int)
            cppSelf->QSvgRenderer::setCurrentFrame(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSvgRendererFunc_setCurrentFrame_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSvg.QSvgRenderer.setCurrentFrame", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_setFramesPerSecond(PyObject* self, PyObject* arg)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFramesPerSecond(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFramesPerSecond(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_setFramesPerSecond_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFramesPerSecond(int)
            cppSelf->QSvgRenderer::setFramesPerSecond(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSvgRendererFunc_setFramesPerSecond_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSvg.QSvgRenderer.setFramesPerSecond", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_setViewBox(PyObject* self, PyObject* arg)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewBox(QRect)
    // 1: setViewBox(QRectF)
    if (Shiboken::Converter<const QRect & >::isConvertible(arg)) {
        overloadId = 0; // setViewBox(QRect)
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 1; // setViewBox(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQSvgRendererFunc_setViewBox_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setViewBox(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setViewBox(QRect)
                cppSelf->QSvgRenderer::setViewBox(*cpp_arg0);
                }
                break;
            }
            case 1: // setViewBox(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
                if (!Shiboken::Converter<QRectF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setViewBox(QRectF)
                cppSelf->QSvgRenderer::setViewBox(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQSvgRendererFunc_setViewBox_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtSvg.QSvgRenderer.setViewBox", overloads);
        return 0;
}

static PyObject* SbkQSvgRendererFunc_viewBox(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewBox()const
            QRect cppResult = cppSelf->QSvgRenderer::viewBox();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQSvgRendererFunc_viewBoxF(PyObject* self)
{
    QSvgRenderer* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QSvgRenderer* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewBoxF()const
            QRectF cppResult = cppSelf->QSvgRenderer::viewBoxF();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQSvgRenderer_methods[] = {
    {"animated", (PyCFunction)SbkQSvgRendererFunc_animated, METH_NOARGS},
    {"animationDuration", (PyCFunction)SbkQSvgRendererFunc_animationDuration, METH_NOARGS},
    {"boundsOnElement", (PyCFunction)SbkQSvgRendererFunc_boundsOnElement, METH_O},
    {"currentFrame", (PyCFunction)SbkQSvgRendererFunc_currentFrame, METH_NOARGS},
    {"defaultSize", (PyCFunction)SbkQSvgRendererFunc_defaultSize, METH_NOARGS},
    {"elementExists", (PyCFunction)SbkQSvgRendererFunc_elementExists, METH_O},
    {"framesPerSecond", (PyCFunction)SbkQSvgRendererFunc_framesPerSecond, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQSvgRendererFunc_isValid, METH_NOARGS},
    {"load", (PyCFunction)SbkQSvgRendererFunc_load, METH_O},
    {"matrixForElement", (PyCFunction)SbkQSvgRendererFunc_matrixForElement, METH_O},
    {"render", (PyCFunction)SbkQSvgRendererFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"setCurrentFrame", (PyCFunction)SbkQSvgRendererFunc_setCurrentFrame, METH_O},
    {"setFramesPerSecond", (PyCFunction)SbkQSvgRendererFunc_setFramesPerSecond, METH_O},
    {"setViewBox", (PyCFunction)SbkQSvgRendererFunc_setViewBox, METH_O},
    {"viewBox", (PyCFunction)SbkQSvgRendererFunc_viewBox, METH_NOARGS},
    {"viewBoxF", (PyCFunction)SbkQSvgRendererFunc_viewBoxF, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQSvgRenderer_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtSvg.QSvgRenderer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQSvgRenderer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQSvgRenderer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QSvgRenderer >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QSvgRenderer*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQSvgRenderer_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QSvgRenderer*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQSvgRenderer_Type;
    return 0;
}


void init_QSvgRenderer(PyObject* module)
{
    SbkPySide_QtSvgTypes[SBK_QSVGRENDERER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQSvgRenderer_Type);

    SbkQSvgRenderer_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQSvgRenderer_Type.type_discovery = &SbkQSvgRenderer_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQSvgRenderer_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQSvgRenderer_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQSvgRenderer_Type));
    PyModule_AddObject(module, "QSvgRenderer",
        ((PyObject*)&SbkQSvgRenderer_Type));

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("repaintNeeded", "void", NULL);
    PyDict_SetItemString(SbkQSvgRenderer_Type.super.ht_type.tp_dict, "repaintNeeded", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QSvgRenderer >("QSvgRenderer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSvgRenderer >(typeid(QSvgRenderer).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSvgRenderer >(typeid(QSvgRendererWrapper).name());
    PySide::initQtMetaType<QSvgRenderer* >();
}

