/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebelement_wrapper.h"

// Extra includes
#include <QStringList>
#include <qpainter.h>
#include <qrect.h>
#include <qwebelement.h>
#include <qwebframe.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQWebElement_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebElement >()))
        return -1;

    QWebElement* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWebElement", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QWebElement()
    // 1: QWebElement(QWebElement)
    if (numArgs == 0) {
        overloadId = 0; // QWebElement()
    } else if (numArgs == 1 && Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // QWebElement(QWebElement)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElement_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QWebElement()
            {

                if(!PyErr_Occurred()) {
                // QWebElement()
                cptr = new QWebElement();
                }
                break;
            }
            case 1: // QWebElement(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QWebElement(QWebElement)
                cptr = new QWebElement(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QWebElement >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQWebElement_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQWebElement_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement", overloads);
        return -1;
}

static PyObject* SbkQWebElementFunc_addClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addClass(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // addClass(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_addClass_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addClass(QString)
            cppSelf->QWebElement::addClass(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_addClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.addClass", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_appendInside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendInside(QString)
    // 1: appendInside(QWebElement)
    if (Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // appendInside(QWebElement)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // appendInside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_appendInside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // appendInside(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // appendInside(QString)
                cppSelf->QWebElement::appendInside(cpp_arg0);
                }
                break;
            }
            case 1: // appendInside(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // appendInside(QWebElement)
                cppSelf->QWebElement::appendInside(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_appendInside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.appendInside", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_appendOutside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendOutside(QString)
    // 1: appendOutside(QWebElement)
    if (Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // appendOutside(QWebElement)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // appendOutside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_appendOutside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // appendOutside(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // appendOutside(QString)
                cppSelf->QWebElement::appendOutside(cpp_arg0);
                }
                break;
            }
            case 1: // appendOutside(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // appendOutside(QWebElement)
                cppSelf->QWebElement::appendOutside(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_appendOutside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.appendOutside", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_attribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "defaultValue" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attribute(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:attribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QString,QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // attribute(QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // attribute(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "defaultValue";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // attribute(QString,QString)const
            QString cppResult = cppSelf->QWebElement::attribute(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_attribute_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.attribute", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_attributeNS(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "defaultValue" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNS(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNS(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNS(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:attributeNS", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: attributeNS(QString,QString,QString)const
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_attributeNS_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "defaultValue";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNS(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();

            if(!PyErr_Occurred()) {
            // attributeNS(QString,QString,QString)const
            QString cppResult = cppSelf->QWebElement::attributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_attributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.attributeNS", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_attributeNames(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "namespaceUri" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNames(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNames(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:attributeNames", &arg))
        return 0;


    // Overloaded function decisor
    // 0: attributeNames(QString)const
    if (numArgs == 0) {
        overloadId = 0; // attributeNames(QString)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // attributeNames(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_attributeNames_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "namespaceUri");
                if (value) {
                    if (arg)
                        errorArgName = "namespaceUri";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNames(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // attributeNames(QString)const
            QStringList cppResult = cppSelf->QWebElement::attributeNames(cpp_arg0);
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_attributeNames_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.attributeNames", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_classes(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // classes()const
            QStringList cppResult = cppSelf->QWebElement::classes();
            pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_clone(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clone()const
            QWebElement cppResult = cppSelf->QWebElement::clone();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_document(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // document()const
            QWebElement cppResult = cppSelf->QWebElement::document();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_encloseContentsWith(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: encloseContentsWith(QString)
    // 1: encloseContentsWith(QWebElement)
    if (Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // encloseContentsWith(QWebElement)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // encloseContentsWith(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_encloseContentsWith_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // encloseContentsWith(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // encloseContentsWith(QString)
                cppSelf->QWebElement::encloseContentsWith(cpp_arg0);
                }
                break;
            }
            case 1: // encloseContentsWith(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // encloseContentsWith(QWebElement)
                cppSelf->QWebElement::encloseContentsWith(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_encloseContentsWith_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.encloseContentsWith", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_encloseWith(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: encloseWith(QString)
    // 1: encloseWith(QWebElement)
    if (Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // encloseWith(QWebElement)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // encloseWith(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_encloseWith_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // encloseWith(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // encloseWith(QString)
                cppSelf->QWebElement::encloseWith(cpp_arg0);
                }
                break;
            }
            case 1: // encloseWith(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // encloseWith(QWebElement)
                cppSelf->QWebElement::encloseWith(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_encloseWith_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.encloseWith", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_evaluateJavaScript(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: evaluateJavaScript(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // evaluateJavaScript(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_evaluateJavaScript_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // evaluateJavaScript(QString)
            QVariant cppResult = cppSelf->QWebElement::evaluateJavaScript(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_evaluateJavaScript_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.evaluateJavaScript", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_findAll(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findAll(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // findAll(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_findAll_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // findAll(QString)const
            QWebElementCollection cppResult = cppSelf->QWebElement::findAll(cpp_arg0);
            pyResult = Shiboken::Converter<QWebElementCollection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_findAll_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.findAll", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_findFirst(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findFirst(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // findFirst(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_findFirst_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // findFirst(QString)const
            QWebElement cppResult = cppSelf->QWebElement::findFirst(cpp_arg0);
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_findFirst_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.findFirst", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_firstChild(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // firstChild()const
            QWebElement cppResult = cppSelf->QWebElement::firstChild();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_geometry(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // geometry()const
            QRect cppResult = cppSelf->QWebElement::geometry();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_hasAttribute(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasAttribute(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasAttribute(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_hasAttribute_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasAttribute(QString)const
            bool cppResult = cppSelf->QWebElement::hasAttribute(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_hasAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.hasAttribute", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_hasAttributeNS(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hasAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hasAttributeNS(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // hasAttributeNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_hasAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // hasAttributeNS(QString,QString)const
            bool cppResult = cppSelf->QWebElement::hasAttributeNS(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_hasAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.hasAttributeNS", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_hasAttributes(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasAttributes()const
            bool cppResult = cppSelf->QWebElement::hasAttributes();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_hasClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasClass(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasClass(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_hasClass_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasClass(QString)const
            bool cppResult = cppSelf->QWebElement::hasClass(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_hasClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.hasClass", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_hasFocus(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasFocus()const
            bool cppResult = cppSelf->QWebElement::hasFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_isNull(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QWebElement::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_lastChild(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastChild()const
            QWebElement cppResult = cppSelf->QWebElement::lastChild();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_localName(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // localName()const
            QString cppResult = cppSelf->QWebElement::localName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_namespaceUri(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namespaceUri()const
            QString cppResult = cppSelf->QWebElement::namespaceUri();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_nextSibling(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextSibling()const
            QWebElement cppResult = cppSelf->QWebElement::nextSibling();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_parent(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parent()const
            QWebElement cppResult = cppSelf->QWebElement::parent();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_prefix(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prefix()const
            QString cppResult = cppSelf->QWebElement::prefix();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_prependInside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prependInside(QString)
    // 1: prependInside(QWebElement)
    if (Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // prependInside(QWebElement)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // prependInside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_prependInside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // prependInside(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // prependInside(QString)
                cppSelf->QWebElement::prependInside(cpp_arg0);
                }
                break;
            }
            case 1: // prependInside(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // prependInside(QWebElement)
                cppSelf->QWebElement::prependInside(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_prependInside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.prependInside", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_prependOutside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prependOutside(QString)
    // 1: prependOutside(QWebElement)
    if (Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // prependOutside(QWebElement)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // prependOutside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_prependOutside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // prependOutside(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // prependOutside(QString)
                cppSelf->QWebElement::prependOutside(cpp_arg0);
                }
                break;
            }
            case 1: // prependOutside(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // prependOutside(QWebElement)
                cppSelf->QWebElement::prependOutside(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_prependOutside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.prependOutside", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_previousSibling(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // previousSibling()const
            QWebElement cppResult = cppSelf->QWebElement::previousSibling();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_removeAllChildren(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // removeAllChildren()
            cppSelf->QWebElement::removeAllChildren();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebElementFunc_removeAttribute(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAttribute(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeAttribute(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_removeAttribute_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAttribute(QString)
            cppSelf->QWebElement::removeAttribute(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_removeAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.removeAttribute", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_removeAttributeNS(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeAttributeNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // removeAttributeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_removeAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // removeAttributeNS(QString,QString)
            cppSelf->QWebElement::removeAttributeNS(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_removeAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.removeAttributeNS", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_removeClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeClass(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeClass(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_removeClass_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeClass(QString)
            cppSelf->QWebElement::removeClass(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_removeClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.removeClass", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_removeFromDocument(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // removeFromDocument()
            cppSelf->QWebElement::removeFromDocument();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebElementFunc_render(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: render(QPainter*)
    if (Shiboken::Converter<QPainter * >::isConvertible(arg)) {
        overloadId = 0; // render(QPainter*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_render_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // render(QPainter*)
            cppSelf->QWebElement::render(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.render", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_replace(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: replace(QString)
    // 1: replace(QWebElement)
    if (Shiboken::Converter<const QWebElement & >::isConvertible(arg)) {
        overloadId = 1; // replace(QWebElement)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // replace(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_replace_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // replace(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // replace(QString)
                cppSelf->QWebElement::replace(cpp_arg0);
                }
                break;
            }
            case 1: // replace(QWebElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QWebElement* cpp_arg0 = Shiboken::Converter<QWebElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // replace(QWebElement)
                cppSelf->QWebElement::replace(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_replace_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.replace", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_setAttribute(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setAttribute(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setAttribute(QString,QString)
            cppSelf->QWebElement::setAttribute(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_setAttribute_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.setAttribute", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_setAttributeNS(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttributeNS", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeNS(QString,QString,QString)
    if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // setAttributeNS(QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_setAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setAttributeNS(QString,QString,QString)
            cppSelf->QWebElement::setAttributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_setAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.setAttributeNS", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_setFocus(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // setFocus()
            cppSelf->QWebElement::setFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebElementFunc_setInnerXml(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInnerXml(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setInnerXml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_setInnerXml_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInnerXml(QString)
            cppSelf->QWebElement::setInnerXml(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_setInnerXml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.setInnerXml", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_setOuterXml(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOuterXml(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setOuterXml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_setOuterXml_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOuterXml(QString)
            cppSelf->QWebElement::setOuterXml(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_setOuterXml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.setOuterXml", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_setPlainText(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPlainText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_setPlainText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPlainText(QString)
            cppSelf->QWebElement::setPlainText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_setPlainText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.setPlainText", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_setStyleProperty(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setStyleProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStyleProperty(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setStyleProperty(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_setStyleProperty_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setStyleProperty(QString,QString)
            cppSelf->QWebElement::setStyleProperty(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_setStyleProperty_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.setStyleProperty", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_styleProperty(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "styleProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: styleProperty(QString,QWebElement::StyleResolveStrategy)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QWebElement::StyleResolveStrategy >::isConvertible(pyargs[1])) {
        overloadId = 0; // styleProperty(QString,QWebElement::StyleResolveStrategy)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_styleProperty_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QWebElement::StyleResolveStrategy cpp_arg1 = Shiboken::Converter<QWebElement::StyleResolveStrategy >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // styleProperty(QString,QWebElement::StyleResolveStrategy)const
            QString cppResult = cppSelf->QWebElement::styleProperty(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebElementFunc_styleProperty_TypeError:
        const char* overloads[] = {"QString, PySide.QtWebKit.QWebElement.StyleResolveStrategy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.styleProperty", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_tagName(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tagName()const
            QString cppResult = cppSelf->QWebElement::tagName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_takeFromDocument(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // takeFromDocument()
            QWebElement & cppResult = cppSelf->QWebElement::takeFromDocument();
            pyResult = Shiboken::Converter<QWebElement & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_toInnerXml(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toInnerXml()const
            QString cppResult = cppSelf->QWebElement::toInnerXml();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_toOuterXml(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toOuterXml()const
            QString cppResult = cppSelf->QWebElement::toOuterXml();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_toPlainText(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPlainText()const
            QString cppResult = cppSelf->QWebElement::toPlainText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebElementFunc_toggleClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: toggleClass(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // toggleClass(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebElementFunc_toggleClass_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toggleClass(QString)
            cppSelf->QWebElement::toggleClass(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebElementFunc_toggleClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.toggleClass", overloads);
        return 0;
}

static PyObject* SbkQWebElementFunc_webFrame(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // webFrame()const
            QWebFrame * cppResult = cppSelf->QWebElement::webFrame();
            pyResult = Shiboken::Converter<QWebFrame * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQWebElement_methods[] = {
    {"addClass", (PyCFunction)SbkQWebElementFunc_addClass, METH_O},
    {"appendInside", (PyCFunction)SbkQWebElementFunc_appendInside, METH_O},
    {"appendOutside", (PyCFunction)SbkQWebElementFunc_appendOutside, METH_O},
    {"attribute", (PyCFunction)SbkQWebElementFunc_attribute, METH_VARARGS|METH_KEYWORDS},
    {"attributeNS", (PyCFunction)SbkQWebElementFunc_attributeNS, METH_VARARGS|METH_KEYWORDS},
    {"attributeNames", (PyCFunction)SbkQWebElementFunc_attributeNames, METH_VARARGS|METH_KEYWORDS},
    {"classes", (PyCFunction)SbkQWebElementFunc_classes, METH_NOARGS},
    {"clone", (PyCFunction)SbkQWebElementFunc_clone, METH_NOARGS},
    {"document", (PyCFunction)SbkQWebElementFunc_document, METH_NOARGS},
    {"encloseContentsWith", (PyCFunction)SbkQWebElementFunc_encloseContentsWith, METH_O},
    {"encloseWith", (PyCFunction)SbkQWebElementFunc_encloseWith, METH_O},
    {"evaluateJavaScript", (PyCFunction)SbkQWebElementFunc_evaluateJavaScript, METH_O},
    {"findAll", (PyCFunction)SbkQWebElementFunc_findAll, METH_O},
    {"findFirst", (PyCFunction)SbkQWebElementFunc_findFirst, METH_O},
    {"firstChild", (PyCFunction)SbkQWebElementFunc_firstChild, METH_NOARGS},
    {"geometry", (PyCFunction)SbkQWebElementFunc_geometry, METH_NOARGS},
    {"hasAttribute", (PyCFunction)SbkQWebElementFunc_hasAttribute, METH_O},
    {"hasAttributeNS", (PyCFunction)SbkQWebElementFunc_hasAttributeNS, METH_VARARGS},
    {"hasAttributes", (PyCFunction)SbkQWebElementFunc_hasAttributes, METH_NOARGS},
    {"hasClass", (PyCFunction)SbkQWebElementFunc_hasClass, METH_O},
    {"hasFocus", (PyCFunction)SbkQWebElementFunc_hasFocus, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQWebElementFunc_isNull, METH_NOARGS},
    {"lastChild", (PyCFunction)SbkQWebElementFunc_lastChild, METH_NOARGS},
    {"localName", (PyCFunction)SbkQWebElementFunc_localName, METH_NOARGS},
    {"namespaceUri", (PyCFunction)SbkQWebElementFunc_namespaceUri, METH_NOARGS},
    {"nextSibling", (PyCFunction)SbkQWebElementFunc_nextSibling, METH_NOARGS},
    {"parent", (PyCFunction)SbkQWebElementFunc_parent, METH_NOARGS},
    {"prefix", (PyCFunction)SbkQWebElementFunc_prefix, METH_NOARGS},
    {"prependInside", (PyCFunction)SbkQWebElementFunc_prependInside, METH_O},
    {"prependOutside", (PyCFunction)SbkQWebElementFunc_prependOutside, METH_O},
    {"previousSibling", (PyCFunction)SbkQWebElementFunc_previousSibling, METH_NOARGS},
    {"removeAllChildren", (PyCFunction)SbkQWebElementFunc_removeAllChildren, METH_NOARGS},
    {"removeAttribute", (PyCFunction)SbkQWebElementFunc_removeAttribute, METH_O},
    {"removeAttributeNS", (PyCFunction)SbkQWebElementFunc_removeAttributeNS, METH_VARARGS},
    {"removeClass", (PyCFunction)SbkQWebElementFunc_removeClass, METH_O},
    {"removeFromDocument", (PyCFunction)SbkQWebElementFunc_removeFromDocument, METH_NOARGS},
    {"render", (PyCFunction)SbkQWebElementFunc_render, METH_O},
    {"replace", (PyCFunction)SbkQWebElementFunc_replace, METH_O},
    {"setAttribute", (PyCFunction)SbkQWebElementFunc_setAttribute, METH_VARARGS},
    {"setAttributeNS", (PyCFunction)SbkQWebElementFunc_setAttributeNS, METH_VARARGS},
    {"setFocus", (PyCFunction)SbkQWebElementFunc_setFocus, METH_NOARGS},
    {"setInnerXml", (PyCFunction)SbkQWebElementFunc_setInnerXml, METH_O},
    {"setOuterXml", (PyCFunction)SbkQWebElementFunc_setOuterXml, METH_O},
    {"setPlainText", (PyCFunction)SbkQWebElementFunc_setPlainText, METH_O},
    {"setStyleProperty", (PyCFunction)SbkQWebElementFunc_setStyleProperty, METH_VARARGS},
    {"styleProperty", (PyCFunction)SbkQWebElementFunc_styleProperty, METH_VARARGS},
    {"tagName", (PyCFunction)SbkQWebElementFunc_tagName, METH_NOARGS},
    {"takeFromDocument", (PyCFunction)SbkQWebElementFunc_takeFromDocument, METH_NOARGS},
    {"toInnerXml", (PyCFunction)SbkQWebElementFunc_toInnerXml, METH_NOARGS},
    {"toOuterXml", (PyCFunction)SbkQWebElementFunc_toOuterXml, METH_NOARGS},
    {"toPlainText", (PyCFunction)SbkQWebElementFunc_toPlainText, METH_NOARGS},
    {"toggleClass", (PyCFunction)SbkQWebElementFunc_toggleClass, METH_O},
    {"webFrame", (PyCFunction)SbkQWebElementFunc_webFrame, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQWebElement_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QWebElement& cpp_self = *Shiboken::Converter<QWebElement* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QWebElement & >::isConvertible(other)) {
                // operator!=(const QWebElement & o) const
                QWebElement* cpp_other = Shiboken::Converter<QWebElement* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QWebElement  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQWebElement_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QWebElement & >::isConvertible(other)) {
                // operator==(const QWebElement & o) const
                QWebElement* cpp_other = Shiboken::Converter<QWebElement* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QWebElement  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQWebElement_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQWebElement_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWebElement_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebElement",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQWebElement_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWebElement_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQWebElement_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QWebElement >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWebElement",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "StyleResolveStrategy",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QWebElement(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBELEMENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWebElement_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWebElement_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWebElement_Type));
    PyModule_AddObject(module, "QWebElement",
        ((PyObject*)&SbkQWebElement_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: StyleResolveStrategy
    SbkPySide_QtWebKitTypes[SBK_QWEBELEMENT_STYLERESOLVESTRATEGY_IDX] = &SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type);
    PyDict_SetItemString(SbkQWebElement_Type.super.ht_type.tp_dict,
            "StyleResolveStrategy",((PyObject*)&SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type,
        (long) QWebElement::InlineStyle, "InlineStyle");
    PyDict_SetItemString(SbkQWebElement_Type.super.ht_type.tp_dict,
        "InlineStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type.tp_dict,
        "InlineStyle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type,
        (long) QWebElement::CascadedStyle, "CascadedStyle");
    PyDict_SetItemString(SbkQWebElement_Type.super.ht_type.tp_dict,
        "CascadedStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type.tp_dict,
        "CascadedStyle", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type,
        (long) QWebElement::ComputedStyle, "ComputedStyle");
    PyDict_SetItemString(SbkQWebElement_Type.super.ht_type.tp_dict,
        "ComputedStyle", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy_Type.tp_dict,
        "ComputedStyle", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebElement::StyleResolveStrategy");


    Shiboken::TypeResolver::createValueTypeResolver<QWebElement >("QWebElement");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebElement >("QWebElement*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebElement >(typeid(QWebElement).name());
    PySide::initQtMetaType<QWebElement >();
}

