/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtwebkit_python.h"

#include "qwebframe_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qicon.h>
#include <qnetworkrequest.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpoint.h>
#include <qprinter.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qthread.h>
#include <qurl.h>
#include <qwebelement.h>
#include <qwebframe.h>
#include <qwebpage.h>
#include <qwebsecurityorigin.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQWebFrameFunc_addToJavaScriptWindowObject(PyObject* self, PyObject* args)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addToJavaScriptWindowObject", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addToJavaScriptWindowObject(QString,QObject*)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
        overloadId = 0; // addToJavaScriptWindowObject(QString,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_addToJavaScriptWindowObject_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QObject* cpp_arg1 = Shiboken::Converter<QObject* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // addToJavaScriptWindowObject(QString,QObject*)
            cppSelf->QWebFrame::addToJavaScriptWindowObject(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[1]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_addToJavaScriptWindowObject_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.addToJavaScriptWindowObject", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_baseUrl(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // baseUrl()const
            QUrl cppResult = cppSelf->QWebFrame::baseUrl();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_childFrames(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childFrames()const
            QList<QWebFrame * > cppResult = cppSelf->QWebFrame::childFrames();
            pyResult = Shiboken::Converter<QList<QWebFrame * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_contentsSize(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contentsSize()const
            QSize cppResult = cppSelf->QWebFrame::contentsSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_documentElement(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentElement()const
            QWebElement cppResult = cppSelf->QWebFrame::documentElement();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_evaluateJavaScript(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: evaluateJavaScript(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // evaluateJavaScript(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_evaluateJavaScript_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // evaluateJavaScript(QString)
            QVariant cppResult = cppSelf->QWebFrame::evaluateJavaScript(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_evaluateJavaScript_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.evaluateJavaScript", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_event(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QWebFrame::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.event", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_findAllElements(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findAllElements(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // findAllElements(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_findAllElements_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // findAllElements(QString)const
            QWebElementCollection cppResult = cppSelf->QWebFrame::findAllElements(cpp_arg0);
            pyResult = Shiboken::Converter<QWebElementCollection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_findAllElements_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.findAllElements", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_findFirstElement(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findFirstElement(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // findFirstElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_findFirstElement_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // findFirstElement(QString)const
            QWebElement cppResult = cppSelf->QWebFrame::findFirstElement(cpp_arg0);
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_findFirstElement_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.findFirstElement", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_frameName(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // frameName()const
            QString cppResult = cppSelf->QWebFrame::frameName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_geometry(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // geometry()const
            QRect cppResult = cppSelf->QWebFrame::geometry();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_hasFocus(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasFocus()const
            bool cppResult = cppSelf->QWebFrame::hasFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_hitTestContent(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hitTestContent(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // hitTestContent(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_hitTestContent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hitTestContent(QPoint)const
            QWebHitTestResult cppResult = cppSelf->QWebFrame::hitTestContent(*cpp_arg0);
            pyResult = Shiboken::Converter<QWebHitTestResult >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_hitTestContent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.hitTestContent", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_icon(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // icon()const
            QIcon cppResult = cppSelf->QWebFrame::icon();
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_load(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "body", "operation" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.load(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.load(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.load(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:load", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: load(QNetworkRequest,QNetworkAccessManager::Operation,QByteArray)
    // 1: load(QUrl)
    if (numArgs == 1 && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[0])) {
        overloadId = 1; // load(QUrl)
    } else if (Shiboken::Converter<const QNetworkRequest & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // load(QNetworkRequest,QNetworkAccessManager::Operation,QByteArray)
        } else if (Shiboken::Converter<QNetworkAccessManager::Operation >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // load(QNetworkRequest,QNetworkAccessManager::Operation,QByteArray)
            } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[2])) {
                overloadId = 0; // load(QNetworkRequest,QNetworkAccessManager::Operation,QByteArray)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_load_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // load(QNetworkRequest,QNetworkAccessManager::Operation,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "operation");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "operation";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "body");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "body";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.load(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QNetworkRequest* cpp_arg0 = Shiboken::Converter<QNetworkRequest* >::toCpp(pyargs[0]);
                QNetworkAccessManager::Operation cpp_arg1 = pyargs[1] ? Shiboken::Converter<QNetworkAccessManager::Operation >::toCpp(pyargs[1]) : QNetworkAccessManager::GetOperation;
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg2_auto_ptr;
                QByteArray cpp_arg2_tmp = QByteArray();
                QByteArray* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QByteArray >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // load(QNetworkRequest,QNetworkAccessManager::Operation,QByteArray)
                cppSelf->QWebFrame::load(*cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 1: // load(QUrl)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QUrl >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // load(QUrl)
                cppSelf->QWebFrame::load(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_load_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkRequest, PySide.QtNetwork.QNetworkAccessManager.Operation = QNetworkAccessManager.GetOperation, PySide.QtCore.QByteArray = QByteArray()", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.load", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_page(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // page()const
            QWebPage * cppResult = cppSelf->QWebFrame::page();
            pyResult = Shiboken::Converter<QWebPage * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_parentFrame(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentFrame()const
            QWebFrame * cppResult = cppSelf->QWebFrame::parentFrame();
            pyResult = Shiboken::Converter<QWebFrame * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_pos(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            QPoint cppResult = cppSelf->QWebFrame::pos();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_print(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: print(QPrinter*)const
    if (Shiboken::Converter<QPrinter * >::isConvertible(arg)) {
        overloadId = 0; // print(QPrinter*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_print_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPrinter* cpp_arg0 = Shiboken::Converter<QPrinter* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // print(QPrinter*)const
            cppSelf->QWebFrame::print(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_print_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.print", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "clip" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.render(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPainter*)
    // 1: render(QPainter*,QWebFrame::RenderLayer,QRegion)
    // 2: render(QPainter*,QRegion)
    if (Shiboken::Converter<QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*)
        } else if (numArgs == 2 && Shiboken::Converter<const QRegion & >::isConvertible(pyargs[1])) {
            overloadId = 2; // render(QPainter*,QRegion)
        } else if (Shiboken::Converter<QWebFrame::RenderLayer >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // render(QPainter*,QWebFrame::RenderLayer,QRegion)
            } else if (Shiboken::Converter<const QRegion & >::isConvertible(pyargs[2])) {
                overloadId = 1; // render(QPainter*,QWebFrame::RenderLayer,QRegion)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_render_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // render(QPainter*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // render(QPainter*)
                cppSelf->QWebFrame::render(cpp_arg0);
                }
                break;
            }
            case 1: // render(QPainter*,QWebFrame::RenderLayer,QRegion)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "clip");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "clip";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.render(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
                QWebFrame::RenderLayer cpp_arg1 = Shiboken::Converter<QWebFrame::RenderLayer >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg2_auto_ptr;
                QRegion cpp_arg2_tmp = QRegion();
                QRegion* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegion* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QRegion >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRegion >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // render(QPainter*,QWebFrame::RenderLayer,QRegion)
                cppSelf->QWebFrame::render(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 2: // render(QPainter*,QRegion)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg1_auto_ptr;
                QRegion* cpp_arg1 = Shiboken::Converter<QRegion* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QRegion >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QRegion >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // render(QPainter*,QRegion)
                cppSelf->QWebFrame::render(cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter", "PySide.QtGui.QPainter, PySide.QtWebKit.QWebFrame.RenderLayer, PySide.QtGui.QRegion = QRegion()", "PySide.QtGui.QPainter, PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.render", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_renderTreeDump(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // renderTreeDump()const
            QString cppResult = cppSelf->QWebFrame::renderTreeDump();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_requestedUrl(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // requestedUrl()const
            QUrl cppResult = cppSelf->QWebFrame::requestedUrl();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_scroll(PyObject* self, PyObject* args)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scroll", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scroll(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scroll(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_scroll_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scroll(int,int)
            cppSelf->QWebFrame::scroll(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_scroll_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.scroll", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_scrollBarGeometry(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollBarGeometry(Qt::Orientation)const
    if (Shiboken::Converter<Qt::Orientation >::isConvertible(arg)) {
        overloadId = 0; // scrollBarGeometry(Qt::Orientation)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_scrollBarGeometry_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scrollBarGeometry(Qt::Orientation)const
            QRect cppResult = cppSelf->QWebFrame::scrollBarGeometry(cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_scrollBarGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.scrollBarGeometry", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_scrollBarMaximum(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollBarMaximum(Qt::Orientation)const
    if (Shiboken::Converter<Qt::Orientation >::isConvertible(arg)) {
        overloadId = 0; // scrollBarMaximum(Qt::Orientation)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_scrollBarMaximum_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scrollBarMaximum(Qt::Orientation)const
            int cppResult = cppSelf->QWebFrame::scrollBarMaximum(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_scrollBarMaximum_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.scrollBarMaximum", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_scrollBarMinimum(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollBarMinimum(Qt::Orientation)const
    if (Shiboken::Converter<Qt::Orientation >::isConvertible(arg)) {
        overloadId = 0; // scrollBarMinimum(Qt::Orientation)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_scrollBarMinimum_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scrollBarMinimum(Qt::Orientation)const
            int cppResult = cppSelf->QWebFrame::scrollBarMinimum(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_scrollBarMinimum_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.scrollBarMinimum", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_scrollBarPolicy(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollBarPolicy(Qt::Orientation)const
    if (Shiboken::Converter<Qt::Orientation >::isConvertible(arg)) {
        overloadId = 0; // scrollBarPolicy(Qt::Orientation)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_scrollBarPolicy_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scrollBarPolicy(Qt::Orientation)const
            Qt::ScrollBarPolicy cppResult = cppSelf->QWebFrame::scrollBarPolicy(cpp_arg0);
            pyResult = Shiboken::Converter<Qt::ScrollBarPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_scrollBarPolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.scrollBarPolicy", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_scrollBarValue(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollBarValue(Qt::Orientation)const
    if (Shiboken::Converter<Qt::Orientation >::isConvertible(arg)) {
        overloadId = 0; // scrollBarValue(Qt::Orientation)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_scrollBarValue_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scrollBarValue(Qt::Orientation)const
            int cppResult = cppSelf->QWebFrame::scrollBarValue(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebFrameFunc_scrollBarValue_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.scrollBarValue", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_scrollPosition(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scrollPosition()const
            QPoint cppResult = cppSelf->QWebFrame::scrollPosition();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_scrollToAnchor(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollToAnchor(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // scrollToAnchor(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_scrollToAnchor_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scrollToAnchor(QString)
            cppSelf->QWebFrame::scrollToAnchor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_scrollToAnchor_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.scrollToAnchor", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_securityOrigin(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // securityOrigin()const
            QWebSecurityOrigin cppResult = cppSelf->QWebFrame::securityOrigin();
            pyResult = Shiboken::Converter<QWebSecurityOrigin >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_setContent(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "baseUrl", "mimeType" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setContent(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setContent(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setContent(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setContent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setContent(QByteArray,QString,QUrl)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setContent(QByteArray,QString,QUrl)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setContent(QByteArray,QString,QUrl)
            } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[2])) {
                overloadId = 0; // setContent(QByteArray,QString,QUrl)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setContent_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mimeType");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mimeType";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "baseUrl");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "baseUrl";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setContent(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QUrl > cpp_arg2_auto_ptr;
            QUrl cpp_arg2_tmp = QUrl();
            QUrl* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QUrl* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            if (pyargs[2] && !Shiboken::Converter<QUrl >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QUrl >(cpp_arg2);

            if(!PyErr_Occurred()) {
            // setContent(QByteArray,QString,QUrl)
            cppSelf->QWebFrame::setContent(*cpp_arg0, cpp_arg1, *cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setContent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, QString = QString(), PySide.QtCore.QUrl = QUrl()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.setContent", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_setFocus(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // setFocus()
            cppSelf->QWebFrame::setFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebFrameFunc_setHtml(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "baseUrl" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setHtml(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setHtml(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setHtml(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setHtml", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setHtml(QString,QUrl)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setHtml(QString,QUrl)
        } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
            overloadId = 0; // setHtml(QString,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setHtml_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "baseUrl");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "baseUrl";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebFrame.setHtml(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
            QUrl cpp_arg1_tmp = QUrl();
            QUrl* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QUrl* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setHtml(QString,QUrl)
            cppSelf->QWebFrame::setHtml(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setHtml_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QUrl = QUrl()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.setHtml", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_setScrollBarPolicy(PyObject* self, PyObject* args)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setScrollBarPolicy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setScrollBarPolicy(Qt::Orientation,Qt::ScrollBarPolicy)
    if (numArgs == 2 && Shiboken::Converter<Qt::Orientation >::isConvertible(pyargs[0]) && Shiboken::Converter<Qt::ScrollBarPolicy >::isConvertible(pyargs[1])) {
        overloadId = 0; // setScrollBarPolicy(Qt::Orientation,Qt::ScrollBarPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setScrollBarPolicy_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[0]);
            Qt::ScrollBarPolicy cpp_arg1 = Shiboken::Converter<Qt::ScrollBarPolicy >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setScrollBarPolicy(Qt::Orientation,Qt::ScrollBarPolicy)
            cppSelf->QWebFrame::setScrollBarPolicy(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setScrollBarPolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation, PySide.QtCore.Qt.ScrollBarPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.setScrollBarPolicy", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_setScrollBarValue(PyObject* self, PyObject* args)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setScrollBarValue", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setScrollBarValue(Qt::Orientation,int)
    if (numArgs == 2 && Shiboken::Converter<Qt::Orientation >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setScrollBarValue(Qt::Orientation,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setScrollBarValue_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cpp_arg0 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setScrollBarValue(Qt::Orientation,int)
            cppSelf->QWebFrame::setScrollBarValue(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setScrollBarValue_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebFrame.setScrollBarValue", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_setScrollPosition(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScrollPosition(QPoint)
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // setScrollPosition(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setScrollPosition_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScrollPosition(QPoint)
            cppSelf->QWebFrame::setScrollPosition(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setScrollPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.setScrollPosition", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_setTextSizeMultiplier(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextSizeMultiplier(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextSizeMultiplier(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setTextSizeMultiplier_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextSizeMultiplier(qreal)
            cppSelf->QWebFrame::setTextSizeMultiplier(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setTextSizeMultiplier_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.setTextSizeMultiplier", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_setUrl(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUrl(QUrl)
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setUrl_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setUrl(QUrl)
            cppSelf->QWebFrame::setUrl(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.setUrl", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_setZoomFactor(PyObject* self, PyObject* arg)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setZoomFactor(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setZoomFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebFrameFunc_setZoomFactor_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setZoomFactor(qreal)
            cppSelf->QWebFrame::setZoomFactor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebFrameFunc_setZoomFactor_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebFrame.setZoomFactor", overloads);
        return 0;
}

static PyObject* SbkQWebFrameFunc_textSizeMultiplier(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textSizeMultiplier()const
            qreal cppResult = cppSelf->QWebFrame::textSizeMultiplier();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_title(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // title()const
            QString cppResult = cppSelf->QWebFrame::title();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_toHtml(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toHtml()const
            QString cppResult = cppSelf->QWebFrame::toHtml();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_toPlainText(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPlainText()const
            QString cppResult = cppSelf->QWebFrame::toPlainText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_url(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = cppSelf->QWebFrame::url();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebFrameFunc_zoomFactor(PyObject* self)
{
    QWebFrame* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebFrame* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // zoomFactor()const
            qreal cppResult = cppSelf->QWebFrame::zoomFactor();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQWebFrame_methods[] = {
    {"addToJavaScriptWindowObject", (PyCFunction)SbkQWebFrameFunc_addToJavaScriptWindowObject, METH_VARARGS},
    {"baseUrl", (PyCFunction)SbkQWebFrameFunc_baseUrl, METH_NOARGS},
    {"childFrames", (PyCFunction)SbkQWebFrameFunc_childFrames, METH_NOARGS},
    {"contentsSize", (PyCFunction)SbkQWebFrameFunc_contentsSize, METH_NOARGS},
    {"documentElement", (PyCFunction)SbkQWebFrameFunc_documentElement, METH_NOARGS},
    {"evaluateJavaScript", (PyCFunction)SbkQWebFrameFunc_evaluateJavaScript, METH_O},
    {"event", (PyCFunction)SbkQWebFrameFunc_event, METH_O},
    {"findAllElements", (PyCFunction)SbkQWebFrameFunc_findAllElements, METH_O},
    {"findFirstElement", (PyCFunction)SbkQWebFrameFunc_findFirstElement, METH_O},
    {"frameName", (PyCFunction)SbkQWebFrameFunc_frameName, METH_NOARGS},
    {"geometry", (PyCFunction)SbkQWebFrameFunc_geometry, METH_NOARGS},
    {"hasFocus", (PyCFunction)SbkQWebFrameFunc_hasFocus, METH_NOARGS},
    {"hitTestContent", (PyCFunction)SbkQWebFrameFunc_hitTestContent, METH_O},
    {"icon", (PyCFunction)SbkQWebFrameFunc_icon, METH_NOARGS},
    {"load", (PyCFunction)SbkQWebFrameFunc_load, METH_VARARGS|METH_KEYWORDS},
    {"page", (PyCFunction)SbkQWebFrameFunc_page, METH_NOARGS},
    {"parentFrame", (PyCFunction)SbkQWebFrameFunc_parentFrame, METH_NOARGS},
    {"pos", (PyCFunction)SbkQWebFrameFunc_pos, METH_NOARGS},
    {"print", (PyCFunction)SbkQWebFrameFunc_print, METH_O},
    {"render", (PyCFunction)SbkQWebFrameFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"renderTreeDump", (PyCFunction)SbkQWebFrameFunc_renderTreeDump, METH_NOARGS},
    {"requestedUrl", (PyCFunction)SbkQWebFrameFunc_requestedUrl, METH_NOARGS},
    {"scroll", (PyCFunction)SbkQWebFrameFunc_scroll, METH_VARARGS},
    {"scrollBarGeometry", (PyCFunction)SbkQWebFrameFunc_scrollBarGeometry, METH_O},
    {"scrollBarMaximum", (PyCFunction)SbkQWebFrameFunc_scrollBarMaximum, METH_O},
    {"scrollBarMinimum", (PyCFunction)SbkQWebFrameFunc_scrollBarMinimum, METH_O},
    {"scrollBarPolicy", (PyCFunction)SbkQWebFrameFunc_scrollBarPolicy, METH_O},
    {"scrollBarValue", (PyCFunction)SbkQWebFrameFunc_scrollBarValue, METH_O},
    {"scrollPosition", (PyCFunction)SbkQWebFrameFunc_scrollPosition, METH_NOARGS},
    {"scrollToAnchor", (PyCFunction)SbkQWebFrameFunc_scrollToAnchor, METH_O},
    {"securityOrigin", (PyCFunction)SbkQWebFrameFunc_securityOrigin, METH_NOARGS},
    {"setContent", (PyCFunction)SbkQWebFrameFunc_setContent, METH_VARARGS|METH_KEYWORDS},
    {"setFocus", (PyCFunction)SbkQWebFrameFunc_setFocus, METH_NOARGS},
    {"setHtml", (PyCFunction)SbkQWebFrameFunc_setHtml, METH_VARARGS|METH_KEYWORDS},
    {"setScrollBarPolicy", (PyCFunction)SbkQWebFrameFunc_setScrollBarPolicy, METH_VARARGS},
    {"setScrollBarValue", (PyCFunction)SbkQWebFrameFunc_setScrollBarValue, METH_VARARGS},
    {"setScrollPosition", (PyCFunction)SbkQWebFrameFunc_setScrollPosition, METH_O},
    {"setTextSizeMultiplier", (PyCFunction)SbkQWebFrameFunc_setTextSizeMultiplier, METH_O},
    {"setUrl", (PyCFunction)SbkQWebFrameFunc_setUrl, METH_O},
    {"setZoomFactor", (PyCFunction)SbkQWebFrameFunc_setZoomFactor, METH_O},
    {"textSizeMultiplier", (PyCFunction)SbkQWebFrameFunc_textSizeMultiplier, METH_NOARGS},
    {"title", (PyCFunction)SbkQWebFrameFunc_title, METH_NOARGS},
    {"toHtml", (PyCFunction)SbkQWebFrameFunc_toHtml, METH_NOARGS},
    {"toPlainText", (PyCFunction)SbkQWebFrameFunc_toPlainText, METH_NOARGS},
    {"url", (PyCFunction)SbkQWebFrameFunc_url, METH_NOARGS},
    {"zoomFactor", (PyCFunction)SbkQWebFrameFunc_zoomFactor, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWebFrame_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebFrame",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          Shiboken::deallocWrapperWithPrivateDtor,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWebFrame_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            0,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWebFrame*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQWebFrame_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QWebFrame*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQWebFrame_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtWebKit_QWebFrame_RenderLayer_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtWebKit_QWebFrame_RenderLayer_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderLayer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtWebKit_QWebFrame_RenderLayer_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtWebKit_QWebFrame_RenderLayer_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtWebKit_QWebFrame_RenderLayer_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QWebFrame(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBFRAME_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWebFrame_Type);

    SbkQWebFrame_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQWebFrame_Type.type_discovery = &SbkQWebFrame_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQWebFrame_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWebFrame_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWebFrame_Type));
    PyModule_AddObject(module, "QWebFrame",
        ((PyObject*)&SbkQWebFrame_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: RenderLayer
    SbkPySide_QtWebKitTypes[SBK_QWEBFRAME_RENDERLAYER_IDX] = &SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict,
            "RenderLayer",((PyObject*)&SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type,
        (long) QWebFrame::ContentsLayer, "ContentsLayer");
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict,
        "ContentsLayer", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type.tp_dict,
        "ContentsLayer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type,
        (long) QWebFrame::ScrollBarLayer, "ScrollBarLayer");
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict,
        "ScrollBarLayer", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type.tp_dict,
        "ScrollBarLayer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type,
        (long) QWebFrame::PanIconLayer, "PanIconLayer");
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict,
        "PanIconLayer", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type.tp_dict,
        "PanIconLayer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type,
        (long) QWebFrame::AllLayers, "AllLayers");
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict,
        "AllLayers", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebFrame_RenderLayer_Type.tp_dict,
        "AllLayers", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebFrame::RenderLayer");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("loadStarted", "void", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "loadStarted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("urlChanged", "const QUrl&", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "urlChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("loadFinished", "bool", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "loadFinished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("iconChanged", "void", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "iconChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("javaScriptWindowObjectCleared", "void", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "javaScriptWindowObjectCleared", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("titleChanged", "const QString&", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "titleChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("contentsSizeChanged", "const QSize&", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "contentsSizeChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("initialLayoutCompleted", "void", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "initialLayoutCompleted", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("pageChanged", "void", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "pageChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("provisionalLoad", "void", NULL);
    PyDict_SetItemString(SbkQWebFrame_Type.super.ht_type.tp_dict, "provisionalLoad", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QWebFrame >("QWebFrame*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebFrame >(typeid(QWebFrame).name());
    PySide::initQtMetaType<QWebFrame* >();
}

