/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebhistory_wrapper.h"

// Extra includes
#include <QList>
#include <qdatastream.h>
#include <qwebhistory.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQWebHistoryFunc_back(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // back()
            cppSelf->QWebHistory::back();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebHistoryFunc_backItem(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backItem()const
            QWebHistoryItem cppResult = cppSelf->QWebHistory::backItem();
            pyResult = Shiboken::Converter<QWebHistoryItem >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_backItems(PyObject* self, PyObject* arg)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: backItems(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // backItems(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryFunc_backItems_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // backItems(int)const
            QList<QWebHistoryItem > cppResult = cppSelf->QWebHistory::backItems(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QWebHistoryItem > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebHistoryFunc_backItems_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistory.backItems", overloads);
        return 0;
}

static PyObject* SbkQWebHistoryFunc_canGoBack(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canGoBack()const
            bool cppResult = cppSelf->QWebHistory::canGoBack();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_canGoForward(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canGoForward()const
            bool cppResult = cppSelf->QWebHistory::canGoForward();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_clear(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QWebHistory::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebHistoryFunc_count(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // count()const
            int cppResult = cppSelf->QWebHistory::count();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_currentItem(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentItem()const
            QWebHistoryItem cppResult = cppSelf->QWebHistory::currentItem();
            pyResult = Shiboken::Converter<QWebHistoryItem >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_currentItemIndex(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentItemIndex()const
            int cppResult = cppSelf->QWebHistory::currentItemIndex();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_forward(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // forward()
            cppSelf->QWebHistory::forward();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebHistoryFunc_forwardItem(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // forwardItem()const
            QWebHistoryItem cppResult = cppSelf->QWebHistory::forwardItem();
            pyResult = Shiboken::Converter<QWebHistoryItem >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_forwardItems(PyObject* self, PyObject* arg)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: forwardItems(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // forwardItems(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryFunc_forwardItems_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // forwardItems(int)const
            QList<QWebHistoryItem > cppResult = cppSelf->QWebHistory::forwardItems(cpp_arg0);
            pyResult = Shiboken::Converter<QList<QWebHistoryItem > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebHistoryFunc_forwardItems_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistory.forwardItems", overloads);
        return 0;
}

static PyObject* SbkQWebHistoryFunc_goToItem(PyObject* self, PyObject* arg)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: goToItem(QWebHistoryItem)
    if (Shiboken::Converter<const QWebHistoryItem & >::isConvertible(arg)) {
        overloadId = 0; // goToItem(QWebHistoryItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryFunc_goToItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWebHistoryItem* cpp_arg0 = Shiboken::Converter<QWebHistoryItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // goToItem(QWebHistoryItem)
            cppSelf->QWebHistory::goToItem(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebHistoryFunc_goToItem_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebHistoryItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistory.goToItem", overloads);
        return 0;
}

static PyObject* SbkQWebHistoryFunc_itemAt(PyObject* self, PyObject* arg)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // itemAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryFunc_itemAt_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // itemAt(int)const
            QWebHistoryItem cppResult = cppSelf->QWebHistory::itemAt(cpp_arg0);
            pyResult = Shiboken::Converter<QWebHistoryItem >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebHistoryFunc_itemAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistory.itemAt", overloads);
        return 0;
}

static PyObject* SbkQWebHistoryFunc_items(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // items()const
            QList<QWebHistoryItem > cppResult = cppSelf->QWebHistory::items();
            pyResult = Shiboken::Converter<QList<QWebHistoryItem > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_maximumItemCount(PyObject* self)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumItemCount()const
            int cppResult = cppSelf->QWebHistory::maximumItemCount();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryFunc_setMaximumItemCount(PyObject* self, PyObject* arg)
{
    QWebHistory* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumItemCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumItemCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryFunc_setMaximumItemCount_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaximumItemCount(int)
            cppSelf->QWebHistory::setMaximumItemCount(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebHistoryFunc_setMaximumItemCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistory.setMaximumItemCount", overloads);
        return 0;
}

static PyMethodDef SbkQWebHistory_methods[] = {
    {"back", (PyCFunction)SbkQWebHistoryFunc_back, METH_NOARGS},
    {"backItem", (PyCFunction)SbkQWebHistoryFunc_backItem, METH_NOARGS},
    {"backItems", (PyCFunction)SbkQWebHistoryFunc_backItems, METH_O},
    {"canGoBack", (PyCFunction)SbkQWebHistoryFunc_canGoBack, METH_NOARGS},
    {"canGoForward", (PyCFunction)SbkQWebHistoryFunc_canGoForward, METH_NOARGS},
    {"clear", (PyCFunction)SbkQWebHistoryFunc_clear, METH_NOARGS},
    {"count", (PyCFunction)SbkQWebHistoryFunc_count, METH_NOARGS},
    {"currentItem", (PyCFunction)SbkQWebHistoryFunc_currentItem, METH_NOARGS},
    {"currentItemIndex", (PyCFunction)SbkQWebHistoryFunc_currentItemIndex, METH_NOARGS},
    {"forward", (PyCFunction)SbkQWebHistoryFunc_forward, METH_NOARGS},
    {"forwardItem", (PyCFunction)SbkQWebHistoryFunc_forwardItem, METH_NOARGS},
    {"forwardItems", (PyCFunction)SbkQWebHistoryFunc_forwardItems, METH_O},
    {"goToItem", (PyCFunction)SbkQWebHistoryFunc_goToItem, METH_O},
    {"itemAt", (PyCFunction)SbkQWebHistoryFunc_itemAt, METH_O},
    {"items", (PyCFunction)SbkQWebHistoryFunc_items, METH_NOARGS},
    {"maximumItemCount", (PyCFunction)SbkQWebHistoryFunc_maximumItemCount, METH_NOARGS},
    {"setMaximumItemCount", (PyCFunction)SbkQWebHistoryFunc_setMaximumItemCount, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQWebHistoryFunc___lshift__(PyObject* self, PyObject* arg)
{
    QWebHistory* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QWebHistory* >::checkType(arg) && !Shiboken::Converter<QWebHistory* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QWebHistory)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QWebHistory)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QWebHistory) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebHistoryFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistory.__lshift__", overloads);
        return 0;
}

static PyObject* SbkQWebHistoryFunc___rshift__(PyObject* self, PyObject* arg)
{
    QWebHistory* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QWebHistory* >::checkType(arg) && !Shiboken::Converter<QWebHistory* >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistory* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QWebHistory&)
    if (isReverse && Shiboken::Converter<QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QWebHistory&)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDataStream* cpp_arg0 = Shiboken::Converter<QDataStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QWebHistory&) [reverse operator]
            QDataStream & cppResult = (*cpp_arg0) >> (*cppSelf);
            pyResult = Shiboken::Converter<QDataStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebHistoryFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistory.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQWebHistory_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQWebHistoryFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)SbkQWebHistoryFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWebHistory_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebHistory",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          Shiboken::deallocWrapperWithPrivateDtor,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQWebHistory_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWebHistory_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            0,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWebHistory*",
    /*user_data*/           0
};
} //extern


void init_QWebHistory(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBHISTORY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWebHistory_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWebHistory_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWebHistory_Type));
    PyModule_AddObject(module, "QWebHistory",
        ((PyObject*)&SbkQWebHistory_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QWebHistory >("QWebHistory*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebHistory >(typeid(QWebHistory).name());
    PySide::initQtMetaType<QWebHistory* >();
}

