/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebhistoryitem_wrapper.h"

// Extra includes
#include <qdatetime.h>
#include <qicon.h>
#include <qurl.h>
#include <qwebhistory.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQWebHistoryItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebHistoryItem >()))
        return -1;

    QWebHistoryItem* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWebHistoryItem", 1, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QWebHistoryItem(QWebHistoryItem)
    if (numArgs == 1 && Shiboken::Converter<const QWebHistoryItem & >::isConvertible(arg)) {
        overloadId = 0; // QWebHistoryItem(QWebHistoryItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryItem_Init_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QWebHistoryItem* cpp_arg0 = Shiboken::Converter<QWebHistoryItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // QWebHistoryItem(QWebHistoryItem)
            cptr = new QWebHistoryItem(*cpp_arg0);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QWebHistoryItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQWebHistoryItem_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQWebHistoryItem_Init_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebHistoryItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebHistoryItem", overloads);
        return -1;
}

static PyObject* SbkQWebHistoryItemFunc_icon(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // icon()const
            QIcon cppResult = cppSelf->QWebHistoryItem::icon();
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryItemFunc_isValid(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QWebHistoryItem::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryItemFunc_lastVisited(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastVisited()const
            QDateTime cppResult = cppSelf->QWebHistoryItem::lastVisited();
            pyResult = Shiboken::Converter<QDateTime >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryItemFunc_originalUrl(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // originalUrl()const
            QUrl cppResult = cppSelf->QWebHistoryItem::originalUrl();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryItemFunc_setUserData(PyObject* self, PyObject* arg)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserData(QVariant)
    if (Shiboken::Converter<QVariant >::isConvertible(arg)) {
        overloadId = 0; // setUserData(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHistoryItemFunc_setUserData_TypeError;

    // Call function/method
    {
        {
            QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUserData(QVariant)
            cppSelf->QWebHistoryItem::setUserData(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebHistoryItemFunc_setUserData_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebHistoryItem.setUserData", overloads);
        return 0;
}

static PyObject* SbkQWebHistoryItemFunc_title(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // title()const
            QString cppResult = cppSelf->QWebHistoryItem::title();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryItemFunc_url(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = cppSelf->QWebHistoryItem::url();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHistoryItemFunc_userData(PyObject* self)
{
    QWebHistoryItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHistoryItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userData()const
            QVariant cppResult = cppSelf->QWebHistoryItem::userData();
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQWebHistoryItem_methods[] = {
    {"icon", (PyCFunction)SbkQWebHistoryItemFunc_icon, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQWebHistoryItemFunc_isValid, METH_NOARGS},
    {"lastVisited", (PyCFunction)SbkQWebHistoryItemFunc_lastVisited, METH_NOARGS},
    {"originalUrl", (PyCFunction)SbkQWebHistoryItemFunc_originalUrl, METH_NOARGS},
    {"setUserData", (PyCFunction)SbkQWebHistoryItemFunc_setUserData, METH_O},
    {"title", (PyCFunction)SbkQWebHistoryItemFunc_title, METH_NOARGS},
    {"url", (PyCFunction)SbkQWebHistoryItemFunc_url, METH_NOARGS},
    {"userData", (PyCFunction)SbkQWebHistoryItemFunc_userData, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWebHistoryItem_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebHistoryItem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWebHistoryItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQWebHistoryItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QWebHistoryItem >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWebHistoryItem",
    /*user_data*/           0
};
} //extern


void init_QWebHistoryItem(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBHISTORYITEM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWebHistoryItem_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWebHistoryItem_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWebHistoryItem_Type));
    PyModule_AddObject(module, "QWebHistoryItem",
        ((PyObject*)&SbkQWebHistoryItem_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QWebHistoryItem >("QWebHistoryItem");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebHistoryItem >("QWebHistoryItem*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebHistoryItem >(typeid(QWebHistoryItem).name());
    PySide::initQtMetaType<QWebHistoryItem >();
}

