/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebhittestresult_wrapper.h"

// Extra includes
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qurl.h>
#include <qwebelement.h>
#include <qwebframe.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQWebHitTestResult_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebHitTestResult >()))
        return -1;

    QWebHitTestResult* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWebHitTestResult", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QWebHitTestResult()
    // 1: QWebHitTestResult(QWebHitTestResult)
    if (numArgs == 0) {
        overloadId = 0; // QWebHitTestResult()
    } else if (numArgs == 1 && Shiboken::Converter<const QWebHitTestResult & >::isConvertible(arg)) {
        overloadId = 1; // QWebHitTestResult(QWebHitTestResult)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebHitTestResult_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QWebHitTestResult()
            {

                if(!PyErr_Occurred()) {
                // QWebHitTestResult()
                cptr = new QWebHitTestResult();
                }
                break;
            }
            case 1: // QWebHitTestResult(QWebHitTestResult)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QWebHitTestResult* cpp_arg0 = Shiboken::Converter<QWebHitTestResult* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QWebHitTestResult(QWebHitTestResult)
                cptr = new QWebHitTestResult(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QWebHitTestResult >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQWebHitTestResult_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQWebHitTestResult_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtWebKit.QWebHitTestResult", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebHitTestResult", overloads);
        return -1;
}

static PyObject* SbkQWebHitTestResultFunc_alternateText(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alternateText()const
            QString cppResult = cppSelf->QWebHitTestResult::alternateText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_boundingRect(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // boundingRect()const
            QRect cppResult = cppSelf->QWebHitTestResult::boundingRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_element(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // element()const
            QWebElement cppResult = cppSelf->QWebHitTestResult::element();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_enclosingBlockElement(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // enclosingBlockElement()const
            QWebElement cppResult = cppSelf->QWebHitTestResult::enclosingBlockElement();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_frame(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // frame()const
            QWebFrame * cppResult = cppSelf->QWebHitTestResult::frame();
            pyResult = Shiboken::Converter<QWebFrame * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_imageUrl(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // imageUrl()const
            QUrl cppResult = cppSelf->QWebHitTestResult::imageUrl();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_isContentEditable(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isContentEditable()const
            bool cppResult = cppSelf->QWebHitTestResult::isContentEditable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_isContentSelected(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isContentSelected()const
            bool cppResult = cppSelf->QWebHitTestResult::isContentSelected();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_isNull(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QWebHitTestResult::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_linkElement(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // linkElement()const
            QWebElement cppResult = cppSelf->QWebHitTestResult::linkElement();
            pyResult = Shiboken::Converter<QWebElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_linkTargetFrame(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // linkTargetFrame()const
            QWebFrame * cppResult = cppSelf->QWebHitTestResult::linkTargetFrame();
            pyResult = Shiboken::Converter<QWebFrame * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_linkText(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // linkText()const
            QString cppResult = cppSelf->QWebHitTestResult::linkText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_linkTitle(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // linkTitle()const
            QUrl cppResult = cppSelf->QWebHitTestResult::linkTitle();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_linkUrl(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // linkUrl()const
            QUrl cppResult = cppSelf->QWebHitTestResult::linkUrl();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_pixmap(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pixmap()const
            QPixmap cppResult = cppSelf->QWebHitTestResult::pixmap();
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_pos(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            QPoint cppResult = cppSelf->QWebHitTestResult::pos();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebHitTestResultFunc_title(PyObject* self)
{
    QWebHitTestResult* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebHitTestResult* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // title()const
            QString cppResult = cppSelf->QWebHitTestResult::title();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQWebHitTestResult_methods[] = {
    {"alternateText", (PyCFunction)SbkQWebHitTestResultFunc_alternateText, METH_NOARGS},
    {"boundingRect", (PyCFunction)SbkQWebHitTestResultFunc_boundingRect, METH_NOARGS},
    {"element", (PyCFunction)SbkQWebHitTestResultFunc_element, METH_NOARGS},
    {"enclosingBlockElement", (PyCFunction)SbkQWebHitTestResultFunc_enclosingBlockElement, METH_NOARGS},
    {"frame", (PyCFunction)SbkQWebHitTestResultFunc_frame, METH_NOARGS},
    {"imageUrl", (PyCFunction)SbkQWebHitTestResultFunc_imageUrl, METH_NOARGS},
    {"isContentEditable", (PyCFunction)SbkQWebHitTestResultFunc_isContentEditable, METH_NOARGS},
    {"isContentSelected", (PyCFunction)SbkQWebHitTestResultFunc_isContentSelected, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQWebHitTestResultFunc_isNull, METH_NOARGS},
    {"linkElement", (PyCFunction)SbkQWebHitTestResultFunc_linkElement, METH_NOARGS},
    {"linkTargetFrame", (PyCFunction)SbkQWebHitTestResultFunc_linkTargetFrame, METH_NOARGS},
    {"linkText", (PyCFunction)SbkQWebHitTestResultFunc_linkText, METH_NOARGS},
    {"linkTitle", (PyCFunction)SbkQWebHitTestResultFunc_linkTitle, METH_NOARGS},
    {"linkUrl", (PyCFunction)SbkQWebHitTestResultFunc_linkUrl, METH_NOARGS},
    {"pixmap", (PyCFunction)SbkQWebHitTestResultFunc_pixmap, METH_NOARGS},
    {"pos", (PyCFunction)SbkQWebHitTestResultFunc_pos, METH_NOARGS},
    {"title", (PyCFunction)SbkQWebHitTestResultFunc_title, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWebHitTestResult_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebHitTestResult",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWebHitTestResult_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQWebHitTestResult_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QWebHitTestResult >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWebHitTestResult",
    /*user_data*/           0
};
} //extern


void init_QWebHitTestResult(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBHITTESTRESULT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWebHitTestResult_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWebHitTestResult_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWebHitTestResult_Type));
    PyModule_AddObject(module, "QWebHitTestResult",
        ((PyObject*)&SbkQWebHitTestResult_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QWebHitTestResult >("QWebHitTestResult");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebHitTestResult >("QWebHitTestResult*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebHitTestResult >(typeid(QWebHitTestResult).name());
    PySide::initQtMetaType<QWebHitTestResult >();
}

