/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebpluginfactory_plugin_wrapper.h"

// Extra includes

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQWebPluginFactory_Plugin_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebPluginFactory::Plugin >()))
        return -1;

    QWebPluginFactory::Plugin* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "Plugin", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: Plugin()
    // 1: Plugin(QWebPluginFactory::Plugin)
    if (numArgs == 0) {
        overloadId = 0; // Plugin()
    } else if (numArgs == 1 && Shiboken::Converter<const QWebPluginFactory::Plugin & >::isConvertible(arg)) {
        overloadId = 1; // Plugin(QWebPluginFactory::Plugin)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebPluginFactory_Plugin_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // Plugin()
            {

                if(!PyErr_Occurred()) {
                // Plugin()
                cptr = new QWebPluginFactory::Plugin();
                }
                break;
            }
            case 1: // Plugin(QWebPluginFactory::Plugin)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QWebPluginFactory::Plugin* cpp_arg0 = Shiboken::Converter<QWebPluginFactory::Plugin* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // Plugin(QWebPluginFactory::Plugin)
                cptr = new QWebPluginFactory::Plugin(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QWebPluginFactory::Plugin >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQWebPluginFactory_Plugin_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQWebPluginFactory_Plugin_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtWebKit.QWebPluginFactory::Plugin", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.Plugin", overloads);
        return -1;
}

static PyMethodDef SbkQWebPluginFactory_Plugin_methods[] = {
    {0} // Sentinel
};

static PyObject* SbkQWebPluginFactory_Plugin_get_description(PyObject* self, void*)
{
    return Shiboken::Converter<QString >::toPython(Shiboken::Converter<QWebPluginFactory::Plugin* >::toCpp(self)->description);
}
static int SbkQWebPluginFactory_Plugin_set_description(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'description' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'description', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QWebPluginFactory::Plugin* >::toCpp(self)->description = Shiboken::Converter<QString >::toCpp(value);

    return 0;
}

static PyObject* SbkQWebPluginFactory_Plugin_get_name(PyObject* self, void*)
{
    return Shiboken::Converter<QString >::toPython(Shiboken::Converter<QWebPluginFactory::Plugin* >::toCpp(self)->name);
}
static int SbkQWebPluginFactory_Plugin_set_name(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'name' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter<QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'name', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter<QWebPluginFactory::Plugin* >::toCpp(self)->name = Shiboken::Converter<QString >::toCpp(value);

    return 0;
}

// Getters and Setters for Plugin
static PyGetSetDef SbkQWebPluginFactory_Plugin_getsetlist[] = {
    {const_cast<char*>("description"), SbkQWebPluginFactory_Plugin_get_description, SbkQWebPluginFactory_Plugin_set_description},
    {const_cast<char*>("name"), SbkQWebPluginFactory_Plugin_get_name, SbkQWebPluginFactory_Plugin_set_name},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWebPluginFactory_Plugin_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.Plugin",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWebPluginFactory_Plugin_methods,
    /*tp_members*/          0,
    /*tp_getset*/           SbkQWebPluginFactory_Plugin_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQWebPluginFactory_Plugin_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QWebPluginFactory::Plugin >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWebPluginFactory::Plugin",
    /*user_data*/           0
};
} //extern


void init_QWebPluginFactory_Plugin(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBPLUGINFACTORY_PLUGIN_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWebPluginFactory_Plugin_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWebPluginFactory_Plugin_Type) < 0)
        return;

    PyDict_SetItemString(module,"Plugin", (PyObject*)&SbkQWebPluginFactory_Plugin_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QWebPluginFactory::Plugin >("QWebPluginFactory::Plugin");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebPluginFactory::Plugin >("QWebPluginFactory::Plugin*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebPluginFactory::Plugin >(typeid(QWebPluginFactory::Plugin).name());
    PySide::initQtMetaType<QWebPluginFactory::Plugin >();
}

