/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebsettings_wrapper.h"

// Extra includes
#include <qicon.h>
#include <qpixmap.h>
#include <qurl.h>
#include <qwebsettings.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQWebSettingsFunc_clearIconDatabase(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearIconDatabase()
            QWebSettings::clearIconDatabase();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebSettingsFunc_clearMemoryCaches(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearMemoryCaches()
            QWebSettings::clearMemoryCaches();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWebSettingsFunc_defaultTextEncoding(PyObject* self)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultTextEncoding()const
            QString cppResult = cppSelf->QWebSettings::defaultTextEncoding();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_enablePersistentStorage(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "path" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebSettings.enablePersistentStorage(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebSettings.enablePersistentStorage(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:enablePersistentStorage", &arg))
        return 0;


    // Overloaded function decisor
    // 0: enablePersistentStorage(QString)
    if (numArgs == 0) {
        overloadId = 0; // enablePersistentStorage(QString)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // enablePersistentStorage(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_enablePersistentStorage_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "path");
                if (value) {
                    if (arg)
                        errorArgName = "path";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebSettings.enablePersistentStorage(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // enablePersistentStorage(QString)
            QWebSettings::enablePersistentStorage(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_enablePersistentStorage_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.enablePersistentStorage", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_fontFamily(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fontFamily(QWebSettings::FontFamily)const
    if (Shiboken::Converter<QWebSettings::FontFamily >::isConvertible(arg)) {
        overloadId = 0; // fontFamily(QWebSettings::FontFamily)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_fontFamily_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontFamily cpp_arg0 = Shiboken::Converter<QWebSettings::FontFamily >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fontFamily(QWebSettings::FontFamily)const
            QString cppResult = cppSelf->QWebSettings::fontFamily(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebSettingsFunc_fontFamily_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontFamily", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.fontFamily", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_fontSize(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fontSize(QWebSettings::FontSize)const
    if (Shiboken::Converter<QWebSettings::FontSize >::isConvertible(arg)) {
        overloadId = 0; // fontSize(QWebSettings::FontSize)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_fontSize_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontSize cpp_arg0 = Shiboken::Converter<QWebSettings::FontSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // fontSize(QWebSettings::FontSize)const
            int cppResult = cppSelf->QWebSettings::fontSize(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebSettingsFunc_fontSize_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.fontSize", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_globalSettings(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // globalSettings()
            QWebSettings * cppResult = QWebSettings::globalSettings();
            pyResult = Shiboken::Converter<QWebSettings * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_iconDatabasePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // iconDatabasePath()
            QString cppResult = QWebSettings::iconDatabasePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_iconForUrl(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: iconForUrl(QUrl)
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // iconForUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_iconForUrl_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // iconForUrl(QUrl)
            QIcon cppResult = QWebSettings::iconForUrl(*cpp_arg0);
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebSettingsFunc_iconForUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.iconForUrl", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_localStoragePath(PyObject* self)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // localStoragePath()const
            QString cppResult = cppSelf->QWebSettings::localStoragePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_maximumPagesInCache(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumPagesInCache()
            int cppResult = QWebSettings::maximumPagesInCache();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_offlineStorageDefaultQuota(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // offlineStorageDefaultQuota()
            qint64 cppResult = QWebSettings::offlineStorageDefaultQuota();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_offlineStoragePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // offlineStoragePath()
            QString cppResult = QWebSettings::offlineStoragePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_offlineWebApplicationCachePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // offlineWebApplicationCachePath()
            QString cppResult = QWebSettings::offlineWebApplicationCachePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_offlineWebApplicationCacheQuota(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // offlineWebApplicationCacheQuota()
            qint64 cppResult = QWebSettings::offlineWebApplicationCacheQuota();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_resetAttribute(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resetAttribute(QWebSettings::WebAttribute)
    if (Shiboken::Converter<QWebSettings::WebAttribute >::isConvertible(arg)) {
        overloadId = 0; // resetAttribute(QWebSettings::WebAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_resetAttribute_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebAttribute cpp_arg0 = Shiboken::Converter<QWebSettings::WebAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resetAttribute(QWebSettings::WebAttribute)
            cppSelf->QWebSettings::resetAttribute(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_resetAttribute_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.resetAttribute", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_resetFontFamily(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resetFontFamily(QWebSettings::FontFamily)
    if (Shiboken::Converter<QWebSettings::FontFamily >::isConvertible(arg)) {
        overloadId = 0; // resetFontFamily(QWebSettings::FontFamily)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_resetFontFamily_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontFamily cpp_arg0 = Shiboken::Converter<QWebSettings::FontFamily >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resetFontFamily(QWebSettings::FontFamily)
            cppSelf->QWebSettings::resetFontFamily(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_resetFontFamily_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontFamily", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.resetFontFamily", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_resetFontSize(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resetFontSize(QWebSettings::FontSize)
    if (Shiboken::Converter<QWebSettings::FontSize >::isConvertible(arg)) {
        overloadId = 0; // resetFontSize(QWebSettings::FontSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_resetFontSize_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontSize cpp_arg0 = Shiboken::Converter<QWebSettings::FontSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resetFontSize(QWebSettings::FontSize)
            cppSelf->QWebSettings::resetFontSize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_resetFontSize_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.resetFontSize", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setAttribute(PyObject* self, PyObject* args)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(QWebSettings::WebAttribute,bool)
    if (numArgs == 2 && Shiboken::Converter<QWebSettings::WebAttribute >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setAttribute(QWebSettings::WebAttribute,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebAttribute cpp_arg0 = Shiboken::Converter<QWebSettings::WebAttribute >::toCpp(pyargs[0]);
            bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setAttribute(QWebSettings::WebAttribute,bool)
            cppSelf->QWebSettings::setAttribute(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setAttribute_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebAttribute, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setAttribute", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setDefaultTextEncoding(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultTextEncoding(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDefaultTextEncoding(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setDefaultTextEncoding_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultTextEncoding(QString)
            cppSelf->QWebSettings::setDefaultTextEncoding(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setDefaultTextEncoding_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setDefaultTextEncoding", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setFontFamily(PyObject* self, PyObject* args)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFontFamily", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFontFamily(QWebSettings::FontFamily,QString)
    if (numArgs == 2 && Shiboken::Converter<QWebSettings::FontFamily >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setFontFamily(QWebSettings::FontFamily,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setFontFamily_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontFamily cpp_arg0 = Shiboken::Converter<QWebSettings::FontFamily >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setFontFamily(QWebSettings::FontFamily,QString)
            cppSelf->QWebSettings::setFontFamily(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setFontFamily_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontFamily, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setFontFamily", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setFontSize(PyObject* self, PyObject* args)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFontSize", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFontSize(QWebSettings::FontSize,int)
    if (numArgs == 2 && Shiboken::Converter<QWebSettings::FontSize >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFontSize(QWebSettings::FontSize,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setFontSize_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontSize cpp_arg0 = Shiboken::Converter<QWebSettings::FontSize >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setFontSize(QWebSettings::FontSize,int)
            cppSelf->QWebSettings::setFontSize(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setFontSize_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontSize, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setFontSize", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setIconDatabasePath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconDatabasePath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setIconDatabasePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setIconDatabasePath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIconDatabasePath(QString)
            QWebSettings::setIconDatabasePath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setIconDatabasePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setIconDatabasePath", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setLocalStoragePath(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocalStoragePath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setLocalStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setLocalStoragePath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLocalStoragePath(QString)
            cppSelf->QWebSettings::setLocalStoragePath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setLocalStoragePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setLocalStoragePath", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setMaximumPagesInCache(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumPagesInCache(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumPagesInCache(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setMaximumPagesInCache_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaximumPagesInCache(int)
            QWebSettings::setMaximumPagesInCache(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setMaximumPagesInCache_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setMaximumPagesInCache", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setObjectCacheCapacities(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setObjectCacheCapacities", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setObjectCacheCapacities(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setObjectCacheCapacities(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setObjectCacheCapacities_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // setObjectCacheCapacities(int,int,int)
            QWebSettings::setObjectCacheCapacities(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setObjectCacheCapacities_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setObjectCacheCapacities", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setOfflineStorageDefaultQuota(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineStorageDefaultQuota(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOfflineStorageDefaultQuota(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setOfflineStorageDefaultQuota_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOfflineStorageDefaultQuota(qint64)
            QWebSettings::setOfflineStorageDefaultQuota(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setOfflineStorageDefaultQuota_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineStorageDefaultQuota", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setOfflineStoragePath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineStoragePath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setOfflineStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setOfflineStoragePath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOfflineStoragePath(QString)
            QWebSettings::setOfflineStoragePath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setOfflineStoragePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineStoragePath", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setOfflineWebApplicationCachePath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineWebApplicationCachePath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setOfflineWebApplicationCachePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setOfflineWebApplicationCachePath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOfflineWebApplicationCachePath(QString)
            QWebSettings::setOfflineWebApplicationCachePath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setOfflineWebApplicationCachePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineWebApplicationCachePath", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setOfflineWebApplicationCacheQuota(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineWebApplicationCacheQuota(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOfflineWebApplicationCacheQuota(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setOfflineWebApplicationCacheQuota_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOfflineWebApplicationCacheQuota(qint64)
            QWebSettings::setOfflineWebApplicationCacheQuota(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setOfflineWebApplicationCacheQuota_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineWebApplicationCacheQuota", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setUserStyleSheetUrl(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserStyleSheetUrl(QUrl)
    if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 0; // setUserStyleSheetUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setUserStyleSheetUrl_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
            QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
            if (!Shiboken::Converter<QUrl >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setUserStyleSheetUrl(QUrl)
            cppSelf->QWebSettings::setUserStyleSheetUrl(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setUserStyleSheetUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setUserStyleSheetUrl", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_setWebGraphic(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setWebGraphic", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setWebGraphic(QWebSettings::WebGraphic,QPixmap)
    if (numArgs == 2 && Shiboken::Converter<QWebSettings::WebGraphic >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
        overloadId = 0; // setWebGraphic(QWebSettings::WebGraphic,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_setWebGraphic_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebGraphic cpp_arg0 = Shiboken::Converter<QWebSettings::WebGraphic >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
            QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // setWebGraphic(QWebSettings::WebGraphic,QPixmap)
            QWebSettings::setWebGraphic(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWebSettingsFunc_setWebGraphic_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebGraphic, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setWebGraphic", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_testAttribute(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testAttribute(QWebSettings::WebAttribute)const
    if (Shiboken::Converter<QWebSettings::WebAttribute >::isConvertible(arg)) {
        overloadId = 0; // testAttribute(QWebSettings::WebAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_testAttribute_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebAttribute cpp_arg0 = Shiboken::Converter<QWebSettings::WebAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // testAttribute(QWebSettings::WebAttribute)const
            bool cppResult = cppSelf->QWebSettings::testAttribute(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebSettingsFunc_testAttribute_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.testAttribute", overloads);
        return 0;
}

static PyObject* SbkQWebSettingsFunc_userStyleSheetUrl(PyObject* self)
{
    QWebSettings* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // userStyleSheetUrl()const
            QUrl cppResult = cppSelf->QWebSettings::userStyleSheetUrl();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWebSettingsFunc_webGraphic(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: webGraphic(QWebSettings::WebGraphic)
    if (Shiboken::Converter<QWebSettings::WebGraphic >::isConvertible(arg)) {
        overloadId = 0; // webGraphic(QWebSettings::WebGraphic)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWebSettingsFunc_webGraphic_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebGraphic cpp_arg0 = Shiboken::Converter<QWebSettings::WebGraphic >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // webGraphic(QWebSettings::WebGraphic)
            QPixmap cppResult = QWebSettings::webGraphic(cpp_arg0);
            pyResult = Shiboken::Converter<QPixmap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWebSettingsFunc_webGraphic_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebGraphic", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.webGraphic", overloads);
        return 0;
}

static PyMethodDef SbkQWebSettings_methods[] = {
    {"clearIconDatabase", (PyCFunction)SbkQWebSettingsFunc_clearIconDatabase, METH_NOARGS|METH_STATIC},
    {"clearMemoryCaches", (PyCFunction)SbkQWebSettingsFunc_clearMemoryCaches, METH_NOARGS|METH_STATIC},
    {"defaultTextEncoding", (PyCFunction)SbkQWebSettingsFunc_defaultTextEncoding, METH_NOARGS},
    {"enablePersistentStorage", (PyCFunction)SbkQWebSettingsFunc_enablePersistentStorage, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fontFamily", (PyCFunction)SbkQWebSettingsFunc_fontFamily, METH_O},
    {"fontSize", (PyCFunction)SbkQWebSettingsFunc_fontSize, METH_O},
    {"globalSettings", (PyCFunction)SbkQWebSettingsFunc_globalSettings, METH_NOARGS|METH_STATIC},
    {"iconDatabasePath", (PyCFunction)SbkQWebSettingsFunc_iconDatabasePath, METH_NOARGS|METH_STATIC},
    {"iconForUrl", (PyCFunction)SbkQWebSettingsFunc_iconForUrl, METH_O|METH_STATIC},
    {"localStoragePath", (PyCFunction)SbkQWebSettingsFunc_localStoragePath, METH_NOARGS},
    {"maximumPagesInCache", (PyCFunction)SbkQWebSettingsFunc_maximumPagesInCache, METH_NOARGS|METH_STATIC},
    {"offlineStorageDefaultQuota", (PyCFunction)SbkQWebSettingsFunc_offlineStorageDefaultQuota, METH_NOARGS|METH_STATIC},
    {"offlineStoragePath", (PyCFunction)SbkQWebSettingsFunc_offlineStoragePath, METH_NOARGS|METH_STATIC},
    {"offlineWebApplicationCachePath", (PyCFunction)SbkQWebSettingsFunc_offlineWebApplicationCachePath, METH_NOARGS|METH_STATIC},
    {"offlineWebApplicationCacheQuota", (PyCFunction)SbkQWebSettingsFunc_offlineWebApplicationCacheQuota, METH_NOARGS|METH_STATIC},
    {"resetAttribute", (PyCFunction)SbkQWebSettingsFunc_resetAttribute, METH_O},
    {"resetFontFamily", (PyCFunction)SbkQWebSettingsFunc_resetFontFamily, METH_O},
    {"resetFontSize", (PyCFunction)SbkQWebSettingsFunc_resetFontSize, METH_O},
    {"setAttribute", (PyCFunction)SbkQWebSettingsFunc_setAttribute, METH_VARARGS},
    {"setDefaultTextEncoding", (PyCFunction)SbkQWebSettingsFunc_setDefaultTextEncoding, METH_O},
    {"setFontFamily", (PyCFunction)SbkQWebSettingsFunc_setFontFamily, METH_VARARGS},
    {"setFontSize", (PyCFunction)SbkQWebSettingsFunc_setFontSize, METH_VARARGS},
    {"setIconDatabasePath", (PyCFunction)SbkQWebSettingsFunc_setIconDatabasePath, METH_O|METH_STATIC},
    {"setLocalStoragePath", (PyCFunction)SbkQWebSettingsFunc_setLocalStoragePath, METH_O},
    {"setMaximumPagesInCache", (PyCFunction)SbkQWebSettingsFunc_setMaximumPagesInCache, METH_O|METH_STATIC},
    {"setObjectCacheCapacities", (PyCFunction)SbkQWebSettingsFunc_setObjectCacheCapacities, METH_VARARGS|METH_STATIC},
    {"setOfflineStorageDefaultQuota", (PyCFunction)SbkQWebSettingsFunc_setOfflineStorageDefaultQuota, METH_O|METH_STATIC},
    {"setOfflineStoragePath", (PyCFunction)SbkQWebSettingsFunc_setOfflineStoragePath, METH_O|METH_STATIC},
    {"setOfflineWebApplicationCachePath", (PyCFunction)SbkQWebSettingsFunc_setOfflineWebApplicationCachePath, METH_O|METH_STATIC},
    {"setOfflineWebApplicationCacheQuota", (PyCFunction)SbkQWebSettingsFunc_setOfflineWebApplicationCacheQuota, METH_O|METH_STATIC},
    {"setUserStyleSheetUrl", (PyCFunction)SbkQWebSettingsFunc_setUserStyleSheetUrl, METH_O},
    {"setWebGraphic", (PyCFunction)SbkQWebSettingsFunc_setWebGraphic, METH_VARARGS|METH_STATIC},
    {"testAttribute", (PyCFunction)SbkQWebSettingsFunc_testAttribute, METH_O},
    {"userStyleSheetUrl", (PyCFunction)SbkQWebSettingsFunc_userStyleSheetUrl, METH_NOARGS},
    {"webGraphic", (PyCFunction)SbkQWebSettingsFunc_webGraphic, METH_O|METH_STATIC},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWebSettings_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebSettings",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          Shiboken::deallocWrapperWithPrivateDtor,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWebSettings_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            0,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWebSettings*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtWebKit_QWebSettings_FontSize_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtWebKit_QWebSettings_FontSize_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtWebKit_QWebSettings_FontSize_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FontSize",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtWebKit_QWebSettings_FontSize_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtWebKit_QWebSettings_FontSize_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtWebKit_QWebSettings_FontSize_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtWebKit_QWebSettings_WebGraphic_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtWebKit_QWebSettings_WebGraphic_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WebGraphic",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtWebKit_QWebSettings_WebGraphic_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtWebKit_QWebSettings_WebGraphic_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtWebKit_QWebSettings_WebGraphic_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtWebKit_QWebSettings_FontFamily_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtWebKit_QWebSettings_FontFamily_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtWebKit_QWebSettings_FontFamily_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FontFamily",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtWebKit_QWebSettings_FontFamily_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtWebKit_QWebSettings_FontFamily_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtWebKit_QWebSettings_FontFamily_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtWebKit_QWebSettings_WebAttribute_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtWebKit_QWebSettings_WebAttribute_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "WebAttribute",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtWebKit_QWebSettings_WebAttribute_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtWebKit_QWebSettings_WebAttribute_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtWebKit_QWebSettings_WebAttribute_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QWebSettings(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWebSettings_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWebSettings_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWebSettings_Type));
    PyModule_AddObject(module, "QWebSettings",
        ((PyObject*)&SbkQWebSettings_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: FontSize
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_FONTSIZE_IDX] = &SbkPySide_QtWebKit_QWebSettings_FontSize_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtWebKit_QWebSettings_FontSize_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtWebKit_QWebSettings_FontSize_Type);
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
            "FontSize",((PyObject*)&SbkPySide_QtWebKit_QWebSettings_FontSize_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontSize_Type,
        (long) QWebSettings::MinimumFontSize, "MinimumFontSize");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "MinimumFontSize", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize_Type.tp_dict,
        "MinimumFontSize", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontSize_Type,
        (long) QWebSettings::MinimumLogicalFontSize, "MinimumLogicalFontSize");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "MinimumLogicalFontSize", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize_Type.tp_dict,
        "MinimumLogicalFontSize", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontSize_Type,
        (long) QWebSettings::DefaultFontSize, "DefaultFontSize");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "DefaultFontSize", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize_Type.tp_dict,
        "DefaultFontSize", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontSize_Type,
        (long) QWebSettings::DefaultFixedFontSize, "DefaultFixedFontSize");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "DefaultFixedFontSize", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize_Type.tp_dict,
        "DefaultFixedFontSize", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::FontSize");

    // init enum class: WebGraphic
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_WEBGRAPHIC_IDX] = &SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type);
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
            "WebGraphic",((PyObject*)&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type,
        (long) QWebSettings::MissingImageGraphic, "MissingImageGraphic");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "MissingImageGraphic", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type.tp_dict,
        "MissingImageGraphic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type,
        (long) QWebSettings::MissingPluginGraphic, "MissingPluginGraphic");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "MissingPluginGraphic", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type.tp_dict,
        "MissingPluginGraphic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type,
        (long) QWebSettings::DefaultFrameIconGraphic, "DefaultFrameIconGraphic");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "DefaultFrameIconGraphic", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type.tp_dict,
        "DefaultFrameIconGraphic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type,
        (long) QWebSettings::TextAreaSizeGripCornerGraphic, "TextAreaSizeGripCornerGraphic");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "TextAreaSizeGripCornerGraphic", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type.tp_dict,
        "TextAreaSizeGripCornerGraphic", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type,
        (long) QWebSettings::DeleteButtonGraphic, "DeleteButtonGraphic");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "DeleteButtonGraphic", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic_Type.tp_dict,
        "DeleteButtonGraphic", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::WebGraphic");

    // init enum class: FontFamily
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_FONTFAMILY_IDX] = &SbkPySide_QtWebKit_QWebSettings_FontFamily_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type);
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
            "FontFamily",((PyObject*)&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type,
        (long) QWebSettings::StandardFont, "StandardFont");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "StandardFont", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily_Type.tp_dict,
        "StandardFont", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type,
        (long) QWebSettings::FixedFont, "FixedFont");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "FixedFont", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily_Type.tp_dict,
        "FixedFont", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type,
        (long) QWebSettings::SerifFont, "SerifFont");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "SerifFont", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily_Type.tp_dict,
        "SerifFont", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type,
        (long) QWebSettings::SansSerifFont, "SansSerifFont");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "SansSerifFont", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily_Type.tp_dict,
        "SansSerifFont", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type,
        (long) QWebSettings::CursiveFont, "CursiveFont");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "CursiveFont", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily_Type.tp_dict,
        "CursiveFont", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_FontFamily_Type,
        (long) QWebSettings::FantasyFont, "FantasyFont");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "FantasyFont", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily_Type.tp_dict,
        "FantasyFont", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::FontFamily");

    // init enum class: WebAttribute
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_WEBATTRIBUTE_IDX] = &SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type);
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
            "WebAttribute",((PyObject*)&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::AutoLoadImages, "AutoLoadImages");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "AutoLoadImages", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "AutoLoadImages", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::JavascriptEnabled, "JavascriptEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "JavascriptEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "JavascriptEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::JavaEnabled, "JavaEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "JavaEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "JavaEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::PluginsEnabled, "PluginsEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "PluginsEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "PluginsEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::PrivateBrowsingEnabled, "PrivateBrowsingEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "PrivateBrowsingEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "PrivateBrowsingEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::JavascriptCanOpenWindows, "JavascriptCanOpenWindows");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "JavascriptCanOpenWindows", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "JavascriptCanOpenWindows", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::JavascriptCanAccessClipboard, "JavascriptCanAccessClipboard");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "JavascriptCanAccessClipboard", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "JavascriptCanAccessClipboard", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::DeveloperExtrasEnabled, "DeveloperExtrasEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "DeveloperExtrasEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "DeveloperExtrasEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::LinksIncludedInFocusChain, "LinksIncludedInFocusChain");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "LinksIncludedInFocusChain", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "LinksIncludedInFocusChain", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::ZoomTextOnly, "ZoomTextOnly");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "ZoomTextOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "ZoomTextOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::PrintElementBackgrounds, "PrintElementBackgrounds");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "PrintElementBackgrounds", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "PrintElementBackgrounds", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::OfflineStorageDatabaseEnabled, "OfflineStorageDatabaseEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "OfflineStorageDatabaseEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "OfflineStorageDatabaseEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::OfflineWebApplicationCacheEnabled, "OfflineWebApplicationCacheEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "OfflineWebApplicationCacheEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "OfflineWebApplicationCacheEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::LocalStorageEnabled, "LocalStorageEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "LocalStorageEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "LocalStorageEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::LocalStorageDatabaseEnabled, "LocalStorageDatabaseEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "LocalStorageDatabaseEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "LocalStorageDatabaseEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::LocalContentCanAccessRemoteUrls, "LocalContentCanAccessRemoteUrls");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "LocalContentCanAccessRemoteUrls", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "LocalContentCanAccessRemoteUrls", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::DnsPrefetchEnabled, "DnsPrefetchEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "DnsPrefetchEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "DnsPrefetchEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::XSSAuditingEnabled, "XSSAuditingEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "XSSAuditingEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "XSSAuditingEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::AcceleratedCompositingEnabled, "AcceleratedCompositingEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "AcceleratedCompositingEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "AcceleratedCompositingEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::SpatialNavigationEnabled, "SpatialNavigationEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "SpatialNavigationEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "SpatialNavigationEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::LocalContentCanAccessFileUrls, "LocalContentCanAccessFileUrls");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "LocalContentCanAccessFileUrls", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "LocalContentCanAccessFileUrls", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::TiledBackingStoreEnabled, "TiledBackingStoreEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "TiledBackingStoreEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "TiledBackingStoreEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::FrameFlatteningEnabled, "FrameFlatteningEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "FrameFlatteningEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "FrameFlatteningEnabled", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type,
        (long) QWebSettings::SiteSpecificQuirksEnabled, "SiteSpecificQuirksEnabled");
    PyDict_SetItemString(SbkQWebSettings_Type.super.ht_type.tp_dict,
        "SiteSpecificQuirksEnabled", enum_item);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute_Type.tp_dict,
        "SiteSpecificQuirksEnabled", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::WebAttribute");


    Shiboken::TypeResolver::createObjectTypeResolver<QWebSettings >("QWebSettings*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebSettings >(typeid(QWebSettings).name());
    PySide::initQtMetaType<QWebSettings* >();
}

