/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomcomment_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDomComment_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomComment >()))
        return -1;

    QDomComment* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomComment", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDomComment()
    // 1: QDomComment(QDomComment)
    if (numArgs == 0) {
        overloadId = 0; // QDomComment()
    } else if (numArgs == 1 && Shiboken::Converter<const QDomComment & >::isConvertible(arg)) {
        overloadId = 1; // QDomComment(QDomComment)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomComment_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomComment()
            {

                if(!PyErr_Occurred()) {
                // QDomComment()
                cptr = new QDomComment();
                }
                break;
            }
            case 1: // QDomComment(QDomComment)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDomComment* cpp_arg0 = Shiboken::Converter<QDomComment* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomComment(QDomComment)
                cptr = new QDomComment(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomComment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomComment_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDomComment_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomComment", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomComment", overloads);
        return -1;
}

static PyMethodDef SbkQDomComment_methods[] = {
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDomComment_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomComment",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomComment_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomComment_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomComment >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDomComment",
    /*user_data*/           0
};
} //extern


void init_QDomComment(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMCOMMENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomComment_Type);

    SbkQDomComment_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMCHARACTERDATA_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQDomComment_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomComment_Type));
    PyModule_AddObject(module, "QDomComment",
        ((PyObject*)&SbkQDomComment_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomComment >("QDomComment");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomComment >("QDomComment*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomComment >(typeid(QDomComment).name());
    PySide::initQtMetaType<QDomComment >();
}

