/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomdocument_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qdom.h>
#include <qiodevice.h>
#include <qtextstream.h>
#include <qxml.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDomDocument_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomDocument >()))
        return -1;

    QDomDocument* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomDocument", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDomDocument()
    // 1: QDomDocument(QDomDocument)
    // 2: QDomDocument(QDomDocumentType)
    // 3: QDomDocument(QString)
    if (numArgs == 0) {
        overloadId = 0; // QDomDocument()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 3; // QDomDocument(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QDomDocumentType & >::isConvertible(arg)) {
        overloadId = 2; // QDomDocument(QDomDocumentType)
    } else if (numArgs == 1 && Shiboken::Converter<const QDomDocument & >::isConvertible(arg)) {
        overloadId = 1; // QDomDocument(QDomDocument)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocument_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomDocument()
            {

                if(!PyErr_Occurred()) {
                // QDomDocument()
                cptr = new QDomDocument();
                }
                break;
            }
            case 1: // QDomDocument(QDomDocument)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDomDocument* cpp_arg0 = Shiboken::Converter<QDomDocument* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomDocument(QDomDocument)
                cptr = new QDomDocument(*cpp_arg0);
                }
                break;
            }
            case 2: // QDomDocument(QDomDocumentType)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDomDocumentType* cpp_arg0 = Shiboken::Converter<QDomDocumentType* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomDocument(QDomDocumentType)
                cptr = new QDomDocument(*cpp_arg0);
                }
                break;
            }
            case 3: // QDomDocument(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomDocument(QString)
                cptr = new QDomDocument(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomDocument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomDocument_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDomDocument_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomDocument", "PySide.QtXml.QDomDocumentType", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocument", overloads);
        return -1;
}

static PyObject* SbkQDomDocumentFunc_createAttribute(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createAttribute(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // createAttribute(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createAttribute_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createAttribute(QString)
            QDomAttr cppResult = cppSelf->QDomDocument::createAttribute(cpp_arg0);
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.createAttribute", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createAttributeNS(PyObject* self, PyObject* args)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createAttributeNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // createAttributeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // createAttributeNS(QString,QString)
            QDomAttr cppResult = cppSelf->QDomDocument::createAttributeNS(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocument.createAttributeNS", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createCDATASection(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createCDATASection(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // createCDATASection(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createCDATASection_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createCDATASection(QString)
            QDomCDATASection cppResult = cppSelf->QDomDocument::createCDATASection(cpp_arg0);
            pyResult = Shiboken::Converter<QDomCDATASection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createCDATASection_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.createCDATASection", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createComment(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createComment(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // createComment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createComment_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createComment(QString)
            QDomComment cppResult = cppSelf->QDomDocument::createComment(cpp_arg0);
            pyResult = Shiboken::Converter<QDomComment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createComment_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.createComment", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createDocumentFragment(PyObject* self)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // createDocumentFragment()
            QDomDocumentFragment cppResult = cppSelf->QDomDocument::createDocumentFragment();
            pyResult = Shiboken::Converter<QDomDocumentFragment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentFunc_createElement(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createElement(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // createElement(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createElement_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createElement(QString)
            QDomElement cppResult = cppSelf->QDomDocument::createElement(cpp_arg0);
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createElement_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.createElement", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createElementNS(PyObject* self, PyObject* args)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createElementNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createElementNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // createElementNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createElementNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // createElementNS(QString,QString)
            QDomElement cppResult = cppSelf->QDomDocument::createElementNS(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createElementNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocument.createElementNS", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createEntityReference(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createEntityReference(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // createEntityReference(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createEntityReference_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createEntityReference(QString)
            QDomEntityReference cppResult = cppSelf->QDomDocument::createEntityReference(cpp_arg0);
            pyResult = Shiboken::Converter<QDomEntityReference >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createEntityReference_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.createEntityReference", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createProcessingInstruction(PyObject* self, PyObject* args)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createProcessingInstruction", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createProcessingInstruction(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // createProcessingInstruction(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createProcessingInstruction_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // createProcessingInstruction(QString,QString)
            QDomProcessingInstruction cppResult = cppSelf->QDomDocument::createProcessingInstruction(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDomProcessingInstruction >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createProcessingInstruction_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocument.createProcessingInstruction", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_createTextNode(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createTextNode(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // createTextNode(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_createTextNode_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // createTextNode(QString)
            QDomText cppResult = cppSelf->QDomDocument::createTextNode(cpp_arg0);
            pyResult = Shiboken::Converter<QDomText >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_createTextNode_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.createTextNode", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_doctype(PyObject* self)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // doctype()const
            QDomDocumentType cppResult = cppSelf->QDomDocument::doctype();
            pyResult = Shiboken::Converter<QDomDocumentType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentFunc_documentElement(PyObject* self)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentElement()const
            QDomElement cppResult = cppSelf->QDomDocument::documentElement();
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentFunc_elementById(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementById(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // elementById(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_elementById_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // elementById(QString)
            QDomElement cppResult = cppSelf->QDomDocument::elementById(cpp_arg0);
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_elementById_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.elementById", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_elementsByTagName(PyObject* self, PyObject* arg)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementsByTagName(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // elementsByTagName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_elementsByTagName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // elementsByTagName(QString)const
            QDomNodeList cppResult = cppSelf->QDomDocument::elementsByTagName(cpp_arg0);
            pyResult = Shiboken::Converter<QDomNodeList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_elementsByTagName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.elementsByTagName", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_elementsByTagNameNS(PyObject* self, PyObject* args)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "elementsByTagNameNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: elementsByTagNameNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // elementsByTagNameNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_elementsByTagNameNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // elementsByTagNameNS(QString,QString)
            QDomNodeList cppResult = cppSelf->QDomDocument::elementsByTagNameNS(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDomNodeList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_elementsByTagNameNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocument.elementsByTagNameNS", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_implementation(PyObject* self)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // implementation()const
            QDomImplementation cppResult = cppSelf->QDomDocument::implementation();
            pyResult = Shiboken::Converter<QDomImplementation >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentFunc_importNode(PyObject* self, PyObject* args)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "importNode", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: importNode(QDomNode,bool)
    if (numArgs == 2 && Shiboken::Converter<const QDomNode & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // importNode(QDomNode,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_importNode_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QDomNode* cpp_arg0 = Shiboken::Converter<QDomNode* >::toCpp(pyargs[0]);
            bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // importNode(QDomNode,bool)
            QDomNode cppResult = cppSelf->QDomDocument::importNode(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_importNode_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocument.importNode", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_setContent(PyObject* self, PyObject* args)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setContent", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setContent(QIODevice*,QString*,int*,int*)
    // 1: setContent(QIODevice*,bool,QString*,int*,int*)
    // 2: setContent(QXmlInputSource*,QXmlReader*,QString*,int*,int*)
    // 3: setContent(QXmlInputSource*,bool,QString*,int*,int*)
    // 4: setContent(QByteArray,QString*,int*,int*)
    // 5: setContent(QByteArray,bool,QString*,int*,int*)
    // 6: setContent(QString,QString*,int*,int*)
    // 7: setContent(QString,bool,QString*,int*,int*)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 6; // setContent(QString,QString*,int*,int*)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 7; // setContent(QString,bool,QString*,int*,int*)
        }
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // setContent(QByteArray,QString*,int*,int*)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 5; // setContent(QByteArray,bool,QString*,int*,int*)
        }
    } else if (Shiboken::Converter<QXmlInputSource * >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 3; // setContent(QXmlInputSource*,bool,QString*,int*,int*)
        } else if (numArgs == 2 && Shiboken::Converter<QXmlReader * >::isConvertible(pyargs[1])) {
            overloadId = 2; // setContent(QXmlInputSource*,QXmlReader*,QString*,int*,int*)
        }
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setContent(QIODevice*,QString*,int*,int*)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // setContent(QIODevice*,bool,QString*,int*,int*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_setContent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setContent(QIODevice*,QString*,int*,int*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setContent(QIODevice*,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(cpp_arg0, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
            case 1: // setContent(QIODevice*,bool,QString*,int*,int*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setContent(QIODevice*,bool,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(cpp_arg0, cpp_arg1, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
            case 2: // setContent(QXmlInputSource*,QXmlReader*,QString*,int*,int*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlInputSource* cpp_arg0 = Shiboken::Converter<QXmlInputSource* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QXmlReader* cpp_arg1 = Shiboken::Converter<QXmlReader* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setContent(QXmlInputSource*,QXmlReader*,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(cpp_arg0, cpp_arg1, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
            case 3: // setContent(QXmlInputSource*,bool,QString*,int*,int*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlInputSource* cpp_arg0 = Shiboken::Converter<QXmlInputSource* >::toCpp(pyargs[0]);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setContent(QXmlInputSource*,bool,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(cpp_arg0, cpp_arg1, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
            case 4: // setContent(QByteArray,QString*,int*,int*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setContent(QByteArray,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(*cpp_arg0, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
            case 5: // setContent(QByteArray,bool,QString*,int*,int*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setContent(QByteArray,bool,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(*cpp_arg0, cpp_arg1, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
            case 6: // setContent(QString,QString*,int*,int*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setContent(QString,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(cpp_arg0, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
            case 7: // setContent(QString,bool,QString*,int*,int*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setContent(QString,bool,QString*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - qdomdocument_setcontent - START
                QString _errorMsg_;
                int _errorLine_ = 0;
                int _errorColumn_ = 0;
                bool _ret_ = cppSelf->setContent(cpp_arg0, cpp_arg1, &_errorMsg_, &_errorLine_, &_errorColumn_);
                pyResult = Shiboken::makeTuple(_ret_, _errorMsg_, _errorLine_, _errorColumn_);
                // TEMPLATE - qdomdocument_setcontent - END
                
                // End of code injection


                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_setContent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, QString, int, int", "PySide.QtCore.QIODevice, bool, QString, int, int", "PySide.QtXml.QXmlInputSource, PySide.QtXml.QXmlReader, QString, int, int", "PySide.QtXml.QXmlInputSource, bool, QString, int, int", "PySide.QtCore.QByteArray, QString, int, int", "PySide.QtCore.QByteArray, bool, QString, int, int", "QString, QString, int, int", "QString, bool, QString, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocument.setContent", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_toByteArray(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "arg__1" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomDocument.toByteArray(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomDocument.toByteArray(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toByteArray", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toByteArray(int)const
    if (numArgs == 0) {
        overloadId = 0; // toByteArray(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toByteArray(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_toByteArray_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "arg__1");
                if (value) {
                    if (arg)
                        errorArgName = "arg__1";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomDocument.toByteArray(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 1;

            if(!PyErr_Occurred()) {
            // toByteArray(int)const
            QByteArray cppResult = cppSelf->QDomDocument::toByteArray(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_toByteArray_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.toByteArray", overloads);
        return 0;
}

static PyObject* SbkQDomDocumentFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomDocument* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "arg__1" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomDocument.toString(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomDocument.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toString(int)const
    if (numArgs == 0) {
        overloadId = 0; // toString(int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toString(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentFunc_toString_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "arg__1");
                if (value) {
                    if (arg)
                        errorArgName = "arg__1";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomDocument.toString(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 1;

            if(!PyErr_Occurred()) {
            // toString(int)const
            QString cppResult = cppSelf->QDomDocument::toString(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomDocumentFunc_toString_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomDocument.toString", overloads);
        return 0;
}

static PyMethodDef SbkQDomDocument_methods[] = {
    {"createAttribute", (PyCFunction)SbkQDomDocumentFunc_createAttribute, METH_O},
    {"createAttributeNS", (PyCFunction)SbkQDomDocumentFunc_createAttributeNS, METH_VARARGS},
    {"createCDATASection", (PyCFunction)SbkQDomDocumentFunc_createCDATASection, METH_O},
    {"createComment", (PyCFunction)SbkQDomDocumentFunc_createComment, METH_O},
    {"createDocumentFragment", (PyCFunction)SbkQDomDocumentFunc_createDocumentFragment, METH_NOARGS},
    {"createElement", (PyCFunction)SbkQDomDocumentFunc_createElement, METH_O},
    {"createElementNS", (PyCFunction)SbkQDomDocumentFunc_createElementNS, METH_VARARGS},
    {"createEntityReference", (PyCFunction)SbkQDomDocumentFunc_createEntityReference, METH_O},
    {"createProcessingInstruction", (PyCFunction)SbkQDomDocumentFunc_createProcessingInstruction, METH_VARARGS},
    {"createTextNode", (PyCFunction)SbkQDomDocumentFunc_createTextNode, METH_O},
    {"doctype", (PyCFunction)SbkQDomDocumentFunc_doctype, METH_NOARGS},
    {"documentElement", (PyCFunction)SbkQDomDocumentFunc_documentElement, METH_NOARGS},
    {"elementById", (PyCFunction)SbkQDomDocumentFunc_elementById, METH_O},
    {"elementsByTagName", (PyCFunction)SbkQDomDocumentFunc_elementsByTagName, METH_O},
    {"elementsByTagNameNS", (PyCFunction)SbkQDomDocumentFunc_elementsByTagNameNS, METH_VARARGS},
    {"implementation", (PyCFunction)SbkQDomDocumentFunc_implementation, METH_NOARGS},
    {"importNode", (PyCFunction)SbkQDomDocumentFunc_importNode, METH_VARARGS},
    {"setContent", (PyCFunction)SbkQDomDocumentFunc_setContent, METH_VARARGS},
    {"toByteArray", (PyCFunction)SbkQDomDocumentFunc_toByteArray, METH_VARARGS|METH_KEYWORDS},
    {"toString", (PyCFunction)SbkQDomDocumentFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDomDocument_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomDocument",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomDocument_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomDocument_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomDocument >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDomDocument",
    /*user_data*/           0
};
} //extern


void init_QDomDocument(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMDOCUMENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomDocument_Type);

    SbkQDomDocument_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQDomDocument_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomDocument_Type));
    PyModule_AddObject(module, "QDomDocument",
        ((PyObject*)&SbkQDomDocument_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomDocument >("QDomDocument");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomDocument >("QDomDocument*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomDocument >(typeid(QDomDocument).name());
    PySide::initQtMetaType<QDomDocument >();
}

