/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomdocumenttype_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDomDocumentType_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomDocumentType >()))
        return -1;

    QDomDocumentType* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomDocumentType", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDomDocumentType()
    // 1: QDomDocumentType(QDomDocumentType)
    if (numArgs == 0) {
        overloadId = 0; // QDomDocumentType()
    } else if (numArgs == 1 && Shiboken::Converter<const QDomDocumentType & >::isConvertible(arg)) {
        overloadId = 1; // QDomDocumentType(QDomDocumentType)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomDocumentType_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomDocumentType()
            {

                if(!PyErr_Occurred()) {
                // QDomDocumentType()
                cptr = new QDomDocumentType();
                }
                break;
            }
            case 1: // QDomDocumentType(QDomDocumentType)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDomDocumentType* cpp_arg0 = Shiboken::Converter<QDomDocumentType* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomDocumentType(QDomDocumentType)
                cptr = new QDomDocumentType(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomDocumentType >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomDocumentType_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDomDocumentType_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomDocumentType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomDocumentType", overloads);
        return -1;
}

static PyObject* SbkQDomDocumentTypeFunc_entities(PyObject* self)
{
    QDomDocumentType* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // entities()const
            QDomNamedNodeMap cppResult = cppSelf->QDomDocumentType::entities();
            pyResult = Shiboken::Converter<QDomNamedNodeMap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentTypeFunc_internalSubset(PyObject* self)
{
    QDomDocumentType* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // internalSubset()const
            QString cppResult = cppSelf->QDomDocumentType::internalSubset();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentTypeFunc_name(PyObject* self)
{
    QDomDocumentType* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->QDomDocumentType::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentTypeFunc_notations(PyObject* self)
{
    QDomDocumentType* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // notations()const
            QDomNamedNodeMap cppResult = cppSelf->QDomDocumentType::notations();
            pyResult = Shiboken::Converter<QDomNamedNodeMap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentTypeFunc_publicId(PyObject* self)
{
    QDomDocumentType* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // publicId()const
            QString cppResult = cppSelf->QDomDocumentType::publicId();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomDocumentTypeFunc_systemId(PyObject* self)
{
    QDomDocumentType* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomDocumentType* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // systemId()const
            QString cppResult = cppSelf->QDomDocumentType::systemId();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDomDocumentType_methods[] = {
    {"entities", (PyCFunction)SbkQDomDocumentTypeFunc_entities, METH_NOARGS},
    {"internalSubset", (PyCFunction)SbkQDomDocumentTypeFunc_internalSubset, METH_NOARGS},
    {"name", (PyCFunction)SbkQDomDocumentTypeFunc_name, METH_NOARGS},
    {"notations", (PyCFunction)SbkQDomDocumentTypeFunc_notations, METH_NOARGS},
    {"publicId", (PyCFunction)SbkQDomDocumentTypeFunc_publicId, METH_NOARGS},
    {"systemId", (PyCFunction)SbkQDomDocumentTypeFunc_systemId, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDomDocumentType_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomDocumentType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomDocumentType_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomDocumentType_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomDocumentType >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDomDocumentType",
    /*user_data*/           0
};
} //extern


void init_QDomDocumentType(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMDOCUMENTTYPE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomDocumentType_Type);

    SbkQDomDocumentType_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQDomDocumentType_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomDocumentType_Type));
    PyModule_AddObject(module, "QDomDocumentType",
        ((PyObject*)&SbkQDomDocumentType_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomDocumentType >("QDomDocumentType");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomDocumentType >("QDomDocumentType*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomDocumentType >(typeid(QDomDocumentType).name());
    PySide::initQtMetaType<QDomDocumentType >();
}

