/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomelement_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDomElement_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomElement >()))
        return -1;

    QDomElement* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomElement", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDomElement()
    // 1: QDomElement(QDomElement)
    if (numArgs == 0) {
        overloadId = 0; // QDomElement()
    } else if (numArgs == 1 && Shiboken::Converter<const QDomElement & >::isConvertible(arg)) {
        overloadId = 1; // QDomElement(QDomElement)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElement_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomElement()
            {

                if(!PyErr_Occurred()) {
                // QDomElement()
                cptr = new QDomElement();
                }
                break;
            }
            case 1: // QDomElement(QDomElement)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDomElement* cpp_arg0 = Shiboken::Converter<QDomElement* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomElement(QDomElement)
                cptr = new QDomElement(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomElement >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomElement_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDomElement_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomElement", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement", overloads);
        return -1;
}

static PyObject* SbkQDomElementFunc_attribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "defValue" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomElement.attribute(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:attribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QString,QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // attribute(QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // attribute(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defValue");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "defValue";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomElement.attribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
            // attribute(QString,QString)const
            QString cppResult = cppSelf->QDomElement::attribute(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_attribute_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.attribute", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_attributeNS(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "defValue" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomElement.attributeNS(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attributeNS(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomElement.attributeNS(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:attributeNS", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: attributeNS(QString,QString,QString)const
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_attributeNS_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defValue");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "defValue";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomElement.attributeNS(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();

            if(!PyErr_Occurred()) {
            // attributeNS(QString,QString,QString)const
            QString cppResult = cppSelf->QDomElement::attributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_attributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.attributeNS", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_attributeNode(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: attributeNode(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // attributeNode(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_attributeNode_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // attributeNode(QString)
            QDomAttr cppResult = cppSelf->QDomElement::attributeNode(cpp_arg0);
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_attributeNode_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.attributeNode", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_attributeNodeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "attributeNodeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attributeNodeNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // attributeNodeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_attributeNodeNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // attributeNodeNS(QString,QString)
            QDomAttr cppResult = cppSelf->QDomElement::attributeNodeNS(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_attributeNodeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.attributeNodeNS", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_attributes(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // attributes()const
            QDomNamedNodeMap cppResult = cppSelf->QDomElement::attributes();
            pyResult = Shiboken::Converter<QDomNamedNodeMap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomElementFunc_elementsByTagName(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: elementsByTagName(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // elementsByTagName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_elementsByTagName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // elementsByTagName(QString)const
            QDomNodeList cppResult = cppSelf->QDomElement::elementsByTagName(cpp_arg0);
            pyResult = Shiboken::Converter<QDomNodeList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_elementsByTagName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.elementsByTagName", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_elementsByTagNameNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "elementsByTagNameNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: elementsByTagNameNS(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // elementsByTagNameNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_elementsByTagNameNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // elementsByTagNameNS(QString,QString)const
            QDomNodeList cppResult = cppSelf->QDomElement::elementsByTagNameNS(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QDomNodeList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_elementsByTagNameNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.elementsByTagNameNS", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_hasAttribute(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasAttribute(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasAttribute(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_hasAttribute_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasAttribute(QString)const
            bool cppResult = cppSelf->QDomElement::hasAttribute(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_hasAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.hasAttribute", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_hasAttributeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hasAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hasAttributeNS(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // hasAttributeNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_hasAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // hasAttributeNS(QString,QString)const
            bool cppResult = cppSelf->QDomElement::hasAttributeNS(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_hasAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.hasAttributeNS", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_nodeType(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nodeType()const
            QDomNode::NodeType cppResult = cppSelf->QDomElement::nodeType();
            pyResult = Shiboken::Converter<QDomNode::NodeType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomElementFunc_removeAttribute(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAttribute(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // removeAttribute(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_removeAttribute_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAttribute(QString)
            cppSelf->QDomElement::removeAttribute(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomElementFunc_removeAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.removeAttribute", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_removeAttributeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeAttributeNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // removeAttributeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_removeAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // removeAttributeNS(QString,QString)
            cppSelf->QDomElement::removeAttributeNS(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomElementFunc_removeAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.removeAttributeNS", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_removeAttributeNode(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAttributeNode(QDomAttr)
    if (Shiboken::Converter<const QDomAttr & >::isConvertible(arg)) {
        overloadId = 0; // removeAttributeNode(QDomAttr)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_removeAttributeNode_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDomAttr* cpp_arg0 = Shiboken::Converter<QDomAttr* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAttributeNode(QDomAttr)
            QDomAttr cppResult = cppSelf->QDomElement::removeAttributeNode(*cpp_arg0);
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_removeAttributeNode_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomAttr", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.removeAttributeNode", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_setAttribute(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(QString,QString)
    // 1: setAttribute(QString,double)
    // 2: setAttribute(QString,float)
    // 3: setAttribute(QString,int)
    // 4: setAttribute(QString,qlonglong)
    // 5: setAttribute(QString,qulonglong)
    // 6: setAttribute(QString,uint)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 6; // setAttribute(QString,uint)
        } else if (numArgs == 2 && PyLong_Check(pyargs[1])) {
            overloadId = 5; // setAttribute(QString,qulonglong)
        } else if (numArgs == 2 && PyLong_Check(pyargs[1])) {
            overloadId = 4; // setAttribute(QString,qlonglong)
        } else if (numArgs == 2 && PyFloat_Check(pyargs[1])) {
            overloadId = 2; // setAttribute(QString,float)
        } else if (numArgs == 2 && PyFloat_Check(pyargs[1])) {
            overloadId = 1; // setAttribute(QString,double)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 3; // setAttribute(QString,int)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // setAttribute(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_setAttribute_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttribute(QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttribute(QString,QString)
                cppSelf->QDomElement::setAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // setAttribute(QString,double)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                double cpp_arg1 = Shiboken::Converter<double >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttribute(QString,double)
                cppSelf->QDomElement::setAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // setAttribute(QString,float)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                float cpp_arg1 = Shiboken::Converter<float >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttribute(QString,float)
                cppSelf->QDomElement::setAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // setAttribute(QString,int)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttribute(QString,int)
                cppSelf->QDomElement::setAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 4: // setAttribute(QString,qlonglong)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                qlonglong cpp_arg1 = Shiboken::Converter<qlonglong >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttribute(QString,qlonglong)
                cppSelf->QDomElement::setAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 5: // setAttribute(QString,qulonglong)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                qulonglong cpp_arg1 = Shiboken::Converter<qulonglong >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttribute(QString,qulonglong)
                cppSelf->QDomElement::setAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 6: // setAttribute(QString,uint)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                uint cpp_arg1 = Shiboken::Converter<uint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setAttribute(QString,uint)
                cppSelf->QDomElement::setAttribute(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomElementFunc_setAttribute_TypeError:
        const char* overloads[] = {"QString, QString", "QString, float", "QString, float", "QString, int", "QString, long long", "QString, unsigned long long", "QString, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.setAttribute", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_setAttributeNS(PyObject* self, PyObject* args)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttributeNS", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeNS(QString,QString,QString)
    // 1: setAttributeNS(QString,QString,double)
    // 2: setAttributeNS(QString,QString,int)
    // 3: setAttributeNS(QString,QString,qlonglong)
    // 4: setAttributeNS(QString,QString,qulonglong)
    // 5: setAttributeNS(QString,QString,uint)
    if (numArgs >= 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 5; // setAttributeNS(QString,QString,uint)
        } else if (numArgs == 3 && PyLong_Check(pyargs[2])) {
            overloadId = 4; // setAttributeNS(QString,QString,qulonglong)
        } else if (numArgs == 3 && PyLong_Check(pyargs[2])) {
            overloadId = 3; // setAttributeNS(QString,QString,qlonglong)
        } else if (numArgs == 3 && PyFloat_Check(pyargs[2])) {
            overloadId = 1; // setAttributeNS(QString,QString,double)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 2; // setAttributeNS(QString,QString,int)
        } else if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // setAttributeNS(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_setAttributeNS_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAttributeNS(QString,QString,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeNS(QString,QString,QString)
                cppSelf->QDomElement::setAttributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // setAttributeNS(QString,QString,double)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                double cpp_arg2 = Shiboken::Converter<double >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeNS(QString,QString,double)
                cppSelf->QDomElement::setAttributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // setAttributeNS(QString,QString,int)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeNS(QString,QString,int)
                cppSelf->QDomElement::setAttributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 3: // setAttributeNS(QString,QString,qlonglong)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                qlonglong cpp_arg2 = Shiboken::Converter<qlonglong >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeNS(QString,QString,qlonglong)
                cppSelf->QDomElement::setAttributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 4: // setAttributeNS(QString,QString,qulonglong)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                qulonglong cpp_arg2 = Shiboken::Converter<qulonglong >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeNS(QString,QString,qulonglong)
                cppSelf->QDomElement::setAttributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 5: // setAttributeNS(QString,QString,uint)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                uint cpp_arg2 = Shiboken::Converter<uint >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setAttributeNS(QString,QString,uint)
                cppSelf->QDomElement::setAttributeNS(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomElementFunc_setAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString", "QString, QString, float", "QString, QString, int", "QString, QString, long long", "QString, QString, unsigned long long", "QString, QString, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomElement.setAttributeNS", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_setAttributeNode(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAttributeNode(QDomAttr)
    if (Shiboken::Converter<const QDomAttr & >::isConvertible(arg)) {
        overloadId = 0; // setAttributeNode(QDomAttr)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_setAttributeNode_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDomAttr* cpp_arg0 = Shiboken::Converter<QDomAttr* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAttributeNode(QDomAttr)
            QDomAttr cppResult = cppSelf->QDomElement::setAttributeNode(*cpp_arg0);
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_setAttributeNode_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomAttr", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.setAttributeNode", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_setAttributeNodeNS(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAttributeNodeNS(QDomAttr)
    if (Shiboken::Converter<const QDomAttr & >::isConvertible(arg)) {
        overloadId = 0; // setAttributeNodeNS(QDomAttr)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_setAttributeNodeNS_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDomAttr* cpp_arg0 = Shiboken::Converter<QDomAttr* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAttributeNodeNS(QDomAttr)
            QDomAttr cppResult = cppSelf->QDomElement::setAttributeNodeNS(*cpp_arg0);
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomElementFunc_setAttributeNodeNS_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomAttr", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.setAttributeNodeNS", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_setTagName(PyObject* self, PyObject* arg)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTagName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setTagName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomElementFunc_setTagName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTagName(QString)
            cppSelf->QDomElement::setTagName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomElementFunc_setTagName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomElement.setTagName", overloads);
        return 0;
}

static PyObject* SbkQDomElementFunc_tagName(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tagName()const
            QString cppResult = cppSelf->QDomElement::tagName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomElementFunc_text(PyObject* self)
{
    QDomElement* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // text()const
            QString cppResult = cppSelf->QDomElement::text();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDomElement_methods[] = {
    {"attribute", (PyCFunction)SbkQDomElementFunc_attribute, METH_VARARGS|METH_KEYWORDS},
    {"attributeNS", (PyCFunction)SbkQDomElementFunc_attributeNS, METH_VARARGS|METH_KEYWORDS},
    {"attributeNode", (PyCFunction)SbkQDomElementFunc_attributeNode, METH_O},
    {"attributeNodeNS", (PyCFunction)SbkQDomElementFunc_attributeNodeNS, METH_VARARGS},
    {"attributes", (PyCFunction)SbkQDomElementFunc_attributes, METH_NOARGS},
    {"elementsByTagName", (PyCFunction)SbkQDomElementFunc_elementsByTagName, METH_O},
    {"elementsByTagNameNS", (PyCFunction)SbkQDomElementFunc_elementsByTagNameNS, METH_VARARGS},
    {"hasAttribute", (PyCFunction)SbkQDomElementFunc_hasAttribute, METH_O},
    {"hasAttributeNS", (PyCFunction)SbkQDomElementFunc_hasAttributeNS, METH_VARARGS},
    {"nodeType", (PyCFunction)SbkQDomElementFunc_nodeType, METH_NOARGS},
    {"removeAttribute", (PyCFunction)SbkQDomElementFunc_removeAttribute, METH_O},
    {"removeAttributeNS", (PyCFunction)SbkQDomElementFunc_removeAttributeNS, METH_VARARGS},
    {"removeAttributeNode", (PyCFunction)SbkQDomElementFunc_removeAttributeNode, METH_O},
    {"setAttribute", (PyCFunction)SbkQDomElementFunc_setAttribute, METH_VARARGS},
    {"setAttributeNS", (PyCFunction)SbkQDomElementFunc_setAttributeNS, METH_VARARGS},
    {"setAttributeNode", (PyCFunction)SbkQDomElementFunc_setAttributeNode, METH_O},
    {"setAttributeNodeNS", (PyCFunction)SbkQDomElementFunc_setAttributeNodeNS, METH_O},
    {"setTagName", (PyCFunction)SbkQDomElementFunc_setTagName, METH_O},
    {"tagName", (PyCFunction)SbkQDomElementFunc_tagName, METH_NOARGS},
    {"text", (PyCFunction)SbkQDomElementFunc_text, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDomElement_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomElement",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomElement_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomElement_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomElement >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDomElement",
    /*user_data*/           0
};
} //extern


void init_QDomElement(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMELEMENT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomElement_Type);

    SbkQDomElement_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    if (PyType_Ready((PyTypeObject*)&SbkQDomElement_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomElement_Type));
    PyModule_AddObject(module, "QDomElement",
        ((PyObject*)&SbkQDomElement_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomElement >("QDomElement");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomElement >("QDomElement*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomElement >(typeid(QDomElement).name());
    PySide::initQtMetaType<QDomElement >();
}

