/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomnode_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDomNode_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomNode >()))
        return -1;

    QDomNode* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomNode", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDomNode()
    // 1: QDomNode(QDomNode)
    if (numArgs == 0) {
        overloadId = 0; // QDomNode()
    } else if (numArgs == 1 && Shiboken::Converter<const QDomNode & >::isConvertible(arg)) {
        overloadId = 1; // QDomNode(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNode_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomNode()
            {

                if(!PyErr_Occurred()) {
                // QDomNode()
                cptr = new QDomNode();
                }
                break;
            }
            case 1: // QDomNode(QDomNode)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDomNode* cpp_arg0 = Shiboken::Converter<QDomNode* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomNode(QDomNode)
                cptr = new QDomNode(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomNode_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDomNode_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode", overloads);
        return -1;
}

static PyObject* SbkQDomNodeFunc_appendChild(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendChild(QDomNode)
    if (Shiboken::Converter<const QDomNode & >::isConvertible(arg)) {
        overloadId = 0; // appendChild(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_appendChild_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDomNode* cpp_arg0 = Shiboken::Converter<QDomNode* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // appendChild(QDomNode)
            QDomNode cppResult = cppSelf->QDomNode::appendChild(*cpp_arg0);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_appendChild_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.appendChild", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_attributes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // attributes()const
            QDomNamedNodeMap cppResult = cppSelf->QDomNode::attributes();
            pyResult = Shiboken::Converter<QDomNamedNodeMap >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_childNodes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childNodes()const
            QDomNodeList cppResult = cppSelf->QDomNode::childNodes();
            pyResult = Shiboken::Converter<QDomNodeList >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_clear(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QDomNode::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDomNodeFunc_cloneNode(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "deep" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.cloneNode(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.cloneNode(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:cloneNode", &arg))
        return 0;


    // Overloaded function decisor
    // 0: cloneNode(bool)const
    if (numArgs == 0) {
        overloadId = 0; // cloneNode(bool)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // cloneNode(bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_cloneNode_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "deep");
                if (value) {
                    if (arg)
                        errorArgName = "deep";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.cloneNode(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cpp_arg0 = arg ? Shiboken::Converter<bool >::toCpp(arg) : true;

            if(!PyErr_Occurred()) {
            // cloneNode(bool)const
            QDomNode cppResult = cppSelf->QDomNode::cloneNode(cpp_arg0);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_cloneNode_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.cloneNode", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_columnNumber(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columnNumber()const
            int cppResult = cppSelf->QDomNode::columnNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_firstChild(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // firstChild()const
            QDomNode cppResult = cppSelf->QDomNode::firstChild();
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_firstChildElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "tagName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.firstChildElement(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.firstChildElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:firstChildElement", &arg))
        return 0;


    // Overloaded function decisor
    // 0: firstChildElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // firstChildElement(QString)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // firstChildElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_firstChildElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tagName");
                if (value) {
                    if (arg)
                        errorArgName = "tagName";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.firstChildElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // firstChildElement(QString)const
            QDomElement cppResult = cppSelf->QDomNode::firstChildElement(cpp_arg0);
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_firstChildElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.firstChildElement", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_hasAttributes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasAttributes()const
            bool cppResult = cppSelf->QDomNode::hasAttributes();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_hasChildNodes(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasChildNodes()const
            bool cppResult = cppSelf->QDomNode::hasChildNodes();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_insertAfter(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertAfter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertAfter(QDomNode,QDomNode)
    if (numArgs == 2 && Shiboken::Converter<const QDomNode & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QDomNode & >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertAfter(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_insertAfter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QDomNode* cpp_arg0 = Shiboken::Converter<QDomNode* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDomNode* cpp_arg1 = Shiboken::Converter<QDomNode* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insertAfter(QDomNode,QDomNode)
            QDomNode cppResult = cppSelf->QDomNode::insertAfter(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_insertAfter_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode, PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.insertAfter", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_insertBefore(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertBefore", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertBefore(QDomNode,QDomNode)
    if (numArgs == 2 && Shiboken::Converter<const QDomNode & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QDomNode & >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertBefore(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_insertBefore_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QDomNode* cpp_arg0 = Shiboken::Converter<QDomNode* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDomNode* cpp_arg1 = Shiboken::Converter<QDomNode* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insertBefore(QDomNode,QDomNode)
            QDomNode cppResult = cppSelf->QDomNode::insertBefore(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_insertBefore_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode, PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.insertBefore", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_isAttr(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAttr()const
            bool cppResult = cppSelf->QDomNode::isAttr();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isCDATASection(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCDATASection()const
            bool cppResult = cppSelf->QDomNode::isCDATASection();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isCharacterData(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isCharacterData()const
            bool cppResult = cppSelf->QDomNode::isCharacterData();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isComment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isComment()const
            bool cppResult = cppSelf->QDomNode::isComment();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isDocument(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDocument()const
            bool cppResult = cppSelf->QDomNode::isDocument();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isDocumentFragment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDocumentFragment()const
            bool cppResult = cppSelf->QDomNode::isDocumentFragment();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isDocumentType(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isDocumentType()const
            bool cppResult = cppSelf->QDomNode::isDocumentType();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isElement(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isElement()const
            bool cppResult = cppSelf->QDomNode::isElement();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isEntity(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEntity()const
            bool cppResult = cppSelf->QDomNode::isEntity();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isEntityReference(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEntityReference()const
            bool cppResult = cppSelf->QDomNode::isEntityReference();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isNotation(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNotation()const
            bool cppResult = cppSelf->QDomNode::isNotation();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isNull(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QDomNode::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isProcessingInstruction(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isProcessingInstruction()const
            bool cppResult = cppSelf->QDomNode::isProcessingInstruction();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_isSupported(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isSupported", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isSupported(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // isSupported(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_isSupported_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // isSupported(QString,QString)const
            bool cppResult = cppSelf->QDomNode::isSupported(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_isSupported_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.isSupported", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_isText(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isText()const
            bool cppResult = cppSelf->QDomNode::isText();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_lastChild(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lastChild()const
            QDomNode cppResult = cppSelf->QDomNode::lastChild();
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_lastChildElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "tagName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.lastChildElement(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.lastChildElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:lastChildElement", &arg))
        return 0;


    // Overloaded function decisor
    // 0: lastChildElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // lastChildElement(QString)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // lastChildElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_lastChildElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tagName");
                if (value) {
                    if (arg)
                        errorArgName = "tagName";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.lastChildElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // lastChildElement(QString)const
            QDomElement cppResult = cppSelf->QDomNode::lastChildElement(cpp_arg0);
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_lastChildElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.lastChildElement", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_lineNumber(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineNumber()const
            int cppResult = cppSelf->QDomNode::lineNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_localName(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // localName()const
            QString cppResult = cppSelf->QDomNode::localName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_namedItem(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namedItem(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // namedItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_namedItem_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // namedItem(QString)const
            QDomNode cppResult = cppSelf->QDomNode::namedItem(cpp_arg0);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_namedItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.namedItem", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_namespaceURI(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namespaceURI()const
            QString cppResult = cppSelf->QDomNode::namespaceURI();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_nextSibling(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextSibling()const
            QDomNode cppResult = cppSelf->QDomNode::nextSibling();
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_nextSiblingElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "taName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.nextSiblingElement(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.nextSiblingElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:nextSiblingElement", &arg))
        return 0;


    // Overloaded function decisor
    // 0: nextSiblingElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // nextSiblingElement(QString)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // nextSiblingElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_nextSiblingElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "taName");
                if (value) {
                    if (arg)
                        errorArgName = "taName";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.nextSiblingElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // nextSiblingElement(QString)const
            QDomElement cppResult = cppSelf->QDomNode::nextSiblingElement(cpp_arg0);
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_nextSiblingElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.nextSiblingElement", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_nodeName(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nodeName()const
            QString cppResult = cppSelf->QDomNode::nodeName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_nodeType(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nodeType()const
            QDomNode::NodeType cppResult = cppSelf->QDomNode::nodeType();
            pyResult = Shiboken::Converter<QDomNode::NodeType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_nodeValue(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nodeValue()const
            QString cppResult = cppSelf->QDomNode::nodeValue();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_normalize(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalize()
            cppSelf->QDomNode::normalize();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQDomNodeFunc_ownerDocument(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ownerDocument()const
            QDomDocument cppResult = cppSelf->QDomNode::ownerDocument();
            pyResult = Shiboken::Converter<QDomDocument >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_parentNode(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentNode()const
            QDomNode cppResult = cppSelf->QDomNode::parentNode();
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_prefix(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prefix()const
            QString cppResult = cppSelf->QDomNode::prefix();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_previousSibling(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // previousSibling()const
            QDomNode cppResult = cppSelf->QDomNode::previousSibling();
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_previousSiblingElement(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "tagName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.previousSiblingElement(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QDomNode.previousSiblingElement(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:previousSiblingElement", &arg))
        return 0;


    // Overloaded function decisor
    // 0: previousSiblingElement(QString)const
    if (numArgs == 0) {
        overloadId = 0; // previousSiblingElement(QString)const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // previousSiblingElement(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_previousSiblingElement_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "tagName");
                if (value) {
                    if (arg)
                        errorArgName = "tagName";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QDomNode.previousSiblingElement(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = arg ? Shiboken::Converter<QString >::toCpp(arg) : QString();

            if(!PyErr_Occurred()) {
            // previousSiblingElement(QString)const
            QDomElement cppResult = cppSelf->QDomNode::previousSiblingElement(cpp_arg0);
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_previousSiblingElement_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.previousSiblingElement", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_removeChild(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeChild(QDomNode)
    if (Shiboken::Converter<const QDomNode & >::isConvertible(arg)) {
        overloadId = 0; // removeChild(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_removeChild_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDomNode* cpp_arg0 = Shiboken::Converter<QDomNode* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeChild(QDomNode)
            QDomNode cppResult = cppSelf->QDomNode::removeChild(*cpp_arg0);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_removeChild_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.removeChild", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_replaceChild(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replaceChild", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replaceChild(QDomNode,QDomNode)
    if (numArgs == 2 && Shiboken::Converter<const QDomNode & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QDomNode & >::isConvertible(pyargs[1])) {
        overloadId = 0; // replaceChild(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_replaceChild_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QDomNode* cpp_arg0 = Shiboken::Converter<QDomNode* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QDomNode* cpp_arg1 = Shiboken::Converter<QDomNode* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // replaceChild(QDomNode,QDomNode)
            QDomNode cppResult = cppSelf->QDomNode::replaceChild(*cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc_replaceChild_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode, PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.replaceChild", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_save(PyObject* self, PyObject* args)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "save", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: save(QTextStream&,int)const
    // 1: save(QTextStream&,int,QDomNode::EncodingPolicy)const
    if (numArgs >= 2 && Shiboken::Converter<QTextStream & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // save(QTextStream&,int)const
        } else if (numArgs == 3 && Shiboken::Converter<QDomNode::EncodingPolicy >::isConvertible(pyargs[2])) {
            overloadId = 1; // save(QTextStream&,int,QDomNode::EncodingPolicy)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_save_TypeError;

    // Call function/method
    {
        Shiboken::ThreadStateSaver threadStateSaver;
        switch (overloadId) {
            case 0: // save(QTextStream&,int)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTextStream* cpp_arg0 = Shiboken::Converter<QTextStream* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // save(QTextStream&,int)const
                threadStateSaver.save();
                cppSelf->QDomNode::save(*cpp_arg0, cpp_arg1);
                threadStateSaver.restore();
                }
                break;
            }
            case 1: // save(QTextStream&,int,QDomNode::EncodingPolicy)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QTextStream* cpp_arg0 = Shiboken::Converter<QTextStream* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QDomNode::EncodingPolicy cpp_arg2 = Shiboken::Converter<QDomNode::EncodingPolicy >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // save(QTextStream&,int,QDomNode::EncodingPolicy)const
                threadStateSaver.save();
                cppSelf->QDomNode::save(*cpp_arg0, cpp_arg1, cpp_arg2);
                threadStateSaver.restore();
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomNodeFunc_save_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream, int", "PySide.QtCore.QTextStream, int, PySide.QtXml.QDomNode.EncodingPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNode.save", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_setNodeValue(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNodeValue(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setNodeValue(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_setNodeValue_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setNodeValue(QString)
            cppSelf->QDomNode::setNodeValue(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomNodeFunc_setNodeValue_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.setNodeValue", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_setPrefix(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrefix(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPrefix(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc_setPrefix_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPrefix(QString)
            cppSelf->QDomNode::setPrefix(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQDomNodeFunc_setPrefix_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.setPrefix", overloads);
        return 0;
}

static PyObject* SbkQDomNodeFunc_toAttr(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toAttr()const
            QDomAttr cppResult = cppSelf->QDomNode::toAttr();
            pyResult = Shiboken::Converter<QDomAttr >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toCDATASection(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toCDATASection()const
            QDomCDATASection cppResult = cppSelf->QDomNode::toCDATASection();
            pyResult = Shiboken::Converter<QDomCDATASection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toCharacterData(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toCharacterData()const
            QDomCharacterData cppResult = cppSelf->QDomNode::toCharacterData();
            pyResult = Shiboken::Converter<QDomCharacterData >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toComment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toComment()const
            QDomComment cppResult = cppSelf->QDomNode::toComment();
            pyResult = Shiboken::Converter<QDomComment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toDocument(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toDocument()const
            QDomDocument cppResult = cppSelf->QDomNode::toDocument();
            pyResult = Shiboken::Converter<QDomDocument >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toDocumentFragment(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toDocumentFragment()const
            QDomDocumentFragment cppResult = cppSelf->QDomNode::toDocumentFragment();
            pyResult = Shiboken::Converter<QDomDocumentFragment >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toDocumentType(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toDocumentType()const
            QDomDocumentType cppResult = cppSelf->QDomNode::toDocumentType();
            pyResult = Shiboken::Converter<QDomDocumentType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toElement(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toElement()const
            QDomElement cppResult = cppSelf->QDomNode::toElement();
            pyResult = Shiboken::Converter<QDomElement >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toEntity(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toEntity()const
            QDomEntity cppResult = cppSelf->QDomNode::toEntity();
            pyResult = Shiboken::Converter<QDomEntity >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toEntityReference(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toEntityReference()const
            QDomEntityReference cppResult = cppSelf->QDomNode::toEntityReference();
            pyResult = Shiboken::Converter<QDomEntityReference >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toNotation(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toNotation()const
            QDomNotation cppResult = cppSelf->QDomNode::toNotation();
            pyResult = Shiboken::Converter<QDomNotation >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toProcessingInstruction(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toProcessingInstruction()const
            QDomProcessingInstruction cppResult = cppSelf->QDomNode::toProcessingInstruction();
            pyResult = Shiboken::Converter<QDomProcessingInstruction >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeFunc_toText(PyObject* self)
{
    QDomNode* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toText()const
            QDomText cppResult = cppSelf->QDomNode::toText();
            pyResult = Shiboken::Converter<QDomText >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDomNode_methods[] = {
    {"appendChild", (PyCFunction)SbkQDomNodeFunc_appendChild, METH_O},
    {"attributes", (PyCFunction)SbkQDomNodeFunc_attributes, METH_NOARGS},
    {"childNodes", (PyCFunction)SbkQDomNodeFunc_childNodes, METH_NOARGS},
    {"clear", (PyCFunction)SbkQDomNodeFunc_clear, METH_NOARGS},
    {"cloneNode", (PyCFunction)SbkQDomNodeFunc_cloneNode, METH_VARARGS|METH_KEYWORDS},
    {"columnNumber", (PyCFunction)SbkQDomNodeFunc_columnNumber, METH_NOARGS},
    {"firstChild", (PyCFunction)SbkQDomNodeFunc_firstChild, METH_NOARGS},
    {"firstChildElement", (PyCFunction)SbkQDomNodeFunc_firstChildElement, METH_VARARGS|METH_KEYWORDS},
    {"hasAttributes", (PyCFunction)SbkQDomNodeFunc_hasAttributes, METH_NOARGS},
    {"hasChildNodes", (PyCFunction)SbkQDomNodeFunc_hasChildNodes, METH_NOARGS},
    {"insertAfter", (PyCFunction)SbkQDomNodeFunc_insertAfter, METH_VARARGS},
    {"insertBefore", (PyCFunction)SbkQDomNodeFunc_insertBefore, METH_VARARGS},
    {"isAttr", (PyCFunction)SbkQDomNodeFunc_isAttr, METH_NOARGS},
    {"isCDATASection", (PyCFunction)SbkQDomNodeFunc_isCDATASection, METH_NOARGS},
    {"isCharacterData", (PyCFunction)SbkQDomNodeFunc_isCharacterData, METH_NOARGS},
    {"isComment", (PyCFunction)SbkQDomNodeFunc_isComment, METH_NOARGS},
    {"isDocument", (PyCFunction)SbkQDomNodeFunc_isDocument, METH_NOARGS},
    {"isDocumentFragment", (PyCFunction)SbkQDomNodeFunc_isDocumentFragment, METH_NOARGS},
    {"isDocumentType", (PyCFunction)SbkQDomNodeFunc_isDocumentType, METH_NOARGS},
    {"isElement", (PyCFunction)SbkQDomNodeFunc_isElement, METH_NOARGS},
    {"isEntity", (PyCFunction)SbkQDomNodeFunc_isEntity, METH_NOARGS},
    {"isEntityReference", (PyCFunction)SbkQDomNodeFunc_isEntityReference, METH_NOARGS},
    {"isNotation", (PyCFunction)SbkQDomNodeFunc_isNotation, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQDomNodeFunc_isNull, METH_NOARGS},
    {"isProcessingInstruction", (PyCFunction)SbkQDomNodeFunc_isProcessingInstruction, METH_NOARGS},
    {"isSupported", (PyCFunction)SbkQDomNodeFunc_isSupported, METH_VARARGS},
    {"isText", (PyCFunction)SbkQDomNodeFunc_isText, METH_NOARGS},
    {"lastChild", (PyCFunction)SbkQDomNodeFunc_lastChild, METH_NOARGS},
    {"lastChildElement", (PyCFunction)SbkQDomNodeFunc_lastChildElement, METH_VARARGS|METH_KEYWORDS},
    {"lineNumber", (PyCFunction)SbkQDomNodeFunc_lineNumber, METH_NOARGS},
    {"localName", (PyCFunction)SbkQDomNodeFunc_localName, METH_NOARGS},
    {"namedItem", (PyCFunction)SbkQDomNodeFunc_namedItem, METH_O},
    {"namespaceURI", (PyCFunction)SbkQDomNodeFunc_namespaceURI, METH_NOARGS},
    {"nextSibling", (PyCFunction)SbkQDomNodeFunc_nextSibling, METH_NOARGS},
    {"nextSiblingElement", (PyCFunction)SbkQDomNodeFunc_nextSiblingElement, METH_VARARGS|METH_KEYWORDS},
    {"nodeName", (PyCFunction)SbkQDomNodeFunc_nodeName, METH_NOARGS},
    {"nodeType", (PyCFunction)SbkQDomNodeFunc_nodeType, METH_NOARGS},
    {"nodeValue", (PyCFunction)SbkQDomNodeFunc_nodeValue, METH_NOARGS},
    {"normalize", (PyCFunction)SbkQDomNodeFunc_normalize, METH_NOARGS},
    {"ownerDocument", (PyCFunction)SbkQDomNodeFunc_ownerDocument, METH_NOARGS},
    {"parentNode", (PyCFunction)SbkQDomNodeFunc_parentNode, METH_NOARGS},
    {"prefix", (PyCFunction)SbkQDomNodeFunc_prefix, METH_NOARGS},
    {"previousSibling", (PyCFunction)SbkQDomNodeFunc_previousSibling, METH_NOARGS},
    {"previousSiblingElement", (PyCFunction)SbkQDomNodeFunc_previousSiblingElement, METH_VARARGS|METH_KEYWORDS},
    {"removeChild", (PyCFunction)SbkQDomNodeFunc_removeChild, METH_O},
    {"replaceChild", (PyCFunction)SbkQDomNodeFunc_replaceChild, METH_VARARGS},
    {"save", (PyCFunction)SbkQDomNodeFunc_save, METH_VARARGS},
    {"setNodeValue", (PyCFunction)SbkQDomNodeFunc_setNodeValue, METH_O},
    {"setPrefix", (PyCFunction)SbkQDomNodeFunc_setPrefix, METH_O},
    {"toAttr", (PyCFunction)SbkQDomNodeFunc_toAttr, METH_NOARGS},
    {"toCDATASection", (PyCFunction)SbkQDomNodeFunc_toCDATASection, METH_NOARGS},
    {"toCharacterData", (PyCFunction)SbkQDomNodeFunc_toCharacterData, METH_NOARGS},
    {"toComment", (PyCFunction)SbkQDomNodeFunc_toComment, METH_NOARGS},
    {"toDocument", (PyCFunction)SbkQDomNodeFunc_toDocument, METH_NOARGS},
    {"toDocumentFragment", (PyCFunction)SbkQDomNodeFunc_toDocumentFragment, METH_NOARGS},
    {"toDocumentType", (PyCFunction)SbkQDomNodeFunc_toDocumentType, METH_NOARGS},
    {"toElement", (PyCFunction)SbkQDomNodeFunc_toElement, METH_NOARGS},
    {"toEntity", (PyCFunction)SbkQDomNodeFunc_toEntity, METH_NOARGS},
    {"toEntityReference", (PyCFunction)SbkQDomNodeFunc_toEntityReference, METH_NOARGS},
    {"toNotation", (PyCFunction)SbkQDomNodeFunc_toNotation, METH_NOARGS},
    {"toProcessingInstruction", (PyCFunction)SbkQDomNodeFunc_toProcessingInstruction, METH_NOARGS},
    {"toText", (PyCFunction)SbkQDomNodeFunc_toText, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* SbkQDomNodeFunc___lshift__(PyObject* self, PyObject* arg)
{
    QDomNode* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QDomNode >::checkType(arg) && !Shiboken::Converter<QDomNode >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNode* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QTextStream&,QDomNode)
    if (isReverse && Shiboken::Converter<QTextStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QTextStream&,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextStream* cpp_arg0 = Shiboken::Converter<QTextStream* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // operator<<(QTextStream&,QDomNode) [reverse operator]
            QTextStream & cppResult = (*cpp_arg0) << (*cppSelf);
            pyResult = Shiboken::Converter<QTextStream & >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNode.__lshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQDomNode_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)SbkQDomNodeFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* SbkQDomNode_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QDomNode& cpp_self = *Shiboken::Converter<QDomNode* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QDomNode & >::isConvertible(other)) {
                // operator!=(const QDomNode & arg__1) const
                QDomNode* cpp_other = Shiboken::Converter<QDomNode* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDomNode  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQDomNode_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QDomNode & >::isConvertible(other)) {
                // operator==(const QDomNode & arg__1) const
                QDomNode* cpp_other = Shiboken::Converter<QDomNode* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDomNode  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQDomNode_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQDomNode_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDomNode_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomNode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQDomNode_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQDomNode_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomNode_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomNode_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomNode >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDomNode",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtXml_QDomNode_NodeType_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtXml_QDomNode_NodeType_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtXml_QDomNode_NodeType_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "NodeType",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtXml_QDomNode_NodeType_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtXml_QDomNode_NodeType_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtXml_QDomNode_NodeType_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtXml_QDomNode_EncodingPolicy_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtXml_QDomNode_EncodingPolicy_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtXml_QDomNode_EncodingPolicy_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "EncodingPolicy",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtXml_QDomNode_EncodingPolicy_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtXml_QDomNode_EncodingPolicy_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtXml_QDomNode_EncodingPolicy_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QDomNode(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomNode_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDomNode_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomNode_Type));
    PyModule_AddObject(module, "QDomNode",
        ((PyObject*)&SbkQDomNode_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: NodeType
    SbkPySide_QtXmlTypes[SBK_QDOMNODE_NODETYPE_IDX] = &SbkPySide_QtXml_QDomNode_NodeType_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtXml_QDomNode_NodeType_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtXml_QDomNode_NodeType_Type);
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
            "NodeType",((PyObject*)&SbkPySide_QtXml_QDomNode_NodeType_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::ElementNode, "ElementNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "ElementNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "ElementNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::AttributeNode, "AttributeNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "AttributeNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "AttributeNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::TextNode, "TextNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "TextNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "TextNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::CDATASectionNode, "CDATASectionNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "CDATASectionNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "CDATASectionNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::EntityReferenceNode, "EntityReferenceNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "EntityReferenceNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "EntityReferenceNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::EntityNode, "EntityNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "EntityNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "EntityNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::ProcessingInstructionNode, "ProcessingInstructionNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "ProcessingInstructionNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "ProcessingInstructionNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::CommentNode, "CommentNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "CommentNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "CommentNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::DocumentNode, "DocumentNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "DocumentNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "DocumentNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::DocumentTypeNode, "DocumentTypeNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "DocumentTypeNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "DocumentTypeNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::DocumentFragmentNode, "DocumentFragmentNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "DocumentFragmentNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "DocumentFragmentNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::NotationNode, "NotationNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "NotationNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "NotationNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::BaseNode, "BaseNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "BaseNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "BaseNode", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_NodeType_Type,
        (long) QDomNode::CharacterDataNode, "CharacterDataNode");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "CharacterDataNode", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_NodeType_Type.tp_dict,
        "CharacterDataNode", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDomNode::NodeType");

    // init enum class: EncodingPolicy
    SbkPySide_QtXmlTypes[SBK_QDOMNODE_ENCODINGPOLICY_IDX] = &SbkPySide_QtXml_QDomNode_EncodingPolicy_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtXml_QDomNode_EncodingPolicy_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtXml_QDomNode_EncodingPolicy_Type);
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
            "EncodingPolicy",((PyObject*)&SbkPySide_QtXml_QDomNode_EncodingPolicy_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_EncodingPolicy_Type,
        (long) QDomNode::EncodingFromDocument, "EncodingFromDocument");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "EncodingFromDocument", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_EncodingPolicy_Type.tp_dict,
        "EncodingFromDocument", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXml_QDomNode_EncodingPolicy_Type,
        (long) QDomNode::EncodingFromTextStream, "EncodingFromTextStream");
    PyDict_SetItemString(SbkQDomNode_Type.super.ht_type.tp_dict,
        "EncodingFromTextStream", enum_item);
    PyDict_SetItemString(SbkPySide_QtXml_QDomNode_EncodingPolicy_Type.tp_dict,
        "EncodingFromTextStream", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDomNode::EncodingPolicy");


    Shiboken::TypeResolver::createValueTypeResolver<QDomNode >("QDomNode");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomNode >("QDomNode*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomNode >(typeid(QDomNode).name());
    PySide::initQtMetaType<QDomNode >();
}

