/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomnodelist_wrapper.h"

// Extra includes
#include <qdom.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQDomNodeList_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomNodeList >()))
        return -1;

    QDomNodeList* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomNodeList", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QDomNodeList()
    // 1: QDomNodeList(QDomNodeList)
    if (numArgs == 0) {
        overloadId = 0; // QDomNodeList()
    } else if (numArgs == 1 && Shiboken::Converter<const QDomNodeList & >::isConvertible(arg)) {
        overloadId = 1; // QDomNodeList(QDomNodeList)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeList_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomNodeList()
            {

                if(!PyErr_Occurred()) {
                // QDomNodeList()
                cptr = new QDomNodeList();
                }
                break;
            }
            case 1: // QDomNodeList(QDomNodeList)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QDomNodeList* cpp_arg0 = Shiboken::Converter<QDomNodeList* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QDomNodeList(QDomNodeList)
                cptr = new QDomNodeList(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QDomNodeList >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQDomNodeList_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQDomNodeList_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomNodeList", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNodeList", overloads);
        return -1;
}

static PyObject* SbkQDomNodeListFunc_at(PyObject* self, PyObject* arg)
{
    QDomNodeList* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNodeList* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeListFunc_at_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // at(int)const
            QDomNode cppResult = cppSelf->QDomNodeList::at(cpp_arg0);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeListFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNodeList.at", overloads);
        return 0;
}

static PyObject* SbkQDomNodeListFunc_count(PyObject* self)
{
    QDomNodeList* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNodeList* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // count()const
            int cppResult = cppSelf->QDomNodeList::count();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeListFunc_isEmpty(PyObject* self)
{
    QDomNodeList* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNodeList* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QDomNodeList::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeListFunc_item(PyObject* self, PyObject* arg)
{
    QDomNodeList* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNodeList* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: item(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // item(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQDomNodeListFunc_item_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // item(int)const
            QDomNode cppResult = cppSelf->QDomNodeList::item(cpp_arg0);
            pyResult = Shiboken::Converter<QDomNode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQDomNodeListFunc_item_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNodeList.item", overloads);
        return 0;
}

static PyObject* SbkQDomNodeListFunc_length(PyObject* self)
{
    QDomNodeList* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNodeList* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            uint cppResult = cppSelf->QDomNodeList::length();
            pyResult = Shiboken::Converter<unsigned int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQDomNodeListFunc_size(PyObject* self)
{
    QDomNodeList* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QDomNodeList* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            int cppResult = cppSelf->QDomNodeList::size();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQDomNodeList_methods[] = {
    {"at", (PyCFunction)SbkQDomNodeListFunc_at, METH_O},
    {"count", (PyCFunction)SbkQDomNodeListFunc_count, METH_NOARGS},
    {"isEmpty", (PyCFunction)SbkQDomNodeListFunc_isEmpty, METH_NOARGS},
    {"item", (PyCFunction)SbkQDomNodeListFunc_item, METH_O},
    {"length", (PyCFunction)SbkQDomNodeListFunc_length, METH_NOARGS},
    {"size", (PyCFunction)SbkQDomNodeListFunc_size, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQDomNodeList_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QDomNodeList& cpp_self = *Shiboken::Converter<QDomNodeList* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QDomNodeList & >::isConvertible(other)) {
                // operator!=(const QDomNodeList & arg__1) const
                QDomNodeList* cpp_other = Shiboken::Converter<QDomNodeList* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDomNodeList  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQDomNodeList_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QDomNodeList & >::isConvertible(other)) {
                // operator==(const QDomNodeList & arg__1) const
                QDomNodeList* cpp_other = Shiboken::Converter<QDomNodeList* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QDomNodeList  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQDomNodeList_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQDomNodeList_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQDomNodeList_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomNodeList",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQDomNodeList_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQDomNodeList_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQDomNodeList_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QDomNodeList >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QDomNodeList",
    /*user_data*/           0
};
} //extern


void init_QDomNodeList(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMNODELIST_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQDomNodeList_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQDomNodeList_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQDomNodeList_Type));
    PyModule_AddObject(module, "QDomNodeList",
        ((PyObject*)&SbkQDomNodeList_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomNodeList >("QDomNodeList");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomNodeList >("QDomNodeList*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomNodeList >(typeid(QDomNodeList).name());
    PySide::initQtMetaType<QDomNodeList >();
}

