/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlattributes_wrapper.h"

// Extra includes

using namespace Shiboken;

// Native ---------------------------------------------------------

QXmlAttributesWrapper::QXmlAttributesWrapper() : QXmlAttributes() {
    // ... middle
}

QXmlAttributesWrapper::~QXmlAttributesWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlAttributes_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlAttributes >()))
        return -1;

    QXmlAttributesWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlAttributes", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlAttributes(QXmlAttributes)
    // 1: QXmlAttributes()
    if (numArgs == 0) {
        overloadId = 1; // QXmlAttributes()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlAttributes & >::isConvertible(arg)) {
        overloadId = 0; // QXmlAttributes(QXmlAttributes)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributes_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlAttributes(QXmlAttributes)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QXmlAttributes* cpp_arg0 = Shiboken::Converter<QXmlAttributes* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlAttributes(QXmlAttributes)
                cptr = new QXmlAttributesWrapper(*reinterpret_cast<QXmlAttributesWrapper*>(cpp_arg0));
                }
                break;
            }
            case 1: // QXmlAttributes()
            {

                if(!PyErr_Occurred()) {
                // QXmlAttributes()
                cptr = new QXmlAttributesWrapper();
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlAttributes >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlAttributes_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlAttributes_Init_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlAttributes", "", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlAttributes", overloads);
        return -1;
}

static PyObject* SbkQXmlAttributesFunc_append(PyObject* self, PyObject* args)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "append", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: append(QString,QString,QString,QString)
    if (numArgs == 4 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2]) && Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
        overloadId = 0; // append(QString,QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributesFunc_append_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            QString cpp_arg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // append(QString,QString,QString,QString)
            cppSelf->QXmlAttributes::append(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlAttributesFunc_append_TypeError:
        const char* overloads[] = {"QString, QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlAttributes.append", overloads);
        return 0;
}

static PyObject* SbkQXmlAttributesFunc_clear(PyObject* self)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QXmlAttributes::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlAttributesFunc_count(PyObject* self)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // count()const
            int cppResult = cppSelf->QXmlAttributes::count();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlAttributesFunc_index(PyObject* self, PyObject* args)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "index", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: index(QString)const
    // 1: index(QString,QString)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // index(QString)const
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // index(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributesFunc_index_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // index(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // index(QString)const
                int cppResult = cppSelf->QXmlAttributes::index(cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // index(QString,QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // index(QString,QString)const
                int cppResult = cppSelf->QXmlAttributes::index(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlAttributesFunc_index_TypeError:
        const char* overloads[] = {"QString", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlAttributes.index", overloads);
        return 0;
}

static PyObject* SbkQXmlAttributesFunc_length(PyObject* self)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            int cppResult = cppSelf->QXmlAttributes::length();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlAttributesFunc_localName(PyObject* self, PyObject* arg)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: localName(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // localName(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributesFunc_localName_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // localName(int)const
            QString cppResult = cppSelf->QXmlAttributes::localName(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlAttributesFunc_localName_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlAttributes.localName", overloads);
        return 0;
}

static PyObject* SbkQXmlAttributesFunc_qName(PyObject* self, PyObject* arg)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qName(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qName(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributesFunc_qName_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // qName(int)const
            QString cppResult = cppSelf->QXmlAttributes::qName(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlAttributesFunc_qName_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlAttributes.qName", overloads);
        return 0;
}

static PyObject* SbkQXmlAttributesFunc_type(PyObject* self, PyObject* args)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "type", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: type(QString)const
    // 1: type(QString,QString)const
    // 2: type(int)const
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // type(int)const
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // type(QString)const
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // type(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributesFunc_type_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // type(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // type(QString)const
                QString cppResult = cppSelf->QXmlAttributes::type(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // type(QString,QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // type(QString,QString)const
                QString cppResult = cppSelf->QXmlAttributes::type(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 2: // type(int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // type(int)const
                QString cppResult = cppSelf->QXmlAttributes::type(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlAttributesFunc_type_TypeError:
        const char* overloads[] = {"QString", "QString, QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlAttributes.type", overloads);
        return 0;
}

static PyObject* SbkQXmlAttributesFunc_uri(PyObject* self, PyObject* arg)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: uri(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // uri(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributesFunc_uri_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // uri(int)const
            QString cppResult = cppSelf->QXmlAttributes::uri(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlAttributesFunc_uri_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlAttributes.uri", overloads);
        return 0;
}

static PyObject* SbkQXmlAttributesFunc_value(PyObject* self, PyObject* args)
{
    QXmlAttributes* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlAttributes* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(QString)const
    // 1: value(QString,QString)const
    // 2: value(int)const
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // value(int)const
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // value(QString)const
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // value(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlAttributesFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // value(QString)const
                QString cppResult = cppSelf->QXmlAttributes::value(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(QString,QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // value(QString,QString)const
                QString cppResult = cppSelf->QXmlAttributes::value(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 2: // value(int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // value(int)const
                QString cppResult = cppSelf->QXmlAttributes::value(cpp_arg0);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlAttributesFunc_value_TypeError:
        const char* overloads[] = {"QString", "QString, QString", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlAttributes.value", overloads);
        return 0;
}

static PyMethodDef SbkQXmlAttributes_methods[] = {
    {"append", (PyCFunction)SbkQXmlAttributesFunc_append, METH_VARARGS},
    {"clear", (PyCFunction)SbkQXmlAttributesFunc_clear, METH_NOARGS},
    {"count", (PyCFunction)SbkQXmlAttributesFunc_count, METH_NOARGS},
    {"index", (PyCFunction)SbkQXmlAttributesFunc_index, METH_VARARGS},
    {"length", (PyCFunction)SbkQXmlAttributesFunc_length, METH_NOARGS},
    {"localName", (PyCFunction)SbkQXmlAttributesFunc_localName, METH_O},
    {"qName", (PyCFunction)SbkQXmlAttributesFunc_qName, METH_O},
    {"type", (PyCFunction)SbkQXmlAttributesFunc_type, METH_VARARGS},
    {"uri", (PyCFunction)SbkQXmlAttributesFunc_uri, METH_O},
    {"value", (PyCFunction)SbkQXmlAttributesFunc_value, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQXmlAttributes_ObjCopierFunc(const void* ptr){
    return new QXmlAttributesWrapper(*reinterpret_cast<const QXmlAttributes*>(ptr));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlAttributes_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlAttributes",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlAttributes_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlAttributes_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          &SbkQXmlAttributes_ObjCopierFunc,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlAttributes >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlAttributes",
    /*user_data*/           0
};
} //extern


void init_QXmlAttributes(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLATTRIBUTES_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlAttributes_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQXmlAttributes_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlAttributes_Type));
    PyModule_AddObject(module, "QXmlAttributes",
        ((PyObject*)&SbkQXmlAttributes_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlAttributes >("QXmlAttributes");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlAttributes >("QXmlAttributes*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlAttributes >(typeid(QXmlAttributes).name());
    Shiboken::TypeResolver::createValueTypeResolver<QXmlAttributes >(typeid(QXmlAttributesWrapper).name());
    PySide::initQtMetaType<QXmlAttributes >();
}

