/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmldeclhandler_wrapper.h"

// Extra includes

using namespace Shiboken;

// Native ---------------------------------------------------------

QXmlDeclHandlerWrapper::QXmlDeclHandlerWrapper() : QXmlDeclHandler() {
    // ... middle
}

bool QXmlDeclHandlerWrapper::attributeDecl(const QString & eName, const QString & aName, const QString & type, const QString & valueDefault, const QString & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "attributeDecl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.attributeDecl()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNNN)",
        Shiboken::Converter<QString >::toPython(eName),
        Shiboken::Converter<QString >::toPython(aName),
        Shiboken::Converter<QString >::toPython(type),
        Shiboken::Converter<QString >::toPython(valueDefault),
        Shiboken::Converter<QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlDeclHandler.attributeDecl", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QString QXmlDeclHandlerWrapper::errorString() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "errorString"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.errorString()' not implemented.");
        return QString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlDeclHandler.errorString", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

bool QXmlDeclHandlerWrapper::externalEntityDecl(const QString & name, const QString & publicId, const QString & systemId)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "externalEntityDecl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.externalEntityDecl()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter<QString >::toPython(name),
        Shiboken::Converter<QString >::toPython(publicId),
        Shiboken::Converter<QString >::toPython(systemId)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlDeclHandler.externalEntityDecl", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QXmlDeclHandlerWrapper::internalEntityDecl(const QString & name, const QString & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "internalEntityDecl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.internalEntityDecl()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QString >::toPython(name),
        Shiboken::Converter<QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlDeclHandler.internalEntityDecl", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QXmlDeclHandlerWrapper::~QXmlDeclHandlerWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlDeclHandler_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlDeclHandler >()))
        return -1;

    QXmlDeclHandlerWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtXmlTypes[SBK_QXMLDECLHANDLER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QXmlDeclHandler' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QXmlDeclHandler()
            cptr = new QXmlDeclHandlerWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlDeclHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQXmlDeclHandlerFunc_attributeDecl(PyObject* self, PyObject* args)
{
    QXmlDeclHandler* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlDeclHandler* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "attributeDecl", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: attributeDecl(QString,QString,QString,QString,QString)
    if (numArgs == 5 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2]) && Shiboken::Converter<QString >::isConvertible(pyargs[3]) && Shiboken::Converter<QString >::isConvertible(pyargs[4])) {
        overloadId = 0; // attributeDecl(QString,QString,QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlDeclHandlerFunc_attributeDecl_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            QString cpp_arg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);
            QString cpp_arg4 = Shiboken::Converter<QString >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
            // attributeDecl(QString,QString,QString,QString,QString)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.attributeDecl()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->attributeDecl(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlDeclHandlerFunc_attributeDecl_TypeError:
        const char* overloads[] = {"QString, QString, QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlDeclHandler.attributeDecl", overloads);
        return 0;
}

static PyObject* SbkQXmlDeclHandlerFunc_errorString(PyObject* self)
{
    QXmlDeclHandler* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlDeclHandler* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.errorString()' not implemented.");
                return 0;
            }
            QString cppResult = cppSelf->errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlDeclHandlerFunc_externalEntityDecl(PyObject* self, PyObject* args)
{
    QXmlDeclHandler* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlDeclHandler* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "externalEntityDecl", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: externalEntityDecl(QString,QString,QString)
    if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // externalEntityDecl(QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlDeclHandlerFunc_externalEntityDecl_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // externalEntityDecl(QString,QString,QString)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.externalEntityDecl()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->externalEntityDecl(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlDeclHandlerFunc_externalEntityDecl_TypeError:
        const char* overloads[] = {"QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlDeclHandler.externalEntityDecl", overloads);
        return 0;
}

static PyObject* SbkQXmlDeclHandlerFunc_internalEntityDecl(PyObject* self, PyObject* args)
{
    QXmlDeclHandler* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlDeclHandler* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "internalEntityDecl", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: internalEntityDecl(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // internalEntityDecl(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlDeclHandlerFunc_internalEntityDecl_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // internalEntityDecl(QString,QString)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDeclHandler.internalEntityDecl()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->internalEntityDecl(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlDeclHandlerFunc_internalEntityDecl_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlDeclHandler.internalEntityDecl", overloads);
        return 0;
}

static PyMethodDef SbkQXmlDeclHandler_methods[] = {
    {"attributeDecl", (PyCFunction)SbkQXmlDeclHandlerFunc_attributeDecl, METH_VARARGS},
    {"errorString", (PyCFunction)SbkQXmlDeclHandlerFunc_errorString, METH_NOARGS},
    {"externalEntityDecl", (PyCFunction)SbkQXmlDeclHandlerFunc_externalEntityDecl, METH_VARARGS},
    {"internalEntityDecl", (PyCFunction)SbkQXmlDeclHandlerFunc_internalEntityDecl, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlDeclHandler_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlDeclHandler",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlDeclHandler_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlDeclHandler_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlDeclHandler >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlDeclHandler*",
    /*user_data*/           0
};
} //extern


void init_QXmlDeclHandler(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLDECLHANDLER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlDeclHandler_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQXmlDeclHandler_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlDeclHandler_Type));
    PyModule_AddObject(module, "QXmlDeclHandler",
        ((PyObject*)&SbkQXmlDeclHandler_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlDeclHandler >("QXmlDeclHandler*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlDeclHandler >(typeid(QXmlDeclHandler).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlDeclHandler >(typeid(QXmlDeclHandlerWrapper).name());
    PySide::initQtMetaType<QXmlDeclHandler* >();
}

