/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlinputsource_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QXmlInputSourceWrapper::QXmlInputSourceWrapper() : QXmlInputSource() {
    // ... middle
}

QXmlInputSourceWrapper::QXmlInputSourceWrapper(QIODevice * dev) : QXmlInputSource(dev) {
    // ... middle
}

QString QXmlInputSourceWrapper::data() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "data"));
    if (py_override.isNull()) {
        return this->QXmlInputSource::data();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlInputSource.data", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

void QXmlInputSourceWrapper::fetchData()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "fetchData"));
    if (py_override.isNull()) {
        return this->QXmlInputSource::fetchData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QString QXmlInputSourceWrapper::fromRawData(const QByteArray & data, bool beginning)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "fromRawData"));
    if (py_override.isNull()) {
        return this->QXmlInputSource::fromRawData(data, beginning);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QByteArray & >::toPython(data),
        Shiboken::Converter<bool >::toPython(beginning)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlInputSource.fromRawData", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

QChar QXmlInputSourceWrapper::next()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "next"));
    if (py_override.isNull()) {
        return this->QXmlInputSource::next();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QChar(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QChar >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlInputSource.next", "QChar", pyResult->ob_type->tp_name);
        return QChar(0);
    }
    QChar cppResult(Shiboken::Converter<QChar >::toCpp(pyResult));
    return cppResult;
}

void QXmlInputSourceWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QXmlInputSource::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlInputSourceWrapper::setData(const QByteArray & dat)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setData"));
    if (py_override.isNull()) {
        return this->QXmlInputSource::setData(dat);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QByteArray & >::toPython(dat)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlInputSourceWrapper::setData(const QString & dat)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setData"));
    if (py_override.isNull()) {
        return this->QXmlInputSource::setData(dat);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(dat)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QXmlInputSourceWrapper::~QXmlInputSourceWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlInputSource_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlInputSource >()))
        return -1;

    QXmlInputSourceWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlInputSource", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlInputSource()
    // 1: QXmlInputSource(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlInputSource()
    } else if (numArgs == 1 && Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 1; // QXmlInputSource(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlInputSource_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlInputSource()
            {

                if(!PyErr_Occurred()) {
                // QXmlInputSource()
                cptr = new QXmlInputSourceWrapper();
                }
                break;
            }
            case 1: // QXmlInputSource(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlInputSource(QIODevice*)
                cptr = new QXmlInputSourceWrapper(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlInputSource >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlInputSource_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlInputSource_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlInputSource", overloads);
        return -1;
}

static PyObject* SbkQXmlInputSourceFunc_data(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlInputSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // data()const
            QString cppResult = cppSelf->QXmlInputSource::data();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlInputSourceFunc_fetchData(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlInputSource* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fetchData()
            cppSelf->QXmlInputSource::fetchData();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlInputSourceFunc_fromRawData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlInputSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlInputSource* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "beginning" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QXmlInputSource.fromRawData(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QXmlInputSource.fromRawData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QXmlInputSource.fromRawData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromRawData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromRawData(QByteArray,bool)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromRawData(QByteArray,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // fromRawData(QByteArray,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlInputSourceFunc_fromRawData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "beginning");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "beginning";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QXmlInputSource.fromRawData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // fromRawData(QByteArray,bool)
            QString cppResult = cppSelf->QXmlInputSource::fromRawData(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlInputSourceFunc_fromRawData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlInputSource.fromRawData", overloads);
        return 0;
}

static PyObject* SbkQXmlInputSourceFunc_next(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlInputSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // next()
            QChar cppResult = cppSelf->QXmlInputSource::next();
            pyResult = Shiboken::Converter<QChar >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlInputSourceFunc_reset(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlInputSource* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QXmlInputSource::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlInputSourceFunc_setData(PyObject* self, PyObject* arg)
{
    QXmlInputSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlInputSource* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setData(QByteArray)
    // 1: setData(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // setData(QString)
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // setData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlInputSourceFunc_setData_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setData(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setData(QByteArray)
                cppSelf->QXmlInputSource::setData(*cpp_arg0);
                }
                break;
            }
            case 1: // setData(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setData(QString)
                cppSelf->QXmlInputSource::setData(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlInputSourceFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlInputSource.setData", overloads);
        return 0;
}

static PyMethodDef SbkQXmlInputSource_methods[] = {
    {"data", (PyCFunction)SbkQXmlInputSourceFunc_data, METH_NOARGS},
    {"fetchData", (PyCFunction)SbkQXmlInputSourceFunc_fetchData, METH_NOARGS},
    {"fromRawData", (PyCFunction)SbkQXmlInputSourceFunc_fromRawData, METH_VARARGS|METH_KEYWORDS},
    {"next", (PyCFunction)SbkQXmlInputSourceFunc_next, METH_NOARGS},
    {"reset", (PyCFunction)SbkQXmlInputSourceFunc_reset, METH_NOARGS},
    {"setData", (PyCFunction)SbkQXmlInputSourceFunc_setData, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlInputSource_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlInputSource",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlInputSource_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlInputSource_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlInputSource >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlInputSource*",
    /*user_data*/           0
};
} //extern


void init_QXmlInputSource(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLINPUTSOURCE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlInputSource_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkQXmlInputSource_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlInputSource_Type));
    PyModule_AddObject(module, "QXmlInputSource",
        ((PyObject*)&SbkQXmlInputSource_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlInputSource >("QXmlInputSource*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlInputSource >(typeid(QXmlInputSource).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlInputSource >(typeid(QXmlInputSourceWrapper).name());
    PySide::initQtMetaType<QXmlInputSource* >();
}

