/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlnamespacesupport_wrapper.h"

// Extra includes
#include <QStringList>
#include <qxml.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlNamespaceSupport_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlNamespaceSupport >()))
        return -1;

    QXmlNamespaceSupport* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QXmlNamespaceSupport()
            cptr = new QXmlNamespaceSupport();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlNamespaceSupport >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQXmlNamespaceSupportFunc_popContext(PyObject* self)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // popContext()
            cppSelf->QXmlNamespaceSupport::popContext();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlNamespaceSupportFunc_prefix(PyObject* self, PyObject* arg)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: prefix(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // prefix(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNamespaceSupportFunc_prefix_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // prefix(QString)const
            QString cppResult = cppSelf->QXmlNamespaceSupport::prefix(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNamespaceSupportFunc_prefix_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlNamespaceSupport.prefix", overloads);
        return 0;
}

static PyObject* SbkQXmlNamespaceSupportFunc_prefixes(PyObject* self, PyObject* arg)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: prefixes()const
    // 1: prefixes(QString)const
    if (numArgs == 0) {
        overloadId = 0; // prefixes()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // prefixes(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNamespaceSupportFunc_prefixes_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // prefixes()const
            {

                if(!PyErr_Occurred()) {
                // prefixes()const
                QStringList cppResult = cppSelf->QXmlNamespaceSupport::prefixes();
                pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
                }
                break;
            }
            case 1: // prefixes(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // prefixes(QString)const
                QStringList cppResult = cppSelf->QXmlNamespaceSupport::prefixes(cpp_arg0);
                pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNamespaceSupportFunc_prefixes_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlNamespaceSupport.prefixes", overloads);
        return 0;
}

static PyObject* SbkQXmlNamespaceSupportFunc_processName(PyObject* self, PyObject* args)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "processName", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: processName(QString,bool,QString&,QString&)const
    if (numArgs == 4 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QString & >::isConvertible(pyargs[2]) && Shiboken::Converter<QString & >::isConvertible(pyargs[3])) {
        overloadId = 0; // processName(QString,bool,QString&,QString&)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNamespaceSupportFunc_processName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            QString cpp_arg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
            // processName(QString,bool,QString&,QString&)const
            cppSelf->QXmlNamespaceSupport::processName(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlNamespaceSupportFunc_processName_TypeError:
        const char* overloads[] = {"QString, bool, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlNamespaceSupport.processName", overloads);
        return 0;
}

static PyObject* SbkQXmlNamespaceSupportFunc_pushContext(PyObject* self)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pushContext()
            cppSelf->QXmlNamespaceSupport::pushContext();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlNamespaceSupportFunc_reset(PyObject* self)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QXmlNamespaceSupport::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQXmlNamespaceSupportFunc_setPrefix(PyObject* self, PyObject* args)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPrefix", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPrefix(QString,QString)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setPrefix(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNamespaceSupportFunc_setPrefix_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setPrefix(QString,QString)
            cppSelf->QXmlNamespaceSupport::setPrefix(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlNamespaceSupportFunc_setPrefix_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlNamespaceSupport.setPrefix", overloads);
        return 0;
}

static PyObject* SbkQXmlNamespaceSupportFunc_splitName(PyObject* self, PyObject* args)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "splitName", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: splitName(QString,QString&,QString&)const
    if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<QString & >::isConvertible(pyargs[1]) && Shiboken::Converter<QString & >::isConvertible(pyargs[2])) {
        overloadId = 0; // splitName(QString,QString&,QString&)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNamespaceSupportFunc_splitName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // splitName(QString,QString&,QString&)const
            cppSelf->QXmlNamespaceSupport::splitName(cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlNamespaceSupportFunc_splitName_TypeError:
        const char* overloads[] = {"QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlNamespaceSupport.splitName", overloads);
        return 0;
}

static PyObject* SbkQXmlNamespaceSupportFunc_uri(PyObject* self, PyObject* arg)
{
    QXmlNamespaceSupport* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlNamespaceSupport* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: uri(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // uri(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNamespaceSupportFunc_uri_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // uri(QString)const
            QString cppResult = cppSelf->QXmlNamespaceSupport::uri(cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNamespaceSupportFunc_uri_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlNamespaceSupport.uri", overloads);
        return 0;
}

static PyMethodDef SbkQXmlNamespaceSupport_methods[] = {
    {"popContext", (PyCFunction)SbkQXmlNamespaceSupportFunc_popContext, METH_NOARGS},
    {"prefix", (PyCFunction)SbkQXmlNamespaceSupportFunc_prefix, METH_O},
    {"prefixes", (PyCFunction)SbkQXmlNamespaceSupportFunc_prefixes, METH_NOARGS|METH_O},
    {"processName", (PyCFunction)SbkQXmlNamespaceSupportFunc_processName, METH_VARARGS},
    {"pushContext", (PyCFunction)SbkQXmlNamespaceSupportFunc_pushContext, METH_NOARGS},
    {"reset", (PyCFunction)SbkQXmlNamespaceSupportFunc_reset, METH_NOARGS},
    {"setPrefix", (PyCFunction)SbkQXmlNamespaceSupportFunc_setPrefix, METH_VARARGS},
    {"splitName", (PyCFunction)SbkQXmlNamespaceSupportFunc_splitName, METH_VARARGS},
    {"uri", (PyCFunction)SbkQXmlNamespaceSupportFunc_uri, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlNamespaceSupport_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlNamespaceSupport",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlNamespaceSupport_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlNamespaceSupport_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlNamespaceSupport >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlNamespaceSupport*",
    /*user_data*/           0
};
} //extern


void init_QXmlNamespaceSupport(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLNAMESPACESUPPORT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlNamespaceSupport_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlNamespaceSupport_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlNamespaceSupport_Type));
    PyModule_AddObject(module, "QXmlNamespaceSupport",
        ((PyObject*)&SbkQXmlNamespaceSupport_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlNamespaceSupport >("QXmlNamespaceSupport*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlNamespaceSupport >(typeid(QXmlNamespaceSupport).name());
    PySide::initQtMetaType<QXmlNamespaceSupport* >();
}

