/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlparseexception_wrapper.h"

// Extra includes
#include <qxml.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlParseException_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlParseException >()))
        return -1;

    QXmlParseException* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "c", "l", "name", "p", "s" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 5, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXml.QXmlParseException(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QXmlParseException(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QXmlParseException", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlParseException(QString,int,int,QString,QString)
    // 1: QXmlParseException(QXmlParseException)
    if (numArgs == 0) {
        overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlParseException & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QXmlParseException(QXmlParseException)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
                } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
                    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[4])) {
                        overloadId = 0; // QXmlParseException(QString,int,int,QString,QString)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlParseException_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlParseException(QString,int,int,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "name");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "name";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "c");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "c";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "l");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "l";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "p");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "p";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "s");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "s";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXml.QXmlParseException(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;
                QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();
                QString cpp_arg4 = pyargs[4] ? Shiboken::Converter<QString >::toCpp(pyargs[4]) : QString();

                if(!PyErr_Occurred()) {
                // QXmlParseException(QString,int,int,QString,QString)
                cptr = new QXmlParseException(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 1: // QXmlParseException(QXmlParseException)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QXmlParseException* cpp_arg0 = Shiboken::Converter<QXmlParseException* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QXmlParseException(QXmlParseException)
                cptr = new QXmlParseException(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlParseException >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlParseException_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlParseException_Init_TypeError:
        const char* overloads[] = {"QString = QString(), int = -1, int = -1, QString = QString(), QString = QString()", "PySide.QtXml.QXmlParseException", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlParseException", overloads);
        return -1;
}

static PyObject* SbkQXmlParseExceptionFunc_columnNumber(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // columnNumber()const
            int cppResult = cppSelf->QXmlParseException::columnNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlParseExceptionFunc_lineNumber(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineNumber()const
            int cppResult = cppSelf->QXmlParseException::lineNumber();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlParseExceptionFunc_message(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // message()const
            QString cppResult = cppSelf->QXmlParseException::message();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlParseExceptionFunc_publicId(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // publicId()const
            QString cppResult = cppSelf->QXmlParseException::publicId();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlParseExceptionFunc_systemId(PyObject* self)
{
    QXmlParseException* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlParseException* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // systemId()const
            QString cppResult = cppSelf->QXmlParseException::systemId();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQXmlParseException_methods[] = {
    {"columnNumber", (PyCFunction)SbkQXmlParseExceptionFunc_columnNumber, METH_NOARGS},
    {"lineNumber", (PyCFunction)SbkQXmlParseExceptionFunc_lineNumber, METH_NOARGS},
    {"message", (PyCFunction)SbkQXmlParseExceptionFunc_message, METH_NOARGS},
    {"publicId", (PyCFunction)SbkQXmlParseExceptionFunc_publicId, METH_NOARGS},
    {"systemId", (PyCFunction)SbkQXmlParseExceptionFunc_systemId, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlParseException_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlParseException",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlParseException_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlParseException_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlParseException >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlParseException",
    /*user_data*/           0
};
} //extern


void init_QXmlParseException(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLPARSEEXCEPTION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlParseException_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlParseException_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlParseException_Type));
    PyModule_AddObject(module, "QXmlParseException",
        ((PyObject*)&SbkQXmlParseException_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlParseException >("QXmlParseException");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlParseException >("QXmlParseException*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlParseException >(typeid(QXmlParseException).name());
    PySide::initQtMetaType<QXmlParseException >();
}

