/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlsimplereader_wrapper.h"

// Extra includes
#include <qxml.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QXmlDTDHandler * QXmlSimpleReaderWrapper::DTDHandler() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "DTDHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::DTDHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QXmlDTDHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.DTDHandler", SbkType<QXmlDTDHandler * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlDTDHandler * cppResult(Shiboken::Converter<QXmlDTDHandler * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QXmlSimpleReader.DTDHandler");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QXmlSimpleReaderWrapper::QXmlSimpleReaderWrapper() : QXmlSimpleReader() {
    // ... middle
}

QXmlContentHandler * QXmlSimpleReaderWrapper::contentHandler() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contentHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::contentHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QXmlContentHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.contentHandler", SbkType<QXmlContentHandler * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlContentHandler * cppResult(Shiboken::Converter<QXmlContentHandler * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QXmlSimpleReader.contentHandler");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QXmlDeclHandler * QXmlSimpleReaderWrapper::declHandler() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "declHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::declHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QXmlDeclHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.declHandler", SbkType<QXmlDeclHandler * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlDeclHandler * cppResult(Shiboken::Converter<QXmlDeclHandler * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QXmlSimpleReader.declHandler");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QXmlEntityResolver * QXmlSimpleReaderWrapper::entityResolver() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "entityResolver"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::entityResolver();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QXmlEntityResolver * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.entityResolver", SbkType<QXmlEntityResolver * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlEntityResolver * cppResult(Shiboken::Converter<QXmlEntityResolver * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QXmlSimpleReader.entityResolver");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

QXmlErrorHandler * QXmlSimpleReaderWrapper::errorHandler() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "errorHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::errorHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QXmlErrorHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.errorHandler", SbkType<QXmlErrorHandler * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlErrorHandler * cppResult(Shiboken::Converter<QXmlErrorHandler * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QXmlSimpleReader.errorHandler");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

bool QXmlSimpleReaderWrapper::feature(const QString & name, bool * ok) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "feature"));
    if (py_override.isNull()) {

        return this->QXmlSimpleReader::feature(name, ok);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(name)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PySequence_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.feature", "PySequence", pyResult->ob_type->tp_name);
        return bool(0);
    }
    // Begin code injection
    
    // TEMPLATE - fix_virtual_method_return_value_and_bool* - START
    AutoDecRef _py_ret_(PySequence_GetItem(pyResult, 0));
    AutoDecRef _py_ok_(PySequence_GetItem(pyResult, 1));
    bool cppResult = Shiboken::Converter<bool >::toCpp(_py_ret_);
    *ok = Shiboken::Converter<bool >::toCpp(_py_ok_);
    // TEMPLATE - fix_virtual_method_return_value_and_bool* - END
    
    // End of code injection

    return cppResult;
}

bool QXmlSimpleReaderWrapper::hasFeature(const QString & name) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasFeature"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::hasFeature(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.hasFeature", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::hasProperty(const QString & name) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasProperty"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::hasProperty(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.hasProperty", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

QXmlLexicalHandler * QXmlSimpleReaderWrapper::lexicalHandler() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "lexicalHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::lexicalHandler();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QXmlLexicalHandler * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.lexicalHandler", SbkType<QXmlLexicalHandler * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QXmlLexicalHandler * cppResult(Shiboken::Converter<QXmlLexicalHandler * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QXmlSimpleReader.lexicalHandler");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parse(const QXmlInputSource & input)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "parse"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::parse(input);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QXmlInputSource & >::toPython(input)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parse", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parse(const QXmlInputSource * input)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "parse"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::parse(input);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QXmlInputSource * >::toPython(input)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parse", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parse(const QXmlInputSource * input, bool incremental)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "parse"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::parse(input, incremental);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QXmlInputSource * >::toPython(input),
        Shiboken::Converter<bool >::toPython(incremental)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parse", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QXmlSimpleReaderWrapper::parseContinue()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "parseContinue"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::parseContinue();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.parseContinue", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void * QXmlSimpleReaderWrapper::property(const QString & name, bool * ok) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "property"));
    if (py_override.isNull()) {

        return this->QXmlSimpleReader::property(name, ok);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(name)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = PySequence_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlSimpleReader.property", "PySequence", pyResult->ob_type->tp_name);
        return 0;
    }
    // Begin code injection
    
    // TEMPLATE - fix_virtual_method_return_value_and_bool* - START
    AutoDecRef _py_ret_(PySequence_GetItem(pyResult, 0));
    AutoDecRef _py_ok_(PySequence_GetItem(pyResult, 1));
    void * cppResult = Shiboken::Converter<void * >::toCpp(_py_ret_);
    *ok = Shiboken::Converter<bool >::toCpp(_py_ok_);
    // TEMPLATE - fix_virtual_method_return_value_and_bool* - END
    
    // End of code injection

    return cppResult;
}

void QXmlSimpleReaderWrapper::setContentHandler(QXmlContentHandler * handler)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setContentHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setContentHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QXmlContentHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSimpleReaderWrapper::setDTDHandler(QXmlDTDHandler * handler)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setDTDHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setDTDHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QXmlDTDHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSimpleReaderWrapper::setDeclHandler(QXmlDeclHandler * handler)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setDeclHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setDeclHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QXmlDeclHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSimpleReaderWrapper::setEntityResolver(QXmlEntityResolver * handler)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setEntityResolver"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setEntityResolver(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QXmlEntityResolver * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSimpleReaderWrapper::setErrorHandler(QXmlErrorHandler * handler)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setErrorHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setErrorHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QXmlErrorHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSimpleReaderWrapper::setFeature(const QString & name, bool value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setFeature"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setFeature(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QString >::toPython(name),
        Shiboken::Converter<bool >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSimpleReaderWrapper::setLexicalHandler(QXmlLexicalHandler * handler)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setLexicalHandler"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setLexicalHandler(handler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QXmlLexicalHandler * >::toPython(handler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QXmlSimpleReaderWrapper::setProperty(const QString & name, void * value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setProperty"));
    if (py_override.isNull()) {
        return this->QXmlSimpleReader::setProperty(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QString >::toPython(name),
        Shiboken::Converter<void * >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QXmlSimpleReaderWrapper::~QXmlSimpleReaderWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject* SbkQXmlSimpleReaderFunc_DTDHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // DTDHandler()const
            QXmlDTDHandler * cppResult = cppSelf->QXmlSimpleReader::DTDHandler();
            pyResult = Shiboken::Converter<QXmlDTDHandler * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static int
SbkQXmlSimpleReader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlSimpleReader >()))
        return -1;

    QXmlSimpleReaderWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // QXmlSimpleReader()
            cptr = new QXmlSimpleReaderWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlSimpleReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkQXmlSimpleReaderFunc_contentHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contentHandler()const
            QXmlContentHandler * cppResult = cppSelf->QXmlSimpleReader::contentHandler();
            pyResult = Shiboken::Converter<QXmlContentHandler * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSimpleReaderFunc_declHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // declHandler()const
            QXmlDeclHandler * cppResult = cppSelf->QXmlSimpleReader::declHandler();
            pyResult = Shiboken::Converter<QXmlDeclHandler * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSimpleReaderFunc_entityResolver(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // entityResolver()const
            QXmlEntityResolver * cppResult = cppSelf->QXmlSimpleReader::entityResolver();
            pyResult = Shiboken::Converter<QXmlEntityResolver * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSimpleReaderFunc_errorHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorHandler()const
            QXmlErrorHandler * cppResult = cppSelf->QXmlSimpleReader::errorHandler();
            pyResult = Shiboken::Converter<QXmlErrorHandler * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSimpleReaderFunc_feature(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: feature(QString,bool*)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // feature(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_feature_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // feature(QString,bool*)const
            // Begin code injection
            
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            bool retval_ = cppSelf->feature(cpp_arg0, &ok_);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_args,bool* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlSimpleReaderFunc_feature_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.feature", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_hasFeature(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasFeature(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasFeature(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_hasFeature_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasFeature(QString)const
            bool cppResult = cppSelf->QXmlSimpleReader::hasFeature(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlSimpleReaderFunc_hasFeature_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.hasFeature", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_hasProperty(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasProperty(QString)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // hasProperty(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_hasProperty_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hasProperty(QString)const
            bool cppResult = cppSelf->QXmlSimpleReader::hasProperty(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlSimpleReaderFunc_hasProperty_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.hasProperty", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_lexicalHandler(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lexicalHandler()const
            QXmlLexicalHandler * cppResult = cppSelf->QXmlSimpleReader::lexicalHandler();
            pyResult = Shiboken::Converter<QXmlLexicalHandler * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSimpleReaderFunc_parse(PyObject* self, PyObject* args)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "parse", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: parse(QXmlInputSource)
    // 1: parse(const QXmlInputSource*)
    // 2: parse(const QXmlInputSource*,bool)
    if (Shiboken::Converter< QXmlInputSource & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // parse(QXmlInputSource)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // parse(const QXmlInputSource*,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_parse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // parse(QXmlInputSource)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlInputSource* cpp_arg0 = Shiboken::Converter<QXmlInputSource* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // parse(QXmlInputSource)
                bool cppResult = cppSelf->QXmlSimpleReader::parse(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // parse(const QXmlInputSource*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlInputSource* cpp_arg0 = Shiboken::Converter<QXmlInputSource* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // parse(const QXmlInputSource*)
                bool cppResult = cppSelf->QXmlSimpleReader::parse(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // parse(const QXmlInputSource*,bool)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlInputSource* cpp_arg0 = Shiboken::Converter<QXmlInputSource* >::toCpp(pyargs[0]);
                bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // parse(const QXmlInputSource*,bool)
                bool cppResult = cppSelf->QXmlSimpleReader::parse(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlSimpleReaderFunc_parse_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlInputSource", "PySide.QtXml.QXmlInputSource", "PySide.QtXml.QXmlInputSource, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlSimpleReader.parse", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_parseContinue(PyObject* self)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parseContinue()
            bool cppResult = cppSelf->QXmlSimpleReader::parseContinue();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSimpleReaderFunc_property(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(QString,bool*)const
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // property(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_property_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // property(QString,bool*)const
            // Begin code injection
            
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            void * retval_ = cppSelf->property(cpp_arg0, &ok_);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_args,bool* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlSimpleReaderFunc_property_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.property", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setContentHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContentHandler(QXmlContentHandler*)
    if (Shiboken::Converter<QXmlContentHandler * >::isConvertible(arg)) {
        overloadId = 0; // setContentHandler(QXmlContentHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setContentHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlContentHandler* cpp_arg0 = Shiboken::Converter<QXmlContentHandler* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setContentHandler(QXmlContentHandler*)
            cppSelf->QXmlSimpleReader::setContentHandler(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setContentHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlContentHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setContentHandler", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setDTDHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDTDHandler(QXmlDTDHandler*)
    if (Shiboken::Converter<QXmlDTDHandler * >::isConvertible(arg)) {
        overloadId = 0; // setDTDHandler(QXmlDTDHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setDTDHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlDTDHandler* cpp_arg0 = Shiboken::Converter<QXmlDTDHandler* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDTDHandler(QXmlDTDHandler*)
            cppSelf->QXmlSimpleReader::setDTDHandler(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setDTDHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlDTDHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setDTDHandler", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setDeclHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDeclHandler(QXmlDeclHandler*)
    if (Shiboken::Converter<QXmlDeclHandler * >::isConvertible(arg)) {
        overloadId = 0; // setDeclHandler(QXmlDeclHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setDeclHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlDeclHandler* cpp_arg0 = Shiboken::Converter<QXmlDeclHandler* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDeclHandler(QXmlDeclHandler*)
            cppSelf->QXmlSimpleReader::setDeclHandler(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setDeclHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlDeclHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setDeclHandler", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setEntityResolver(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEntityResolver(QXmlEntityResolver*)
    if (Shiboken::Converter<QXmlEntityResolver * >::isConvertible(arg)) {
        overloadId = 0; // setEntityResolver(QXmlEntityResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setEntityResolver_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlEntityResolver* cpp_arg0 = Shiboken::Converter<QXmlEntityResolver* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEntityResolver(QXmlEntityResolver*)
            cppSelf->QXmlSimpleReader::setEntityResolver(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setEntityResolver_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlEntityResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setEntityResolver", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setErrorHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setErrorHandler(QXmlErrorHandler*)
    if (Shiboken::Converter<QXmlErrorHandler * >::isConvertible(arg)) {
        overloadId = 0; // setErrorHandler(QXmlErrorHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setErrorHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlErrorHandler* cpp_arg0 = Shiboken::Converter<QXmlErrorHandler* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setErrorHandler(QXmlErrorHandler*)
            cppSelf->QXmlSimpleReader::setErrorHandler(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setErrorHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlErrorHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setErrorHandler", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setFeature(PyObject* self, PyObject* args)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFeature", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFeature(QString,bool)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFeature(QString,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setFeature_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            bool cpp_arg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setFeature(QString,bool)
            cppSelf->QXmlSimpleReader::setFeature(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setFeature_TypeError:
        const char* overloads[] = {"QString, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlSimpleReader.setFeature", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setLexicalHandler(PyObject* self, PyObject* arg)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLexicalHandler(QXmlLexicalHandler*)
    if (Shiboken::Converter<QXmlLexicalHandler * >::isConvertible(arg)) {
        overloadId = 0; // setLexicalHandler(QXmlLexicalHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setLexicalHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlLexicalHandler* cpp_arg0 = Shiboken::Converter<QXmlLexicalHandler* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLexicalHandler(QXmlLexicalHandler*)
            cppSelf->QXmlSimpleReader::setLexicalHandler(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setLexicalHandler_TypeError:
        const char* overloads[] = {"PySide.QtXml.QXmlLexicalHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlSimpleReader.setLexicalHandler", overloads);
        return 0;
}

static PyObject* SbkQXmlSimpleReaderFunc_setProperty(PyObject* self, PyObject* args)
{
    QXmlSimpleReader* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSimpleReader* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(QString,void*)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<void * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setProperty(QString,void*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSimpleReaderFunc_setProperty_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            void * cpp_arg1 = Shiboken::Converter<void * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setProperty(QString,void*)
            cppSelf->QXmlSimpleReader::setProperty(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSimpleReaderFunc_setProperty_TypeError:
        const char* overloads[] = {"QString, void", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlSimpleReader.setProperty", overloads);
        return 0;
}

static PyMethodDef SbkQXmlSimpleReader_methods[] = {
    {"DTDHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_DTDHandler, METH_NOARGS},
    {"contentHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_contentHandler, METH_NOARGS},
    {"declHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_declHandler, METH_NOARGS},
    {"entityResolver", (PyCFunction)SbkQXmlSimpleReaderFunc_entityResolver, METH_NOARGS},
    {"errorHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_errorHandler, METH_NOARGS},
    {"feature", (PyCFunction)SbkQXmlSimpleReaderFunc_feature, METH_O},
    {"hasFeature", (PyCFunction)SbkQXmlSimpleReaderFunc_hasFeature, METH_O},
    {"hasProperty", (PyCFunction)SbkQXmlSimpleReaderFunc_hasProperty, METH_O},
    {"lexicalHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_lexicalHandler, METH_NOARGS},
    {"parse", (PyCFunction)SbkQXmlSimpleReaderFunc_parse, METH_VARARGS},
    {"parseContinue", (PyCFunction)SbkQXmlSimpleReaderFunc_parseContinue, METH_NOARGS},
    {"property", (PyCFunction)SbkQXmlSimpleReaderFunc_property, METH_O},
    {"setContentHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_setContentHandler, METH_O},
    {"setDTDHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_setDTDHandler, METH_O},
    {"setDeclHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_setDeclHandler, METH_O},
    {"setEntityResolver", (PyCFunction)SbkQXmlSimpleReaderFunc_setEntityResolver, METH_O},
    {"setErrorHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_setErrorHandler, METH_O},
    {"setFeature", (PyCFunction)SbkQXmlSimpleReaderFunc_setFeature, METH_VARARGS},
    {"setLexicalHandler", (PyCFunction)SbkQXmlSimpleReaderFunc_setLexicalHandler, METH_O},
    {"setProperty", (PyCFunction)SbkQXmlSimpleReaderFunc_setProperty, METH_VARARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlSimpleReader_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlSimpleReader",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlSimpleReader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlSimpleReader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlSimpleReader >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlSimpleReader*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQXmlSimpleReader_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QXmlReader >()) && dynamic_cast<QXmlSimpleReader*>(reinterpret_cast<QXmlReader*>(cptr)))
        return &SbkQXmlSimpleReader_Type;
    return 0;
}


void init_QXmlSimpleReader(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLSIMPLEREADER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlSimpleReader_Type);

    SbkQXmlSimpleReader_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QXMLREADER_IDX];
    // Fill type discovery information
    SbkQXmlSimpleReader_Type.type_discovery = &SbkQXmlSimpleReader_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtXmlTypes[SBK_QXMLREADER_IDX]), &SbkQXmlSimpleReader_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlSimpleReader_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlSimpleReader_Type));
    PyModule_AddObject(module, "QXmlSimpleReader",
        ((PyObject*)&SbkQXmlSimpleReader_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSimpleReader >("QXmlSimpleReader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSimpleReader >(typeid(QXmlSimpleReader).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSimpleReader >(typeid(QXmlSimpleReaderWrapper).name());
    PySide::initQtMetaType<QXmlSimpleReader* >();
}

