/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlitem_wrapper.h"

// Extra includes
#include <qabstractxmlnodemodel.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlItem >()))
        return -1;

    QXmlItem* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlItem", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlItem()
    // 1: QXmlItem(QVariant)
    // 2: QXmlItem(QXmlItem)
    // 3: QXmlItem(QXmlNodeModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QXmlItem()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlNodeModelIndex & >::isConvertible(arg)) {
        overloadId = 3; // QXmlItem(QXmlNodeModelIndex)
    } else if (numArgs == 1 && Shiboken::Converter<QVariant >::isConvertible(arg)) {
        overloadId = 1; // QXmlItem(QVariant)
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlItem & >::isConvertible(arg)) {
        overloadId = 2; // QXmlItem(QXmlItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlItem_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlItem()
            {

                if(!PyErr_Occurred()) {
                // QXmlItem()
                cptr = new QXmlItem();
                }
                break;
            }
            case 1: // QXmlItem(QVariant)
            {
                QVariant cpp_arg0 = Shiboken::Converter<QVariant >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlItem(QVariant)
                cptr = new QXmlItem(cpp_arg0);
                }
                break;
            }
            case 2: // QXmlItem(QXmlItem)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                std::auto_ptr<QXmlItem > cpp_arg0_auto_ptr;
                QXmlItem* cpp_arg0 = Shiboken::Converter<QXmlItem* >::toCpp(arg);
                if (!Shiboken::Converter<QXmlItem >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QXmlItem >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QXmlItem(QXmlItem)
                cptr = new QXmlItem(*cpp_arg0);
                }
                break;
            }
            case 3: // QXmlItem(QXmlNodeModelIndex)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QXmlNodeModelIndex* cpp_arg0 = Shiboken::Converter<QXmlNodeModelIndex* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlItem(QXmlNodeModelIndex)
                cptr = new QXmlItem(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlItem_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlItem_Init_TypeError:
        const char* overloads[] = {"", "QVariant", "PySide.QtXmlPatterns.QXmlItem", "PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlItem", overloads);
        return -1;
}

static PyObject* SbkQXmlItemFunc_isAtomicValue(PyObject* self)
{
    QXmlItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isAtomicValue()const
            bool cppResult = cppSelf->QXmlItem::isAtomicValue();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlItemFunc_isNode(PyObject* self)
{
    QXmlItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNode()const
            bool cppResult = cppSelf->QXmlItem::isNode();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlItemFunc_isNull(PyObject* self)
{
    QXmlItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QXmlItem::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlItemFunc_toAtomicValue(PyObject* self)
{
    QXmlItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toAtomicValue()const
            QVariant cppResult = cppSelf->QXmlItem::toAtomicValue();
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlItemFunc_toNodeModelIndex(PyObject* self)
{
    QXmlItem* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlItem* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toNodeModelIndex()const
            QXmlNodeModelIndex cppResult = cppSelf->QXmlItem::toNodeModelIndex();
            pyResult = Shiboken::Converter<QXmlNodeModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQXmlItem_methods[] = {
    {"isAtomicValue", (PyCFunction)SbkQXmlItemFunc_isAtomicValue, METH_NOARGS},
    {"isNode", (PyCFunction)SbkQXmlItemFunc_isNode, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQXmlItemFunc_isNull, METH_NOARGS},
    {"toAtomicValue", (PyCFunction)SbkQXmlItemFunc_toAtomicValue, METH_NOARGS},
    {"toNodeModelIndex", (PyCFunction)SbkQXmlItemFunc_toNodeModelIndex, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlItem_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlItem",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlItem >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlItem",
    /*user_data*/           0
};
} //extern


void init_QXmlItem(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLITEM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlItem_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlItem_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlItem_Type));
    PyModule_AddObject(module, "QXmlItem",
        ((PyObject*)&SbkQXmlItem_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlItem >("QXmlItem");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlItem >("QXmlItem*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlItem >(typeid(QXmlItem).name());
    PySide::initQtMetaType<QXmlItem >();
}

