/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlname_wrapper.h"

// Extra includes
#include <qxmlname.h>
#include <qxmlnamepool.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlName_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlName >()))
        return -1;

    QXmlName* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "namespaceURI", "prefix" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlName(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlName(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QXmlName", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlName(QXmlName)
    // 1: QXmlName()
    // 2: QXmlName(QXmlNamePool&,QString,QString,QString)
    if (numArgs == 0) {
        overloadId = 1; // QXmlName()
    } else if (numArgs >= 2 && Shiboken::Converter<QXmlNamePool & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QXmlName(QXmlNamePool&,QString,QString,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QXmlName(QXmlNamePool&,QString,QString,QString)
            } else if (Shiboken::Converter<QString >::isConvertible(pyargs[3])) {
                overloadId = 2; // QXmlName(QXmlNamePool&,QString,QString,QString)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlName & >::isConvertible(pyargs[0])) {
        overloadId = 0; // QXmlName(QXmlName)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlName_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlName(QXmlName)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QXmlName(QXmlName)
                cptr = new QXmlName(*cpp_arg0);
                }
                break;
            }
            case 1: // QXmlName()
            {

                if(!PyErr_Occurred()) {
                // QXmlName()
                cptr = new QXmlName();
                }
                break;
            }
            case 2: // QXmlName(QXmlNamePool&,QString,QString,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "namespaceURI");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "namespaceURI";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "prefix");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "prefix";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlName(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QXmlNamePool* cpp_arg0 = Shiboken::Converter<QXmlNamePool* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QString cpp_arg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();
                QString cpp_arg3 = pyargs[3] ? Shiboken::Converter<QString >::toCpp(pyargs[3]) : QString();

                if(!PyErr_Occurred()) {
                // QXmlName(QXmlNamePool&,QString,QString,QString)
                cptr = new QXmlName(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlName >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlName_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlName_Init_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", "", "PySide.QtXmlPatterns.QXmlNamePool, QString, QString = QString(), QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlName", overloads);
        return -1;
}

static PyObject* SbkQXmlNameFunc_fromClarkName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromClarkName", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromClarkName(QString,QXmlNamePool)
    if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<const QXmlNamePool & >::isConvertible(pyargs[1])) {
        overloadId = 0; // fromClarkName(QString,QXmlNamePool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNameFunc_fromClarkName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QXmlNamePool* cpp_arg1 = Shiboken::Converter<QXmlNamePool* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // fromClarkName(QString,QXmlNamePool)
            QXmlName cppResult = QXmlName::fromClarkName(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QXmlName >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNameFunc_fromClarkName_TypeError:
        const char* overloads[] = {"QString, PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlName.fromClarkName", overloads);
        return 0;
}

static PyObject* SbkQXmlNameFunc_isNCName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isNCName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // isNCName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNameFunc_isNCName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isNCName(QString)
            bool cppResult = QXmlName::isNCName(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNameFunc_isNCName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.isNCName", overloads);
        return 0;
}

static PyObject* SbkQXmlNameFunc_isNull(PyObject* self)
{
    QXmlName* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QXmlName::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlNameFunc_localName(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: localName(QXmlNamePool)const
    if (Shiboken::Converter<const QXmlNamePool & >::isConvertible(arg)) {
        overloadId = 0; // localName(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNameFunc_localName_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlNamePool* cpp_arg0 = Shiboken::Converter<QXmlNamePool* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // localName(QXmlNamePool)const
            QString cppResult = cppSelf->QXmlName::localName(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNameFunc_localName_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.localName", overloads);
        return 0;
}

static PyObject* SbkQXmlNameFunc_namespaceUri(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namespaceUri(QXmlNamePool)const
    if (Shiboken::Converter<const QXmlNamePool & >::isConvertible(arg)) {
        overloadId = 0; // namespaceUri(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNameFunc_namespaceUri_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlNamePool* cpp_arg0 = Shiboken::Converter<QXmlNamePool* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // namespaceUri(QXmlNamePool)const
            QString cppResult = cppSelf->QXmlName::namespaceUri(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNameFunc_namespaceUri_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.namespaceUri", overloads);
        return 0;
}

static PyObject* SbkQXmlNameFunc_prefix(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: prefix(QXmlNamePool)const
    if (Shiboken::Converter<const QXmlNamePool & >::isConvertible(arg)) {
        overloadId = 0; // prefix(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNameFunc_prefix_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlNamePool* cpp_arg0 = Shiboken::Converter<QXmlNamePool* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // prefix(QXmlNamePool)const
            QString cppResult = cppSelf->QXmlName::prefix(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNameFunc_prefix_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.prefix", overloads);
        return 0;
}

static PyObject* SbkQXmlNameFunc_toClarkName(PyObject* self, PyObject* arg)
{
    QXmlName* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlName* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toClarkName(QXmlNamePool)const
    if (Shiboken::Converter<const QXmlNamePool & >::isConvertible(arg)) {
        overloadId = 0; // toClarkName(QXmlNamePool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlNameFunc_toClarkName_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlNamePool* cpp_arg0 = Shiboken::Converter<QXmlNamePool* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // toClarkName(QXmlNamePool)const
            QString cppResult = cppSelf->QXmlName::toClarkName(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlNameFunc_toClarkName_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlNamePool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlName.toClarkName", overloads);
        return 0;
}

static PyMethodDef SbkQXmlName_methods[] = {
    {"fromClarkName", (PyCFunction)SbkQXmlNameFunc_fromClarkName, METH_VARARGS|METH_STATIC},
    {"isNCName", (PyCFunction)SbkQXmlNameFunc_isNCName, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)SbkQXmlNameFunc_isNull, METH_NOARGS},
    {"localName", (PyCFunction)SbkQXmlNameFunc_localName, METH_O},
    {"namespaceUri", (PyCFunction)SbkQXmlNameFunc_namespaceUri, METH_O},
    {"prefix", (PyCFunction)SbkQXmlNameFunc_prefix, METH_O},
    {"toClarkName", (PyCFunction)SbkQXmlNameFunc_toClarkName, METH_O},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkQXmlName_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QXmlName& cpp_self = *Shiboken::Converter<QXmlName* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QXmlName & >::isConvertible(other)) {
                // operator!=(const QXmlName & other) const
                QXmlName* cpp_other = Shiboken::Converter<QXmlName* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlName  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkQXmlName_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QXmlName & >::isConvertible(other)) {
                // operator==(const QXmlName & other) const
                QXmlName* cpp_other = Shiboken::Converter<QXmlName* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QXmlName  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkQXmlName_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQXmlName_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlName_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlName",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQXmlName_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlName_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlName_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlName >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlName",
    /*user_data*/           0
};
} //extern


void init_QXmlName(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLNAME_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlName_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlName_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlName_Type));
    PyModule_AddObject(module, "QXmlName",
        ((PyObject*)&SbkQXmlName_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QXmlName >("QXmlName");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlName >("QXmlName*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlName >(typeid(QXmlName).name());
    PySide::initQtMetaType<QXmlName >();
}

