/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlquery_wrapper.h"

// Extra includes
#include <QStringList>
#include <qabstractmessagehandler.h>
#include <qabstracturiresolver.h>
#include <qabstractxmlnodemodel.h>
#include <qabstractxmlreceiver.h>
#include <qiodevice.h>
#include <qurl.h>
#include <qxmlname.h>
#include <qxmlnamepool.h>
#include <qxmlquery.h>
#include <qxmlresultitems.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlQuery_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlQuery >()))
        return -1;

    QXmlQuery* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "np" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QXmlQuery", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlQuery()
    // 1: QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
    // 2: QXmlQuery(QXmlNamePool)
    // 3: QXmlQuery(QXmlQuery)
    if (numArgs == 0) {
        overloadId = 0; // QXmlQuery()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlNamePool & >::isConvertible(pyargs[0])) {
        overloadId = 2; // QXmlQuery(QXmlNamePool)
    } else if (Shiboken::Converter<QXmlQuery::QueryLanguage >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
        } else if (Shiboken::Converter<const QXmlNamePool & >::isConvertible(pyargs[1])) {
            overloadId = 1; // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlQuery & >::isConvertible(pyargs[0])) {
        overloadId = 3; // QXmlQuery(QXmlQuery)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQuery_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlQuery()
            {

                if(!PyErr_Occurred()) {
                // QXmlQuery()
                cptr = new QXmlQuery();
                }
                break;
            }
            case 1: // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "np");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "np";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QXmlQuery::QueryLanguage cpp_arg0 = Shiboken::Converter<QXmlQuery::QueryLanguage >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QXmlNamePool cpp_arg1_tmp = QXmlNamePool();
                QXmlNamePool* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QXmlNamePool* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;

                if(!PyErr_Occurred()) {
                // QXmlQuery(QXmlQuery::QueryLanguage,QXmlNamePool)
                cptr = new QXmlQuery(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // QXmlQuery(QXmlNamePool)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QXmlNamePool* cpp_arg0 = Shiboken::Converter<QXmlNamePool* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QXmlQuery(QXmlNamePool)
                cptr = new QXmlQuery(*cpp_arg0);
                }
                break;
            }
            case 3: // QXmlQuery(QXmlQuery)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QXmlQuery > cpp_arg0_auto_ptr;
                QXmlQuery* cpp_arg0 = Shiboken::Converter<QXmlQuery* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QXmlQuery >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QXmlQuery >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QXmlQuery(QXmlQuery)
                cptr = new QXmlQuery(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlQuery_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlQuery_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QXmlQuery.QueryLanguage, PySide.QtXmlPatterns.QXmlNamePool = QXmlNamePool()", "PySide.QtXmlPatterns.QXmlNamePool", "PySide.QtXmlPatterns.QXmlQuery", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlQuery", overloads);
        return -1;
}

static PyObject* SbkQXmlQueryFunc_bindVariable(PyObject* self, PyObject* args)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "bindVariable", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bindVariable(QString,QIODevice*)
    // 1: bindVariable(QString,QXmlItem)
    // 2: bindVariable(QString,QXmlQuery)
    // 3: bindVariable(QXmlName,QIODevice*)
    // 4: bindVariable(QXmlName,QXmlItem)
    // 5: bindVariable(QXmlName,QXmlQuery)
    if (Shiboken::Converter<const QXmlName & >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<const QXmlQuery & >::isConvertible(pyargs[1])) {
            overloadId = 5; // bindVariable(QXmlName,QXmlQuery)
        } else if (numArgs == 2 && Shiboken::Converter<const QXmlItem & >::isConvertible(pyargs[1])) {
            overloadId = 4; // bindVariable(QXmlName,QXmlItem)
        } else if (numArgs == 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 3; // bindVariable(QXmlName,QIODevice*)
        }
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<const QXmlQuery & >::isConvertible(pyargs[1])) {
            overloadId = 2; // bindVariable(QString,QXmlQuery)
        } else if (numArgs == 2 && Shiboken::Converter<const QXmlItem & >::isConvertible(pyargs[1])) {
            overloadId = 1; // bindVariable(QString,QXmlItem)
        } else if (numArgs == 2 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[1])) {
            overloadId = 0; // bindVariable(QString,QIODevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQueryFunc_bindVariable_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindVariable(QString,QIODevice*)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QIODevice* cpp_arg1 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // bindVariable(QString,QIODevice*)
                cppSelf->QXmlQuery::bindVariable(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // bindVariable(QString,QXmlItem)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QXmlItem > cpp_arg1_auto_ptr;
                QXmlItem* cpp_arg1 = Shiboken::Converter<QXmlItem* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QXmlItem >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QXmlItem >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // bindVariable(QString,QXmlItem)
                cppSelf->QXmlQuery::bindVariable(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // bindVariable(QString,QXmlQuery)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QXmlQuery > cpp_arg1_auto_ptr;
                QXmlQuery* cpp_arg1 = Shiboken::Converter<QXmlQuery* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QXmlQuery >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QXmlQuery >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // bindVariable(QString,QXmlQuery)
                cppSelf->QXmlQuery::bindVariable(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // bindVariable(QXmlName,QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QIODevice* cpp_arg1 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // bindVariable(QXmlName,QIODevice*)
                cppSelf->QXmlQuery::bindVariable(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 4: // bindVariable(QXmlName,QXmlItem)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QXmlItem > cpp_arg1_auto_ptr;
                QXmlItem* cpp_arg1 = Shiboken::Converter<QXmlItem* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QXmlItem >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QXmlItem >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // bindVariable(QXmlName,QXmlItem)
                cppSelf->QXmlQuery::bindVariable(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 5: // bindVariable(QXmlName,QXmlQuery)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QXmlQuery > cpp_arg1_auto_ptr;
                QXmlQuery* cpp_arg1 = Shiboken::Converter<QXmlQuery* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QXmlQuery >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QXmlQuery >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // bindVariable(QXmlName,QXmlQuery)
                cppSelf->QXmlQuery::bindVariable(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlQueryFunc_bindVariable_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice", "QString, PySide.QtXmlPatterns.QXmlItem", "QString, PySide.QtXmlPatterns.QXmlQuery", "PySide.QtXmlPatterns.QXmlName, PySide.QtCore.QIODevice", "PySide.QtXmlPatterns.QXmlName, PySide.QtXmlPatterns.QXmlItem", "PySide.QtXmlPatterns.QXmlName, PySide.QtXmlPatterns.QXmlQuery", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlQuery.bindVariable", overloads);
        return 0;
}

static PyObject* SbkQXmlQueryFunc_evaluateTo(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: evaluateTo(QAbstractXmlReceiver*)const
    // 1: evaluateTo(QIODevice*)const
    // 2: evaluateTo(QString*)const
    // 3: evaluateTo(QStringList*)const
    // 4: evaluateTo(QXmlResultItems*)const
    if (Shiboken::Converter<QXmlResultItems * >::isConvertible(arg)) {
        overloadId = 4; // evaluateTo(QXmlResultItems*)const
    } else if (Shiboken::Converter<QStringList * >::isConvertible(arg)) {
        overloadId = 3; // evaluateTo(QStringList*)const
    } else if (Shiboken::Converter<QString * >::isConvertible(arg)) {
        overloadId = 2; // evaluateTo(QString*)const
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 1; // evaluateTo(QIODevice*)const
    } else if (Shiboken::Converter<QAbstractXmlReceiver * >::isConvertible(arg)) {
        overloadId = 0; // evaluateTo(QAbstractXmlReceiver*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQueryFunc_evaluateTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // evaluateTo(QAbstractXmlReceiver*)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QAbstractXmlReceiver* cpp_arg0 = Shiboken::Converter<QAbstractXmlReceiver* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // evaluateTo(QAbstractXmlReceiver*)const
                bool cppResult = cppSelf->QXmlQuery::evaluateTo(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // evaluateTo(QIODevice*)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // evaluateTo(QIODevice*)const
                bool cppResult = cppSelf->QXmlQuery::evaluateTo(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // evaluateTo(QString*)const
            {
                QString * cpp_arg0 = Shiboken::Converter<QString * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // evaluateTo(QString*)const
                bool cppResult = cppSelf->QXmlQuery::evaluateTo(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // evaluateTo(QStringList*)const
            {
                QStringList * cpp_arg0 = Shiboken::Converter<QStringList * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // evaluateTo(QStringList*)const
                bool cppResult = cppSelf->QXmlQuery::evaluateTo(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 4: // evaluateTo(QXmlResultItems*)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QXmlResultItems* cpp_arg0 = Shiboken::Converter<QXmlResultItems* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // evaluateTo(QXmlResultItems*)const
                cppSelf->QXmlQuery::evaluateTo(cpp_arg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlQueryFunc_evaluateTo_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractXmlReceiver", "PySide.QtCore.QIODevice", "QString", "list", "PySide.QtXmlPatterns.QXmlResultItems", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.evaluateTo", overloads);
        return 0;
}

static PyObject* SbkQXmlQueryFunc_initialTemplateName(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // initialTemplateName()const
            QXmlName cppResult = cppSelf->QXmlQuery::initialTemplateName();
            pyResult = Shiboken::Converter<QXmlName >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlQueryFunc_isValid(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->QXmlQuery::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlQueryFunc_messageHandler(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // messageHandler()const
            QAbstractMessageHandler * cppResult = cppSelf->QXmlQuery::messageHandler();
            pyResult = Shiboken::Converter<QAbstractMessageHandler * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlQueryFunc_namePool(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namePool()const
            QXmlNamePool cppResult = cppSelf->QXmlQuery::namePool();
            pyResult = Shiboken::Converter<QXmlNamePool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlQueryFunc_queryLanguage(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // queryLanguage()const
            QXmlQuery::QueryLanguage cppResult = cppSelf->QXmlQuery::queryLanguage();
            pyResult = Shiboken::Converter<QXmlQuery::QueryLanguage >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlQueryFunc_setFocus(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocus(QIODevice*)
    // 1: setFocus(QString)
    // 2: setFocus(QUrl)
    // 3: setFocus(QXmlItem)
    if (Shiboken::Converter<const QXmlItem & >::isConvertible(arg)) {
        overloadId = 3; // setFocus(QXmlItem)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 1; // setFocus(QString)
    } else if (Shiboken::Converter<const QUrl & >::isConvertible(arg)) {
        overloadId = 2; // setFocus(QUrl)
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setFocus(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQueryFunc_setFocus_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFocus(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setFocus(QIODevice*)
                bool cppResult = cppSelf->QXmlQuery::setFocus(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // setFocus(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setFocus(QString)
                bool cppResult = cppSelf->QXmlQuery::setFocus(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // setFocus(QUrl)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(arg);
                if (!Shiboken::Converter<QUrl >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setFocus(QUrl)
                bool cppResult = cppSelf->QXmlQuery::setFocus(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // setFocus(QXmlItem)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QXmlItem > cpp_arg0_auto_ptr;
                QXmlItem* cpp_arg0 = Shiboken::Converter<QXmlItem* >::toCpp(arg);
                if (!Shiboken::Converter<QXmlItem >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QXmlItem >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setFocus(QXmlItem)
                cppSelf->QXmlQuery::setFocus(*cpp_arg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlQueryFunc_setFocus_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", "QString", "PySide.QtCore.QUrl", "PySide.QtXmlPatterns.QXmlItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setFocus", overloads);
        return 0;
}

static PyObject* SbkQXmlQueryFunc_setInitialTemplateName(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInitialTemplateName(QString)
    // 1: setInitialTemplateName(QXmlName)
    if (Shiboken::Converter<const QXmlName & >::isConvertible(arg)) {
        overloadId = 1; // setInitialTemplateName(QXmlName)
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setInitialTemplateName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQueryFunc_setInitialTemplateName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setInitialTemplateName(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setInitialTemplateName(QString)
                cppSelf->QXmlQuery::setInitialTemplateName(cpp_arg0);
                }
                break;
            }
            case 1: // setInitialTemplateName(QXmlName)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QXmlName* cpp_arg0 = Shiboken::Converter<QXmlName* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setInitialTemplateName(QXmlName)
                cppSelf->QXmlQuery::setInitialTemplateName(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlQueryFunc_setInitialTemplateName_TypeError:
        const char* overloads[] = {"QString", "PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setInitialTemplateName", overloads);
        return 0;
}

static PyObject* SbkQXmlQueryFunc_setMessageHandler(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMessageHandler(QAbstractMessageHandler*)
    if (Shiboken::Converter<QAbstractMessageHandler * >::isConvertible(arg)) {
        overloadId = 0; // setMessageHandler(QAbstractMessageHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQueryFunc_setMessageHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractMessageHandler* cpp_arg0 = Shiboken::Converter<QAbstractMessageHandler* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMessageHandler(QAbstractMessageHandler*)
            cppSelf->QXmlQuery::setMessageHandler(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlQueryFunc_setMessageHandler_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractMessageHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setMessageHandler", overloads);
        return 0;
}

static PyObject* SbkQXmlQueryFunc_setQuery(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "baseURI", "documentURI" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setQuery", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setQuery(QIODevice*,QUrl)
    // 1: setQuery(QString,QUrl)
    // 2: setQuery(QUrl,QUrl)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setQuery(QString,QUrl)
        } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
            overloadId = 1; // setQuery(QString,QUrl)
        }
    } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // setQuery(QUrl,QUrl)
        } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
            overloadId = 2; // setQuery(QUrl,QUrl)
        }
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setQuery(QIODevice*,QUrl)
        } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
            overloadId = 0; // setQuery(QIODevice*,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQueryFunc_setQuery_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setQuery(QIODevice*,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentURI");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentURI";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
                QUrl cpp_arg1_tmp = QUrl();
                QUrl* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QUrl* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setQuery(QIODevice*,QUrl)
                cppSelf->QXmlQuery::setQuery(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // setQuery(QString,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentURI");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentURI";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
                QUrl cpp_arg1_tmp = QUrl();
                QUrl* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QUrl* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setQuery(QString,QUrl)
                cppSelf->QXmlQuery::setQuery(cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // setQuery(QUrl,QUrl)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "baseURI");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "baseURI";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlQuery.setQuery(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QUrl >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
                QUrl cpp_arg1_tmp = QUrl();
                QUrl* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QUrl* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // setQuery(QUrl,QUrl)
                cppSelf->QXmlQuery::setQuery(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlQueryFunc_setQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, PySide.QtCore.QUrl = QUrl()", "QString, PySide.QtCore.QUrl = QUrl()", "PySide.QtCore.QUrl, PySide.QtCore.QUrl = QUrl()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlQuery.setQuery", overloads);
        return 0;
}

static PyObject* SbkQXmlQueryFunc_setUriResolver(PyObject* self, PyObject* arg)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUriResolver(const QAbstractUriResolver*)
    if (Shiboken::Converter<const QAbstractUriResolver * >::isConvertible(arg)) {
        overloadId = 0; // setUriResolver(const QAbstractUriResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlQueryFunc_setUriResolver_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractUriResolver* cpp_arg0 = Shiboken::Converter<QAbstractUriResolver* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUriResolver(const QAbstractUriResolver*)
            cppSelf->QXmlQuery::setUriResolver(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlQueryFunc_setUriResolver_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractUriResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlQuery.setUriResolver", overloads);
        return 0;
}

static PyObject* SbkQXmlQueryFunc_uriResolver(PyObject* self)
{
    QXmlQuery* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlQuery* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // uriResolver()const
            const QAbstractUriResolver * cppResult = cppSelf->QXmlQuery::uriResolver();
            pyResult = Shiboken::Converter<const QAbstractUriResolver * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQXmlQuery_methods[] = {
    {"bindVariable", (PyCFunction)SbkQXmlQueryFunc_bindVariable, METH_VARARGS},
    {"evaluateTo", (PyCFunction)SbkQXmlQueryFunc_evaluateTo, METH_O},
    {"initialTemplateName", (PyCFunction)SbkQXmlQueryFunc_initialTemplateName, METH_NOARGS},
    {"isValid", (PyCFunction)SbkQXmlQueryFunc_isValid, METH_NOARGS},
    {"messageHandler", (PyCFunction)SbkQXmlQueryFunc_messageHandler, METH_NOARGS},
    {"namePool", (PyCFunction)SbkQXmlQueryFunc_namePool, METH_NOARGS},
    {"queryLanguage", (PyCFunction)SbkQXmlQueryFunc_queryLanguage, METH_NOARGS},
    {"setFocus", (PyCFunction)SbkQXmlQueryFunc_setFocus, METH_O},
    {"setInitialTemplateName", (PyCFunction)SbkQXmlQueryFunc_setInitialTemplateName, METH_O},
    {"setMessageHandler", (PyCFunction)SbkQXmlQueryFunc_setMessageHandler, METH_O},
    {"setQuery", (PyCFunction)SbkQXmlQueryFunc_setQuery, METH_VARARGS|METH_KEYWORDS},
    {"setUriResolver", (PyCFunction)SbkQXmlQueryFunc_setUriResolver, METH_O},
    {"uriResolver", (PyCFunction)SbkQXmlQueryFunc_uriResolver, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlQuery_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlQuery",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlQuery_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlQuery_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlQuery >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlQuery",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "QueryLanguage",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QXmlQuery(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLQUERY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlQuery_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlQuery_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlQuery_Type));
    PyModule_AddObject(module, "QXmlQuery",
        ((PyObject*)&SbkQXmlQuery_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: QueryLanguage
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLQUERY_QUERYLANGUAGE_IDX] = &SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type);
    PyDict_SetItemString(SbkQXmlQuery_Type.super.ht_type.tp_dict,
            "QueryLanguage",((PyObject*)&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type,
        (long) QXmlQuery::XQuery10, "XQuery10");
    PyDict_SetItemString(SbkQXmlQuery_Type.super.ht_type.tp_dict,
        "XQuery10", enum_item);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type.tp_dict,
        "XQuery10", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type,
        (long) QXmlQuery::XSLT20, "XSLT20");
    PyDict_SetItemString(SbkQXmlQuery_Type.super.ht_type.tp_dict,
        "XSLT20", enum_item);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type.tp_dict,
        "XSLT20", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type,
        (long) QXmlQuery::XmlSchema11IdentityConstraintSelector, "XmlSchema11IdentityConstraintSelector");
    PyDict_SetItemString(SbkQXmlQuery_Type.super.ht_type.tp_dict,
        "XmlSchema11IdentityConstraintSelector", enum_item);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type.tp_dict,
        "XmlSchema11IdentityConstraintSelector", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type,
        (long) QXmlQuery::XmlSchema11IdentityConstraintField, "XmlSchema11IdentityConstraintField");
    PyDict_SetItemString(SbkQXmlQuery_Type.super.ht_type.tp_dict,
        "XmlSchema11IdentityConstraintField", enum_item);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type.tp_dict,
        "XmlSchema11IdentityConstraintField", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type,
        (long) QXmlQuery::XPath20, "XPath20");
    PyDict_SetItemString(SbkQXmlQuery_Type.super.ht_type.tp_dict,
        "XPath20", enum_item);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlQuery_QueryLanguage_Type.tp_dict,
        "XPath20", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlQuery::QueryLanguage");


    Shiboken::TypeResolver::createValueTypeResolver<QXmlQuery >("QXmlQuery");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlQuery >("QXmlQuery*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlQuery >(typeid(QXmlQuery).name());
    PySide::initQtMetaType<QXmlQuery >();
}

