/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlschemavalidator_wrapper.h"

// Extra includes
#include <qabstractmessagehandler.h>
#include <qabstracturiresolver.h>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qurl.h>
#include <qxmlnamepool.h>
#include <qxmlschema.h>
#include <qxmlschemavalidator.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQXmlSchemaValidator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlSchemaValidator >()))
        return -1;

    QXmlSchemaValidator* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlSchemaValidator", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QXmlSchemaValidator()
    // 1: QXmlSchemaValidator(QXmlSchema)
    if (numArgs == 0) {
        overloadId = 0; // QXmlSchemaValidator()
    } else if (numArgs == 1 && Shiboken::Converter<const QXmlSchema & >::isConvertible(arg)) {
        overloadId = 1; // QXmlSchemaValidator(QXmlSchema)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSchemaValidator_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlSchemaValidator()
            {

                if(!PyErr_Occurred()) {
                // QXmlSchemaValidator()
                cptr = new QXmlSchemaValidator();
                }
                break;
            }
            case 1: // QXmlSchemaValidator(QXmlSchema)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QXmlSchema* cpp_arg0 = Shiboken::Converter<QXmlSchema* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QXmlSchemaValidator(QXmlSchema)
                cptr = new QXmlSchemaValidator(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlSchemaValidator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQXmlSchemaValidator_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQXmlSchemaValidator_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QXmlSchema", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSchemaValidator", overloads);
        return -1;
}

static PyObject* SbkQXmlSchemaValidatorFunc_messageHandler(PyObject* self)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // messageHandler()const
            QAbstractMessageHandler * cppResult = cppSelf->QXmlSchemaValidator::messageHandler();
            pyResult = Shiboken::Converter<QAbstractMessageHandler * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSchemaValidatorFunc_namePool(PyObject* self)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // namePool()const
            QXmlNamePool cppResult = cppSelf->QXmlSchemaValidator::namePool();
            pyResult = Shiboken::Converter<QXmlNamePool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSchemaValidatorFunc_schema(PyObject* self)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // schema()const
            QXmlSchema cppResult = cppSelf->QXmlSchemaValidator::schema();
            pyResult = Shiboken::Converter<QXmlSchema >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSchemaValidatorFunc_setMessageHandler(PyObject* self, PyObject* arg)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMessageHandler(QAbstractMessageHandler*)
    if (Shiboken::Converter<QAbstractMessageHandler * >::isConvertible(arg)) {
        overloadId = 0; // setMessageHandler(QAbstractMessageHandler*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSchemaValidatorFunc_setMessageHandler_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractMessageHandler* cpp_arg0 = Shiboken::Converter<QAbstractMessageHandler* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMessageHandler(QAbstractMessageHandler*)
            cppSelf->QXmlSchemaValidator::setMessageHandler(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSchemaValidatorFunc_setMessageHandler_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractMessageHandler", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSchemaValidator.setMessageHandler", overloads);
        return 0;
}

static PyObject* SbkQXmlSchemaValidatorFunc_setSchema(PyObject* self, PyObject* arg)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSchema(QXmlSchema)
    if (Shiboken::Converter<const QXmlSchema & >::isConvertible(arg)) {
        overloadId = 0; // setSchema(QXmlSchema)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSchemaValidatorFunc_setSchema_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QXmlSchema* cpp_arg0 = Shiboken::Converter<QXmlSchema* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSchema(QXmlSchema)
            cppSelf->QXmlSchemaValidator::setSchema(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSchemaValidatorFunc_setSchema_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlSchema", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSchemaValidator.setSchema", overloads);
        return 0;
}

static PyObject* SbkQXmlSchemaValidatorFunc_setUriResolver(PyObject* self, PyObject* arg)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUriResolver(const QAbstractUriResolver*)
    if (Shiboken::Converter<const QAbstractUriResolver * >::isConvertible(arg)) {
        overloadId = 0; // setUriResolver(const QAbstractUriResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSchemaValidatorFunc_setUriResolver_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractUriResolver* cpp_arg0 = Shiboken::Converter<QAbstractUriResolver* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUriResolver(const QAbstractUriResolver*)
            cppSelf->QXmlSchemaValidator::setUriResolver(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQXmlSchemaValidatorFunc_setUriResolver_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QAbstractUriResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlSchemaValidator.setUriResolver", overloads);
        return 0;
}

static PyObject* SbkQXmlSchemaValidatorFunc_uriResolver(PyObject* self)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // uriResolver()const
            const QAbstractUriResolver * cppResult = cppSelf->QXmlSchemaValidator::uriResolver();
            pyResult = Shiboken::Converter<const QAbstractUriResolver * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQXmlSchemaValidatorFunc_validate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlSchemaValidator* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QXmlSchemaValidator* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "documentUri" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchemaValidator.validate(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchemaValidator.validate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchemaValidator.validate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:validate", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: validate(QIODevice*,QUrl)const
    // 1: validate(QByteArray,QUrl)const
    // 2: validate(QUrl)const
    if (numArgs == 1 && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[0])) {
        overloadId = 2; // validate(QUrl)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // validate(QByteArray,QUrl)const
        } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
            overloadId = 1; // validate(QByteArray,QUrl)const
        }
    } else if (Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // validate(QIODevice*,QUrl)const
        } else if (Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
            overloadId = 0; // validate(QIODevice*,QUrl)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQXmlSchemaValidatorFunc_validate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // validate(QIODevice*,QUrl)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentUri");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentUri";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchemaValidator.validate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
                QUrl cpp_arg1_tmp = QUrl();
                QUrl* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QUrl* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // validate(QIODevice*,QUrl)const
                bool cppResult = cppSelf->QXmlSchemaValidator::validate(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // validate(QByteArray,QUrl)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "documentUri");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "documentUri";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QXmlSchemaValidator.validate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
                QUrl cpp_arg1_tmp = QUrl();
                QUrl* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QUrl* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // validate(QByteArray,QUrl)const
                bool cppResult = cppSelf->QXmlSchemaValidator::validate(*cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // validate(QUrl)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QUrl >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // validate(QUrl)const
                bool cppResult = cppSelf->QXmlSchemaValidator::validate(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQXmlSchemaValidatorFunc_validate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, PySide.QtCore.QUrl = QUrl()", "PySide.QtCore.QByteArray, PySide.QtCore.QUrl = QUrl()", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlSchemaValidator.validate", overloads);
        return 0;
}

static PyMethodDef SbkQXmlSchemaValidator_methods[] = {
    {"messageHandler", (PyCFunction)SbkQXmlSchemaValidatorFunc_messageHandler, METH_NOARGS},
    {"namePool", (PyCFunction)SbkQXmlSchemaValidatorFunc_namePool, METH_NOARGS},
    {"schema", (PyCFunction)SbkQXmlSchemaValidatorFunc_schema, METH_NOARGS},
    {"setMessageHandler", (PyCFunction)SbkQXmlSchemaValidatorFunc_setMessageHandler, METH_O},
    {"setSchema", (PyCFunction)SbkQXmlSchemaValidatorFunc_setSchema, METH_O},
    {"setUriResolver", (PyCFunction)SbkQXmlSchemaValidatorFunc_setUriResolver, METH_O},
    {"uriResolver", (PyCFunction)SbkQXmlSchemaValidatorFunc_uriResolver, METH_NOARGS},
    {"validate", (PyCFunction)SbkQXmlSchemaValidatorFunc_validate, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQXmlSchemaValidator_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlSchemaValidator",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQXmlSchemaValidator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQXmlSchemaValidator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QXmlSchemaValidator >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QXmlSchemaValidator*",
    /*user_data*/           0
};
} //extern


void init_QXmlSchemaValidator(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLSCHEMAVALIDATOR_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQXmlSchemaValidator_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQXmlSchemaValidator_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQXmlSchemaValidator_Type));
    PyModule_AddObject(module, "QXmlSchemaValidator",
        ((PyObject*)&SbkQXmlSchemaValidator_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSchemaValidator >("QXmlSchemaValidator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlSchemaValidator >(typeid(QXmlSchemaValidator).name());
    PySide::initQtMetaType<QXmlSchemaValidator* >();
}

