/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_phonon_python.h"

#include "phonon_abstractmediastream_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Shiboken;
using namespace Phonon;

// Native ---------------------------------------------------------

AbstractMediaStreamWrapper::AbstractMediaStreamWrapper(QObject * parent) : Phonon::AbstractMediaStream(parent), m_metaObject(0) {
    // ... middle
}

void AbstractMediaStreamWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void AbstractMediaStreamWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AbstractMediaStreamWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void AbstractMediaStreamWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AbstractMediaStreamWrapper::enoughData()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enoughData"));
    if (py_override.isNull()) {
        return this->Phonon::AbstractMediaStream::enoughData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool AbstractMediaStreamWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "AbstractMediaStream.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool AbstractMediaStreamWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "AbstractMediaStream.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void AbstractMediaStreamWrapper::needData()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "needData"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AbstractMediaStream.needData()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AbstractMediaStreamWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AbstractMediaStream.reset()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AbstractMediaStreamWrapper::seekStream(qint64 offset)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "seekStream"));
    if (py_override.isNull()) {
        return this->Phonon::AbstractMediaStream::seekStream(offset);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(offset)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AbstractMediaStreamWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* AbstractMediaStreamWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &Phonon::AbstractMediaStream::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int AbstractMediaStreamWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = Phonon::AbstractMediaStream::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

AbstractMediaStreamWrapper::~AbstractMediaStreamWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_AbstractMediaStream_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::AbstractMediaStream >()))
        return -1;

    AbstractMediaStreamWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_ABSTRACTMEDIASTREAM_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::AbstractMediaStream' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:AbstractMediaStream", &arg))
        return -1;

    // Overloaded function decisor
    // 0: AbstractMediaStream(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // AbstractMediaStream(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // AbstractMediaStream(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AbstractMediaStream_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.AbstractMediaStream(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // AbstractMediaStream(QObject*)
            cptr = new AbstractMediaStreamWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::AbstractMediaStream >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkPhonon_AbstractMediaStream_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkPhonon_AbstractMediaStream_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.AbstractMediaStream", overloads);
        return -1;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_endOfData(PyObject* self)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endOfData()
            cppSelf->Phonon::AbstractMediaStream::endOfData();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_enoughData(PyObject* self)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // enoughData()
            cppSelf->Phonon::AbstractMediaStream::enoughData();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_error(PyObject* self, PyObject* args)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "error", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: error(Phonon::ErrorType,QString)
    if (numArgs == 2 && Shiboken::Converter<Phonon::ErrorType >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // error(Phonon::ErrorType,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AbstractMediaStreamFunc_error_TypeError;

    // Call function/method
    {
        {
            Phonon::ErrorType cpp_arg0 = Shiboken::Converter<Phonon::ErrorType >::toCpp(pyargs[0]);
            QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // error(Phonon::ErrorType,QString)
            cppSelf->Phonon::AbstractMediaStream::error(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AbstractMediaStreamFunc_error_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.ErrorType, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.AbstractMediaStream.error", overloads);
        return 0;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_needData(PyObject* self)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // needData()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AbstractMediaStream.needData()' not implemented.");
                return 0;
            }
            cppSelf->needData();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_reset(PyObject* self)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'AbstractMediaStream.reset()' not implemented.");
                return 0;
            }
            cppSelf->reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_seekStream(PyObject* self, PyObject* arg)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: seekStream(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seekStream(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AbstractMediaStreamFunc_seekStream_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // seekStream(qint64)
            cppSelf->Phonon::AbstractMediaStream::seekStream(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AbstractMediaStreamFunc_seekStream_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AbstractMediaStream.seekStream", overloads);
        return 0;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_setStreamSeekable(PyObject* self, PyObject* arg)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStreamSeekable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStreamSeekable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AbstractMediaStreamFunc_setStreamSeekable_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStreamSeekable(bool)
            cppSelf->Phonon::AbstractMediaStream::setStreamSeekable(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AbstractMediaStreamFunc_setStreamSeekable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AbstractMediaStream.setStreamSeekable", overloads);
        return 0;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_setStreamSize(PyObject* self, PyObject* arg)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStreamSize(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStreamSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AbstractMediaStreamFunc_setStreamSize_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStreamSize(qint64)
            cppSelf->Phonon::AbstractMediaStream::setStreamSize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AbstractMediaStreamFunc_setStreamSize_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AbstractMediaStream.setStreamSize", overloads);
        return 0;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_streamSeekable(PyObject* self)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // streamSeekable()const
            bool cppResult = cppSelf->Phonon::AbstractMediaStream::streamSeekable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_streamSize(PyObject* self)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // streamSize()const
            qint64 cppResult = cppSelf->Phonon::AbstractMediaStream::streamSize();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_AbstractMediaStreamFunc_writeData(PyObject* self, PyObject* arg)
{
    Phonon::AbstractMediaStream* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: writeData(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // writeData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AbstractMediaStreamFunc_writeData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // writeData(QByteArray)
            cppSelf->Phonon::AbstractMediaStream::writeData(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AbstractMediaStreamFunc_writeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AbstractMediaStream.writeData", overloads);
        return 0;
}

static PyMethodDef SbkPhonon_AbstractMediaStream_methods[] = {
    {"endOfData", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_endOfData, METH_NOARGS},
    {"enoughData", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_enoughData, METH_NOARGS},
    {"error", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_error, METH_VARARGS},
    {"needData", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_needData, METH_NOARGS},
    {"reset", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_reset, METH_NOARGS},
    {"seekStream", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_seekStream, METH_O},
    {"setStreamSeekable", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_setStreamSeekable, METH_O},
    {"setStreamSize", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_setStreamSize, METH_O},
    {"streamSeekable", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_streamSeekable, METH_NOARGS},
    {"streamSize", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_streamSize, METH_NOARGS},
    {"writeData", (PyCFunction)SbkPhonon_AbstractMediaStreamFunc_writeData, METH_O},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_AbstractMediaStream_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.AbstractMediaStream",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_AbstractMediaStream_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_AbstractMediaStream_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::AbstractMediaStream >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::AbstractMediaStream*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkPhonon_AbstractMediaStream_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<Phonon::AbstractMediaStream*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkPhonon_AbstractMediaStream_Type;
    return 0;
}


void init_Phonon_AbstractMediaStream(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_ABSTRACTMEDIASTREAM_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_AbstractMediaStream_Type);

    SbkPhonon_AbstractMediaStream_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkPhonon_AbstractMediaStream_Type.type_discovery = &SbkPhonon_AbstractMediaStream_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkPhonon_AbstractMediaStream_Type);

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_AbstractMediaStream_Type) < 0)
        return;

    PyDict_SetItemString(module,"AbstractMediaStream", (PyObject*)&SbkPhonon_AbstractMediaStream_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AbstractMediaStream >("Phonon::AbstractMediaStream*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AbstractMediaStream >(typeid(Phonon::AbstractMediaStream).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AbstractMediaStream >(typeid(AbstractMediaStreamWrapper).name());
    PySide::initQtMetaType<Phonon::AbstractMediaStream* >();
}

