/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_phonon_python.h"

#include "phonon_audiooutput_wrapper.h"

// Extra includes
#include <QList>
#include <objectdescription.h>
#include <path.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

using namespace Shiboken;
using namespace Phonon;

// Native ---------------------------------------------------------

AudioOutputWrapper::AudioOutputWrapper(Phonon::Category category, QObject * parent) : Phonon::AudioOutput(category, parent), m_metaObject(0) {
    // ... middle
}

AudioOutputWrapper::AudioOutputWrapper(QObject * parent) : Phonon::AudioOutput(parent), m_metaObject(0) {
    // ... middle
}

void AudioOutputWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AudioOutputWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AudioOutputWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void AudioOutputWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool AudioOutputWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "AudioOutput.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool AudioOutputWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "AudioOutput.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void AudioOutputWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

const QMetaObject* AudioOutputWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &Phonon::AudioOutput::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int AudioOutputWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = Phonon::AudioOutput::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

AudioOutputWrapper::~AudioOutputWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_AudioOutput_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::AudioOutput >()))
        return -1;

    AudioOutputWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:AudioOutput", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: AudioOutput(Phonon::Category,QObject*)
    // 1: AudioOutput(QObject*)
    if (numArgs == 0) {
        overloadId = 1; // AudioOutput(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 1; // AudioOutput(QObject*)
    } else if (Shiboken::Converter<Phonon::Category >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // AudioOutput(Phonon::Category,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 0; // AudioOutput(Phonon::Category,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AudioOutput_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // AudioOutput(Phonon::Category,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.phonon.AudioOutput(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                Phonon::Category cpp_arg0 = Shiboken::Converter<Phonon::Category >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // AudioOutput(Phonon::Category,QObject*)
                cptr = new AudioOutputWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // AudioOutput(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.phonon.AudioOutput(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // AudioOutput(QObject*)
                cptr = new AudioOutputWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::AudioOutput >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkPhonon_AudioOutput_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkPhonon_AudioOutput_Init_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon.Category, PySide.QtCore.QObject = None", "PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.AudioOutput", overloads);
        return -1;
}

static PyObject* SbkPhonon_AudioOutputFunc_category(PyObject* self)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // category()const
            Phonon::Category cppResult = cppSelf->Phonon::AudioOutput::category();
            pyResult = Shiboken::Converter<Phonon::Category >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_AudioOutputFunc_isMuted(PyObject* self)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isMuted()const
            bool cppResult = cppSelf->Phonon::AudioOutput::isMuted();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_AudioOutputFunc_name(PyObject* self)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->Phonon::AudioOutput::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_AudioOutputFunc_outputDevice(PyObject* self)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // outputDevice()const
            Phonon::AudioOutputDevice cppResult = cppSelf->Phonon::AudioOutput::outputDevice();
            pyResult = Shiboken::Converter<Phonon::AudioOutputDevice >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_AudioOutputFunc_setMuted(PyObject* self, PyObject* arg)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMuted(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMuted(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AudioOutputFunc_setMuted_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMuted(bool)
            cppSelf->Phonon::AudioOutput::setMuted(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AudioOutputFunc_setMuted_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AudioOutput.setMuted", overloads);
        return 0;
}

static PyObject* SbkPhonon_AudioOutputFunc_setName(PyObject* self, PyObject* arg)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AudioOutputFunc_setName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setName(QString)
            cppSelf->Phonon::AudioOutput::setName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AudioOutputFunc_setName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AudioOutput.setName", overloads);
        return 0;
}

static PyObject* SbkPhonon_AudioOutputFunc_setOutputDevice(PyObject* self, PyObject* arg)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOutputDevice(Phonon::AudioOutputDevice)
    if (Shiboken::Converter<const Phonon::AudioOutputDevice & >::isConvertible(arg)) {
        overloadId = 0; // setOutputDevice(Phonon::AudioOutputDevice)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AudioOutputFunc_setOutputDevice_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            Phonon::AudioOutputDevice* cpp_arg0 = Shiboken::Converter<Phonon::AudioOutputDevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOutputDevice(Phonon::AudioOutputDevice)
            bool cppResult = cppSelf->Phonon::AudioOutput::setOutputDevice(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_AudioOutputFunc_setOutputDevice_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::AudioOutputDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AudioOutput.setOutputDevice", overloads);
        return 0;
}

static PyObject* SbkPhonon_AudioOutputFunc_setVolume(PyObject* self, PyObject* arg)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVolume(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVolume(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AudioOutputFunc_setVolume_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVolume(qreal)
            cppSelf->Phonon::AudioOutput::setVolume(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AudioOutputFunc_setVolume_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AudioOutput.setVolume", overloads);
        return 0;
}

static PyObject* SbkPhonon_AudioOutputFunc_setVolumeDecibel(PyObject* self, PyObject* arg)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVolumeDecibel(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVolumeDecibel(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_AudioOutputFunc_setVolumeDecibel_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVolumeDecibel(qreal)
            cppSelf->Phonon::AudioOutput::setVolumeDecibel(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_AudioOutputFunc_setVolumeDecibel_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.AudioOutput.setVolumeDecibel", overloads);
        return 0;
}

static PyObject* SbkPhonon_AudioOutputFunc_volume(PyObject* self)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // volume()const
            qreal cppResult = cppSelf->Phonon::AudioOutput::volume();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_AudioOutputFunc_volumeDecibel(PyObject* self)
{
    Phonon::AudioOutput* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::AudioOutput* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // volumeDecibel()const
            qreal cppResult = cppSelf->Phonon::AudioOutput::volumeDecibel();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkPhonon_AudioOutput_methods[] = {
    {"category", (PyCFunction)SbkPhonon_AudioOutputFunc_category, METH_NOARGS},
    {"isMuted", (PyCFunction)SbkPhonon_AudioOutputFunc_isMuted, METH_NOARGS},
    {"name", (PyCFunction)SbkPhonon_AudioOutputFunc_name, METH_NOARGS},
    {"outputDevice", (PyCFunction)SbkPhonon_AudioOutputFunc_outputDevice, METH_NOARGS},
    {"setMuted", (PyCFunction)SbkPhonon_AudioOutputFunc_setMuted, METH_O},
    {"setName", (PyCFunction)SbkPhonon_AudioOutputFunc_setName, METH_O},
    {"setOutputDevice", (PyCFunction)SbkPhonon_AudioOutputFunc_setOutputDevice, METH_O},
    {"setVolume", (PyCFunction)SbkPhonon_AudioOutputFunc_setVolume, METH_O},
    {"setVolumeDecibel", (PyCFunction)SbkPhonon_AudioOutputFunc_setVolumeDecibel, METH_O},
    {"volume", (PyCFunction)SbkPhonon_AudioOutputFunc_volume, METH_NOARGS},
    {"volumeDecibel", (PyCFunction)SbkPhonon_AudioOutputFunc_volumeDecibel, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkPhonon_AudioOutputSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    Phonon::AudioOutput* me = reinterpret_cast<Phonon::AudioOutput*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_ABSTRACTAUDIOOUTPUT_IDX]))
        return static_cast<Phonon::AbstractAudioOutput*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX]))
        return static_cast<Phonon::MediaNode*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_AudioOutput_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.AudioOutput",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_AudioOutput_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_AudioOutput_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkPhonon_AudioOutputSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::AudioOutput >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::AudioOutput*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkPhonon_AudioOutput_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<Phonon::AudioOutput*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkPhonon_AudioOutput_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<Phonon::MediaNode >()) && dynamic_cast<Phonon::AudioOutput*>(reinterpret_cast<Phonon::MediaNode*>(cptr)))
        return &SbkPhonon_AudioOutput_Type;
    return 0;
}


void init_Phonon_AudioOutput(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_AUDIOOUTPUT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_AudioOutput_Type);

    SbkPhonon_AudioOutput_Type.super.ht_type.tp_base = SbkPySide_phononTypes[SBK_PHONON_ABSTRACTAUDIOOUTPUT_IDX];
    SbkPhonon_AudioOutput_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_ABSTRACTAUDIOOUTPUT_IDX])->mi_init;

    // Fill type discovery information
    SbkPhonon_AudioOutput_Type.type_discovery = &SbkPhonon_AudioOutput_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_ABSTRACTAUDIOOUTPUT_IDX]), &SbkPhonon_AudioOutput_Type);

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_AudioOutput_Type) < 0)
        return;

    PyDict_SetItemString(module,"AudioOutput", (PyObject*)&SbkPhonon_AudioOutput_Type);
    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("volumeChanged", "qreal", NULL);
    PyDict_SetItemString(SbkPhonon_AudioOutput_Type.super.ht_type.tp_dict, "volumeChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("mutedChanged", "bool", NULL);
    PyDict_SetItemString(SbkPhonon_AudioOutput_Type.super.ht_type.tp_dict, "mutedChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("outputDeviceChanged", "const Phonon::AudioOutputDevice&", NULL);
    PyDict_SetItemString(SbkPhonon_AudioOutput_Type.super.ht_type.tp_dict, "outputDeviceChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AudioOutput >("Phonon::AudioOutput*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AudioOutput >(typeid(Phonon::AudioOutput).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::AudioOutput >(typeid(AudioOutputWrapper).name());
    PySide::initQtMetaType<Phonon::AudioOutput* >();
}

