/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_phonon_python.h"

#include "phonon_mediaobject_wrapper.h"

// Extra includes
#include <QList>
#include <QMultiMap>
#include <QStringList>
#include <mediasource.h>
#include <path.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>

using namespace Shiboken;
using namespace Phonon;

// Native ---------------------------------------------------------

MediaObjectWrapper::MediaObjectWrapper(QObject * parent) : Phonon::MediaObject(parent), m_metaObject(0) {
    // ... middle
}

void MediaObjectWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool MediaObjectWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObject.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool MediaObjectWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObject.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void MediaObjectWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

const QMetaObject* MediaObjectWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &Phonon::MediaObject::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int MediaObjectWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = Phonon::MediaObject::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

MediaObjectWrapper::~MediaObjectWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_MediaObject_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::MediaObject >()))
        return -1;

    MediaObjectWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECT_IDX]);
    if (type != myType) {
        type->mi_init = myType->mi_init;
        type->mi_offsets = myType->mi_offsets;
        type->mi_specialcast = myType->mi_specialcast;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:MediaObject", &arg))
        return -1;

    // Overloaded function decisor
    // 0: MediaObject(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // MediaObject(QObject*)
    } else if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // MediaObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObject_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.MediaObject(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QObject* cpp_arg0 = arg ? Shiboken::Converter<QObject* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // MediaObject(QObject*)
            cptr = new MediaObjectWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::MediaObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkPhonon_MediaObject_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkPhonon_MediaObject_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.MediaObject", overloads);
        return -1;
}

static PyObject* SbkPhonon_MediaObjectFunc_clear(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->Phonon::MediaObject::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectFunc_clearQueue(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearQueue()
            cppSelf->Phonon::MediaObject::clearQueue();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectFunc_currentSource(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentSource()const
            Phonon::MediaSource cppResult = cppSelf->Phonon::MediaObject::currentSource();
            pyResult = Shiboken::Converter<Phonon::MediaSource >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_currentTime(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentTime()const
            qint64 cppResult = cppSelf->Phonon::MediaObject::currentTime();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_enqueue(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: enqueue(Phonon::MediaSource)
    // 1: enqueue(QList<Phonon::MediaSource>)
    // 2: enqueue(QList<QUrl>)
    if (Shiboken::Converter<const Phonon::MediaSource & >::isConvertible(arg)) {
        overloadId = 0; // enqueue(Phonon::MediaSource)
    } else if (Shiboken::Converter< QList<Phonon::MediaSource >  >::isConvertible(arg)) {
        overloadId = 1; // enqueue(QList<Phonon::MediaSource>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_enqueue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // enqueue(Phonon::MediaSource)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<Phonon::MediaSource > cpp_arg0_auto_ptr;
                Phonon::MediaSource* cpp_arg0 = Shiboken::Converter<Phonon::MediaSource* >::toCpp(arg);
                if (!Shiboken::Converter<Phonon::MediaSource >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<Phonon::MediaSource >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // enqueue(Phonon::MediaSource)
                cppSelf->Phonon::MediaObject::enqueue(*cpp_arg0);
                }
                break;
            }
            case 1: // enqueue(QList<Phonon::MediaSource>)
            {
                QList<Phonon::MediaSource > cpp_arg0 = Shiboken::Converter<QList<Phonon::MediaSource > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // enqueue(QList<Phonon::MediaSource>)
                cppSelf->Phonon::MediaObject::enqueue(cpp_arg0);
                }
                break;
            }
            case 2: // enqueue(QList<QUrl>)
            {
                QList<QUrl > cpp_arg0 = Shiboken::Converter<QList<QUrl > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // enqueue(QList<QUrl>)
                cppSelf->Phonon::MediaObject::enqueue(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectFunc_enqueue_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaSource", "list", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.enqueue", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_errorString(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            QString cppResult = cppSelf->Phonon::MediaObject::errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_errorType(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorType()const
            Phonon::ErrorType cppResult = cppSelf->Phonon::MediaObject::errorType();
            pyResult = Shiboken::Converter<Phonon::ErrorType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_hasVideo(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasVideo()const
            bool cppResult = cppSelf->Phonon::MediaObject::hasVideo();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_isSeekable(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSeekable()const
            bool cppResult = cppSelf->Phonon::MediaObject::isSeekable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_metaData(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: metaData()const
    // 1: metaData(Phonon::MetaData)const
    // 2: metaData(QString)const
    if (numArgs == 0) {
        overloadId = 0; // metaData()const
    } else if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 2; // metaData(QString)const
    } else if (Shiboken::Converter<Phonon::MetaData >::isConvertible(arg)) {
        overloadId = 1; // metaData(Phonon::MetaData)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_metaData_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // metaData()const
            {

                if(!PyErr_Occurred()) {
                // metaData()const
                QMultiMap<QString, QString > cppResult = cppSelf->Phonon::MediaObject::metaData();
                pyResult = Shiboken::Converter<QMultiMap<QString, QString > >::toPython(cppResult);
                }
                break;
            }
            case 1: // metaData(Phonon::MetaData)const
            {
                Phonon::MetaData cpp_arg0 = Shiboken::Converter<Phonon::MetaData >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // metaData(Phonon::MetaData)const
                QStringList cppResult = cppSelf->Phonon::MediaObject::metaData(cpp_arg0);
                pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
                }
                break;
            }
            case 2: // metaData(QString)const
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // metaData(QString)const
                QStringList cppResult = cppSelf->Phonon::MediaObject::metaData(cpp_arg0);
                pyResult = Shiboken::Converter<QStringList >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_MediaObjectFunc_metaData_TypeError:
        const char* overloads[] = {"", "PySide.phonon.Phonon.MetaData", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.metaData", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_pause(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pause()
            cppSelf->Phonon::MediaObject::pause();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectFunc_play(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // play()
            cppSelf->Phonon::MediaObject::play();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectFunc_prefinishMark(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prefinishMark()const
            qint32 cppResult = cppSelf->Phonon::MediaObject::prefinishMark();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_queue(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // queue()const
            QList<Phonon::MediaSource > cppResult = cppSelf->Phonon::MediaObject::queue();
            pyResult = Shiboken::Converter<QList<Phonon::MediaSource > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_remainingTime(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // remainingTime()const
            qint64 cppResult = cppSelf->Phonon::MediaObject::remainingTime();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_seek(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_seek_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // seek(qint64)
            cppSelf->Phonon::MediaObject::seek(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.seek", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_setCurrentSource(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentSource(Phonon::MediaSource)
    if (Shiboken::Converter<const Phonon::MediaSource & >::isConvertible(arg)) {
        overloadId = 0; // setCurrentSource(Phonon::MediaSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_setCurrentSource_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<Phonon::MediaSource > cpp_arg0_auto_ptr;
            Phonon::MediaSource* cpp_arg0 = Shiboken::Converter<Phonon::MediaSource* >::toCpp(arg);
            if (!Shiboken::Converter<Phonon::MediaSource >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<Phonon::MediaSource >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setCurrentSource(Phonon::MediaSource)
            cppSelf->Phonon::MediaObject::setCurrentSource(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectFunc_setCurrentSource_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaSource", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.setCurrentSource", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_setPrefinishMark(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrefinishMark(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPrefinishMark(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_setPrefinishMark_TypeError;

    // Call function/method
    {
        {
            qint32 cpp_arg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPrefinishMark(qint32)
            cppSelf->Phonon::MediaObject::setPrefinishMark(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectFunc_setPrefinishMark_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.setPrefinishMark", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_setQueue(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQueue(QList<Phonon::MediaSource>)
    // 1: setQueue(QList<QUrl>)
    if (Shiboken::Converter< QList<Phonon::MediaSource >  >::isConvertible(arg)) {
        overloadId = 0; // setQueue(QList<Phonon::MediaSource>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_setQueue_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setQueue(QList<Phonon::MediaSource>)
            {
                QList<Phonon::MediaSource > cpp_arg0 = Shiboken::Converter<QList<Phonon::MediaSource > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setQueue(QList<Phonon::MediaSource>)
                cppSelf->Phonon::MediaObject::setQueue(cpp_arg0);
                }
                break;
            }
            case 1: // setQueue(QList<QUrl>)
            {
                QList<QUrl > cpp_arg0 = Shiboken::Converter<QList<QUrl > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setQueue(QList<QUrl>)
                cppSelf->Phonon::MediaObject::setQueue(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectFunc_setQueue_TypeError:
        const char* overloads[] = {"list", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.setQueue", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_setTickInterval(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTickInterval(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTickInterval(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_setTickInterval_TypeError;

    // Call function/method
    {
        {
            qint32 cpp_arg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTickInterval(qint32)
            cppSelf->Phonon::MediaObject::setTickInterval(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectFunc_setTickInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.setTickInterval", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_setTransitionTime(PyObject* self, PyObject* arg)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransitionTime(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTransitionTime(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectFunc_setTransitionTime_TypeError;

    // Call function/method
    {
        {
            qint32 cpp_arg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTransitionTime(qint32)
            cppSelf->Phonon::MediaObject::setTransitionTime(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectFunc_setTransitionTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObject.setTransitionTime", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectFunc_state(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            Phonon::State cppResult = cppSelf->Phonon::MediaObject::state();
            pyResult = Shiboken::Converter<Phonon::State >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_stop(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stop()
            cppSelf->Phonon::MediaObject::stop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectFunc_tickInterval(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tickInterval()const
            qint32 cppResult = cppSelf->Phonon::MediaObject::tickInterval();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_totalTime(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // totalTime()const
            qint64 cppResult = cppSelf->Phonon::MediaObject::totalTime();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectFunc_transitionTime(PyObject* self)
{
    Phonon::MediaObject* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transitionTime()const
            qint32 cppResult = cppSelf->Phonon::MediaObject::transitionTime();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkPhonon_MediaObject_methods[] = {
    {"clear", (PyCFunction)SbkPhonon_MediaObjectFunc_clear, METH_NOARGS},
    {"clearQueue", (PyCFunction)SbkPhonon_MediaObjectFunc_clearQueue, METH_NOARGS},
    {"currentSource", (PyCFunction)SbkPhonon_MediaObjectFunc_currentSource, METH_NOARGS},
    {"currentTime", (PyCFunction)SbkPhonon_MediaObjectFunc_currentTime, METH_NOARGS},
    {"enqueue", (PyCFunction)SbkPhonon_MediaObjectFunc_enqueue, METH_O},
    {"errorString", (PyCFunction)SbkPhonon_MediaObjectFunc_errorString, METH_NOARGS},
    {"errorType", (PyCFunction)SbkPhonon_MediaObjectFunc_errorType, METH_NOARGS},
    {"hasVideo", (PyCFunction)SbkPhonon_MediaObjectFunc_hasVideo, METH_NOARGS},
    {"isSeekable", (PyCFunction)SbkPhonon_MediaObjectFunc_isSeekable, METH_NOARGS},
    {"metaData", (PyCFunction)SbkPhonon_MediaObjectFunc_metaData, METH_NOARGS|METH_O},
    {"pause", (PyCFunction)SbkPhonon_MediaObjectFunc_pause, METH_NOARGS},
    {"play", (PyCFunction)SbkPhonon_MediaObjectFunc_play, METH_NOARGS},
    {"prefinishMark", (PyCFunction)SbkPhonon_MediaObjectFunc_prefinishMark, METH_NOARGS},
    {"queue", (PyCFunction)SbkPhonon_MediaObjectFunc_queue, METH_NOARGS},
    {"remainingTime", (PyCFunction)SbkPhonon_MediaObjectFunc_remainingTime, METH_NOARGS},
    {"seek", (PyCFunction)SbkPhonon_MediaObjectFunc_seek, METH_O},
    {"setCurrentSource", (PyCFunction)SbkPhonon_MediaObjectFunc_setCurrentSource, METH_O},
    {"setPrefinishMark", (PyCFunction)SbkPhonon_MediaObjectFunc_setPrefinishMark, METH_O},
    {"setQueue", (PyCFunction)SbkPhonon_MediaObjectFunc_setQueue, METH_O},
    {"setTickInterval", (PyCFunction)SbkPhonon_MediaObjectFunc_setTickInterval, METH_O},
    {"setTransitionTime", (PyCFunction)SbkPhonon_MediaObjectFunc_setTransitionTime, METH_O},
    {"state", (PyCFunction)SbkPhonon_MediaObjectFunc_state, METH_NOARGS},
    {"stop", (PyCFunction)SbkPhonon_MediaObjectFunc_stop, METH_NOARGS},
    {"tickInterval", (PyCFunction)SbkPhonon_MediaObjectFunc_tickInterval, METH_NOARGS},
    {"totalTime", (PyCFunction)SbkPhonon_MediaObjectFunc_totalTime, METH_NOARGS},
    {"transitionTime", (PyCFunction)SbkPhonon_MediaObjectFunc_transitionTime, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1, -1, -1 };
int*
SbkPhonon_MediaObject_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const Phonon::MediaObject* class_ptr = reinterpret_cast<const Phonon::MediaObject*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((Phonon::MediaObject*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const Phonon::MediaNode*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const Phonon::MediaNode*>((Phonon::MediaObject*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* SbkPhonon_MediaObjectSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    Phonon::MediaObject* me = reinterpret_cast<Phonon::MediaObject*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX]))
        return static_cast<Phonon::MediaNode*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_MediaObject_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.MediaObject",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_MediaObject_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_MediaObject_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             SbkPhonon_MediaObject_mi_init,
    /*mi_specialcast*/      &SbkPhonon_MediaObjectSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::MediaObject >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::MediaObject*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkPhonon_MediaObject_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<Phonon::MediaObject*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkPhonon_MediaObject_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<Phonon::MediaNode >()) && dynamic_cast<Phonon::MediaObject*>(reinterpret_cast<Phonon::MediaNode*>(cptr)))
        return &SbkPhonon_MediaObject_Type;
    return 0;
}


void init_Phonon_MediaObject(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_MediaObject_Type);

    SbkPhonon_MediaObject_Type.super.ht_type.tp_base = SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX];
    SbkPhonon_MediaObject_Type.super.ht_type.tp_bases = PyTuple_Pack(2,
        (PyTypeObject*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX], (PyTypeObject*)SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX]);

    // Fill type discovery information
    SbkPhonon_MediaObject_Type.type_discovery = &SbkPhonon_MediaObject_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkPhonon_MediaObject_Type);
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX]), &SbkPhonon_MediaObject_Type);

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_MediaObject_Type) < 0)
        return;

    PyDict_SetItemString(module,"MediaObject", (PyObject*)&SbkPhonon_MediaObject_Type);
    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("seekableChanged", "bool", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "seekableChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("hasVideoChanged", "bool", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "hasVideoChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("currentSourceChanged", "const Phonon::MediaSource&", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "currentSourceChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("prefinishMarkReached", "qint32", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "prefinishMarkReached", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("finished", "void", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "finished", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("metaDataChanged", "void", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "metaDataChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("aboutToFinish", "void", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "aboutToFinish", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("totalTimeChanged", "qint64", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "totalTimeChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("bufferStatus", "int", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "bufferStatus", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("tick", "qint64", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "tick", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("stateChanged", "Phonon::State,Phonon::State", NULL);
    PyDict_SetItemString(SbkPhonon_MediaObject_Type.super.ht_type.tp_dict, "stateChanged", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObject >("Phonon::MediaObject*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObject >(typeid(Phonon::MediaObject).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObject >(typeid(MediaObjectWrapper).name());
    PySide::initQtMetaType<Phonon::MediaObject* >();
}

