/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_mediaobjectinterface_wrapper.h"

// Extra includes
#include <mediasource.h>

using namespace Shiboken;
using namespace Phonon;

// Native ---------------------------------------------------------

MediaObjectInterfaceWrapper::MediaObjectInterfaceWrapper() : Phonon::MediaObjectInterface() {
    // ... middle
}

qint64 MediaObjectInterfaceWrapper::currentTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "currentTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.currentTime()' not implemented.");
        return qint64(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.currentTime", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

QString MediaObjectInterfaceWrapper::errorString() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "errorString"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorString()' not implemented.");
        return QString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.errorString", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter<QString >::toCpp(pyResult));
    return cppResult;
}

Phonon::ErrorType MediaObjectInterfaceWrapper::errorType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "errorType"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorType()' not implemented.");
        return Phonon::ErrorType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return Phonon::ErrorType();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<Phonon::ErrorType >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.errorType", SbkType<Phonon::ErrorType >()->tp_name, pyResult->ob_type->tp_name);
        return Phonon::ErrorType();
    }
    Phonon::ErrorType cppResult(Shiboken::Converter<Phonon::ErrorType >::toCpp(pyResult));
    return cppResult;
}

bool MediaObjectInterfaceWrapper::hasVideo() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hasVideo"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.hasVideo()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.hasVideo", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool MediaObjectInterfaceWrapper::isSeekable() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isSeekable"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.isSeekable()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.isSeekable", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void MediaObjectInterfaceWrapper::pause()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "pause"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.pause()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectInterfaceWrapper::play()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "play"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.play()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

qint32 MediaObjectInterfaceWrapper::prefinishMark() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "prefinishMark"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.prefinishMark()' not implemented.");
        return qint32(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint32(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.prefinishMark", "qint32", pyResult->ob_type->tp_name);
        return qint32(0);
    }
    qint32 cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

qint64 MediaObjectInterfaceWrapper::remainingTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "remainingTime"));
    if (py_override.isNull()) {
        return this->Phonon::MediaObjectInterface::remainingTime();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.remainingTime", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

void MediaObjectInterfaceWrapper::seek(qint64 milliseconds)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.seek()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        Shiboken::Converter<long long >::toPython(milliseconds)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectInterfaceWrapper::setNextSource(const Phonon::MediaSource & source)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setNextSource"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setNextSource()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const Phonon::MediaSource & >::toPython(source)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectInterfaceWrapper::setPrefinishMark(qint32 arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setPrefinishMark"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setPrefinishMark()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        Shiboken::Converter<int >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectInterfaceWrapper::setSource(const Phonon::MediaSource & arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setSource"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setSource()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const Phonon::MediaSource & >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectInterfaceWrapper::setTickInterval(qint32 interval)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setTickInterval"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTickInterval()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        Shiboken::Converter<int >::toPython(interval)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void MediaObjectInterfaceWrapper::setTransitionTime(qint32 arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setTransitionTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTransitionTime()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        Shiboken::Converter<int >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

Phonon::MediaSource MediaObjectInterfaceWrapper::source() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "source"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.source()' not implemented.");
        return Phonon::MediaSource();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return Phonon::MediaSource();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<Phonon::MediaSource >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.source", SbkType<Phonon::MediaSource >()->tp_name, pyResult->ob_type->tp_name);
        return Phonon::MediaSource();
    }
    Phonon::MediaSource cppResult(Shiboken::Converter<Phonon::MediaSource >::toCpp(pyResult));
    return cppResult;
}

Phonon::State MediaObjectInterfaceWrapper::state() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "state"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.state()' not implemented.");
        return Phonon::State();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return Phonon::State();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<Phonon::State >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.state", SbkType<Phonon::State >()->tp_name, pyResult->ob_type->tp_name);
        return Phonon::State();
    }
    Phonon::State cppResult(Shiboken::Converter<Phonon::State >::toCpp(pyResult));
    return cppResult;
}

void MediaObjectInterfaceWrapper::stop()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "stop"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.stop()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

qint32 MediaObjectInterfaceWrapper::tickInterval() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tickInterval"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.tickInterval()' not implemented.");
        return qint32(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint32(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.tickInterval", "qint32", pyResult->ob_type->tp_name);
        return qint32(0);
    }
    qint32 cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

qint64 MediaObjectInterfaceWrapper::totalTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "totalTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.totalTime()' not implemented.");
        return qint64(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.totalTime", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter<long long >::toCpp(pyResult));
    return cppResult;
}

qint32 MediaObjectInterfaceWrapper::transitionTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "transitionTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.transitionTime()' not implemented.");
        return qint32(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint32(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.transitionTime", "qint32", pyResult->ob_type->tp_name);
        return qint32(0);
    }
    qint32 cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

MediaObjectInterfaceWrapper::~MediaObjectInterfaceWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_MediaObjectInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::MediaObjectInterface >()))
        return -1;

    MediaObjectInterfaceWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECTINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::MediaObjectInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // MediaObjectInterface()
            cptr = new MediaObjectInterfaceWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::MediaObjectInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_currentTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentTime()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.currentTime()' not implemented.");
                return 0;
            }
            qint64 cppResult = cppSelf->currentTime();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_errorString(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorString()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorString()' not implemented.");
                return 0;
            }
            QString cppResult = cppSelf->errorString();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_errorType(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // errorType()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorType()' not implemented.");
                return 0;
            }
            Phonon::ErrorType cppResult = cppSelf->errorType();
            pyResult = Shiboken::Converter<Phonon::ErrorType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_hasVideo(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasVideo()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.hasVideo()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->hasVideo();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_isSeekable(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSeekable()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.isSeekable()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->isSeekable();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_pause(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pause()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.pause()' not implemented.");
                return 0;
            }
            cppSelf->pause();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_play(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // play()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.play()' not implemented.");
                return 0;
            }
            cppSelf->play();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_prefinishMark(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // prefinishMark()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.prefinishMark()' not implemented.");
                return 0;
            }
            qint32 cppResult = cppSelf->prefinishMark();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_remainingTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // remainingTime()const
            qint64 cppResult = cppSelf->Phonon::MediaObjectInterface::remainingTime();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_seek(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectInterfaceFunc_seek_TypeError;

    // Call function/method
    {
        {
            qint64 cpp_arg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // seek(qint64)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.seek()' not implemented.");
                return 0;
            }
            cppSelf->seek(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectInterfaceFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.seek", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_setNextSource(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNextSource(Phonon::MediaSource)
    if (Shiboken::Converter<const Phonon::MediaSource & >::isConvertible(arg)) {
        overloadId = 0; // setNextSource(Phonon::MediaSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectInterfaceFunc_setNextSource_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<Phonon::MediaSource > cpp_arg0_auto_ptr;
            Phonon::MediaSource* cpp_arg0 = Shiboken::Converter<Phonon::MediaSource* >::toCpp(arg);
            if (!Shiboken::Converter<Phonon::MediaSource >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<Phonon::MediaSource >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setNextSource(Phonon::MediaSource)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setNextSource()' not implemented.");
                return 0;
            }
            cppSelf->setNextSource(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectInterfaceFunc_setNextSource_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaSource", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setNextSource", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_setPrefinishMark(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrefinishMark(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPrefinishMark(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectInterfaceFunc_setPrefinishMark_TypeError;

    // Call function/method
    {
        {
            qint32 cpp_arg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPrefinishMark(qint32)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setPrefinishMark()' not implemented.");
                return 0;
            }
            cppSelf->setPrefinishMark(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectInterfaceFunc_setPrefinishMark_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setPrefinishMark", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_setSource(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSource(Phonon::MediaSource)
    if (Shiboken::Converter<const Phonon::MediaSource & >::isConvertible(arg)) {
        overloadId = 0; // setSource(Phonon::MediaSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectInterfaceFunc_setSource_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<Phonon::MediaSource > cpp_arg0_auto_ptr;
            Phonon::MediaSource* cpp_arg0 = Shiboken::Converter<Phonon::MediaSource* >::toCpp(arg);
            if (!Shiboken::Converter<Phonon::MediaSource >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<Phonon::MediaSource >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setSource(Phonon::MediaSource)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setSource()' not implemented.");
                return 0;
            }
            cppSelf->setSource(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectInterfaceFunc_setSource_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaSource", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setSource", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_setTickInterval(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTickInterval(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTickInterval(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectInterfaceFunc_setTickInterval_TypeError;

    // Call function/method
    {
        {
            qint32 cpp_arg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTickInterval(qint32)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTickInterval()' not implemented.");
                return 0;
            }
            cppSelf->setTickInterval(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectInterfaceFunc_setTickInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setTickInterval", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_setTransitionTime(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransitionTime(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTransitionTime(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaObjectInterfaceFunc_setTransitionTime_TypeError;

    // Call function/method
    {
        {
            qint32 cpp_arg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTransitionTime(qint32)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTransitionTime()' not implemented.");
                return 0;
            }
            cppSelf->setTransitionTime(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaObjectInterfaceFunc_setTransitionTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setTransitionTime", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_source(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // source()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.source()' not implemented.");
                return 0;
            }
            Phonon::MediaSource cppResult = cppSelf->source();
            pyResult = Shiboken::Converter<Phonon::MediaSource >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_state(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.state()' not implemented.");
                return 0;
            }
            Phonon::State cppResult = cppSelf->state();
            pyResult = Shiboken::Converter<Phonon::State >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_stop(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stop()
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.stop()' not implemented.");
                return 0;
            }
            cppSelf->stop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_tickInterval(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tickInterval()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.tickInterval()' not implemented.");
                return 0;
            }
            qint32 cppResult = cppSelf->tickInterval();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_totalTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // totalTime()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.totalTime()' not implemented.");
                return 0;
            }
            qint64 cppResult = cppSelf->totalTime();
            pyResult = Shiboken::Converter<long long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaObjectInterfaceFunc_transitionTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transitionTime()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.transitionTime()' not implemented.");
                return 0;
            }
            qint32 cppResult = cppSelf->transitionTime();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkPhonon_MediaObjectInterface_methods[] = {
    {"currentTime", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_currentTime, METH_NOARGS},
    {"errorString", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_errorString, METH_NOARGS},
    {"errorType", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_errorType, METH_NOARGS},
    {"hasVideo", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_hasVideo, METH_NOARGS},
    {"isSeekable", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_isSeekable, METH_NOARGS},
    {"pause", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_pause, METH_NOARGS},
    {"play", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_play, METH_NOARGS},
    {"prefinishMark", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_prefinishMark, METH_NOARGS},
    {"remainingTime", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_remainingTime, METH_NOARGS},
    {"seek", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_seek, METH_O},
    {"setNextSource", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_setNextSource, METH_O},
    {"setPrefinishMark", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_setPrefinishMark, METH_O},
    {"setSource", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_setSource, METH_O},
    {"setTickInterval", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_setTickInterval, METH_O},
    {"setTransitionTime", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_setTransitionTime, METH_O},
    {"source", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_source, METH_NOARGS},
    {"state", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_state, METH_NOARGS},
    {"stop", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_stop, METH_NOARGS},
    {"tickInterval", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_tickInterval, METH_NOARGS},
    {"totalTime", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_totalTime, METH_NOARGS},
    {"transitionTime", (PyCFunction)SbkPhonon_MediaObjectInterfaceFunc_transitionTime, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_MediaObjectInterface_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.MediaObjectInterface",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_MediaObjectInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_MediaObjectInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::MediaObjectInterface >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::MediaObjectInterface*",
    /*user_data*/           0
};
} //extern


void init_Phonon_MediaObjectInterface(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECTINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_MediaObjectInterface_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_MediaObjectInterface_Type) < 0)
        return;

    PyDict_SetItemString(module,"MediaObjectInterface", (PyObject*)&SbkPhonon_MediaObjectInterface_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObjectInterface >("Phonon::MediaObjectInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObjectInterface >(typeid(Phonon::MediaObjectInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObjectInterface >(typeid(MediaObjectInterfaceWrapper).name());
    PySide::initQtMetaType<Phonon::MediaObjectInterface* >();
}

