/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_mediasource_wrapper.h"

// Extra includes
#include <abstractmediastream.h>
#include <mediasource.h>
#include <qiodevice.h>
#include <qurl.h>

using namespace Shiboken;
using namespace Phonon;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_MediaSource_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::MediaSource >()))
        return -1;

    Phonon::MediaSource* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "deviceName" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.phonon.MediaSource(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return -1;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.MediaSource(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:MediaSource", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: MediaSource()
    // 1: MediaSource(Phonon::AbstractMediaStream*)
    // 2: MediaSource(Phonon::DiscType,QString)
    // 3: MediaSource(QIODevice*)
    // 4: MediaSource(Phonon::MediaSource)
    // 5: MediaSource(QString)
    // 6: MediaSource(QUrl)
    if (numArgs == 0) {
        overloadId = 0; // MediaSource()
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 5; // MediaSource(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[0])) {
        overloadId = 6; // MediaSource(QUrl)
    } else if (numArgs == 1 && Shiboken::Converter<QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 3; // MediaSource(QIODevice*)
    } else if (Shiboken::Converter<Phonon::DiscType >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // MediaSource(Phonon::DiscType,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 2; // MediaSource(Phonon::DiscType,QString)
        }
    } else if (numArgs == 1 && Shiboken::Converter<Phonon::AbstractMediaStream * >::isConvertible(pyargs[0])) {
        overloadId = 1; // MediaSource(Phonon::AbstractMediaStream*)
    } else if (numArgs == 1 && Shiboken::Converter<const Phonon::MediaSource & >::isConvertible(pyargs[0])) {
        overloadId = 4; // MediaSource(Phonon::MediaSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaSource_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // MediaSource()
            {

                if(!PyErr_Occurred()) {
                // MediaSource()
                cptr = new Phonon::MediaSource();
                }
                break;
            }
            case 1: // MediaSource(Phonon::AbstractMediaStream*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                Phonon::AbstractMediaStream* cpp_arg0 = Shiboken::Converter<Phonon::AbstractMediaStream* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // MediaSource(Phonon::AbstractMediaStream*)
                cptr = new Phonon::MediaSource(cpp_arg0);
                }
                break;
            }
            case 2: // MediaSource(Phonon::DiscType,QString)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceName");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "deviceName";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.phonon.MediaSource(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                Phonon::DiscType cpp_arg0 = Shiboken::Converter<Phonon::DiscType >::toCpp(pyargs[0]);
                QString cpp_arg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

                if(!PyErr_Occurred()) {
                // MediaSource(Phonon::DiscType,QString)
                cptr = new Phonon::MediaSource(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // MediaSource(QIODevice*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QIODevice* cpp_arg0 = Shiboken::Converter<QIODevice* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // MediaSource(QIODevice*)
                cptr = new Phonon::MediaSource(cpp_arg0);
                }
                break;
            }
            case 4: // MediaSource(Phonon::MediaSource)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<Phonon::MediaSource > cpp_arg0_auto_ptr;
                Phonon::MediaSource* cpp_arg0 = Shiboken::Converter<Phonon::MediaSource* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<Phonon::MediaSource >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<Phonon::MediaSource >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // MediaSource(Phonon::MediaSource)
                cptr = new Phonon::MediaSource(*cpp_arg0);
                }
                break;
            }
            case 5: // MediaSource(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // MediaSource(QString)
                cptr = new Phonon::MediaSource(cpp_arg0);
                }
                break;
            }
            case 6: // MediaSource(QUrl)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QUrl > cpp_arg0_auto_ptr;
                QUrl* cpp_arg0 = Shiboken::Converter<QUrl* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QUrl >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QUrl >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // MediaSource(QUrl)
                cptr = new Phonon::MediaSource(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::MediaSource >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkPhonon_MediaSource_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkPhonon_MediaSource_Init_TypeError:
        const char* overloads[] = {"", "PySide.phonon.Phonon::AbstractMediaStream", "PySide.phonon.Phonon.DiscType, QString = QString()", "PySide.QtCore.QIODevice", "PySide.phonon.Phonon::MediaSource", "QString", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.MediaSource", overloads);
        return -1;
}

static PyObject* SbkPhonon_MediaSourceFunc_autoDelete(PyObject* self)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoDelete()const
            bool cppResult = cppSelf->Phonon::MediaSource::autoDelete();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaSourceFunc_deviceName(PyObject* self)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deviceName()const
            QString cppResult = cppSelf->Phonon::MediaSource::deviceName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaSourceFunc_discType(PyObject* self)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // discType()const
            Phonon::DiscType cppResult = cppSelf->Phonon::MediaSource::discType();
            pyResult = Shiboken::Converter<Phonon::DiscType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaSourceFunc_fileName(PyObject* self)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fileName()const
            QString cppResult = cppSelf->Phonon::MediaSource::fileName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaSourceFunc_setAutoDelete(PyObject* self, PyObject* arg)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoDelete(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoDelete(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_MediaSourceFunc_setAutoDelete_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoDelete(bool)
            cppSelf->Phonon::MediaSource::setAutoDelete(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_MediaSourceFunc_setAutoDelete_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaSource.setAutoDelete", overloads);
        return 0;
}

static PyObject* SbkPhonon_MediaSourceFunc_stream(PyObject* self)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stream()const
            Phonon::AbstractMediaStream * cppResult = cppSelf->Phonon::MediaSource::stream();
            pyResult = Shiboken::Converter<Phonon::AbstractMediaStream * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaSourceFunc_type(PyObject* self)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // type()const
            Phonon::MediaSource::Type cppResult = cppSelf->Phonon::MediaSource::type();
            pyResult = Shiboken::Converter<Phonon::MediaSource::Type >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_MediaSourceFunc_url(PyObject* self)
{
    Phonon::MediaSource* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // url()const
            QUrl cppResult = cppSelf->Phonon::MediaSource::url();
            pyResult = Shiboken::Converter<QUrl >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkPhonon_MediaSource_methods[] = {
    {"autoDelete", (PyCFunction)SbkPhonon_MediaSourceFunc_autoDelete, METH_NOARGS},
    {"deviceName", (PyCFunction)SbkPhonon_MediaSourceFunc_deviceName, METH_NOARGS},
    {"discType", (PyCFunction)SbkPhonon_MediaSourceFunc_discType, METH_NOARGS},
    {"fileName", (PyCFunction)SbkPhonon_MediaSourceFunc_fileName, METH_NOARGS},
    {"setAutoDelete", (PyCFunction)SbkPhonon_MediaSourceFunc_setAutoDelete, METH_O},
    {"stream", (PyCFunction)SbkPhonon_MediaSourceFunc_stream, METH_NOARGS},
    {"type", (PyCFunction)SbkPhonon_MediaSourceFunc_type, METH_NOARGS},
    {"url", (PyCFunction)SbkPhonon_MediaSourceFunc_url, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkPhonon_MediaSource_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    Phonon::MediaSource& cpp_self = *Shiboken::Converter<Phonon::MediaSource* >::toCpp(self);

    switch (op) {
        case Py_EQ:
            if (Shiboken::Converter<const Phonon::MediaSource & >::isConvertible(other)) {
                // operator==(const Phonon::MediaSource & rhs) const
                Phonon::MediaSource* cpp_other = Shiboken::Converter<Phonon::MediaSource* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< Phonon::MediaSource  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<Phonon::MediaSource >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<Phonon::MediaSource > cpp_other_auto_ptr;
                Phonon::MediaSource* cpp_other = Shiboken::Converter<Phonon::MediaSource* >::toCpp(other);
                if (!Shiboken::Converter<Phonon::MediaSource >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<Phonon::MediaSource >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkPhonon_MediaSource_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkPhonon_MediaSource_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_MediaSource_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.MediaSource",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkPhonon_MediaSource_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_MediaSource_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_MediaSource_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::MediaSource >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::MediaSource",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_phonon_Phonon_MediaSource_Type_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_phonon_Phonon_MediaSource_Type_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_phonon_Phonon_MediaSource_Type_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Type",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_phonon_Phonon_MediaSource_Type_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_phonon_Phonon_MediaSource_Type_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_phonon_Phonon_MediaSource_Type_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_Phonon_MediaSource(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_MediaSource_Type);

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_MediaSource_Type) < 0)
        return;

    PyDict_SetItemString(module,"MediaSource", (PyObject*)&SbkPhonon_MediaSource_Type);
    // Initialize enums
    PyObject* enum_item;

    // init enum class: Type
    SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX] = &SbkPySide_phonon_Phonon_MediaSource_Type_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_phonon_Phonon_MediaSource_Type_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_phonon_Phonon_MediaSource_Type_Type);
    PyDict_SetItemString(SbkPhonon_MediaSource_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)&SbkPySide_phonon_Phonon_MediaSource_Type_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_MediaSource_Type_Type,
        (long) Phonon::MediaSource::Invalid, "Invalid");
    PyDict_SetItemString(SbkPhonon_MediaSource_Type.super.ht_type.tp_dict,
        "Invalid", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaSource_Type_Type.tp_dict,
        "Invalid", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_MediaSource_Type_Type,
        (long) Phonon::MediaSource::LocalFile, "LocalFile");
    PyDict_SetItemString(SbkPhonon_MediaSource_Type.super.ht_type.tp_dict,
        "LocalFile", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaSource_Type_Type.tp_dict,
        "LocalFile", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_MediaSource_Type_Type,
        (long) Phonon::MediaSource::Url, "Url");
    PyDict_SetItemString(SbkPhonon_MediaSource_Type.super.ht_type.tp_dict,
        "Url", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaSource_Type_Type.tp_dict,
        "Url", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_MediaSource_Type_Type,
        (long) Phonon::MediaSource::Disc, "Disc");
    PyDict_SetItemString(SbkPhonon_MediaSource_Type.super.ht_type.tp_dict,
        "Disc", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaSource_Type_Type.tp_dict,
        "Disc", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_MediaSource_Type_Type,
        (long) Phonon::MediaSource::Stream, "Stream");
    PyDict_SetItemString(SbkPhonon_MediaSource_Type.super.ht_type.tp_dict,
        "Stream", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaSource_Type_Type.tp_dict,
        "Stream", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_phonon_Phonon_MediaSource_Type_Type,
        (long) Phonon::MediaSource::Empty, "Empty");
    PyDict_SetItemString(SbkPhonon_MediaSource_Type.super.ht_type.tp_dict,
        "Empty", enum_item);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaSource_Type_Type.tp_dict,
        "Empty", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::MediaSource::Type");


    Shiboken::TypeResolver::createValueTypeResolver<Phonon::MediaSource >("Phonon::MediaSource");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaSource >("Phonon::MediaSource*");
    Shiboken::TypeResolver::createValueTypeResolver<Phonon::MediaSource >(typeid(Phonon::MediaSource).name());
    PySide::initQtMetaType<Phonon::MediaSource >();
}

