/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_path_wrapper.h"

// Extra includes
#include <QList>
#include <effect.h>
#include <medianode.h>
#include <objectdescription.h>
#include <path.h>

using namespace Shiboken;
using namespace Phonon;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_Path_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::Path >()))
        return -1;

    Phonon::Path* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "Path", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: Path()
    // 1: Path(Phonon::Path)
    if (numArgs == 0) {
        overloadId = 0; // Path()
    } else if (numArgs == 1 && Shiboken::Converter<const Phonon::Path & >::isConvertible(arg)) {
        overloadId = 1; // Path(Phonon::Path)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_Path_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // Path()
            {

                if(!PyErr_Occurred()) {
                // Path()
                cptr = new Phonon::Path();
                }
                break;
            }
            case 1: // Path(Phonon::Path)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                Phonon::Path* cpp_arg0 = Shiboken::Converter<Phonon::Path* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // Path(Phonon::Path)
                cptr = new Phonon::Path(*cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::Path >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkPhonon_Path_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkPhonon_Path_Init_TypeError:
        const char* overloads[] = {"", "PySide.phonon.Phonon::Path", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.Path", overloads);
        return -1;
}

static PyObject* SbkPhonon_PathFunc_disconnectPath(PyObject* self)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // disconnect()
            bool cppResult = cppSelf->Phonon::Path::disconnect();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_PathFunc_effects(PyObject* self)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // effects()const
            QList<Phonon::Effect * > cppResult = cppSelf->Phonon::Path::effects();
            pyResult = Shiboken::Converter<QList<Phonon::Effect * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_PathFunc_insertEffect(PyObject* self, PyObject* args, PyObject* kwds)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "insertBefore" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.phonon.Path.insertEffect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.Path.insertEffect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.Path.insertEffect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:insertEffect", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertEffect(Phonon::Effect*,Phonon::Effect*)
    // 1: insertEffect(Phonon::EffectDescription,Phonon::Effect*)
    if (Shiboken::Converter<const Phonon::EffectDescription & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // insertEffect(Phonon::EffectDescription,Phonon::Effect*)
        } else if (Shiboken::Converter<Phonon::Effect * >::isConvertible(pyargs[1])) {
            overloadId = 1; // insertEffect(Phonon::EffectDescription,Phonon::Effect*)
        }
    } else if (Shiboken::Converter<Phonon::Effect * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // insertEffect(Phonon::Effect*,Phonon::Effect*)
        } else if (Shiboken::Converter<Phonon::Effect * >::isConvertible(pyargs[1])) {
            overloadId = 0; // insertEffect(Phonon::Effect*,Phonon::Effect*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_PathFunc_insertEffect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insertEffect(Phonon::Effect*,Phonon::Effect*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "insertBefore");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "insertBefore";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.phonon.Path.insertEffect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                Phonon::Effect* cpp_arg0 = Shiboken::Converter<Phonon::Effect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                Phonon::Effect* cpp_arg1 = pyargs[1] ? Shiboken::Converter<Phonon::Effect* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // insertEffect(Phonon::Effect*,Phonon::Effect*)
                bool cppResult = cppSelf->Phonon::Path::insertEffect(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // insertEffect(Phonon::EffectDescription,Phonon::Effect*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "insertBefore");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "insertBefore";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.phonon.Path.insertEffect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                Phonon::EffectDescription* cpp_arg0 = Shiboken::Converter<Phonon::EffectDescription* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                Phonon::Effect* cpp_arg1 = pyargs[1] ? Shiboken::Converter<Phonon::Effect* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // insertEffect(Phonon::EffectDescription,Phonon::Effect*)
                Phonon::Effect * cppResult = cppSelf->Phonon::Path::insertEffect(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<Phonon::Effect * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                Shiboken::setParent(self, pyargs[0]);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_PathFunc_insertEffect_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::Effect, PySide.phonon.Phonon::Effect = None", "PySide.phonon.Phonon::EffectDescription, PySide.phonon.Phonon::Effect = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.Path.insertEffect", overloads);
        return 0;
}

static PyObject* SbkPhonon_PathFunc_isValid(PyObject* self)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->Phonon::Path::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_PathFunc_reconnect(PyObject* self, PyObject* args)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "reconnect", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: reconnect(Phonon::MediaNode*,Phonon::MediaNode*)
    if (numArgs == 2 && Shiboken::Converter<Phonon::MediaNode * >::isConvertible(pyargs[0]) && Shiboken::Converter<Phonon::MediaNode * >::isConvertible(pyargs[1])) {
        overloadId = 0; // reconnect(Phonon::MediaNode*,Phonon::MediaNode*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_PathFunc_reconnect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            Phonon::MediaNode* cpp_arg0 = Shiboken::Converter<Phonon::MediaNode* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            Phonon::MediaNode* cpp_arg1 = Shiboken::Converter<Phonon::MediaNode* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // reconnect(Phonon::MediaNode*,Phonon::MediaNode*)
            bool cppResult = cppSelf->Phonon::Path::reconnect(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_PathFunc_reconnect_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaNode, PySide.phonon.Phonon::MediaNode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.Path.reconnect", overloads);
        return 0;
}

static PyObject* SbkPhonon_PathFunc_removeEffect(PyObject* self, PyObject* arg)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeEffect(Phonon::Effect*)
    if (Shiboken::Converter<Phonon::Effect * >::isConvertible(arg)) {
        overloadId = 0; // removeEffect(Phonon::Effect*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_PathFunc_removeEffect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            Phonon::Effect* cpp_arg0 = Shiboken::Converter<Phonon::Effect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeEffect(Phonon::Effect*)
            bool cppResult = cppSelf->Phonon::Path::removeEffect(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_PathFunc_removeEffect_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::Effect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.Path.removeEffect", overloads);
        return 0;
}

static PyObject* SbkPhonon_PathFunc_sink(PyObject* self)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sink()const
            Phonon::MediaNode * cppResult = cppSelf->Phonon::Path::sink();
            pyResult = Shiboken::Converter<Phonon::MediaNode * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_PathFunc_source(PyObject* self)
{
    Phonon::Path* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::Path* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // source()const
            Phonon::MediaNode * cppResult = cppSelf->Phonon::Path::source();
            pyResult = Shiboken::Converter<Phonon::MediaNode * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkPhonon_Path_methods[] = {
    {"disconnectPath", (PyCFunction)SbkPhonon_PathFunc_disconnectPath, METH_NOARGS},
    {"effects", (PyCFunction)SbkPhonon_PathFunc_effects, METH_NOARGS},
    {"insertEffect", (PyCFunction)SbkPhonon_PathFunc_insertEffect, METH_VARARGS|METH_KEYWORDS},
    {"isValid", (PyCFunction)SbkPhonon_PathFunc_isValid, METH_NOARGS},
    {"reconnect", (PyCFunction)SbkPhonon_PathFunc_reconnect, METH_VARARGS},
    {"removeEffect", (PyCFunction)SbkPhonon_PathFunc_removeEffect, METH_O},
    {"sink", (PyCFunction)SbkPhonon_PathFunc_sink, METH_NOARGS},
    {"source", (PyCFunction)SbkPhonon_PathFunc_source, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkPhonon_Path_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    Phonon::Path& cpp_self = *Shiboken::Converter<Phonon::Path* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const Phonon::Path & >::isConvertible(other)) {
                // operator!=(const Phonon::Path & p) const
                Phonon::Path* cpp_other = Shiboken::Converter<Phonon::Path* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< Phonon::Path  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else goto SbkPhonon_Path_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const Phonon::Path & >::isConvertible(other)) {
                // operator==(const Phonon::Path & p) const
                Phonon::Path* cpp_other = Shiboken::Converter<Phonon::Path* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< Phonon::Path  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else goto SbkPhonon_Path_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkPhonon_Path_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_Path_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.Path",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkPhonon_Path_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_Path_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_Path_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::Path >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::Path",
    /*user_data*/           0
};
} //extern


void init_Phonon_Path(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_PATH_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_Path_Type);

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_Path_Type) < 0)
        return;

    PyDict_SetItemString(module,"Path", (PyObject*)&SbkPhonon_Path_Type);

    Shiboken::TypeResolver::createValueTypeResolver<Phonon::Path >("Phonon::Path");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::Path >("Phonon::Path*");
    Shiboken::TypeResolver::createValueTypeResolver<Phonon::Path >(typeid(Phonon::Path).name());
    PySide::initQtMetaType<Phonon::Path >();
}

