/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_subtitledescription_wrapper.h"

// Extra includes
#include <QList>
#include <pysideconversions.h>
#include <qbytearray.h>

using namespace Shiboken;
using namespace Phonon;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_SubtitleDescription_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::SubtitleDescription >()))
        return -1;

    Phonon::SubtitleDescription* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "SubtitleDescription", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: SubtitleDescription(Phonon::SubtitleDescription)
    // 1: SubtitleDescription()
    // 2: SubtitleDescription(int,QHash<QByteArray,QVariant>)
    if (numArgs == 0) {
        overloadId = 1; // SubtitleDescription()
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< QHash<QByteArray, QVariant >  >::isConvertible(pyargs[1])) {
        overloadId = 2; // SubtitleDescription(int,QHash<QByteArray,QVariant>)
    } else if (numArgs == 1 && Shiboken::Converter<const Phonon::SubtitleDescription & >::isConvertible(pyargs[0])) {
        overloadId = 0; // SubtitleDescription(Phonon::SubtitleDescription)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_SubtitleDescription_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // SubtitleDescription(Phonon::SubtitleDescription)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                Phonon::SubtitleDescription* cpp_arg0 = Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // SubtitleDescription(Phonon::SubtitleDescription)
                cptr = new Phonon::SubtitleDescription(*cpp_arg0);
                }
                break;
            }
            case 1: // SubtitleDescription()
            {

                if(!PyErr_Occurred()) {
                // SubtitleDescription()
                cptr = new Phonon::SubtitleDescription();
                }
                break;
            }
            case 2: // SubtitleDescription(int,QHash<QByteArray,QVariant>)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QHash<QByteArray, QVariant > cpp_arg1 = Shiboken::Converter<QHash<QByteArray, QVariant > >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // SubtitleDescription(int,QHash<QByteArray,QVariant>)
                cptr = new Phonon::SubtitleDescription(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::SubtitleDescription >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkPhonon_SubtitleDescription_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkPhonon_SubtitleDescription_Init_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::SubtitleDescription", "", "int, dict", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.SubtitleDescription", overloads);
        return -1;
}

static PyObject* SbkPhonon_SubtitleDescriptionFunc_description(PyObject* self)
{
    Phonon::SubtitleDescription* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // description()const
            QString cppResult = cppSelf->Phonon::SubtitleDescription::description();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_SubtitleDescriptionFunc_index(PyObject* self)
{
    Phonon::SubtitleDescription* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // index()const
            int cppResult = cppSelf->Phonon::SubtitleDescription::index();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_SubtitleDescriptionFunc_isValid(PyObject* self)
{
    Phonon::SubtitleDescription* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isValid()const
            bool cppResult = cppSelf->Phonon::SubtitleDescription::isValid();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_SubtitleDescriptionFunc_name(PyObject* self)
{
    Phonon::SubtitleDescription* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // name()const
            QString cppResult = cppSelf->Phonon::SubtitleDescription::name();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_SubtitleDescriptionFunc_property(PyObject* self, PyObject* arg)
{
    Phonon::SubtitleDescription* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(const char*)const
    if (Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 0; // property(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_SubtitleDescriptionFunc_property_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // property(const char*)const
            QVariant cppResult = cppSelf->Phonon::SubtitleDescription::property(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkPhonon_SubtitleDescriptionFunc_property_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.SubtitleDescription.property", overloads);
        return 0;
}

static PyObject* SbkPhonon_SubtitleDescriptionFunc_propertyNames(PyObject* self)
{
    Phonon::SubtitleDescription* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // propertyNames()const
            QList<QByteArray > cppResult = cppSelf->Phonon::SubtitleDescription::propertyNames();
            pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkPhonon_SubtitleDescription_methods[] = {
    {"description", (PyCFunction)SbkPhonon_SubtitleDescriptionFunc_description, METH_NOARGS},
    {"index", (PyCFunction)SbkPhonon_SubtitleDescriptionFunc_index, METH_NOARGS},
    {"isValid", (PyCFunction)SbkPhonon_SubtitleDescriptionFunc_isValid, METH_NOARGS},
    {"name", (PyCFunction)SbkPhonon_SubtitleDescriptionFunc_name, METH_NOARGS},
    {"property", (PyCFunction)SbkPhonon_SubtitleDescriptionFunc_property, METH_O},
    {"propertyNames", (PyCFunction)SbkPhonon_SubtitleDescriptionFunc_propertyNames, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* SbkPhonon_SubtitleDescription_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    Phonon::SubtitleDescription& cpp_self = *Shiboken::Converter<Phonon::SubtitleDescription* >::toCpp(self);

    switch (op) {
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkPhonon_SubtitleDescription_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_SubtitleDescription_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.SubtitleDescription",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkPhonon_SubtitleDescription_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_SubtitleDescription_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_SubtitleDescription_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::SubtitleDescription >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::SubtitleDescription",
    /*user_data*/           0
};
} //extern


void init_Phonon_SubtitleDescription(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_SUBTITLEDESCRIPTION_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_SubtitleDescription_Type);

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_SubtitleDescription_Type) < 0)
        return;

    PyDict_SetItemString(module,"SubtitleDescription", (PyObject*)&SbkPhonon_SubtitleDescription_Type);

    Shiboken::TypeResolver::createValueTypeResolver<Phonon::SubtitleDescription >("Phonon::SubtitleDescription");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::SubtitleDescription >("Phonon::SubtitleDescription*");
    Shiboken::TypeResolver::createValueTypeResolver<Phonon::SubtitleDescription >(typeid(Phonon::SubtitleDescription).name());
    PySide::initQtMetaType<Phonon::SubtitleDescription >();
}

