/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_volumefaderinterface_wrapper.h"

// Extra includes

using namespace Shiboken;
using namespace Phonon;

// Native ---------------------------------------------------------

VolumeFaderInterfaceWrapper::VolumeFaderInterfaceWrapper() : Phonon::VolumeFaderInterface() {
    // ... middle
}

Phonon::VolumeFaderEffect::FadeCurve VolumeFaderInterfaceWrapper::fadeCurve() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "fadeCurve"));
    if (py_override.isNull()) {
        return this->Phonon::VolumeFaderInterface::fadeCurve();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return Phonon::VolumeFaderEffect::FadeCurve();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<Phonon::VolumeFaderEffect::FadeCurve >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "VolumeFaderInterface.fadeCurve", SbkType<Phonon::VolumeFaderEffect::FadeCurve >()->tp_name, pyResult->ob_type->tp_name);
        return Phonon::VolumeFaderEffect::FadeCurve();
    }
    Phonon::VolumeFaderEffect::FadeCurve cppResult(Shiboken::Converter<Phonon::VolumeFaderEffect::FadeCurve >::toCpp(pyResult));
    return cppResult;
}

void VolumeFaderInterfaceWrapper::fadeTo(float arg__1, int arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "fadeTo"));
    if (py_override.isNull()) {
        return this->Phonon::VolumeFaderInterface::fadeTo(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(fi)",
        arg__1,
        arg__2
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void VolumeFaderInterfaceWrapper::setFadeCurve(Phonon::VolumeFaderEffect::FadeCurve arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setFadeCurve"));
    if (py_override.isNull()) {
        return this->Phonon::VolumeFaderInterface::setFadeCurve(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Phonon::VolumeFaderEffect::FadeCurve >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void VolumeFaderInterfaceWrapper::setVolume(float arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVolume"));
    if (py_override.isNull()) {
        return this->Phonon::VolumeFaderInterface::setVolume(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(f)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

float VolumeFaderInterfaceWrapper::volume() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "volume"));
    if (py_override.isNull()) {
        return this->Phonon::VolumeFaderInterface::volume();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return float(0);
    }
    // Check return type
    bool typeIsValid = PyFloat_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "VolumeFaderInterface.volume", "float", pyResult->ob_type->tp_name);
        return float(0);
    }
    float cppResult(Shiboken::Converter<float >::toCpp(pyResult));
    return cppResult;
}

VolumeFaderInterfaceWrapper::~VolumeFaderInterfaceWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkPhonon_VolumeFaderInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::VolumeFaderInterface >()))
        return -1;

    VolumeFaderInterfaceWrapper* cptr = 0;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // VolumeFaderInterface()
            cptr = new VolumeFaderInterfaceWrapper();
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::VolumeFaderInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* SbkPhonon_VolumeFaderInterfaceFunc_fadeCurve(PyObject* self)
{
    Phonon::VolumeFaderInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::VolumeFaderInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fadeCurve()const
            Phonon::VolumeFaderEffect::FadeCurve cppResult = cppSelf->Phonon::VolumeFaderInterface::fadeCurve();
            pyResult = Shiboken::Converter<Phonon::VolumeFaderEffect::FadeCurve >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkPhonon_VolumeFaderInterfaceFunc_fadeTo(PyObject* self, PyObject* args)
{
    Phonon::VolumeFaderInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::VolumeFaderInterface* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fadeTo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fadeTo(float,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // fadeTo(float,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_VolumeFaderInterfaceFunc_fadeTo_TypeError;

    // Call function/method
    {
        {
            float cpp_arg0 = Shiboken::Converter<float >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // fadeTo(float,int)
            cppSelf->Phonon::VolumeFaderInterface::fadeTo(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_VolumeFaderInterfaceFunc_fadeTo_TypeError:
        const char* overloads[] = {"float, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.VolumeFaderInterface.fadeTo", overloads);
        return 0;
}

static PyObject* SbkPhonon_VolumeFaderInterfaceFunc_setFadeCurve(PyObject* self, PyObject* arg)
{
    Phonon::VolumeFaderInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::VolumeFaderInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFadeCurve(Phonon::VolumeFaderEffect::FadeCurve)
    if (Shiboken::Converter<Phonon::VolumeFaderEffect::FadeCurve >::isConvertible(arg)) {
        overloadId = 0; // setFadeCurve(Phonon::VolumeFaderEffect::FadeCurve)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_VolumeFaderInterfaceFunc_setFadeCurve_TypeError;

    // Call function/method
    {
        {
            Phonon::VolumeFaderEffect::FadeCurve cpp_arg0 = Shiboken::Converter<Phonon::VolumeFaderEffect::FadeCurve >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFadeCurve(Phonon::VolumeFaderEffect::FadeCurve)
            cppSelf->Phonon::VolumeFaderInterface::setFadeCurve(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_VolumeFaderInterfaceFunc_setFadeCurve_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::VolumeFaderEffect.FadeCurve", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.VolumeFaderInterface.setFadeCurve", overloads);
        return 0;
}

static PyObject* SbkPhonon_VolumeFaderInterfaceFunc_setVolume(PyObject* self, PyObject* arg)
{
    Phonon::VolumeFaderInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::VolumeFaderInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVolume(float)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVolume(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkPhonon_VolumeFaderInterfaceFunc_setVolume_TypeError;

    // Call function/method
    {
        {
            float cpp_arg0 = Shiboken::Converter<float >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVolume(float)
            cppSelf->Phonon::VolumeFaderInterface::setVolume(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkPhonon_VolumeFaderInterfaceFunc_setVolume_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.VolumeFaderInterface.setVolume", overloads);
        return 0;
}

static PyObject* SbkPhonon_VolumeFaderInterfaceFunc_volume(PyObject* self)
{
    Phonon::VolumeFaderInterface* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<Phonon::VolumeFaderInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // volume()const
            float cppResult = cppSelf->Phonon::VolumeFaderInterface::volume();
            pyResult = Shiboken::Converter<float >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkPhonon_VolumeFaderInterface_methods[] = {
    {"fadeCurve", (PyCFunction)SbkPhonon_VolumeFaderInterfaceFunc_fadeCurve, METH_NOARGS},
    {"fadeTo", (PyCFunction)SbkPhonon_VolumeFaderInterfaceFunc_fadeTo, METH_VARARGS},
    {"setFadeCurve", (PyCFunction)SbkPhonon_VolumeFaderInterfaceFunc_setFadeCurve, METH_O},
    {"setVolume", (PyCFunction)SbkPhonon_VolumeFaderInterfaceFunc_setVolume, METH_O},
    {"volume", (PyCFunction)SbkPhonon_VolumeFaderInterfaceFunc_volume, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkPhonon_VolumeFaderInterface_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.VolumeFaderInterface",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkPhonon_VolumeFaderInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkPhonon_VolumeFaderInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<Phonon::VolumeFaderInterface >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "Phonon::VolumeFaderInterface*",
    /*user_data*/           0
};
} //extern


void init_Phonon_VolumeFaderInterface(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_VOLUMEFADERINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkPhonon_VolumeFaderInterface_Type);

    // Fill type discovery information

    if (PyType_Ready((PyTypeObject*)&SbkPhonon_VolumeFaderInterface_Type) < 0)
        return;

    PyDict_SetItemString(module,"VolumeFaderInterface", (PyObject*)&SbkPhonon_VolumeFaderInterface_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::VolumeFaderInterface >("Phonon::VolumeFaderInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::VolumeFaderInterface >(typeid(Phonon::VolumeFaderInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::VolumeFaderInterface >(typeid(VolumeFaderInterfaceWrapper).name());
    PySide::initQtMetaType<Phonon::VolumeFaderInterface* >();
}

