/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qbytearray_wrapper.h"

// Extra includes
#include <QList>
#include <QNoImplicitBoolCast>
#include <qbytearray.h>

using namespace Shiboken;

// Begin code injection
// ========================================================================
// START of custom code block [file: glue/qbytearray_bufferprotocol.cpp]

#if PY_VERSION_HEX < 0x03000000

// QByteArray buffer protocol functions
// see: http://www.python.org/dev/peps/pep-3118/

extern "C" {

static Py_ssize_t SbkQByteArray_segcountproc(PyObject* self, Py_ssize_t* lenp)
{
    if (lenp)
        *lenp = self->ob_type->tp_as_sequence->sq_length(self);
    return 1;
}

static Py_ssize_t SbkQByteArray_readbufferproc(PyObject* self, Py_ssize_t segment, void** ptrptr)
{
    if (segment || Shiboken::cppObjectIsInvalid(self))
        return -1;

    QByteArray* cppSelf = Converter<QByteArray*>::toCpp(self);
    *ptrptr = reinterpret_cast<void*>(cppSelf->data());
    return cppSelf->size();
}

PyBufferProcs SbkQByteArrayBufferProc = {
    /*bf_getreadbuffer*/  &SbkQByteArray_readbufferproc,
    /*bf_getwritebuffer*/ (writebufferproc) &SbkQByteArray_readbufferproc,
    /*bf_getsegcount*/    &SbkQByteArray_segcountproc,
    /*bf_getcharbuffer*/  (charbufferproc) &SbkQByteArray_readbufferproc
};

}

#endif

// END of custom code block [file: glue/qbytearray_bufferprotocol.cpp]
// ========================================================================

// End of code injection


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQByteArray_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QByteArray >()))
        return -1;

    QByteArray* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QByteArray", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QByteArray()
    // 1: QByteArray(QByteArray)
    // 2: QByteArray(const char*)
    // 3: QByteArray(int,char)
    if (numArgs == 0) {
        overloadId = 0; // QByteArray()
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<char >::isConvertible(pyargs[1])) {
        overloadId = 3; // QByteArray(int,char)
    } else if (numArgs == 1 && Shiboken::Converter<const char * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QByteArray(const char*)
    } else if (numArgs == 1 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        overloadId = 1; // QByteArray(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArray_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QByteArray()
            {

                if(!PyErr_Occurred()) {
                // QByteArray()
                cptr = new QByteArray();
                }
                break;
            }
            case 1: // QByteArray(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // QByteArray(QByteArray)
                cptr = new QByteArray(*cpp_arg0);
                }
                break;
            }
            case 2: // QByteArray(const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // QByteArray(const char*)
                // Begin code injection
                
                int size = PyString_Size(pyargs[0]);
                cptr = new QByteArray(cpp_arg0, size);
                
                // End of code injection

                }
                break;
            }
            case 3: // QByteArray(int,char)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                char cpp_arg1 = Shiboken::Converter<char >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // QByteArray(int,char)
                cptr = new QByteArray(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QByteArray >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQByteArray_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQByteArray_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", "str", "int, char", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray", overloads);
        return -1;
}

static PyObject* SbkQByteArrayFunc___str__(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // __str__()
            // Begin code injection
            
            pyResult = PyString_FromString(cppSelf->data());
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_append(PyObject* self, PyObject* args)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "append", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: append(QByteArray)
    // 1: append(QString)
    // 2: append(const char*,int)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // append(const char*,int)
    } else if (numArgs == 1 && Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // append(QString)
    } else if (numArgs == 1 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        overloadId = 0; // append(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_append_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // append(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // append(QByteArray)
                QByteArray & cppResult = cppSelf->QByteArray::append(*cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 1: // append(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // append(QString)
                QByteArray & cppResult = cppSelf->QByteArray::append(cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 2: // append(const char*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // append(const char*,int)
                QByteArray & cppResult = cppSelf->QByteArray::append(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.append", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_appendByte(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(char)
    if (Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // append(char)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_appendByte_TypeError;

    // Call function/method
    {
        {
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // append(char)
            QByteArray & cppResult = cppSelf->QByteArray::append(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_appendByte_TypeError:
        const char* overloads[] = {"char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.appendByte", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_at(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_at_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // at(int)const
            char cppResult = cppSelf->QByteArray::at(cpp_arg0);
            pyResult = Shiboken::Converter<char >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.at", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_capacity(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // capacity()const
            int cppResult = cppSelf->QByteArray::capacity();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_chop(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: chop(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // chop(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_chop_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // chop(int)
            cppSelf->QByteArray::chop(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQByteArrayFunc_chop_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.chop", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_clear(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QByteArray::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQByteArrayFunc_count(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: count()const
    // 1: count(char)const
    // 2: count(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 1; // count(char)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 2; // count(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                // count()const
                int cppResult = cppSelf->QByteArray::count();
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(char)const
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // count(char)const
                int cppResult = cppSelf->QByteArray::count(cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 2: // count(QByteArray)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // count(QByteArray)const
                int cppResult = cppSelf->QByteArray::count(*cpp_arg0);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_count_TypeError:
        const char* overloads[] = {"", "char", "PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.count", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_data(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // data()const
            const char * cppResult = cppSelf->QByteArray::data();
            pyResult = Shiboken::Converter<const char * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_endsWith(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(char)const
    // 1: endsWith(QByteArray)const
    if (Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // endsWith(char)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 1; // endsWith(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_endsWith_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // endsWith(char)const
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // endsWith(char)const
                bool cppResult = cppSelf->QByteArray::endsWith(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // endsWith(QByteArray)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // endsWith(QByteArray)const
                bool cppResult = cppSelf->QByteArray::endsWith(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_endsWith_TypeError:
        const char* overloads[] = {"char", "PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.endsWith", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_fill(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "size" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fill(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fill(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fill(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fill", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fill(char,int)
    if (Shiboken::Converter<char >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fill(char,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // fill(char,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_fill_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "size";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fill(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // fill(char,int)
            QByteArray & cppResult = cppSelf->QByteArray::fill(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_fill_TypeError:
        const char* overloads[] = {"char, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.fill", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_fromBase64(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromBase64(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // fromBase64(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_fromBase64_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // fromBase64(QByteArray)
            QByteArray cppResult = QByteArray::fromBase64(*cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_fromBase64_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.fromBase64", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_fromHex(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromHex(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // fromHex(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_fromHex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // fromHex(QByteArray)
            QByteArray cppResult = QByteArray::fromHex(*cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_fromHex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.fromHex", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_fromInt(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fromInt(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fromInt(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fromInt(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromInt", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: number(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // number(int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // number(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_fromInt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fromInt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 10;

            if(!PyErr_Occurred()) {
            // number(int,int)
            QByteArray cppResult = QByteArray::number(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_fromInt_TypeError:
        const char* overloads[] = {"int, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.fromInt", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_fromLongLong(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fromLongLong(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fromLongLong(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fromLongLong(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromLongLong", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: number(qlonglong,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // number(qlonglong,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // number(qlonglong,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_fromLongLong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fromLongLong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qlonglong cpp_arg0 = Shiboken::Converter<qlonglong >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 10;

            if(!PyErr_Occurred()) {
            // number(qlonglong,int)
            QByteArray cppResult = QByteArray::number(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_fromLongLong_TypeError:
        const char* overloads[] = {"long long, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.fromLongLong", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_fromPercentEncoding(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "percent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fromPercentEncoding(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fromPercentEncoding(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.fromPercentEncoding(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromPercentEncoding", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromPercentEncoding(QByteArray,char)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromPercentEncoding(QByteArray,char)
        } else if (Shiboken::Converter<char >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromPercentEncoding(QByteArray,char)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_fromPercentEncoding_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "percent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "percent";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.fromPercentEncoding(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            char cpp_arg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : '%';

            if(!PyErr_Occurred()) {
            // fromPercentEncoding(QByteArray,char)
            QByteArray cppResult = QByteArray::fromPercentEncoding(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_fromPercentEncoding_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, char = '%'", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.fromPercentEncoding", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QByteArray,int)const
    // 1: indexOf(QString,int)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // indexOf(QString,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // indexOf(QString,int)const
        }
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QByteArray,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(QByteArray,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_indexOf_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // indexOf(QByteArray,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // indexOf(QByteArray,int)const
                int cppResult = cppSelf->QByteArray::indexOf(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // indexOf(QString,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // indexOf(QString,int)const
                int cppResult = cppSelf->QByteArray::indexOf(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int = 0", "QString, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.indexOf", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_indexOfByte(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOfByte(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOfByte(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOfByte(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOfByte", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(char,int)const
    if (Shiboken::Converter<char >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(char,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(char,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_indexOfByte_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.indexOfByte(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // indexOf(char,int)const
            int cppResult = cppSelf->QByteArray::indexOf(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_indexOfByte_TypeError:
        const char* overloads[] = {"char, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.indexOfByte", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_insert(PyObject* self, PyObject* args)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insert", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insert(int,QByteArray)
    // 1: insert(int,QString)
    // 2: insert(int,const char*,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 3 && Shiboken::Converter<const char * >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 2; // insert(int,const char*,int)
        } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // insert(int,QString)
        } else if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 0; // insert(int,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_insert_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insert(int,QByteArray)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // insert(int,QByteArray)
                QByteArray & cppResult = cppSelf->QByteArray::insert(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 1: // insert(int,QString)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // insert(int,QString)
                QByteArray & cppResult = cppSelf->QByteArray::insert(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 2: // insert(int,const char*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                const char * cpp_arg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // insert(int,const char*,int)
                QByteArray & cppResult = cppSelf->QByteArray::insert(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_insert_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QByteArray", "int, QString", "int, str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.insert", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_insertByte(PyObject* self, PyObject* args)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertByte", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insert(int,char)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<char >::isConvertible(pyargs[1])) {
        overloadId = 0; // insert(int,char)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_insertByte_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            char cpp_arg1 = Shiboken::Converter<char >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insert(int,char)
            QByteArray & cppResult = cppSelf->QByteArray::insert(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_insertByte_TypeError:
        const char* overloads[] = {"int, char", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.insertByte", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_isEmpty(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEmpty()const
            bool cppResult = cppSelf->QByteArray::isEmpty();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_isNull(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isNull()const
            bool cppResult = cppSelf->QByteArray::isNull();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_isSharedWith(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSharedWith(QByteArray)const
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // isSharedWith(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_isSharedWith_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // isSharedWith(QByteArray)const
            bool cppResult = cppSelf->QByteArray::isSharedWith(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_isSharedWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.isSharedWith", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOf(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QByteArray,int)const
    // 1: lastIndexOf(QString,int)const
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // lastIndexOf(QString,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // lastIndexOf(QString,int)const
        }
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QByteArray,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(QByteArray,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // lastIndexOf(QByteArray,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

                if(!PyErr_Occurred()) {
                // lastIndexOf(QByteArray,int)const
                int cppResult = cppSelf->QByteArray::lastIndexOf(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
            case 1: // lastIndexOf(QString,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

                if(!PyErr_Occurred()) {
                // lastIndexOf(QString,int)const
                int cppResult = cppSelf->QByteArray::lastIndexOf(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<int >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int = -1", "QString, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.lastIndexOf", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_lastIndexOfByte(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "from" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOfByte(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOfByte(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOfByte(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOfByte", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(char,int)const
    if (Shiboken::Converter<char >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(char,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(char,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_lastIndexOfByte_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.lastIndexOfByte(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // lastIndexOf(char,int)const
            int cppResult = cppSelf->QByteArray::lastIndexOf(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_lastIndexOfByte_TypeError:
        const char* overloads[] = {"char, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.lastIndexOfByte", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_left(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: left(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // left(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_left_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // left(int)const
            QByteArray cppResult = cppSelf->QByteArray::left(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_left_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.left", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_leftJustified(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fill", "truncate" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.leftJustified(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.leftJustified(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.leftJustified(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:leftJustified", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: leftJustified(int,char,bool)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // leftJustified(int,char,bool)const
        } else if (Shiboken::Converter<char >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // leftJustified(int,char,bool)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // leftJustified(int,char,bool)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_leftJustified_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "fill");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "fill";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "truncate");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "truncate";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.leftJustified(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            char cpp_arg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : ' ';
            bool cpp_arg2 = pyargs[2] ? Shiboken::Converter<bool >::toCpp(pyargs[2]) : false;

            if(!PyErr_Occurred()) {
            // leftJustified(int,char,bool)const
            QByteArray cppResult = cppSelf->QByteArray::leftJustified(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_leftJustified_TypeError:
        const char* overloads[] = {"int, char = ' ', bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.leftJustified", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_length(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // length()const
            int cppResult = cppSelf->QByteArray::length();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_mid(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "len" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.mid(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.mid(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.mid(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mid", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mid(int,int)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mid(int,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // mid(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_mid_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "len");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "len";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.mid(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
            // mid(int,int)const
            QByteArray cppResult = cppSelf->QByteArray::mid(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_mid_TypeError:
        const char* overloads[] = {"int, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.mid", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_number(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f", "prec" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.number(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.number(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.number(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:number", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: number(double,char,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // number(double,char,int)
        } else if (Shiboken::Converter<char >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // number(double,char,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // number(double,char,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_number_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "f";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "prec");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "prec";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.number(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);
            char cpp_arg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : 'g';
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 6;

            if(!PyErr_Occurred()) {
            // number(double,char,int)
            QByteArray cppResult = QByteArray::number(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_number_TypeError:
        const char* overloads[] = {"float, char = 'g', int = 6", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.number", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_prepend(PyObject* self, PyObject* args)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "prepend", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: prepend(QByteArray)
    // 1: prepend(const char*,int)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // prepend(const char*,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        overloadId = 0; // prepend(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_prepend_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // prepend(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // prepend(QByteArray)
                QByteArray & cppResult = cppSelf->QByteArray::prepend(*cpp_arg0);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 1: // prepend(const char*,int)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // prepend(const char*,int)
                QByteArray & cppResult = cppSelf->QByteArray::prepend(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.prepend", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_prependByte(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(char)
    if (Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // prepend(char)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_prependByte_TypeError;

    // Call function/method
    {
        {
            char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // prepend(char)
            QByteArray & cppResult = cppSelf->QByteArray::prepend(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_prependByte_TypeError:
        const char* overloads[] = {"char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.prependByte", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_remove(PyObject* self, PyObject* args)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "remove", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: remove(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // remove(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_remove_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // remove(int,int)
            QByteArray & cppResult = cppSelf->QByteArray::remove(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_remove_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.remove", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_repeated(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: repeated(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // repeated(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_repeated_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // repeated(int)const
            QByteArray cppResult = cppSelf->QByteArray::repeated(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_repeated_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.repeated", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_replace(PyObject* self, PyObject* args)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: replace(char,char)
    // 1: replace(char,QByteArray)
    // 2: replace(char,QString)
    // 3: replace(QByteArray,QByteArray)
    // 4: replace(QString,QByteArray)
    // 5: replace(int,int,QByteArray)
    // 6: replace(int,int,const char*,int)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 4 && Shiboken::Converter<const char * >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 6; // replace(int,int,const char*,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[2])) {
            overloadId = 5; // replace(int,int,QByteArray)
        }
    } else if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[0]) && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
        overloadId = 4; // replace(QString,QByteArray)
    } else if (Shiboken::Converter<char >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            overloadId = 2; // replace(char,QString)
        } else if (numArgs == 2 && Shiboken::Converter<char >::isConvertible(pyargs[1])) {
            overloadId = 0; // replace(char,char)
        } else if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            overloadId = 1; // replace(char,QByteArray)
        }
    } else if (numArgs == 2 && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
        overloadId = 3; // replace(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_replace_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // replace(char,char)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
                char cpp_arg1 = Shiboken::Converter<char >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // replace(char,char)
                QByteArray & cppResult = cppSelf->QByteArray::replace(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 1: // replace(char,QByteArray)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // replace(char,QByteArray)
                QByteArray & cppResult = cppSelf->QByteArray::replace(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 2: // replace(char,QString)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // replace(char,QString)
                QByteArray & cppResult = cppSelf->QByteArray::replace(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 3: // replace(QByteArray,QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // replace(QByteArray,QByteArray)
                QByteArray & cppResult = cppSelf->QByteArray::replace(*cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 4: // replace(QString,QByteArray)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
                QByteArray* cpp_arg1 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // replace(QString,QByteArray)
                QByteArray & cppResult = cppSelf->QByteArray::replace(cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 5: // replace(int,int,QByteArray)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg2_auto_ptr;
                QByteArray* cpp_arg2 = Shiboken::Converter<QByteArray* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QByteArray >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // replace(int,int,QByteArray)
                QByteArray & cppResult = cppSelf->QByteArray::replace(cpp_arg0, cpp_arg1, *cpp_arg2);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
            case 6: // replace(int,int,const char*,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                const char * cpp_arg2 = Shiboken::Converter<const char * >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // replace(int,int,const char*,int)
                QByteArray & cppResult = cppSelf->QByteArray::replace(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_replace_TypeError:
        const char* overloads[] = {"char, char", "char, PySide.QtCore.QByteArray", "char, QString", "PySide.QtCore.QByteArray, PySide.QtCore.QByteArray", "QString, PySide.QtCore.QByteArray", "int, int, PySide.QtCore.QByteArray", "int, int, str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.replace", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_reserve(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reserve(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // reserve(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_reserve_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // reserve(int)
            cppSelf->QByteArray::reserve(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQByteArrayFunc_reserve_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.reserve", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_resize(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_resize_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resize(int)
            cppSelf->QByteArray::resize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQByteArrayFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.resize", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_right(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: right(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // right(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_right_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // right(int)const
            QByteArray cppResult = cppSelf->QByteArray::right(cpp_arg0);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_right_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.right", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_rightJustified(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fill", "truncate" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.rightJustified(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.rightJustified(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.rightJustified(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:rightJustified", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: rightJustified(int,char,bool)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // rightJustified(int,char,bool)const
        } else if (Shiboken::Converter<char >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // rightJustified(int,char,bool)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // rightJustified(int,char,bool)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_rightJustified_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "fill");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "fill";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "truncate");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "truncate";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.rightJustified(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            char cpp_arg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : ' ';
            bool cpp_arg2 = pyargs[2] ? Shiboken::Converter<bool >::toCpp(pyargs[2]) : false;

            if(!PyErr_Occurred()) {
            // rightJustified(int,char,bool)const
            QByteArray cppResult = cppSelf->QByteArray::rightJustified(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_rightJustified_TypeError:
        const char* overloads[] = {"int, char = ' ', bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.rightJustified", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_setDouble(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f", "prec" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setDouble(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setDouble(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setDouble(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setDouble", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setNum(double,char,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setNum(double,char,int)
        } else if (Shiboken::Converter<char >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setNum(double,char,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // setNum(double,char,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_setDouble_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "f";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "prec");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "prec";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setDouble(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            double cpp_arg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);
            char cpp_arg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : 'g';
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 6;

            if(!PyErr_Occurred()) {
            // setNum(double,char,int)
            QByteArray & cppResult = cppSelf->QByteArray::setNum(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_setDouble_TypeError:
        const char* overloads[] = {"float, char = 'g', int = 6", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.setDouble", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_setFloat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f", "prec" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setFloat(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setFloat(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setFloat(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setFloat", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setNum(float,char,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setNum(float,char,int)
        } else if (Shiboken::Converter<char >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setNum(float,char,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // setNum(float,char,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_setFloat_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "f";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "prec");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "prec";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setFloat(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            float cpp_arg0 = Shiboken::Converter<float >::toCpp(pyargs[0]);
            char cpp_arg1 = pyargs[1] ? Shiboken::Converter<char >::toCpp(pyargs[1]) : 'g';
            int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 6;

            if(!PyErr_Occurred()) {
            // setNum(float,char,int)
            QByteArray & cppResult = cppSelf->QByteArray::setNum(cpp_arg0, cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_setFloat_TypeError:
        const char* overloads[] = {"float, char = 'g', int = 6", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.setFloat", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_setInt(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setInt(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setInt(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setInt(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setInt", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setNum(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setNum(int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setNum(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_setInt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setInt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 10;

            if(!PyErr_Occurred()) {
            // setNum(int,int)
            QByteArray & cppResult = cppSelf->QByteArray::setNum(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_setInt_TypeError:
        const char* overloads[] = {"int, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.setInt", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_setRawData(PyObject* self, PyObject* args)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRawData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRawData(const char*,uint)
    if (numArgs == 2 && Shiboken::Converter<const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setRawData(const char*,uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_setRawData_TypeError;

    // Call function/method
    {
        {
            const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            uint cpp_arg1 = Shiboken::Converter<uint >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setRawData(const char*,uint)
            QByteArray & cppResult = cppSelf->QByteArray::setRawData(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_setRawData_TypeError:
        const char* overloads[] = {"str, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.setRawData", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_setShort(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setShort(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setShort(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setShort(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setShort", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setNum(short,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setNum(short,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setNum(short,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_setShort_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setShort(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            short cpp_arg0 = Shiboken::Converter<short >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 10;

            if(!PyErr_Occurred()) {
            // setNum(short,int)
            QByteArray & cppResult = cppSelf->QByteArray::setNum(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_setShort_TypeError:
        const char* overloads[] = {"short, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.setShort", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_setULongLong(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setULongLong(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setULongLong(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.setULongLong(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setULongLong", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setNum(qulonglong,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setNum(qulonglong,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setNum(qulonglong,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_setULongLong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "base";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.setULongLong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qulonglong cpp_arg0 = Shiboken::Converter<qulonglong >::toCpp(pyargs[0]);
            int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 10;

            if(!PyErr_Occurred()) {
            // setNum(qulonglong,int)
            QByteArray & cppResult = cppSelf->QByteArray::setNum(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QByteArray & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_setULongLong_TypeError:
        const char* overloads[] = {"unsigned long long, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.setULongLong", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_simplified(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // simplified()const
            QByteArray cppResult = cppSelf->QByteArray::simplified();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_size(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            int cppResult = cppSelf->QByteArray::size();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_split(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: split(char)const
    if (PyString_Check(arg)) {
        overloadId = 0; // split(char)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_split_TypeError;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // split(char)const
            // Begin code injection
            
            char c = PyString_AS_STRING(arg)[0];
            if (c) {
               pyResult = Shiboken::Converter<QList<QByteArray > >::toPython(cppSelf->split(c));
            }
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_split_TypeError:
        const char* overloads[] = {"char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.split", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_squeeze(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // squeeze()
            cppSelf->QByteArray::squeeze();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQByteArrayFunc_startsWith(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(char)const
    // 1: startsWith(QByteArray)const
    if (Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // startsWith(char)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 1; // startsWith(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_startsWith_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // startsWith(char)const
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // startsWith(char)const
                bool cppResult = cppSelf->QByteArray::startsWith(cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // startsWith(QByteArray)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // startsWith(QByteArray)const
                bool cppResult = cppSelf->QByteArray::startsWith(*cpp_arg0);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_startsWith_TypeError:
        const char* overloads[] = {"char", "PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.startsWith", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toBase64(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toBase64()const
            QByteArray cppResult = cppSelf->QByteArray::toBase64();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_toDouble(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toDouble(bool*)const
            // Begin code injection
            
            // TEMPLATE - fix_bool* - START
            bool ok_;
            double retval_ = cppSelf->toDouble(&ok_);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_toFloat(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toFloat(bool*)const
            // Begin code injection
            
            // TEMPLATE - fix_bool* - START
            bool ok_;
            float retval_ = cppSelf->toFloat(&ok_);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool* - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_toHex(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toHex()const
            QByteArray cppResult = cppSelf->QByteArray::toHex();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_toInt(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toInt(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toInt(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toInt", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toInt(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toInt(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toInt(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toInt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toInt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toInt(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            int retval_ = cppSelf->toInt(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toInt_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toInt", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toLong(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toLong(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toLong(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toLong", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toLong(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toLong(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toLong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toLong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toLong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toLong(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            long retval_ = cppSelf->toLong(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toLong_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toLong", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toLongLong(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toLongLong(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toLongLong(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toLongLong", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toLongLong(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toLongLong(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toLongLong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toLongLong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toLongLong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toLongLong(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            qlonglong retval_ = cppSelf->toLongLong(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toLongLong_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toLongLong", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toLower(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toLower()const
            QByteArray cppResult = cppSelf->QByteArray::toLower();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_toPercentEncoding(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "exclude", "include", "percent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toPercentEncoding(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toPercentEncoding(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:toPercentEncoding", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: toPercentEncoding(QByteArray,QByteArray,char)const
    if (numArgs == 0) {
        overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
    } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
        } else if (Shiboken::Converter<const QByteArray & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
            } else if (Shiboken::Converter<char >::isConvertible(pyargs[2])) {
                overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toPercentEncoding_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "exclude");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "exclude";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "include");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "include";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "percent");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "percent";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toPercentEncoding(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray cpp_arg0_tmp = QByteArray();
            QByteArray* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
            if (pyargs[0] && !Shiboken::Converter<QByteArray >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg1_auto_ptr;
            QByteArray cpp_arg1_tmp = QByteArray();
            QByteArray* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QByteArray* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QByteArray >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg1);
            char cpp_arg2 = pyargs[2] ? Shiboken::Converter<char >::toCpp(pyargs[2]) : '%';

            if(!PyErr_Occurred()) {
            // toPercentEncoding(QByteArray,QByteArray,char)const
            QByteArray cppResult = cppSelf->QByteArray::toPercentEncoding(*cpp_arg0, *cpp_arg1, cpp_arg2);
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toPercentEncoding_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray(), PySide.QtCore.QByteArray = QByteArray(), char = '%'", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArray.toPercentEncoding", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toShort(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toShort(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toShort(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toShort", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toShort(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toShort(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toShort(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toShort_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toShort(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toShort(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            short retval_ = cppSelf->toShort(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toShort_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toShort", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toUInt(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toUInt(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toUInt(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toUInt", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toUInt(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toUInt(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toUInt(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toUInt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toUInt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toUInt(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            uint retval_ = cppSelf->toUInt(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toUInt_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toUInt", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toULong(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toULong(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toULong(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toULong", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toULong(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toULong(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toULong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toULong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toULong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toULong(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            ulong retval_ = cppSelf->toULong(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toULong_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toULong", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toULongLong(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toULongLong(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toULongLong(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toULongLong", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toULongLong(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toULongLong(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toULongLong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toULongLong_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toULongLong(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toULongLong(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            qulonglong retval_ = cppSelf->toULongLong(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toULongLong_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toULongLong", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toUShort(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "base" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toUShort(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArray.toUShort(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toUShort", &arg))
        return 0;


    // Overloaded function decisor
    // 0: toUShort(bool*,int)const
    if (numArgs == 0) {
        overloadId = 0; // toUShort(bool*,int)const
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // toUShort(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_toUShort_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "base");
                if (value) {
                    if (arg)
                        errorArgName = "base";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArray.toUShort(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 10;

            if(!PyErr_Occurred()) {
            // toUShort(bool*,int)const
            // Begin code injection
            
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            ushort retval_ = cppSelf->toUShort(&ok_, cpp_arg0);
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool*,arg - END
            
            // End of code injection


            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc_toUShort_TypeError:
        const char* overloads[] = {"bool = 0, int = 10", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.toUShort", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc_toUpper(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toUpper()const
            QByteArray cppResult = cppSelf->QByteArray::toUpper();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_trimmed(PyObject* self)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // trimmed()const
            QByteArray cppResult = cppSelf->QByteArray::trimmed();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQByteArrayFunc_truncate(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: truncate(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // truncate(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc_truncate_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // truncate(int)
            cppSelf->QByteArray::truncate(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQByteArrayFunc_truncate_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.truncate", overloads);
        return 0;
}

static PyMethodDef SbkQByteArray_methods[] = {
    {"append", (PyCFunction)SbkQByteArrayFunc_append, METH_VARARGS},
    {"appendByte", (PyCFunction)SbkQByteArrayFunc_appendByte, METH_O},
    {"at", (PyCFunction)SbkQByteArrayFunc_at, METH_O},
    {"capacity", (PyCFunction)SbkQByteArrayFunc_capacity, METH_NOARGS},
    {"chop", (PyCFunction)SbkQByteArrayFunc_chop, METH_O},
    {"clear", (PyCFunction)SbkQByteArrayFunc_clear, METH_NOARGS},
    {"count", (PyCFunction)SbkQByteArrayFunc_count, METH_NOARGS|METH_O},
    {"data", (PyCFunction)SbkQByteArrayFunc_data, METH_NOARGS},
    {"endsWith", (PyCFunction)SbkQByteArrayFunc_endsWith, METH_O},
    {"fill", (PyCFunction)SbkQByteArrayFunc_fill, METH_VARARGS|METH_KEYWORDS},
    {"fromBase64", (PyCFunction)SbkQByteArrayFunc_fromBase64, METH_O|METH_STATIC},
    {"fromHex", (PyCFunction)SbkQByteArrayFunc_fromHex, METH_O|METH_STATIC},
    {"fromInt", (PyCFunction)SbkQByteArrayFunc_fromInt, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromLongLong", (PyCFunction)SbkQByteArrayFunc_fromLongLong, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromPercentEncoding", (PyCFunction)SbkQByteArrayFunc_fromPercentEncoding, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"indexOf", (PyCFunction)SbkQByteArrayFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"indexOfByte", (PyCFunction)SbkQByteArrayFunc_indexOfByte, METH_VARARGS|METH_KEYWORDS},
    {"insert", (PyCFunction)SbkQByteArrayFunc_insert, METH_VARARGS},
    {"insertByte", (PyCFunction)SbkQByteArrayFunc_insertByte, METH_VARARGS},
    {"isEmpty", (PyCFunction)SbkQByteArrayFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)SbkQByteArrayFunc_isNull, METH_NOARGS},
    {"isSharedWith", (PyCFunction)SbkQByteArrayFunc_isSharedWith, METH_O},
    {"lastIndexOf", (PyCFunction)SbkQByteArrayFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"lastIndexOfByte", (PyCFunction)SbkQByteArrayFunc_lastIndexOfByte, METH_VARARGS|METH_KEYWORDS},
    {"left", (PyCFunction)SbkQByteArrayFunc_left, METH_O},
    {"leftJustified", (PyCFunction)SbkQByteArrayFunc_leftJustified, METH_VARARGS|METH_KEYWORDS},
    {"length", (PyCFunction)SbkQByteArrayFunc_length, METH_NOARGS},
    {"mid", (PyCFunction)SbkQByteArrayFunc_mid, METH_VARARGS|METH_KEYWORDS},
    {"number", (PyCFunction)SbkQByteArrayFunc_number, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"prepend", (PyCFunction)SbkQByteArrayFunc_prepend, METH_VARARGS},
    {"prependByte", (PyCFunction)SbkQByteArrayFunc_prependByte, METH_O},
    {"remove", (PyCFunction)SbkQByteArrayFunc_remove, METH_VARARGS},
    {"repeated", (PyCFunction)SbkQByteArrayFunc_repeated, METH_O},
    {"replace", (PyCFunction)SbkQByteArrayFunc_replace, METH_VARARGS},
    {"reserve", (PyCFunction)SbkQByteArrayFunc_reserve, METH_O},
    {"resize", (PyCFunction)SbkQByteArrayFunc_resize, METH_O},
    {"right", (PyCFunction)SbkQByteArrayFunc_right, METH_O},
    {"rightJustified", (PyCFunction)SbkQByteArrayFunc_rightJustified, METH_VARARGS|METH_KEYWORDS},
    {"setDouble", (PyCFunction)SbkQByteArrayFunc_setDouble, METH_VARARGS|METH_KEYWORDS},
    {"setFloat", (PyCFunction)SbkQByteArrayFunc_setFloat, METH_VARARGS|METH_KEYWORDS},
    {"setInt", (PyCFunction)SbkQByteArrayFunc_setInt, METH_VARARGS|METH_KEYWORDS},
    {"setRawData", (PyCFunction)SbkQByteArrayFunc_setRawData, METH_VARARGS},
    {"setShort", (PyCFunction)SbkQByteArrayFunc_setShort, METH_VARARGS|METH_KEYWORDS},
    {"setULongLong", (PyCFunction)SbkQByteArrayFunc_setULongLong, METH_VARARGS|METH_KEYWORDS},
    {"simplified", (PyCFunction)SbkQByteArrayFunc_simplified, METH_NOARGS},
    {"size", (PyCFunction)SbkQByteArrayFunc_size, METH_NOARGS},
    {"split", (PyCFunction)SbkQByteArrayFunc_split, METH_O},
    {"squeeze", (PyCFunction)SbkQByteArrayFunc_squeeze, METH_NOARGS},
    {"startsWith", (PyCFunction)SbkQByteArrayFunc_startsWith, METH_O},
    {"toBase64", (PyCFunction)SbkQByteArrayFunc_toBase64, METH_NOARGS},
    {"toDouble", (PyCFunction)SbkQByteArrayFunc_toDouble, METH_NOARGS},
    {"toFloat", (PyCFunction)SbkQByteArrayFunc_toFloat, METH_NOARGS},
    {"toHex", (PyCFunction)SbkQByteArrayFunc_toHex, METH_NOARGS},
    {"toInt", (PyCFunction)SbkQByteArrayFunc_toInt, METH_VARARGS|METH_KEYWORDS},
    {"toLong", (PyCFunction)SbkQByteArrayFunc_toLong, METH_VARARGS|METH_KEYWORDS},
    {"toLongLong", (PyCFunction)SbkQByteArrayFunc_toLongLong, METH_VARARGS|METH_KEYWORDS},
    {"toLower", (PyCFunction)SbkQByteArrayFunc_toLower, METH_NOARGS},
    {"toPercentEncoding", (PyCFunction)SbkQByteArrayFunc_toPercentEncoding, METH_VARARGS|METH_KEYWORDS},
    {"toShort", (PyCFunction)SbkQByteArrayFunc_toShort, METH_VARARGS|METH_KEYWORDS},
    {"toUInt", (PyCFunction)SbkQByteArrayFunc_toUInt, METH_VARARGS|METH_KEYWORDS},
    {"toULong", (PyCFunction)SbkQByteArrayFunc_toULong, METH_VARARGS|METH_KEYWORDS},
    {"toULongLong", (PyCFunction)SbkQByteArrayFunc_toULongLong, METH_VARARGS|METH_KEYWORDS},
    {"toUShort", (PyCFunction)SbkQByteArrayFunc_toUShort, METH_VARARGS|METH_KEYWORDS},
    {"toUpper", (PyCFunction)SbkQByteArrayFunc_toUpper, METH_NOARGS},
    {"trimmed", (PyCFunction)SbkQByteArrayFunc_trimmed, METH_NOARGS},
    {"truncate", (PyCFunction)SbkQByteArrayFunc_truncate, METH_O},
    {0} // Sentinel
};

static PyObject* SbkQByteArrayFunc___add__(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QByteArray >::checkType(arg) && !Shiboken::Converter<QByteArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && SbkBaseWrapper_Check(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(char,QByteArray)
    // 1: operator+(QByteArray,char)
    // 2: operator+(QByteArray,QByteArray)
    // 3: operator+(QString,QByteArray)
    // 4: operator+(QByteArray,QString)
    // 5: operator+(const char*,QByteArray)
    // 6: operator+(QByteArray,const char*)
    if (!isReverse && Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 6; // operator+(QByteArray,const char*)
    } else if (isReverse && Shiboken::Converter<const char * >::isConvertible(arg)) {
        overloadId = 5; // operator+(const char*,QByteArray)
    } else if (!isReverse && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 4; // operator+(QByteArray,QString)
    } else if (isReverse && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 3; // operator+(QString,QByteArray)
    } else if (!isReverse && Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 2; // operator+(QByteArray,QByteArray)
    } else if (!isReverse && Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 1; // operator+(QByteArray,char)
    } else if (isReverse && Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // operator+(char,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc___add___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator+(char,QByteArray)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+(char,QByteArray) [reverse operator]
                const QByteArray cppResult = cpp_arg0 + (*cppSelf);
                pyResult = Shiboken::Converter< QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator+(QByteArray,char)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+(QByteArray,char)
                const QByteArray cppResult = (*cppSelf) + cpp_arg0;
                pyResult = Shiboken::Converter< QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator+(QByteArray,QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator+(QByteArray,QByteArray)
                const QByteArray cppResult = (*cppSelf) + (*cpp_arg0);
                pyResult = Shiboken::Converter< QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 3: // operator+(QString,QByteArray)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+(QString,QByteArray) [reverse operator]
                const QString cppResult = cpp_arg0 + (*cppSelf);
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 4: // operator+(QByteArray,QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+(QByteArray,QString)
                const QString cppResult = (*cppSelf) + cpp_arg0;
                pyResult = Shiboken::Converter<QString >::toPython(cppResult);
                }
                break;
            }
            case 5: // operator+(const char*,QByteArray)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+(const char*,QByteArray) [reverse operator]
                const QByteArray cppResult = cpp_arg0 + (*cppSelf);
                pyResult = Shiboken::Converter< QByteArray >::toPython(cppResult);
                }
                break;
            }
            case 6: // operator+(QByteArray,const char*)
            {
                const char * cpp_arg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+(QByteArray,const char*)
                const QByteArray cppResult = (*cppSelf) + cpp_arg0;
                pyResult = Shiboken::Converter< QByteArray >::toPython(cppResult);
                }
                break;
            }
        }
        }

    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQByteArrayFunc___add___TypeError:
        const char* overloads[] = {"char", "char", "PySide.QtCore.QByteArray", "QString", "QString", "str", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.__add__", overloads);
        return 0;
}

static PyObject* SbkQByteArrayFunc___iadd__(PyObject* self, PyObject* arg)
{
    QByteArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter<QByteArray >::checkType(arg) && !Shiboken::Converter<QByteArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(char)
    // 1: operator+=(QByteArray)
    // 2: operator+=(QString)
    if (!isReverse && Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 2; // operator+=(QString)
    } else if (!isReverse && Shiboken::Converter<char >::isConvertible(arg)) {
        overloadId = 0; // operator+=(char)
    } else if (!isReverse && Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 1; // operator+=(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQByteArrayFunc___iadd___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator+=(char)
            {
                char cpp_arg0 = Shiboken::Converter<char >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+=(char)
                (*cppSelf) += cpp_arg0;
                }
                break;
            }
            case 1: // operator+=(QByteArray)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
                QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
                if (!Shiboken::Converter<QByteArray >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // operator+=(QByteArray)
                (*cppSelf) += (*cpp_arg0);
                }
                break;
            }
            case 2: // operator+=(QString)
            {
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // operator+=(QString)
                (*cppSelf) += cpp_arg0;
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    SbkQByteArrayFunc___iadd___TypeError:
        const char* overloads[] = {"char", "PySide.QtCore.QByteArray", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArray.__iadd__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods SbkQByteArray_as_number = {
    /*nb_add*/                  (binaryfunc)SbkQByteArrayFunc___add__,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)SbkQByteArrayFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

Py_ssize_t SbkQByteArrayFunc___len__(PyObject* self)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    QByteArray* cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);
    (void)cppSelf; // avoid warnings about unused variables
    // Begin code injection
    
    return cppSelf->count();
    
    // End of code injection
}

PyObject* SbkQByteArrayFunc___getitem__(PyObject* self, Py_ssize_t _i)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    QByteArray* cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);
    (void)cppSelf; // avoid warnings about unused variables
    // Begin code injection
    
    if (_i < 0 || _i >= cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    } else {
        char res[2];
        res[0] = cppSelf->at(_i);
        res[1] = 0;
        return PyString_FromString(res);
    }
    
    // End of code injection
}

int SbkQByteArrayFunc___setitem__(PyObject* self, Py_ssize_t _i, PyObject* _value)
{
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    QByteArray* cppSelf = Shiboken::Converter<QByteArray* >::toCpp(self);
    (void)cppSelf; // avoid warnings about unused variables
    // Begin code injection
    
    cppSelf->remove(_i, 1);
    PyObject* args = Py_BuildValue("(nO)", _i, _value);
    PyObject* result = SbkQByteArrayFunc_insert(self, args);
    Py_DECREF(args);
    Py_XDECREF(result);
    return !result ? -1 : 0;
    
    // End of code injection
}

static PySequenceMethods PyQByteArray_as_sequence = {
    /*sq_length*/ &SbkQByteArrayFunc___len__,
    /*sq_concat*/ 0,
    /*sq_repeat*/ 0,
    /*sq_item*/ &SbkQByteArrayFunc___getitem__,
    /*sq_slice*/ 0,
    /*sq_ass_item*/ &SbkQByteArrayFunc___setitem__,
    /*sq_ass_slice*/ 0,
    /*sq_contains*/ 0,
    /*sq_inplace_concat*/ 0,
    /*sq_inplace_repeat*/ 0
};

// Rich comparison
static PyObject* SbkQByteArray_richcompare(PyObject* self, PyObject* other, int op)
{
    bool result = false;
    QByteArray& cpp_self = *Shiboken::Converter<QByteArray* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter<const QByteArray & >::isConvertible(other)) {
                // operator!=(const QByteArray & a2)
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QByteArray  >::toCpp(other) : (cpp_self != (*cpp_other));
            } else if (Shiboken::Converter<QString >::isConvertible(other)) {
                // operator!=(const QString & s2) const
                const QString & cpp_other = Shiboken::Converter<QString >::toCpp(other);
                result = (cpp_self != cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator!=(const char * a1)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self != cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator!=(const char * a2)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self != cpp_other);
            } else if (Shiboken::Converter<QByteArray >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QByteArray > cpp_other_auto_ptr;
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                if (!Shiboken::Converter<QByteArray >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QByteArray >(cpp_other);
                result = (cpp_self != (*cpp_other));
            } else goto SbkQByteArray_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter<const QByteArray & >::isConvertible(other)) {
                // operator<(const QByteArray & a2)
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QByteArray  >::toCpp(other) : (cpp_self < (*cpp_other));
            } else if (Shiboken::Converter<QString >::isConvertible(other)) {
                // operator<(const QString & s2) const
                const QString & cpp_other = Shiboken::Converter<QString >::toCpp(other);
                result = (cpp_self < cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator<(const char * a1)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self < cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator<(const char * a2)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self < cpp_other);
            } else if (Shiboken::Converter<QByteArray >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QByteArray > cpp_other_auto_ptr;
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                if (!Shiboken::Converter<QByteArray >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QByteArray >(cpp_other);
                result = (cpp_self < (*cpp_other));
            } else goto SbkQByteArray_RichComparison_TypeError;

            break;
        case Py_LE:
            if (Shiboken::Converter<const QByteArray & >::isConvertible(other)) {
                // operator<=(const QByteArray & a2)
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QByteArray  >::toCpp(other) : (cpp_self <= (*cpp_other));
            } else if (Shiboken::Converter<QString >::isConvertible(other)) {
                // operator<=(const QString & s2) const
                const QString & cpp_other = Shiboken::Converter<QString >::toCpp(other);
                result = (cpp_self <= cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator<=(const char * a1)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self <= cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator<=(const char * a2)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self <= cpp_other);
            } else if (Shiboken::Converter<QByteArray >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QByteArray > cpp_other_auto_ptr;
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                if (!Shiboken::Converter<QByteArray >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QByteArray >(cpp_other);
                result = (cpp_self <= (*cpp_other));
            } else goto SbkQByteArray_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter<const QByteArray & >::isConvertible(other)) {
                // operator==(const QByteArray & a2)
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QByteArray  >::toCpp(other) : (cpp_self == (*cpp_other));
            } else if (Shiboken::Converter<QString >::isConvertible(other)) {
                // operator==(const QString & s2) const
                const QString & cpp_other = Shiboken::Converter<QString >::toCpp(other);
                result = (cpp_self == cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator==(const char * a1)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self == cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator==(const char * a2)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self == cpp_other);
            } else if (Shiboken::Converter<QByteArray >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QByteArray > cpp_other_auto_ptr;
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                if (!Shiboken::Converter<QByteArray >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QByteArray >(cpp_other);
                result = (cpp_self == (*cpp_other));
            } else goto SbkQByteArray_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter<const QByteArray & >::isConvertible(other)) {
                // operator>(const QByteArray & a2)
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QByteArray  >::toCpp(other) : (cpp_self > (*cpp_other));
            } else if (Shiboken::Converter<QString >::isConvertible(other)) {
                // operator>(const QString & s2) const
                const QString & cpp_other = Shiboken::Converter<QString >::toCpp(other);
                result = (cpp_self > cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator>(const char * a1)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self > cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator>(const char * a2)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self > cpp_other);
            } else if (Shiboken::Converter<QByteArray >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QByteArray > cpp_other_auto_ptr;
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                if (!Shiboken::Converter<QByteArray >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QByteArray >(cpp_other);
                result = (cpp_self > (*cpp_other));
            } else goto SbkQByteArray_RichComparison_TypeError;

            break;
        case Py_GE:
            if (Shiboken::Converter<const QByteArray & >::isConvertible(other)) {
                // operator>=(const QByteArray & a2)
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                result = !cpp_other ? cpp_self == Shiboken::Converter< QByteArray  >::toCpp(other) : (cpp_self >= (*cpp_other));
            } else if (Shiboken::Converter<QString >::isConvertible(other)) {
                // operator>=(const QString & s2) const
                const QString & cpp_other = Shiboken::Converter<QString >::toCpp(other);
                result = (cpp_self >= cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator>=(const char * a1)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self >= cpp_other);
            } else if (Shiboken::Converter<const char * >::isConvertible(other)) {
                // operator>=(const char * a2)
                const char * cpp_other = Shiboken::Converter<const char * >::toCpp(other);
                result = (cpp_self >= cpp_other);
            } else if (Shiboken::Converter<QByteArray >::isConvertible(other)) {
                if (Shiboken::cppObjectIsInvalid(other))
                    return 0;
                std::auto_ptr<QByteArray > cpp_other_auto_ptr;
                QByteArray* cpp_other = Shiboken::Converter<QByteArray* >::toCpp(other);
                if (!Shiboken::Converter<QByteArray >::checkType(other))
                    cpp_other_auto_ptr = std::auto_ptr<QByteArray >(cpp_other);
                result = (cpp_self >= (*cpp_other));
            } else goto SbkQByteArray_RichComparison_TypeError;

            break;
        default:
            PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
            return 0;
    }

    if (result)
        Py_RETURN_TRUE;
    SbkQByteArray_RichComparison_TypeError:
    Py_RETURN_FALSE;

}

} // extern "C"

static long SbkQByteArray_HashFunc(PyObject* obj){
    return qHash(Shiboken::Converter<QByteArray >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQByteArray_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QByteArray",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkQByteArray_as_number,
    /*tp_as_sequence*/      &PyQByteArray_as_sequence,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &SbkQByteArray_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              SbkQByteArrayFunc___str__,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      SbkQByteArray_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQByteArray_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQByteArray_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QByteArray >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QByteArray",
    /*user_data*/           0
};
} //extern


void init_QByteArray(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QBYTEARRAY_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQByteArray_Type);


    if (PyType_Ready((PyTypeObject*)&SbkQByteArray_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQByteArray_Type));
    PyModule_AddObject(module, "QByteArray",
        ((PyObject*)&SbkQByteArray_Type));



    // Begin code injection
    
    #if PY_VERSION_HEX < 0x03000000
        Shiboken::SbkType<QByteArray>()->tp_as_buffer = &SbkQByteArrayBufferProc;
        Shiboken::SbkType<QByteArray>()->tp_flags |= Py_TPFLAGS_HAVE_GETCHARBUFFER;
    #endif
    
    // End of code injection
    Shiboken::TypeResolver::createValueTypeResolver<QByteArray >("QByteArray");
    Shiboken::TypeResolver::createObjectTypeResolver<QByteArray >("QByteArray*");
    Shiboken::TypeResolver::createValueTypeResolver<QByteArray >(typeid(QByteArray).name());
    PySide::initQtMetaType<QByteArray >();
}


