/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qabstractitemview_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemdelegate.h>
#include <qabstractitemmodel.h>
#include <qabstractitemview.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qitemselectionmodel.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QAbstractItemViewWrapper::QAbstractItemViewWrapper(QWidget * parent) : QAbstractItemView(parent), m_metaObject(0) {
    // ... middle
}

void QAbstractItemViewWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QFrame::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEditor"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::closeEditor(editor, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QWidget * >::toPython(editor),
        Shiboken::Converter<QAbstractItemDelegate::EndEditHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::commitData(QWidget * editor)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "commitData"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::commitData(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWidget * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::currentChanged(const QModelIndex & current, const QModelIndex & previous)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "currentChanged"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::currentChanged(current, previous);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QModelIndex & >::toPython(current),
        Shiboken::Converter<const QModelIndex & >::toPython(previous)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dataChanged"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::dataChanged(topLeft, bottomRight);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QModelIndex & >::toPython(topLeft),
        Shiboken::Converter<const QModelIndex & >::toPython(bottomRight)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QAbstractItemViewWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::doItemsLayout()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "doItemsLayout"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::doItemsLayout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QAbstractItemViewWrapper::edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "edit"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::edit(index, trigger, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter<const QModelIndex & >::toPython(index),
        Shiboken::Converter<QAbstractItemView::EditTrigger >::toPython(trigger),
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.edit", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 2));
    return cppResult;
}

void QAbstractItemViewWrapper::editorDestroyed(QObject * editor)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "editorDestroyed"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::editorDestroyed(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QObject * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QAbstractItemViewWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemViewWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QAbstractItemViewWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QAbstractItemViewWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QAbstractItemViewWrapper::horizontalOffset() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "horizontalOffset"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.horizontalOffset()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.horizontalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::horizontalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "horizontalScrollbarAction"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::horizontalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::horizontalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "horizontalScrollbarValueChanged"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::horizontalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QModelIndex QAbstractItemViewWrapper::indexAt(const QPoint & point) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "indexAt"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.indexAt()' not implemented.");
        return QModelIndex();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QPoint & >::toPython(point)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.indexAt", SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter<QModelIndex >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QAbstractItemViewWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemViewWrapper::isIndexHidden(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "isIndexHidden"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.isIndexHidden()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.isIndexHidden", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::keyReleaseEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::keyboardSearch(const QString & search)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyboardSearch"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::keyboardSearch(search);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QString >::toPython(search)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QAbstractItemViewWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QAbstractItemViewWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QModelIndex QAbstractItemViewWrapper::moveCursor(QAbstractItemView::CursorAction cursorAction, QFlags<Qt::KeyboardModifier> modifiers)
{
    return QModelIndex();
}

void QAbstractItemViewWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QAbstractItemViewWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QAbstractItemView.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QAbstractItemViewWrapper::paintEvent(QPaintEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::paintEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "rowsAboutToBeRemoved"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::rowsAboutToBeRemoved(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter<const QModelIndex & >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::rowsInserted(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "rowsInserted"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::rowsInserted(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter<const QModelIndex & >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "scrollTo"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.scrollTo()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QModelIndex & >::toPython(index),
        Shiboken::Converter<QAbstractItemView::ScrollHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::selectAll()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "selectAll"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::selectAll();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QList<QModelIndex > QAbstractItemViewWrapper::selectedIndexes() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "selectedIndexes"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::selectedIndexes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QList<QModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.selectedIndexes", "list", pyResult->ob_type->tp_name);
        return QList<QModelIndex >();
    }
    QList<QModelIndex > cppResult(Shiboken::Converter<QList<QModelIndex > >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::selectionChanged(const QItemSelection & selected, const QItemSelection & deselected)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "selectionChanged"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::selectionChanged(selected, deselected);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QItemSelection & >::toPython(selected),
        Shiboken::Converter<const QItemSelection & >::toPython(deselected)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QFlags<QItemSelectionModel::SelectionFlag> QAbstractItemViewWrapper::selectionCommand(const QModelIndex & index, const QEvent * event) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "selectionCommand"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::selectionCommand(index, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QModelIndex & >::toPython(index),
        Shiboken::Converter< QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.selectionCommand", SbkType<QFlags<QItemSelectionModel::SelectionFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    QFlags<QItemSelectionModel::SelectionFlag> cppResult(Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QAbstractItemViewWrapper::setModel(QAbstractItemModel * model)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setModel"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::setModel(model);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QAbstractItemModel * >::toPython(model)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::setRootIndex(const QModelIndex & index)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setRootIndex"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::setRootIndex(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setSelection"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.setSelection()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<const QRect & >::toPython(rect),
        Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::setSelectionModel(QItemSelectionModel * selectionModel)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setSelectionModel"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::setSelectionModel(selectionModel);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QItemSelectionModel * >::toPython(selectionModel)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QWidget::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QAbstractItemViewWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

int QAbstractItemViewWrapper::sizeHintForColumn(int column) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHintForColumn"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::sizeHintForColumn(column);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        column
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.sizeHintForColumn", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

int QAbstractItemViewWrapper::sizeHintForRow(int row) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHintForRow"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::sizeHintForRow(row);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        row
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.sizeHintForRow", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::startDrag(QFlags<Qt::DropAction> supportedActions)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "startDrag"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::startDrag(supportedActions);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFlags<Qt::DropAction> >::toPython(supportedActions)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractItemViewWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::timerEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::updateEditorData()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "updateEditorData"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::updateEditorData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::updateEditorGeometries()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "updateEditorGeometries"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::updateEditorGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::updateGeometries()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "updateGeometries"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::updateGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QAbstractItemViewWrapper::verticalOffset() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "verticalOffset"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.verticalOffset()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.verticalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::verticalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "verticalScrollbarAction"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::verticalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QAbstractItemViewWrapper::verticalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "verticalScrollbarValueChanged"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::verticalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

QStyleOptionViewItem QAbstractItemViewWrapper::viewOptions() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "viewOptions"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::viewOptions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStyleOptionViewItem();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QStyleOptionViewItem >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.viewOptions", SbkType<QStyleOptionViewItem >()->tp_name, pyResult->ob_type->tp_name);
        return QStyleOptionViewItem();
    }
    QStyleOptionViewItem cppResult(Shiboken::Converter<QStyleOptionViewItem >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractItemViewWrapper::viewportEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        return this->QAbstractItemView::viewportEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

QRect QAbstractItemViewWrapper::visualRect(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "visualRect"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.visualRect()' not implemented.");
        return QRect();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QModelIndex & >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.visualRect", SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter<QRect >::toCpp(pyResult));
    return cppResult;
}

QRegion QAbstractItemViewWrapper::visualRegionForSelection(const QItemSelection & selection) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "visualRegionForSelection"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.visualRegionForSelection()' not implemented.");
        return QRegion();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QItemSelection & >::toPython(selection)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRegion();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QRegion >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractItemView.visualRegionForSelection", SbkType<QRegion >()->tp_name, pyResult->ob_type->tp_name);
        return QRegion();
    }
    QRegion cppResult(Shiboken::Converter<QRegion >::toCpp(pyResult));
    return cppResult;
}

void QAbstractItemViewWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QAbstractItemViewWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QAbstractItemView::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QAbstractItemViewWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAbstractItemView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QAbstractItemViewWrapper::~QAbstractItemViewWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQAbstractItemView_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractItemView >()))
        return -1;

    QAbstractItemViewWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAbstractItemView' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QAbstractItemView", &arg))
        return -1;

    // Overloaded function decisor
    // 0: QAbstractItemView(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractItemView(QWidget*)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // QAbstractItemView(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemView_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (arg)
                        errorArgName = "parent";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QAbstractItemView(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(arg))
                return -1;
            QWidget* cpp_arg0 = arg ? Shiboken::Converter<QWidget* >::toCpp(arg) : 0;

            if(!PyErr_Occurred()) {
            // QAbstractItemView(QWidget*)
            cptr = new QAbstractItemViewWrapper(cpp_arg0);
            Shiboken::setParent(arg, self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractItemView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQAbstractItemView_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQAbstractItemView_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView", overloads);
        return -1;
}

static PyObject* SbkQAbstractItemViewFunc_alternatingRowColors(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alternatingRowColors()const
            bool cppResult = cppSelf->QAbstractItemView::alternatingRowColors();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_autoScrollMargin(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoScrollMargin()const
            int cppResult = cppSelf->QAbstractItemView::autoScrollMargin();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_clearSelection(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearSelection()
            cppSelf->QAbstractItemView::clearSelection();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_closeEditor(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "closeEditor", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)
    if (numArgs == 2 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QAbstractItemDelegate::EndEditHint >::isConvertible(pyargs[1])) {
        overloadId = 0; // closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_closeEditor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            QAbstractItemDelegate::EndEditHint cpp_arg1 = Shiboken::Converter<QAbstractItemDelegate::EndEditHint >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)
            cppSelf->QAbstractItemView::closeEditor(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_closeEditor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtGui.QAbstractItemDelegate.EndEditHint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.closeEditor", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_closePersistentEditor(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: closePersistentEditor(QModelIndex)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // closePersistentEditor(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_closePersistentEditor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // closePersistentEditor(QModelIndex)
            cppSelf->QAbstractItemView::closePersistentEditor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_closePersistentEditor_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.closePersistentEditor", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_commitData(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: commitData(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // commitData(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_commitData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // commitData(QWidget*)
            cppSelf->QAbstractItemView::commitData(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_commitData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.commitData", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_currentChanged(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "currentChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: currentChanged(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // currentChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_currentChanged_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // currentChanged(QModelIndex,QModelIndex)
            cppSelf->QAbstractItemView::currentChanged(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_currentChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.currentChanged", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_currentIndex(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentIndex()const
            QModelIndex cppResult = cppSelf->QAbstractItemView::currentIndex();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_dataChanged(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dataChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: dataChanged(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[1])) {
        overloadId = 0; // dataChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_dataChanged_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QModelIndex* cpp_arg1 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // dataChanged(QModelIndex,QModelIndex)
            cppSelf->QAbstractItemView::dataChanged(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_dataChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.dataChanged", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_defaultDropAction(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // defaultDropAction()const
            Qt::DropAction cppResult = cppSelf->QAbstractItemView::defaultDropAction();
            pyResult = Shiboken::Converter<Qt::DropAction >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_dirtyRegionOffset(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dirtyRegionOffset()const
            QPoint cppResult = cppSelf->QAbstractItemView::dirtyRegionOffset();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_doAutoScroll(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // doAutoScroll()
            cppSelf->QAbstractItemView::doAutoScroll();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_doItemsLayout(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // doItemsLayout()
            cppSelf->QAbstractItemView::doItemsLayout();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_dragDropMode(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dragDropMode()const
            QAbstractItemView::DragDropMode cppResult = cppSelf->QAbstractItemView::dragDropMode();
            pyResult = Shiboken::Converter<QAbstractItemView::DragDropMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_dragDropOverwriteMode(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dragDropOverwriteMode()const
            bool cppResult = cppSelf->QAbstractItemView::dragDropOverwriteMode();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_dragEnabled(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dragEnabled()const
            bool cppResult = cppSelf->QAbstractItemView::dragEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QDragEnterEvent*)
    if (Shiboken::Converter<QDragEnterEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragEnterEvent* cpp_arg0 = Shiboken::Converter<QDragEnterEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragEnterEvent(QDragEnterEvent*)
            cppSelf->QAbstractItemView::dragEnterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragEnterEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.dragEnterEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter<QDragLeaveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragLeaveEvent* cpp_arg0 = Shiboken::Converter<QDragLeaveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragLeaveEvent(QDragLeaveEvent*)
            cppSelf->QAbstractItemView::dragLeaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter<QDragMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragMoveEvent* cpp_arg0 = Shiboken::Converter<QDragMoveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragMoveEvent(QDragMoveEvent*)
            cppSelf->QAbstractItemView::dragMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.dragMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter<QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDropEvent* cpp_arg0 = Shiboken::Converter<QDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dropEvent(QDropEvent*)
            cppSelf->QAbstractItemView::dropEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.dropEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_dropIndicatorPosition(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dropIndicatorPosition()const
            QAbstractItemView::DropIndicatorPosition cppResult = cppSelf->QAbstractItemView::dropIndicatorPosition();
            pyResult = Shiboken::Converter<QAbstractItemView::DropIndicatorPosition >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_edit(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQAbstractItemViewFunc_edit_TypeError;

    if (!PyArg_UnpackTuple(args, "edit", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: edit(QModelIndex)
    // 1: edit(QModelIndex,QAbstractItemView::EditTrigger,QEvent*)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // edit(QModelIndex)
        } else if (numArgs == 3 && Shiboken::Converter<QAbstractItemView::EditTrigger >::isConvertible(pyargs[1]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[2])) {
            overloadId = 1; // edit(QModelIndex,QAbstractItemView::EditTrigger,QEvent*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_edit_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // edit(QModelIndex)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // edit(QModelIndex)
                cppSelf->QAbstractItemView::edit(*cpp_arg0);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // edit(QModelIndex,QAbstractItemView::EditTrigger,QEvent*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
                QAbstractItemView::EditTrigger cpp_arg1 = Shiboken::Converter<QAbstractItemView::EditTrigger >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QEvent* cpp_arg2 = Shiboken::Converter<QEvent* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // edit(QModelIndex,QAbstractItemView::EditTrigger,QEvent*)
                bool cppResult = cppSelf->QAbstractItemView::edit(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<bool >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_edit_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", "PySide.QtCore.QModelIndex, PySide.QtGui.QAbstractItemView.EditTrigger, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.edit", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_editTriggers(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // editTriggers()const
            QFlags<QAbstractItemView::EditTrigger> cppResult = cppSelf->QAbstractItemView::editTriggers();
            pyResult = Shiboken::Converter<QFlags<QAbstractItemView::EditTrigger> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_editorDestroyed(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: editorDestroyed(QObject*)
    if (Shiboken::Converter<QObject * >::isConvertible(arg)) {
        overloadId = 0; // editorDestroyed(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_editorDestroyed_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // editorDestroyed(QObject*)
            cppSelf->QAbstractItemView::editorDestroyed(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_editorDestroyed_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.editorDestroyed", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_event(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QAbstractItemView::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.event", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_executeDelayedItemsLayout(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // executeDelayedItemsLayout()
            cppSelf->QAbstractItemView::executeDelayedItemsLayout();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusInEvent(QFocusEvent*)
            cppSelf->QAbstractItemView::focusInEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.focusInEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusNextPrevChild(bool)
            bool cppResult = cppSelf->QAbstractItemView::focusNextPrevChild(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusOutEvent(QFocusEvent*)
            cppSelf->QAbstractItemView::focusOutEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.focusOutEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_hasAutoScroll(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasAutoScroll()const
            bool cppResult = cppSelf->QAbstractItemView::hasAutoScroll();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_horizontalOffset(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // horizontalOffset()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.horizontalOffset()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->horizontalOffset();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_horizontalScrollMode(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // horizontalScrollMode()const
            QAbstractItemView::ScrollMode cppResult = cppSelf->QAbstractItemView::horizontalScrollMode();
            pyResult = Shiboken::Converter<QAbstractItemView::ScrollMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_horizontalScrollbarAction(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: horizontalScrollbarAction(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // horizontalScrollbarAction(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_horizontalScrollbarAction_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // horizontalScrollbarAction(int)
            cppSelf->QAbstractItemView::horizontalScrollbarAction(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_horizontalScrollbarAction_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.horizontalScrollbarAction", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_horizontalScrollbarValueChanged(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: horizontalScrollbarValueChanged(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // horizontalScrollbarValueChanged(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_horizontalScrollbarValueChanged_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // horizontalScrollbarValueChanged(int)
            cppSelf->QAbstractItemView::horizontalScrollbarValueChanged(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_horizontalScrollbarValueChanged_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.horizontalScrollbarValueChanged", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_iconSize(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // iconSize()const
            QSize cppResult = cppSelf->QAbstractItemView::iconSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_indexAt(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexAt(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // indexAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_indexAt_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexAt(QPoint)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.indexAt()' not implemented.");
                return 0;
            }
            QModelIndex cppResult = cppSelf->indexAt(*cpp_arg0);
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_indexAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.indexAt", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_indexWidget(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexWidget(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // indexWidget(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_indexWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // indexWidget(QModelIndex)const
            QWidget * cppResult = cppSelf->QAbstractItemView::indexWidget(*cpp_arg0);
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_indexWidget_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.indexWidget", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            cppSelf->QAbstractItemView::inputMethodEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.inputMethodEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter<Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cpp_arg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = cppSelf->QAbstractItemView::inputMethodQuery(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.inputMethodQuery", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_isIndexHidden(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isIndexHidden(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // isIndexHidden(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_isIndexHidden_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isIndexHidden(QModelIndex)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.isIndexHidden()' not implemented.");
                return 0;
            }
            bool cppResult = cppSelf->isIndexHidden(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_isIndexHidden_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.isIndexHidden", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_itemDelegate(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: itemDelegate()const
    // 1: itemDelegate(QModelIndex)const
    if (numArgs == 0) {
        overloadId = 0; // itemDelegate()const
    } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 1; // itemDelegate(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_itemDelegate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemDelegate()const
            {

                if(!PyErr_Occurred()) {
                // itemDelegate()const
                QAbstractItemDelegate * cppResult = cppSelf->QAbstractItemView::itemDelegate();
                pyResult = Shiboken::Converter<QAbstractItemDelegate * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // itemDelegate(QModelIndex)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // itemDelegate(QModelIndex)const
                QAbstractItemDelegate * cppResult = cppSelf->QAbstractItemView::itemDelegate(*cpp_arg0);
                pyResult = Shiboken::Converter<QAbstractItemDelegate * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_itemDelegate_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.itemDelegate", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_itemDelegateForColumn(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemDelegateForColumn(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // itemDelegateForColumn(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_itemDelegateForColumn_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // itemDelegateForColumn(int)const
            QAbstractItemDelegate * cppResult = cppSelf->QAbstractItemView::itemDelegateForColumn(cpp_arg0);
            pyResult = Shiboken::Converter<QAbstractItemDelegate * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_itemDelegateForColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.itemDelegateForColumn", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_itemDelegateForRow(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemDelegateForRow(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // itemDelegateForRow(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_itemDelegateForRow_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // itemDelegateForRow(int)const
            QAbstractItemDelegate * cppResult = cppSelf->QAbstractItemView::itemDelegateForRow(cpp_arg0);
            pyResult = Shiboken::Converter<QAbstractItemDelegate * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_itemDelegateForRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.itemDelegateForRow", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QAbstractItemView::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_keyboardSearch(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyboardSearch(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // keyboardSearch(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_keyboardSearch_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyboardSearch(QString)
            cppSelf->QAbstractItemView::keyboardSearch(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_keyboardSearch_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.keyboardSearch", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_model(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // model()const
            QAbstractItemModel * cppResult = cppSelf->QAbstractItemView::model();
            pyResult = Shiboken::Converter<QAbstractItemModel * >::toPython(cppResult);

            // Ownership transferences.
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseDoubleClickEvent(QMouseEvent*)
            cppSelf->QAbstractItemView::mouseDoubleClickEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseMoveEvent(QMouseEvent*)
            cppSelf->QAbstractItemView::mouseMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mousePressEvent(QMouseEvent*)
            cppSelf->QAbstractItemView::mousePressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.mousePressEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseReleaseEvent(QMouseEvent*)
            cppSelf->QAbstractItemView::mouseReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_openPersistentEditor(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: openPersistentEditor(QModelIndex)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // openPersistentEditor(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_openPersistentEditor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // openPersistentEditor(QModelIndex)
            cppSelf->QAbstractItemView::openPersistentEditor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_openPersistentEditor_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.openPersistentEditor", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_reset(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // reset()
            cppSelf->QAbstractItemView::reset();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter<QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QResizeEvent* cpp_arg0 = Shiboken::Converter<QResizeEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resizeEvent(QResizeEvent*)
            cppSelf->QAbstractItemView::resizeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.resizeEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_rootIndex(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rootIndex()const
            QModelIndex cppResult = cppSelf->QAbstractItemView::rootIndex();
            pyResult = Shiboken::Converter<QModelIndex >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_rowsAboutToBeRemoved(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rowsAboutToBeRemoved", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: rowsAboutToBeRemoved(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // rowsAboutToBeRemoved(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_rowsAboutToBeRemoved_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // rowsAboutToBeRemoved(QModelIndex,int,int)
            cppSelf->QAbstractItemView::rowsAboutToBeRemoved(*cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_rowsAboutToBeRemoved_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.rowsAboutToBeRemoved", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_rowsInserted(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rowsInserted", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: rowsInserted(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // rowsInserted(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_rowsInserted_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
            // rowsInserted(QModelIndex,int,int)
            cppSelf->QAbstractItemView::rowsInserted(*cpp_arg0, cpp_arg1, cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_rowsInserted_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.rowsInserted", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_scheduleDelayedItemsLayout(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scheduleDelayedItemsLayout()
            cppSelf->QAbstractItemView::scheduleDelayedItemsLayout();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_scrollDirtyRegion(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollDirtyRegion", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollDirtyRegion(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scrollDirtyRegion(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_scrollDirtyRegion_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scrollDirtyRegion(int,int)
            cppSelf->QAbstractItemView::scrollDirtyRegion(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_scrollDirtyRegion_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.scrollDirtyRegion", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_scrollTo(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "hint" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.scrollTo(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.scrollTo(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.scrollTo(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scrollTo", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        } else if (Shiboken::Converter<QAbstractItemView::ScrollHint >::isConvertible(pyargs[1])) {
            overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_scrollTo_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hint");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "hint";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.scrollTo(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            QAbstractItemView::ScrollHint cpp_arg1 = pyargs[1] ? Shiboken::Converter<QAbstractItemView::ScrollHint >::toCpp(pyargs[1]) : QAbstractItemView::EnsureVisible;

            if(!PyErr_Occurred()) {
            // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.scrollTo()' not implemented.");
                return 0;
            }
            cppSelf->scrollTo(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_scrollTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtGui.QAbstractItemView.ScrollHint = EnsureVisible", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.scrollTo", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_scrollToBottom(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scrollToBottom()
            cppSelf->QAbstractItemView::scrollToBottom();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_scrollToTop(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scrollToTop()
            cppSelf->QAbstractItemView::scrollToTop();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_selectAll(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectAll()
            cppSelf->QAbstractItemView::selectAll();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_selectedIndexes(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectedIndexes()const
            QList<QModelIndex > cppResult = cppSelf->QAbstractItemView::selectedIndexes();
            pyResult = Shiboken::Converter<QList<QModelIndex > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_selectionBehavior(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectionBehavior()const
            QAbstractItemView::SelectionBehavior cppResult = cppSelf->QAbstractItemView::selectionBehavior();
            pyResult = Shiboken::Converter<QAbstractItemView::SelectionBehavior >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_selectionChanged(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "selectionChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: selectionChanged(QItemSelection,QItemSelection)
    if (numArgs == 2 && Shiboken::Converter<const QItemSelection & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QItemSelection & >::isConvertible(pyargs[1])) {
        overloadId = 0; // selectionChanged(QItemSelection,QItemSelection)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_selectionChanged_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QItemSelection* cpp_arg0 = Shiboken::Converter<QItemSelection* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QItemSelection* cpp_arg1 = Shiboken::Converter<QItemSelection* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // selectionChanged(QItemSelection,QItemSelection)
            cppSelf->QAbstractItemView::selectionChanged(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_selectionChanged_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection, PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.selectionChanged", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_selectionCommand(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "event" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.selectionCommand(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.selectionCommand(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.selectionCommand(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:selectionCommand", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: selectionCommand(QModelIndex,const QEvent*)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // selectionCommand(QModelIndex,const QEvent*)const
        } else if (Shiboken::Converter< QEvent * >::isConvertible(pyargs[1])) {
            overloadId = 0; // selectionCommand(QModelIndex,const QEvent*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_selectionCommand_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "event");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "event";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QAbstractItemView.selectionCommand(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QEvent* >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
            // selectionCommand(QModelIndex,const QEvent*)const
            QFlags<QItemSelectionModel::SelectionFlag> cppResult = cppSelf->QAbstractItemView::selectionCommand(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_selectionCommand_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QEvent = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.selectionCommand", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_selectionMode(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectionMode()const
            QAbstractItemView::SelectionMode cppResult = cppSelf->QAbstractItemView::selectionMode();
            pyResult = Shiboken::Converter<QAbstractItemView::SelectionMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_selectionModel(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectionModel()const
            QItemSelectionModel * cppResult = cppSelf->QAbstractItemView::selectionModel();
            pyResult = Shiboken::Converter<QItemSelectionModel * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_setAlternatingRowColors(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlternatingRowColors(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAlternatingRowColors(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setAlternatingRowColors_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlternatingRowColors(bool)
            cppSelf->QAbstractItemView::setAlternatingRowColors(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setAlternatingRowColors_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setAlternatingRowColors", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setAutoScroll(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoScroll(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoScroll(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setAutoScroll_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoScroll(bool)
            cppSelf->QAbstractItemView::setAutoScroll(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setAutoScroll_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setAutoScroll", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setAutoScrollMargin(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoScrollMargin(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoScrollMargin(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setAutoScrollMargin_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoScrollMargin(int)
            cppSelf->QAbstractItemView::setAutoScrollMargin(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setAutoScrollMargin_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setAutoScrollMargin", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setCurrentIndex(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentIndex(QModelIndex)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // setCurrentIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setCurrentIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentIndex(QModelIndex)
            cppSelf->QAbstractItemView::setCurrentIndex(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setCurrentIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setCurrentIndex", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setDefaultDropAction(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultDropAction(Qt::DropAction)
    if (Shiboken::Converter<Qt::DropAction >::isConvertible(arg)) {
        overloadId = 0; // setDefaultDropAction(Qt::DropAction)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setDefaultDropAction_TypeError;

    // Call function/method
    {
        {
            Qt::DropAction cpp_arg0 = Shiboken::Converter<Qt::DropAction >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDefaultDropAction(Qt::DropAction)
            cppSelf->QAbstractItemView::setDefaultDropAction(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setDefaultDropAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DropAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setDefaultDropAction", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setDirtyRegion(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDirtyRegion(QRegion)
    if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 0; // setDirtyRegion(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setDirtyRegion_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
            if (!Shiboken::Converter<QRegion >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setDirtyRegion(QRegion)
            cppSelf->QAbstractItemView::setDirtyRegion(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setDirtyRegion_TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setDirtyRegion", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setDragDropMode(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDragDropMode(QAbstractItemView::DragDropMode)
    if (Shiboken::Converter<QAbstractItemView::DragDropMode >::isConvertible(arg)) {
        overloadId = 0; // setDragDropMode(QAbstractItemView::DragDropMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setDragDropMode_TypeError;

    // Call function/method
    {
        {
            QAbstractItemView::DragDropMode cpp_arg0 = Shiboken::Converter<QAbstractItemView::DragDropMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDragDropMode(QAbstractItemView::DragDropMode)
            cppSelf->QAbstractItemView::setDragDropMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setDragDropMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView.DragDropMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setDragDropMode", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setDragDropOverwriteMode(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDragDropOverwriteMode(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDragDropOverwriteMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setDragDropOverwriteMode_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDragDropOverwriteMode(bool)
            cppSelf->QAbstractItemView::setDragDropOverwriteMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setDragDropOverwriteMode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setDragDropOverwriteMode", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setDragEnabled(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDragEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDragEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setDragEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDragEnabled(bool)
            cppSelf->QAbstractItemView::setDragEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setDragEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setDragEnabled", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setDropIndicatorShown(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDropIndicatorShown(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDropIndicatorShown(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setDropIndicatorShown_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDropIndicatorShown(bool)
            cppSelf->QAbstractItemView::setDropIndicatorShown(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setDropIndicatorShown_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setDropIndicatorShown", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setEditTriggers(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEditTriggers(QFlags<QAbstractItemView::EditTrigger>)
    if (Shiboken::Converter<QFlags<QAbstractItemView::EditTrigger> >::isConvertible(arg)) {
        overloadId = 0; // setEditTriggers(QFlags<QAbstractItemView::EditTrigger>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setEditTriggers_TypeError;

    // Call function/method
    {
        {
            QFlags<QAbstractItemView::EditTrigger> cpp_arg0 = Shiboken::Converter<QFlags<QAbstractItemView::EditTrigger> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEditTriggers(QFlags<QAbstractItemView::EditTrigger>)
            cppSelf->QAbstractItemView::setEditTriggers(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setEditTriggers_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView.EditTriggers", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setEditTriggers", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setHorizontalScrollMode(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalScrollMode(QAbstractItemView::ScrollMode)
    if (Shiboken::Converter<QAbstractItemView::ScrollMode >::isConvertible(arg)) {
        overloadId = 0; // setHorizontalScrollMode(QAbstractItemView::ScrollMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setHorizontalScrollMode_TypeError;

    // Call function/method
    {
        {
            QAbstractItemView::ScrollMode cpp_arg0 = Shiboken::Converter<QAbstractItemView::ScrollMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHorizontalScrollMode(QAbstractItemView::ScrollMode)
            cppSelf->QAbstractItemView::setHorizontalScrollMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setHorizontalScrollMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView.ScrollMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setHorizontalScrollMode", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setIconSize(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconSize(QSize)
    if (Shiboken::Converter<const QSize & >::isConvertible(arg)) {
        overloadId = 0; // setIconSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setIconSize_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setIconSize(QSize)
            cppSelf->QAbstractItemView::setIconSize(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setIconSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setIconSize", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setIndexWidget(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setIndexWidget", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setIndexWidget(QModelIndex,QWidget*)
    if (numArgs == 2 && Shiboken::Converter<const QModelIndex & >::isConvertible(pyargs[0]) && Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setIndexWidget(QModelIndex,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setIndexWidget_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setIndexWidget(QModelIndex,QWidget*)
            cppSelf->QAbstractItemView::setIndexWidget(*cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[1]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setIndexWidget_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.setIndexWidget", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setItemDelegate(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItemDelegate(QAbstractItemDelegate*)
    if (Shiboken::Converter<QAbstractItemDelegate * >::isConvertible(arg)) {
        overloadId = 0; // setItemDelegate(QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setItemDelegate_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractItemDelegate* cpp_arg0 = Shiboken::Converter<QAbstractItemDelegate* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setItemDelegate(QAbstractItemDelegate*)
            cppSelf->QAbstractItemView::setItemDelegate(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setItemDelegate_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemDelegate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setItemDelegate", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setItemDelegateForColumn(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItemDelegateForColumn", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setItemDelegateForColumn(int,QAbstractItemDelegate*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QAbstractItemDelegate * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setItemDelegateForColumn(int,QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setItemDelegateForColumn_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QAbstractItemDelegate* cpp_arg1 = Shiboken::Converter<QAbstractItemDelegate* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setItemDelegateForColumn(int,QAbstractItemDelegate*)
            cppSelf->QAbstractItemView::setItemDelegateForColumn(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setItemDelegateForColumn_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QAbstractItemDelegate", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.setItemDelegateForColumn", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setItemDelegateForRow(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItemDelegateForRow", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setItemDelegateForRow(int,QAbstractItemDelegate*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<QAbstractItemDelegate * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setItemDelegateForRow(int,QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setItemDelegateForRow_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QAbstractItemDelegate* cpp_arg1 = Shiboken::Converter<QAbstractItemDelegate* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setItemDelegateForRow(int,QAbstractItemDelegate*)
            cppSelf->QAbstractItemView::setItemDelegateForRow(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setItemDelegateForRow_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QAbstractItemDelegate", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.setItemDelegateForRow", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setModel(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModel(QAbstractItemModel*)
    if (Shiboken::Converter<QAbstractItemModel * >::isConvertible(arg)) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setModel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAbstractItemModel* cpp_arg0 = Shiboken::Converter<QAbstractItemModel* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setModel(QAbstractItemModel*)
            cppSelf->QAbstractItemView::setModel(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setModel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setModel", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setRootIndex(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRootIndex(QModelIndex)
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // setRootIndex(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setRootIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRootIndex(QModelIndex)
            cppSelf->QAbstractItemView::setRootIndex(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setRootIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setRootIndex", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setSelection(PyObject* self, PyObject* args)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSelection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setSelection_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
            QFlags<QItemSelectionModel::SelectionFlag> cpp_arg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.setSelection()' not implemented.");
                return 0;
            }
            cppSelf->setSelection(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setSelection_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QAbstractItemView.setSelection", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setSelectionBehavior(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelectionBehavior(QAbstractItemView::SelectionBehavior)
    if (Shiboken::Converter<QAbstractItemView::SelectionBehavior >::isConvertible(arg)) {
        overloadId = 0; // setSelectionBehavior(QAbstractItemView::SelectionBehavior)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setSelectionBehavior_TypeError;

    // Call function/method
    {
        {
            QAbstractItemView::SelectionBehavior cpp_arg0 = Shiboken::Converter<QAbstractItemView::SelectionBehavior >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSelectionBehavior(QAbstractItemView::SelectionBehavior)
            cppSelf->QAbstractItemView::setSelectionBehavior(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setSelectionBehavior_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView.SelectionBehavior", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setSelectionBehavior", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setSelectionMode(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelectionMode(QAbstractItemView::SelectionMode)
    if (Shiboken::Converter<QAbstractItemView::SelectionMode >::isConvertible(arg)) {
        overloadId = 0; // setSelectionMode(QAbstractItemView::SelectionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setSelectionMode_TypeError;

    // Call function/method
    {
        {
            QAbstractItemView::SelectionMode cpp_arg0 = Shiboken::Converter<QAbstractItemView::SelectionMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSelectionMode(QAbstractItemView::SelectionMode)
            cppSelf->QAbstractItemView::setSelectionMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setSelectionMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView.SelectionMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setSelectionMode", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setSelectionModel(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSelectionModel(QItemSelectionModel*)
    if (Shiboken::Converter<QItemSelectionModel * >::isConvertible(arg)) {
        overloadId = 0; // setSelectionModel(QItemSelectionModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setSelectionModel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QItemSelectionModel* cpp_arg0 = Shiboken::Converter<QItemSelectionModel* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSelectionModel(QItemSelectionModel*)
            cppSelf->QAbstractItemView::setSelectionModel(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setSelectionModel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelectionModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setSelectionModel", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setState(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setState(QAbstractItemView::State)
    if (Shiboken::Converter<QAbstractItemView::State >::isConvertible(arg)) {
        overloadId = 0; // setState(QAbstractItemView::State)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setState_TypeError;

    // Call function/method
    {
        {
            QAbstractItemView::State cpp_arg0 = Shiboken::Converter<QAbstractItemView::State >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setState(QAbstractItemView::State)
            cppSelf->QAbstractItemView::setState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setState_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView.State", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setState", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setTabKeyNavigation(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabKeyNavigation(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTabKeyNavigation(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setTabKeyNavigation_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTabKeyNavigation(bool)
            cppSelf->QAbstractItemView::setTabKeyNavigation(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setTabKeyNavigation_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setTabKeyNavigation", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setTextElideMode(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextElideMode(Qt::TextElideMode)
    if (Shiboken::Converter<Qt::TextElideMode >::isConvertible(arg)) {
        overloadId = 0; // setTextElideMode(Qt::TextElideMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setTextElideMode_TypeError;

    // Call function/method
    {
        {
            Qt::TextElideMode cpp_arg0 = Shiboken::Converter<Qt::TextElideMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextElideMode(Qt::TextElideMode)
            cppSelf->QAbstractItemView::setTextElideMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setTextElideMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextElideMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setTextElideMode", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_setVerticalScrollMode(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalScrollMode(QAbstractItemView::ScrollMode)
    if (Shiboken::Converter<QAbstractItemView::ScrollMode >::isConvertible(arg)) {
        overloadId = 0; // setVerticalScrollMode(QAbstractItemView::ScrollMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_setVerticalScrollMode_TypeError;

    // Call function/method
    {
        {
            QAbstractItemView::ScrollMode cpp_arg0 = Shiboken::Converter<QAbstractItemView::ScrollMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVerticalScrollMode(QAbstractItemView::ScrollMode)
            cppSelf->QAbstractItemView::setVerticalScrollMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_setVerticalScrollMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractItemView.ScrollMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.setVerticalScrollMode", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_showDropIndicator(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // showDropIndicator()const
            bool cppResult = cppSelf->QAbstractItemView::showDropIndicator();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_sizeHintForColumn(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sizeHintForColumn(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sizeHintForColumn(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_sizeHintForColumn_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // sizeHintForColumn(int)const
            int cppResult = cppSelf->QAbstractItemView::sizeHintForColumn(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_sizeHintForColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.sizeHintForColumn", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_sizeHintForIndex(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sizeHintForIndex(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // sizeHintForIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_sizeHintForIndex_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // sizeHintForIndex(QModelIndex)const
            QSize cppResult = cppSelf->QAbstractItemView::sizeHintForIndex(*cpp_arg0);
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_sizeHintForIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.sizeHintForIndex", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_sizeHintForRow(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sizeHintForRow(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sizeHintForRow(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_sizeHintForRow_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // sizeHintForRow(int)const
            int cppResult = cppSelf->QAbstractItemView::sizeHintForRow(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_sizeHintForRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.sizeHintForRow", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_startAutoScroll(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // startAutoScroll()
            cppSelf->QAbstractItemView::startAutoScroll();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_startDrag(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: startDrag(QFlags<Qt::DropAction>)
    if (Shiboken::Converter<QFlags<Qt::DropAction> >::isConvertible(arg)) {
        overloadId = 0; // startDrag(QFlags<Qt::DropAction>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_startDrag_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::DropAction> cpp_arg0 = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // startDrag(QFlags<Qt::DropAction>)
            cppSelf->QAbstractItemView::startDrag(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_startDrag_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DropActions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.startDrag", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_state(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // state()const
            QAbstractItemView::State cppResult = cppSelf->QAbstractItemView::state();
            pyResult = Shiboken::Converter<QAbstractItemView::State >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_stopAutoScroll(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stopAutoScroll()
            cppSelf->QAbstractItemView::stopAutoScroll();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_tabKeyNavigation(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tabKeyNavigation()const
            bool cppResult = cppSelf->QAbstractItemView::tabKeyNavigation();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_textElideMode(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textElideMode()const
            Qt::TextElideMode cppResult = cppSelf->QAbstractItemView::textElideMode();
            pyResult = Shiboken::Converter<Qt::TextElideMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_timerEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: timerEvent(QTimerEvent*)
    if (Shiboken::Converter<QTimerEvent * >::isConvertible(arg)) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_timerEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTimerEvent* cpp_arg0 = Shiboken::Converter<QTimerEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // timerEvent(QTimerEvent*)
            cppSelf->QAbstractItemView::timerEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_timerEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimerEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.timerEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_update(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: update()
    // 1: update(QModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // update()
    } else if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 1; // update(QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_update_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // update()
            {

                if(!PyErr_Occurred()) {
                // update()
                cppSelf->QAbstractItemView::update();
                }
                break;
            }
            case 1: // update(QModelIndex)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // update(QModelIndex)
                cppSelf->QAbstractItemView::update(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_update_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.update", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_updateEditorData(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateEditorData()
            cppSelf->QAbstractItemView::updateEditorData();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_updateEditorGeometries(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateEditorGeometries()
            cppSelf->QAbstractItemView::updateEditorGeometries();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_updateGeometries(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateGeometries()
            cppSelf->QAbstractItemView::updateGeometries();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQAbstractItemViewFunc_verticalOffset(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // verticalOffset()const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.verticalOffset()' not implemented.");
                return 0;
            }
            int cppResult = cppSelf->verticalOffset();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_verticalScrollMode(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // verticalScrollMode()const
            QAbstractItemView::ScrollMode cppResult = cppSelf->QAbstractItemView::verticalScrollMode();
            pyResult = Shiboken::Converter<QAbstractItemView::ScrollMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_verticalScrollbarAction(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: verticalScrollbarAction(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // verticalScrollbarAction(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_verticalScrollbarAction_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // verticalScrollbarAction(int)
            cppSelf->QAbstractItemView::verticalScrollbarAction(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_verticalScrollbarAction_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.verticalScrollbarAction", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_verticalScrollbarValueChanged(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: verticalScrollbarValueChanged(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // verticalScrollbarValueChanged(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_verticalScrollbarValueChanged_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // verticalScrollbarValueChanged(int)
            cppSelf->QAbstractItemView::verticalScrollbarValueChanged(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQAbstractItemViewFunc_verticalScrollbarValueChanged_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.verticalScrollbarValueChanged", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_viewOptions(PyObject* self)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewOptions()const
            QStyleOptionViewItem cppResult = cppSelf->QAbstractItemView::viewOptions();
            pyResult = Shiboken::Converter<QStyleOptionViewItem >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQAbstractItemViewFunc_viewportEvent(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: viewportEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // viewportEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_viewportEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // viewportEvent(QEvent*)
            bool cppResult = cppSelf->QAbstractItemView::viewportEvent(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_viewportEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.viewportEvent", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_visualRect(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualRect(QModelIndex)const
    if (Shiboken::Converter<const QModelIndex & >::isConvertible(arg)) {
        overloadId = 0; // visualRect(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_visualRect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QModelIndex* cpp_arg0 = Shiboken::Converter<QModelIndex* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // visualRect(QModelIndex)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.visualRect()' not implemented.");
                return 0;
            }
            QRect cppResult = cppSelf->visualRect(*cpp_arg0);
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_visualRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.visualRect", overloads);
        return 0;
}

static PyObject* SbkQAbstractItemViewFunc_visualRegionForSelection(PyObject* self, PyObject* arg)
{
    QAbstractItemView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QAbstractItemView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualRegionForSelection(QItemSelection)const
    if (Shiboken::Converter<const QItemSelection & >::isConvertible(arg)) {
        overloadId = 0; // visualRegionForSelection(QItemSelection)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQAbstractItemViewFunc_visualRegionForSelection_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QItemSelection* cpp_arg0 = Shiboken::Converter<QItemSelection* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // visualRegionForSelection(QItemSelection)const
            if (SbkBaseWrapper_containsCppWrapper(self)) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractItemView.visualRegionForSelection()' not implemented.");
                return 0;
            }
            QRegion cppResult = cppSelf->visualRegionForSelection(*cpp_arg0);
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQAbstractItemViewFunc_visualRegionForSelection_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QAbstractItemView.visualRegionForSelection", overloads);
        return 0;
}

static PyMethodDef SbkQAbstractItemView_methods[] = {
    {"alternatingRowColors", (PyCFunction)SbkQAbstractItemViewFunc_alternatingRowColors, METH_NOARGS},
    {"autoScrollMargin", (PyCFunction)SbkQAbstractItemViewFunc_autoScrollMargin, METH_NOARGS},
    {"clearSelection", (PyCFunction)SbkQAbstractItemViewFunc_clearSelection, METH_NOARGS},
    {"closeEditor", (PyCFunction)SbkQAbstractItemViewFunc_closeEditor, METH_VARARGS},
    {"closePersistentEditor", (PyCFunction)SbkQAbstractItemViewFunc_closePersistentEditor, METH_O},
    {"commitData", (PyCFunction)SbkQAbstractItemViewFunc_commitData, METH_O},
    {"currentChanged", (PyCFunction)SbkQAbstractItemViewFunc_currentChanged, METH_VARARGS},
    {"currentIndex", (PyCFunction)SbkQAbstractItemViewFunc_currentIndex, METH_NOARGS},
    {"dataChanged", (PyCFunction)SbkQAbstractItemViewFunc_dataChanged, METH_VARARGS},
    {"defaultDropAction", (PyCFunction)SbkQAbstractItemViewFunc_defaultDropAction, METH_NOARGS},
    {"dirtyRegionOffset", (PyCFunction)SbkQAbstractItemViewFunc_dirtyRegionOffset, METH_NOARGS},
    {"doAutoScroll", (PyCFunction)SbkQAbstractItemViewFunc_doAutoScroll, METH_NOARGS},
    {"doItemsLayout", (PyCFunction)SbkQAbstractItemViewFunc_doItemsLayout, METH_NOARGS},
    {"dragDropMode", (PyCFunction)SbkQAbstractItemViewFunc_dragDropMode, METH_NOARGS},
    {"dragDropOverwriteMode", (PyCFunction)SbkQAbstractItemViewFunc_dragDropOverwriteMode, METH_NOARGS},
    {"dragEnabled", (PyCFunction)SbkQAbstractItemViewFunc_dragEnabled, METH_NOARGS},
    {"dragEnterEvent", (PyCFunction)SbkQAbstractItemViewFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)SbkQAbstractItemViewFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)SbkQAbstractItemViewFunc_dragMoveEvent, METH_O},
    {"dropEvent", (PyCFunction)SbkQAbstractItemViewFunc_dropEvent, METH_O},
    {"dropIndicatorPosition", (PyCFunction)SbkQAbstractItemViewFunc_dropIndicatorPosition, METH_NOARGS},
    {"edit", (PyCFunction)SbkQAbstractItemViewFunc_edit, METH_VARARGS},
    {"editTriggers", (PyCFunction)SbkQAbstractItemViewFunc_editTriggers, METH_NOARGS},
    {"editorDestroyed", (PyCFunction)SbkQAbstractItemViewFunc_editorDestroyed, METH_O},
    {"event", (PyCFunction)SbkQAbstractItemViewFunc_event, METH_O},
    {"executeDelayedItemsLayout", (PyCFunction)SbkQAbstractItemViewFunc_executeDelayedItemsLayout, METH_NOARGS},
    {"focusInEvent", (PyCFunction)SbkQAbstractItemViewFunc_focusInEvent, METH_O},
    {"focusNextPrevChild", (PyCFunction)SbkQAbstractItemViewFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)SbkQAbstractItemViewFunc_focusOutEvent, METH_O},
    {"hasAutoScroll", (PyCFunction)SbkQAbstractItemViewFunc_hasAutoScroll, METH_NOARGS},
    {"horizontalOffset", (PyCFunction)SbkQAbstractItemViewFunc_horizontalOffset, METH_NOARGS},
    {"horizontalScrollMode", (PyCFunction)SbkQAbstractItemViewFunc_horizontalScrollMode, METH_NOARGS},
    {"horizontalScrollbarAction", (PyCFunction)SbkQAbstractItemViewFunc_horizontalScrollbarAction, METH_O},
    {"horizontalScrollbarValueChanged", (PyCFunction)SbkQAbstractItemViewFunc_horizontalScrollbarValueChanged, METH_O},
    {"iconSize", (PyCFunction)SbkQAbstractItemViewFunc_iconSize, METH_NOARGS},
    {"indexAt", (PyCFunction)SbkQAbstractItemViewFunc_indexAt, METH_O},
    {"indexWidget", (PyCFunction)SbkQAbstractItemViewFunc_indexWidget, METH_O},
    {"inputMethodEvent", (PyCFunction)SbkQAbstractItemViewFunc_inputMethodEvent, METH_O},
    {"inputMethodQuery", (PyCFunction)SbkQAbstractItemViewFunc_inputMethodQuery, METH_O},
    {"isIndexHidden", (PyCFunction)SbkQAbstractItemViewFunc_isIndexHidden, METH_O},
    {"itemDelegate", (PyCFunction)SbkQAbstractItemViewFunc_itemDelegate, METH_NOARGS|METH_O},
    {"itemDelegateForColumn", (PyCFunction)SbkQAbstractItemViewFunc_itemDelegateForColumn, METH_O},
    {"itemDelegateForRow", (PyCFunction)SbkQAbstractItemViewFunc_itemDelegateForRow, METH_O},
    {"keyPressEvent", (PyCFunction)SbkQAbstractItemViewFunc_keyPressEvent, METH_O},
    {"keyboardSearch", (PyCFunction)SbkQAbstractItemViewFunc_keyboardSearch, METH_O},
    {"model", (PyCFunction)SbkQAbstractItemViewFunc_model, METH_NOARGS},
    {"mouseDoubleClickEvent", (PyCFunction)SbkQAbstractItemViewFunc_mouseDoubleClickEvent, METH_O},
    {"mouseMoveEvent", (PyCFunction)SbkQAbstractItemViewFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)SbkQAbstractItemViewFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)SbkQAbstractItemViewFunc_mouseReleaseEvent, METH_O},
    {"openPersistentEditor", (PyCFunction)SbkQAbstractItemViewFunc_openPersistentEditor, METH_O},
    {"reset", (PyCFunction)SbkQAbstractItemViewFunc_reset, METH_NOARGS},
    {"resizeEvent", (PyCFunction)SbkQAbstractItemViewFunc_resizeEvent, METH_O},
    {"rootIndex", (PyCFunction)SbkQAbstractItemViewFunc_rootIndex, METH_NOARGS},
    {"rowsAboutToBeRemoved", (PyCFunction)SbkQAbstractItemViewFunc_rowsAboutToBeRemoved, METH_VARARGS},
    {"rowsInserted", (PyCFunction)SbkQAbstractItemViewFunc_rowsInserted, METH_VARARGS},
    {"scheduleDelayedItemsLayout", (PyCFunction)SbkQAbstractItemViewFunc_scheduleDelayedItemsLayout, METH_NOARGS},
    {"scrollDirtyRegion", (PyCFunction)SbkQAbstractItemViewFunc_scrollDirtyRegion, METH_VARARGS},
    {"scrollTo", (PyCFunction)SbkQAbstractItemViewFunc_scrollTo, METH_VARARGS|METH_KEYWORDS},
    {"scrollToBottom", (PyCFunction)SbkQAbstractItemViewFunc_scrollToBottom, METH_NOARGS},
    {"scrollToTop", (PyCFunction)SbkQAbstractItemViewFunc_scrollToTop, METH_NOARGS},
    {"selectAll", (PyCFunction)SbkQAbstractItemViewFunc_selectAll, METH_NOARGS},
    {"selectedIndexes", (PyCFunction)SbkQAbstractItemViewFunc_selectedIndexes, METH_NOARGS},
    {"selectionBehavior", (PyCFunction)SbkQAbstractItemViewFunc_selectionBehavior, METH_NOARGS},
    {"selectionChanged", (PyCFunction)SbkQAbstractItemViewFunc_selectionChanged, METH_VARARGS},
    {"selectionCommand", (PyCFunction)SbkQAbstractItemViewFunc_selectionCommand, METH_VARARGS|METH_KEYWORDS},
    {"selectionMode", (PyCFunction)SbkQAbstractItemViewFunc_selectionMode, METH_NOARGS},
    {"selectionModel", (PyCFunction)SbkQAbstractItemViewFunc_selectionModel, METH_NOARGS},
    {"setAlternatingRowColors", (PyCFunction)SbkQAbstractItemViewFunc_setAlternatingRowColors, METH_O},
    {"setAutoScroll", (PyCFunction)SbkQAbstractItemViewFunc_setAutoScroll, METH_O},
    {"setAutoScrollMargin", (PyCFunction)SbkQAbstractItemViewFunc_setAutoScrollMargin, METH_O},
    {"setCurrentIndex", (PyCFunction)SbkQAbstractItemViewFunc_setCurrentIndex, METH_O},
    {"setDefaultDropAction", (PyCFunction)SbkQAbstractItemViewFunc_setDefaultDropAction, METH_O},
    {"setDirtyRegion", (PyCFunction)SbkQAbstractItemViewFunc_setDirtyRegion, METH_O},
    {"setDragDropMode", (PyCFunction)SbkQAbstractItemViewFunc_setDragDropMode, METH_O},
    {"setDragDropOverwriteMode", (PyCFunction)SbkQAbstractItemViewFunc_setDragDropOverwriteMode, METH_O},
    {"setDragEnabled", (PyCFunction)SbkQAbstractItemViewFunc_setDragEnabled, METH_O},
    {"setDropIndicatorShown", (PyCFunction)SbkQAbstractItemViewFunc_setDropIndicatorShown, METH_O},
    {"setEditTriggers", (PyCFunction)SbkQAbstractItemViewFunc_setEditTriggers, METH_O},
    {"setHorizontalScrollMode", (PyCFunction)SbkQAbstractItemViewFunc_setHorizontalScrollMode, METH_O},
    {"setIconSize", (PyCFunction)SbkQAbstractItemViewFunc_setIconSize, METH_O},
    {"setIndexWidget", (PyCFunction)SbkQAbstractItemViewFunc_setIndexWidget, METH_VARARGS},
    {"setItemDelegate", (PyCFunction)SbkQAbstractItemViewFunc_setItemDelegate, METH_O},
    {"setItemDelegateForColumn", (PyCFunction)SbkQAbstractItemViewFunc_setItemDelegateForColumn, METH_VARARGS},
    {"setItemDelegateForRow", (PyCFunction)SbkQAbstractItemViewFunc_setItemDelegateForRow, METH_VARARGS},
    {"setModel", (PyCFunction)SbkQAbstractItemViewFunc_setModel, METH_O},
    {"setRootIndex", (PyCFunction)SbkQAbstractItemViewFunc_setRootIndex, METH_O},
    {"setSelection", (PyCFunction)SbkQAbstractItemViewFunc_setSelection, METH_VARARGS},
    {"setSelectionBehavior", (PyCFunction)SbkQAbstractItemViewFunc_setSelectionBehavior, METH_O},
    {"setSelectionMode", (PyCFunction)SbkQAbstractItemViewFunc_setSelectionMode, METH_O},
    {"setSelectionModel", (PyCFunction)SbkQAbstractItemViewFunc_setSelectionModel, METH_O},
    {"setState", (PyCFunction)SbkQAbstractItemViewFunc_setState, METH_O},
    {"setTabKeyNavigation", (PyCFunction)SbkQAbstractItemViewFunc_setTabKeyNavigation, METH_O},
    {"setTextElideMode", (PyCFunction)SbkQAbstractItemViewFunc_setTextElideMode, METH_O},
    {"setVerticalScrollMode", (PyCFunction)SbkQAbstractItemViewFunc_setVerticalScrollMode, METH_O},
    {"showDropIndicator", (PyCFunction)SbkQAbstractItemViewFunc_showDropIndicator, METH_NOARGS},
    {"sizeHintForColumn", (PyCFunction)SbkQAbstractItemViewFunc_sizeHintForColumn, METH_O},
    {"sizeHintForIndex", (PyCFunction)SbkQAbstractItemViewFunc_sizeHintForIndex, METH_O},
    {"sizeHintForRow", (PyCFunction)SbkQAbstractItemViewFunc_sizeHintForRow, METH_O},
    {"startAutoScroll", (PyCFunction)SbkQAbstractItemViewFunc_startAutoScroll, METH_NOARGS},
    {"startDrag", (PyCFunction)SbkQAbstractItemViewFunc_startDrag, METH_O},
    {"state", (PyCFunction)SbkQAbstractItemViewFunc_state, METH_NOARGS},
    {"stopAutoScroll", (PyCFunction)SbkQAbstractItemViewFunc_stopAutoScroll, METH_NOARGS},
    {"tabKeyNavigation", (PyCFunction)SbkQAbstractItemViewFunc_tabKeyNavigation, METH_NOARGS},
    {"textElideMode", (PyCFunction)SbkQAbstractItemViewFunc_textElideMode, METH_NOARGS},
    {"timerEvent", (PyCFunction)SbkQAbstractItemViewFunc_timerEvent, METH_O},
    {"update", (PyCFunction)SbkQAbstractItemViewFunc_update, METH_NOARGS|METH_O},
    {"updateEditorData", (PyCFunction)SbkQAbstractItemViewFunc_updateEditorData, METH_NOARGS},
    {"updateEditorGeometries", (PyCFunction)SbkQAbstractItemViewFunc_updateEditorGeometries, METH_NOARGS},
    {"updateGeometries", (PyCFunction)SbkQAbstractItemViewFunc_updateGeometries, METH_NOARGS},
    {"verticalOffset", (PyCFunction)SbkQAbstractItemViewFunc_verticalOffset, METH_NOARGS},
    {"verticalScrollMode", (PyCFunction)SbkQAbstractItemViewFunc_verticalScrollMode, METH_NOARGS},
    {"verticalScrollbarAction", (PyCFunction)SbkQAbstractItemViewFunc_verticalScrollbarAction, METH_O},
    {"verticalScrollbarValueChanged", (PyCFunction)SbkQAbstractItemViewFunc_verticalScrollbarValueChanged, METH_O},
    {"viewOptions", (PyCFunction)SbkQAbstractItemViewFunc_viewOptions, METH_NOARGS},
    {"viewportEvent", (PyCFunction)SbkQAbstractItemViewFunc_viewportEvent, METH_O},
    {"visualRect", (PyCFunction)SbkQAbstractItemViewFunc_visualRect, METH_O},
    {"visualRegionForSelection", (PyCFunction)SbkQAbstractItemViewFunc_visualRegionForSelection, METH_O},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQAbstractItemViewSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QAbstractItemView* me = reinterpret_cast<QAbstractItemView*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQAbstractItemView_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QAbstractItemView",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQAbstractItemView_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQAbstractItemView_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQAbstractItemViewSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QAbstractItemView >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QAbstractItemView*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQAbstractItemView_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAbstractItemView*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQAbstractItemView_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QAbstractItemView*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQAbstractItemView_Type;
    return 0;
}

static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_DragDropMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_DragDropMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DragDropMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_DragDropMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_DragDropMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_DragDropMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SelectionBehavior",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QAbstractItemView_EditTrigger___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QAbstractItemView::EditTriggers >::checkType(self) && Shiboken::Converter<QAbstractItemView::EditTriggers >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QAbstractItemView::EditTriggers >::toPython(
        Shiboken::Converter<QAbstractItemView::EditTriggers>::toCpp(self)
        & Shiboken::Converter< QAbstractItemView::EditTriggers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QAbstractItemView_EditTrigger___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QAbstractItemView::EditTriggers >::checkType(self) && Shiboken::Converter<QAbstractItemView::EditTriggers >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QAbstractItemView::EditTriggers >::toPython(
        Shiboken::Converter<QAbstractItemView::EditTriggers>::toCpp(self)
        | Shiboken::Converter< QAbstractItemView::EditTriggers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QAbstractItemView_EditTrigger___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QAbstractItemView::EditTriggers >::checkType(self) && Shiboken::Converter<QAbstractItemView::EditTriggers >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QAbstractItemView::EditTriggers >::toPython(
        Shiboken::Converter<QAbstractItemView::EditTriggers>::toCpp(self)
        ^ Shiboken::Converter< QAbstractItemView::EditTriggers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QAbstractItemView_EditTrigger___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QAbstractItemView::EditTriggers >::toPython(
        ~Shiboken::Converter<QAbstractItemView::EditTriggers >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QAbstractItemView_EditTrigger_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QAbstractItemView_EditTrigger___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QAbstractItemView_EditTrigger___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QAbstractItemView_EditTrigger___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QAbstractItemView_EditTrigger___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_EditTrigger_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_EditTrigger_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "EditTrigger",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QAbstractItemView_EditTrigger_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_EditTrigger_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_EditTrigger_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_EditTrigger_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QAbstractItemView_EditTriggers_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "EditTriggers",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_ScrollMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_ScrollMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ScrollMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_ScrollMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_ScrollMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_ScrollMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_CursorAction_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_CursorAction_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_CursorAction_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CursorAction",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_CursorAction_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_CursorAction_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_CursorAction_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DropIndicatorPosition",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_ScrollHint_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_ScrollHint_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ScrollHint",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_ScrollHint_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_ScrollHint_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_ScrollHint_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_SelectionMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_SelectionMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SelectionMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_SelectionMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_SelectionMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_SelectionMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QAbstractItemView_State_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QAbstractItemView_State_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QAbstractItemView_State_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "State",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QAbstractItemView_State_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QAbstractItemView_State_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QAbstractItemView_State_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QAbstractItemView(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQAbstractItemView_Type);

    SbkQAbstractItemView_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX];
    SbkQAbstractItemView_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX])->mi_init;

    // Fill type discovery information
    SbkQAbstractItemView_Type.type_discovery = &SbkQAbstractItemView_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]), &SbkQAbstractItemView_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQAbstractItemView_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQAbstractItemView_Type));
    PyModule_AddObject(module, "QAbstractItemView",
        ((PyObject*)&SbkQAbstractItemView_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: DragDropMode
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_DRAGDROPMODE_IDX] = &SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "DragDropMode",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type,
        (long) QAbstractItemView::NoDragDrop, "NoDragDrop");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "NoDragDrop", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type.tp_dict,
        "NoDragDrop", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type,
        (long) QAbstractItemView::DragOnly, "DragOnly");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "DragOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type.tp_dict,
        "DragOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type,
        (long) QAbstractItemView::DropOnly, "DropOnly");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "DropOnly", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type.tp_dict,
        "DropOnly", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type,
        (long) QAbstractItemView::DragDrop, "DragDrop");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "DragDrop", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type.tp_dict,
        "DragDrop", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type,
        (long) QAbstractItemView::InternalMove, "InternalMove");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "InternalMove", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DragDropMode_Type.tp_dict,
        "InternalMove", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::DragDropMode");

    // init enum class: SelectionBehavior
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_SELECTIONBEHAVIOR_IDX] = &SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "SelectionBehavior",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type,
        (long) QAbstractItemView::SelectItems, "SelectItems");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "SelectItems", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type.tp_dict,
        "SelectItems", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type,
        (long) QAbstractItemView::SelectRows, "SelectRows");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "SelectRows", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type.tp_dict,
        "SelectRows", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type,
        (long) QAbstractItemView::SelectColumns, "SelectColumns");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "SelectColumns", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionBehavior_Type.tp_dict,
        "SelectColumns", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::SelectionBehavior");

    // init enum class: EditTrigger
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_EDITTRIGGER_IDX] = &SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "EditTrigger",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type));

    // init flags class: QFlags<QAbstractItemView::EditTrigger>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QABSTRACTITEMVIEW_EDITTRIGGER__IDX] = &SbkPySide_QtGui_QAbstractItemView_EditTriggers_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_EditTriggers_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_EditTriggers_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "EditTriggers",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_EditTriggers_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type,
        (long) QAbstractItemView::NoEditTriggers, "NoEditTriggers");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "NoEditTriggers", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_dict,
        "NoEditTriggers", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type,
        (long) QAbstractItemView::CurrentChanged, "CurrentChanged");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "CurrentChanged", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_dict,
        "CurrentChanged", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type,
        (long) QAbstractItemView::DoubleClicked, "DoubleClicked");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "DoubleClicked", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_dict,
        "DoubleClicked", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type,
        (long) QAbstractItemView::SelectedClicked, "SelectedClicked");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "SelectedClicked", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_dict,
        "SelectedClicked", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type,
        (long) QAbstractItemView::EditKeyPressed, "EditKeyPressed");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "EditKeyPressed", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_dict,
        "EditKeyPressed", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type,
        (long) QAbstractItemView::AnyKeyPressed, "AnyKeyPressed");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "AnyKeyPressed", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_dict,
        "AnyKeyPressed", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type,
        (long) QAbstractItemView::AllEditTriggers, "AllEditTriggers");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "AllEditTriggers", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_EditTrigger_Type.tp_dict,
        "AllEditTriggers", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::EditTrigger");

    // init enum class: ScrollMode
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_SCROLLMODE_IDX] = &SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "ScrollMode",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type,
        (long) QAbstractItemView::ScrollPerItem, "ScrollPerItem");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "ScrollPerItem", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type.tp_dict,
        "ScrollPerItem", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type,
        (long) QAbstractItemView::ScrollPerPixel, "ScrollPerPixel");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "ScrollPerPixel", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_ScrollMode_Type.tp_dict,
        "ScrollPerPixel", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::ScrollMode");

    // init enum class: CursorAction
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_CURSORACTION_IDX] = &SbkPySide_QtGui_QAbstractItemView_CursorAction_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "CursorAction",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MoveUp, "MoveUp");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MoveUp", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MoveUp", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MoveDown, "MoveDown");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MoveDown", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MoveDown", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MoveLeft, "MoveLeft");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MoveLeft", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MoveLeft", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MoveRight, "MoveRight");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MoveRight", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MoveRight", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MoveHome, "MoveHome");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MoveHome", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MoveHome", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MoveEnd, "MoveEnd");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MoveEnd", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MoveEnd", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MovePageUp, "MovePageUp");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MovePageUp", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MovePageUp", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MovePageDown, "MovePageDown");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MovePageDown", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MovePageDown", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MoveNext, "MoveNext");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MoveNext", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MoveNext", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_CursorAction_Type,
        (long) QAbstractItemView::MovePrevious, "MovePrevious");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MovePrevious", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_CursorAction_Type.tp_dict,
        "MovePrevious", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::CursorAction");

    // init enum class: DropIndicatorPosition
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_DROPINDICATORPOSITION_IDX] = &SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "DropIndicatorPosition",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type,
        (long) QAbstractItemView::OnItem, "OnItem");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "OnItem", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type.tp_dict,
        "OnItem", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type,
        (long) QAbstractItemView::AboveItem, "AboveItem");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "AboveItem", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type.tp_dict,
        "AboveItem", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type,
        (long) QAbstractItemView::BelowItem, "BelowItem");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "BelowItem", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type.tp_dict,
        "BelowItem", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type,
        (long) QAbstractItemView::OnViewport, "OnViewport");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "OnViewport", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_DropIndicatorPosition_Type.tp_dict,
        "OnViewport", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::DropIndicatorPosition");

    // init enum class: ScrollHint
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_SCROLLHINT_IDX] = &SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "ScrollHint",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type,
        (long) QAbstractItemView::EnsureVisible, "EnsureVisible");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "EnsureVisible", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type.tp_dict,
        "EnsureVisible", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type,
        (long) QAbstractItemView::PositionAtTop, "PositionAtTop");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "PositionAtTop", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type.tp_dict,
        "PositionAtTop", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type,
        (long) QAbstractItemView::PositionAtBottom, "PositionAtBottom");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "PositionAtBottom", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type.tp_dict,
        "PositionAtBottom", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type,
        (long) QAbstractItemView::PositionAtCenter, "PositionAtCenter");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "PositionAtCenter", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_ScrollHint_Type.tp_dict,
        "PositionAtCenter", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::ScrollHint");

    // init enum class: SelectionMode
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_SELECTIONMODE_IDX] = &SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "SelectionMode",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type,
        (long) QAbstractItemView::NoSelection, "NoSelection");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "NoSelection", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type.tp_dict,
        "NoSelection", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type,
        (long) QAbstractItemView::SingleSelection, "SingleSelection");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "SingleSelection", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type.tp_dict,
        "SingleSelection", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type,
        (long) QAbstractItemView::MultiSelection, "MultiSelection");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "MultiSelection", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type.tp_dict,
        "MultiSelection", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type,
        (long) QAbstractItemView::ExtendedSelection, "ExtendedSelection");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "ExtendedSelection", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type.tp_dict,
        "ExtendedSelection", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type,
        (long) QAbstractItemView::ContiguousSelection, "ContiguousSelection");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "ContiguousSelection", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_SelectionMode_Type.tp_dict,
        "ContiguousSelection", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::SelectionMode");

    // init enum class: State
    SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_STATE_IDX] = &SbkPySide_QtGui_QAbstractItemView_State_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QAbstractItemView_State_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QAbstractItemView_State_Type);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
            "State",((PyObject*)&SbkPySide_QtGui_QAbstractItemView_State_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_State_Type,
        (long) QAbstractItemView::NoState, "NoState");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "NoState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_State_Type.tp_dict,
        "NoState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_State_Type,
        (long) QAbstractItemView::DraggingState, "DraggingState");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "DraggingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_State_Type.tp_dict,
        "DraggingState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_State_Type,
        (long) QAbstractItemView::DragSelectingState, "DragSelectingState");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "DragSelectingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_State_Type.tp_dict,
        "DragSelectingState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_State_Type,
        (long) QAbstractItemView::EditingState, "EditingState");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "EditingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_State_Type.tp_dict,
        "EditingState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_State_Type,
        (long) QAbstractItemView::ExpandingState, "ExpandingState");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "ExpandingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_State_Type.tp_dict,
        "ExpandingState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_State_Type,
        (long) QAbstractItemView::CollapsingState, "CollapsingState");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "CollapsingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_State_Type.tp_dict,
        "CollapsingState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QAbstractItemView_State_Type,
        (long) QAbstractItemView::AnimatingState, "AnimatingState");
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict,
        "AnimatingState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QAbstractItemView_State_Type.tp_dict,
        "AnimatingState", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractItemView::State");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("doubleClicked", "const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict, "doubleClicked", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("pressed", "const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict, "pressed", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("entered", "const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict, "entered", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("clicked", "const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict, "clicked", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("viewportEntered", "void", NULL);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict, "viewportEntered", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("activated", "const QModelIndex&", NULL);
    PyDict_SetItemString(SbkQAbstractItemView_Type.super.ht_type.tp_dict, "activated", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractItemView >("QAbstractItemView*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractItemView >(typeid(QAbstractItemView).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractItemView >(typeid(QAbstractItemViewWrapper).name());
    PySide::initQtMetaType<QAbstractItemView* >();
}

