/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include "pyside_qtgui_python.h"

#include "qgraphicsscene_wrapper.h"

// Extra includes
#include <QList>
#include <QVarLengthArray>
#include <qbrush.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qevent.h>
#include <qfont.h>
#include <qgraphicsitem.h>
#include <qgraphicsproxywidget.h>
#include <qgraphicsscene.h>
#include <qgraphicssceneevent.h>
#include <qgraphicsview.h>
#include <qgraphicswidget.h>
#include <qline.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpalette.h>
#include <qpen.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qstyle.h>
#include <qthread.h>
#include <qtransform.h>
#include <qwidget.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsSceneWrapper::QGraphicsSceneWrapper(QObject * parent) : QGraphicsScene(parent), m_metaObject(0) {
    // ... middle
}

QGraphicsSceneWrapper::QGraphicsSceneWrapper(const QRectF & sceneRect, QObject * parent) : QGraphicsScene(sceneRect, parent), m_metaObject(0) {
    // ... middle
}

QGraphicsSceneWrapper::QGraphicsSceneWrapper(qreal x, qreal y, qreal width, qreal height, QObject * parent) : QGraphicsScene(x, y, width, height, parent), m_metaObject(0) {
    // ... middle
}

void QGraphicsSceneWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsSceneWrapper::contextMenuEvent(QGraphicsSceneContextMenuEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneContextMenuEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsSceneWrapper::dragEnterEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::dragLeaveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::dragMoveEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::drawBackground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "drawBackground"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::drawBackground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        Shiboken::Converter<const QRectF & >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::drawForeground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "drawForeground"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::drawForeground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        Shiboken::Converter<const QRectF & >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::dropEvent(QGraphicsSceneDragDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneDragDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QGraphicsSceneWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsScene.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsSceneWrapper::eventFilter(QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(watched),
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsScene.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGraphicsSceneWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::helpEvent(QGraphicsSceneHelpEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "helpEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::helpEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneHelpEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QGraphicsSceneWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsScene.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsSceneWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mouseMoveEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mousePressEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::mouseReleaseEvent(QGraphicsSceneMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsSceneWrapper::wheelEvent(QGraphicsSceneWheelEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsScene::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QGraphicsSceneWheelEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsSceneWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGraphicsScene::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGraphicsSceneWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsScene::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsSceneWrapper::~QGraphicsSceneWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsScene_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsScene >()))
        return -1;

    QGraphicsSceneWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQGraphicsScene_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:QGraphicsScene", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsScene(QObject*)
    // 1: QGraphicsScene(QRectF,QObject*)
    // 2: QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsScene(QObject*)
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[4])) {
            overloadId = 2; // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGraphicsScene(QRectF,QObject*)
        } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGraphicsScene(QRectF,QObject*)
        }
    } else if (Shiboken::Converter<QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGraphicsScene(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsScene_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGraphicsScene(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QObject* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QObject* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QGraphicsScene(QObject*)
                cptr = new QGraphicsSceneWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QGraphicsScene(QRectF,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QObject* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QObject* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QGraphicsScene(QRectF,QObject*)
                cptr = new QGraphicsSceneWrapper(*cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 2: // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "parent";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return -1;
                QObject* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QObject* >::toCpp(pyargs[4]) : 0;

                if(!PyErr_Occurred()) {
                // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
                cptr = new QGraphicsSceneWrapper(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                Shiboken::setParent(pyargs[4], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsScene >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsScene_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGraphicsScene_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "PySide.QtCore.QRectF, PySide.QtCore.QObject = None", "float, float, float, float, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene", overloads);
        return -1;
}

static PyObject* SbkQGraphicsSceneFunc_activePanel(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // activePanel()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsScene::activePanel();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_activeWindow(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // activeWindow()const
            QGraphicsWidget * cppResult = cppSelf->QGraphicsScene::activeWindow();
            pyResult = Shiboken::Converter<QGraphicsWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_addEllipse(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "brush", "pen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:addEllipse", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addEllipse(QRectF,QPen,QBrush)
    // 1: addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            } else if (Shiboken::Converter<const QBrush & >::isConvertible(pyargs[5])) {
                overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            }
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
            } else if (Shiboken::Converter<const QBrush & >::isConvertible(pyargs[2])) {
                overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addEllipse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addEllipse(QRectF,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "pen";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "brush";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPen > cpp_arg1_auto_ptr;
                QPen cpp_arg1_tmp = QPen();
                QPen* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QPen* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QPen >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPen >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg2_auto_ptr;
                QBrush cpp_arg2_tmp = QBrush();
                QBrush* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QBrush* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QBrush >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QBrush >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // addEllipse(QRectF,QPen,QBrush)
                QGraphicsEllipseItem * cppResult = cppSelf->QGraphicsScene::addEllipse(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                pyResult = Shiboken::Converter<QGraphicsEllipseItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "pen";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "brush";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addEllipse(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QPen > cpp_arg4_auto_ptr;
                QPen cpp_arg4_tmp = QPen();
                QPen* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QPen* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (pyargs[4] && !Shiboken::Converter<QPen >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QPen >(cpp_arg4);
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg5_auto_ptr;
                QBrush cpp_arg5_tmp = QBrush();
                QBrush* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QBrush* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (pyargs[5] && !Shiboken::Converter<QBrush >::checkType(pyargs[5]))
                    cpp_arg5_auto_ptr = std::auto_ptr<QBrush >(cpp_arg5);

                if(!PyErr_Occurred()) {
                // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
                QGraphicsEllipseItem * cppResult = cppSelf->QGraphicsScene::addEllipse(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4, *cpp_arg5);
                pyResult = Shiboken::Converter<QGraphicsEllipseItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addEllipse_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", "float, float, float, float, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addEllipse", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addItem(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addItem(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // addItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addItem(QGraphicsItem*)
            cppSelf->QGraphicsScene::addItem(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_addItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.addItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addLine(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "pen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): not enough arguments");
        return 0;
    } else if (numArgs == 3)
        goto SbkQGraphicsSceneFunc_addLine_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:addLine", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: addLine(QLineF,QPen)
    // 1: addLine(qreal,qreal,qreal,qreal,QPen)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // addLine(qreal,qreal,qreal,qreal,QPen)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[4])) {
            overloadId = 1; // addLine(qreal,qreal,qreal,qreal,QPen)
        }
    } else if (Shiboken::Converter<const QLineF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addLine(QLineF,QPen)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[1])) {
            overloadId = 0; // addLine(QLineF,QPen)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addLine_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addLine(QLineF,QPen)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "pen";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QLineF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPen > cpp_arg1_auto_ptr;
                QPen cpp_arg1_tmp = QPen();
                QPen* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QPen* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QPen >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPen >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // addLine(QLineF,QPen)
                QGraphicsLineItem * cppResult = cppSelf->QGraphicsScene::addLine(*cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QGraphicsLineItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // addLine(qreal,qreal,qreal,qreal,QPen)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "pen";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addLine(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QPen > cpp_arg4_auto_ptr;
                QPen cpp_arg4_tmp = QPen();
                QPen* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QPen* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (pyargs[4] && !Shiboken::Converter<QPen >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QPen >(cpp_arg4);

                if(!PyErr_Occurred()) {
                // addLine(qreal,qreal,qreal,qreal,QPen)
                QGraphicsLineItem * cppResult = cppSelf->QGraphicsScene::addLine(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4);
                pyResult = Shiboken::Converter<QGraphicsLineItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addLine_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLineF, PySide.QtGui.QPen = QPen()", "float, float, float, float, PySide.QtGui.QPen = QPen()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addLine", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addPath(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "brush", "pen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPath(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPath(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPath(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addPath", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addPath(QPainterPath,QPen,QBrush)
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
            } else if (Shiboken::Converter<const QBrush & >::isConvertible(pyargs[2])) {
                overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addPath_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "pen");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "pen";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "brush");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "brush";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPath(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPen > cpp_arg1_auto_ptr;
            QPen cpp_arg1_tmp = QPen();
            QPen* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QPen* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QPen >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPen >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QBrush > cpp_arg2_auto_ptr;
            QBrush cpp_arg2_tmp = QBrush();
            QBrush* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QBrush* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            if (pyargs[2] && !Shiboken::Converter<QBrush >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QBrush >(cpp_arg2);

            if(!PyErr_Occurred()) {
            // addPath(QPainterPath,QPen,QBrush)
            QGraphicsPathItem * cppResult = cppSelf->QGraphicsScene::addPath(*cpp_arg0, *cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<QGraphicsPathItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addPath", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addPixmap(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPixmap(QPixmap)
    if (Shiboken::Converter<const QPixmap & >::isConvertible(arg)) {
        overloadId = 0; // addPixmap(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addPixmap_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPixmap > cpp_arg0_auto_ptr;
            QPixmap* cpp_arg0 = Shiboken::Converter<QPixmap* >::toCpp(arg);
            if (!Shiboken::Converter<QPixmap >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // addPixmap(QPixmap)
            QGraphicsPixmapItem * cppResult = cppSelf->QGraphicsScene::addPixmap(*cpp_arg0);
            pyResult = Shiboken::Converter<QGraphicsPixmapItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.addPixmap", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addPolygon(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "brush", "pen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPolygon(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPolygon(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPolygon(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addPolygon", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addPolygon(QPolygonF,QPen,QBrush)
    if (Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
            } else if (Shiboken::Converter<const QBrush & >::isConvertible(pyargs[2])) {
                overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addPolygon_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "pen");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "pen";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "brush");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "brush";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
            QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPen > cpp_arg1_auto_ptr;
            QPen cpp_arg1_tmp = QPen();
            QPen* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QPen* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QPen >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPen >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QBrush > cpp_arg2_auto_ptr;
            QBrush cpp_arg2_tmp = QBrush();
            QBrush* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QBrush* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            if (pyargs[2] && !Shiboken::Converter<QBrush >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QBrush >(cpp_arg2);

            if(!PyErr_Occurred()) {
            // addPolygon(QPolygonF,QPen,QBrush)
            QGraphicsPolygonItem * cppResult = cppSelf->QGraphicsScene::addPolygon(*cpp_arg0, *cpp_arg1, *cpp_arg2);
            pyResult = Shiboken::Converter<QGraphicsPolygonItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addPolygon", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "brush", "pen" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:addRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: addRect(QRectF,QPen,QBrush)
    // 1: addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            } else if (Shiboken::Converter<const QBrush & >::isConvertible(pyargs[5])) {
                overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            }
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addRect(QRectF,QPen,QBrush)
        } else if (Shiboken::Converter<const QPen & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addRect(QRectF,QPen,QBrush)
            } else if (Shiboken::Converter<const QBrush & >::isConvertible(pyargs[2])) {
                overloadId = 0; // addRect(QRectF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addRect(QRectF,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "pen";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "brush";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPen > cpp_arg1_auto_ptr;
                QPen cpp_arg1_tmp = QPen();
                QPen* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QPen* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (pyargs[1] && !Shiboken::Converter<QPen >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPen >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg2_auto_ptr;
                QBrush cpp_arg2_tmp = QBrush();
                QBrush* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QBrush* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QBrush >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QBrush >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // addRect(QRectF,QPen,QBrush)
                QGraphicsRectItem * cppResult = cppSelf->QGraphicsScene::addRect(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                pyResult = Shiboken::Converter<QGraphicsRectItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pen");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "pen";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "brush");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "brush";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QPen > cpp_arg4_auto_ptr;
                QPen cpp_arg4_tmp = QPen();
                QPen* cpp_arg4 = pyargs[4] ? Shiboken::Converter<QPen* >::toCpp(pyargs[4]) : &cpp_arg4_tmp;
                if (pyargs[4] && !Shiboken::Converter<QPen >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QPen >(cpp_arg4);
                if (Shiboken::cppObjectIsInvalid(pyargs[5]))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg5_auto_ptr;
                QBrush cpp_arg5_tmp = QBrush();
                QBrush* cpp_arg5 = pyargs[5] ? Shiboken::Converter<QBrush* >::toCpp(pyargs[5]) : &cpp_arg5_tmp;
                if (pyargs[5] && !Shiboken::Converter<QBrush >::checkType(pyargs[5]))
                    cpp_arg5_auto_ptr = std::auto_ptr<QBrush >(cpp_arg5);

                if(!PyErr_Occurred()) {
                // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
                QGraphicsRectItem * cppResult = cppSelf->QGraphicsScene::addRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4, *cpp_arg5);
                pyResult = Shiboken::Converter<QGraphicsRectItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", "float, float, float, float, PySide.QtGui.QPen = QPen(), PySide.QtGui.QBrush = QBrush()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addRect", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addSimpleText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "font" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addSimpleText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addSimpleText(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addSimpleText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addSimpleText", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addSimpleText(QString,QFont)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addSimpleText(QString,QFont)
        } else if (Shiboken::Converter<const QFont & >::isConvertible(pyargs[1])) {
            overloadId = 0; // addSimpleText(QString,QFont)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addSimpleText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "font");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "font";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addSimpleText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QFont > cpp_arg1_auto_ptr;
            QFont cpp_arg1_tmp = QFont();
            QFont* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFont* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QFont >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QFont >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // addSimpleText(QString,QFont)
            QGraphicsSimpleTextItem * cppResult = cppSelf->QGraphicsScene::addSimpleText(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QGraphicsSimpleTextItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addSimpleText_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QFont = QFont()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addSimpleText", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "font" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addText(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addText", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addText(QString,QFont)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addText(QString,QFont)
        } else if (Shiboken::Converter<const QFont & >::isConvertible(pyargs[1])) {
            overloadId = 0; // addText(QString,QFont)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "font");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "font";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QFont > cpp_arg1_auto_ptr;
            QFont cpp_arg1_tmp = QFont();
            QFont* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFont* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QFont >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QFont >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // addText(QString,QFont)
            QGraphicsTextItem * cppResult = cppSelf->QGraphicsScene::addText(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QGraphicsTextItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addText_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QFont = QFont()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addText", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_addWidget(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "wFlags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addWidget(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addWidget(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addWidget(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:addWidget", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addWidget(QWidget*,QFlags<Qt::WindowType>)
    if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addWidget(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // addWidget(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_addWidget_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "wFlags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "wFlags";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.addWidget(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            QFlags<Qt::WindowType> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
            // addWidget(QWidget*,QFlags<Qt::WindowType>)
            QGraphicsProxyWidget * cppResult = cppSelf->QGraphicsScene::addWidget(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QGraphicsProxyWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_addWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.addWidget", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_advance(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // advance()
            cppSelf->QGraphicsScene::advance();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsSceneFunc_backgroundBrush(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundBrush()const
            QBrush cppResult = cppSelf->QGraphicsScene::backgroundBrush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_bspTreeDepth(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // bspTreeDepth()const
            int cppResult = cppSelf->QGraphicsScene::bspTreeDepth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_clearFocus(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearFocus()
            cppSelf->QGraphicsScene::clearFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsSceneFunc_clearSelection(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearSelection()
            cppSelf->QGraphicsScene::clearSelection();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsSceneFunc_collidingItems(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.collidingItems(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.collidingItems(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.collidingItems(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:collidingItems", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
    if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_collidingItems_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.collidingItems(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
            Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

            if(!PyErr_Occurred()) {
            // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
            QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::collidingItems(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_collidingItems_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.collidingItems", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    if (Shiboken::Converter<QGraphicsSceneContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneContextMenuEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneContextMenuEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
            cppSelf->QGraphicsScene::contextMenuEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.contextMenuEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragEnterEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsScene::dragEnterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dragEnterEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsScene::dragLeaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragMoveEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsScene::dragMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dragMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_drawBackground(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawBackground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawBackground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawBackground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_drawBackground_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // drawBackground(QPainter*,QRectF)
            cppSelf->QGraphicsScene::drawBackground(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_drawBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.drawBackground", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_drawForeground(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawForeground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawForeground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawForeground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_drawForeground_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // drawForeground(QPainter*,QRectF)
            cppSelf->QGraphicsScene::drawForeground(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_drawForeground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.drawForeground", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QGraphicsSceneDragDropEvent*)
    if (Shiboken::Converter<QGraphicsSceneDragDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneDragDropEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneDragDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dropEvent(QGraphicsSceneDragDropEvent*)
            cppSelf->QGraphicsScene::dropEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneDragDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.dropEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_event(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QGraphicsScene::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.event", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_eventFilter(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: eventFilter(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter<QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_eventFilter_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QObject* cpp_arg0 = Shiboken::Converter<QObject* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = Shiboken::Converter<QEvent* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = cppSelf->QGraphicsScene::eventFilter(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_eventFilter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.eventFilter", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusInEvent(QFocusEvent*)
            cppSelf->QGraphicsScene::focusInEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.focusInEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_focusItem(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusItem()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsScene::focusItem();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusNextPrevChild(bool)
            bool cppResult = cppSelf->QGraphicsScene::focusNextPrevChild(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusOutEvent(QFocusEvent*)
            cppSelf->QGraphicsScene::focusOutEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.focusOutEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_font(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // font()const
            QFont cppResult = cppSelf->QGraphicsScene::font();
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_foregroundBrush(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // foregroundBrush()const
            QBrush cppResult = cppSelf->QGraphicsScene::foregroundBrush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_hasFocus(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasFocus()const
            bool cppResult = cppSelf->QGraphicsScene::hasFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_height(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            qreal cppResult = cppSelf->QGraphicsScene::height();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_helpEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: helpEvent(QGraphicsSceneHelpEvent*)
    if (Shiboken::Converter<QGraphicsSceneHelpEvent * >::isConvertible(arg)) {
        overloadId = 0; // helpEvent(QGraphicsSceneHelpEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_helpEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneHelpEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneHelpEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // helpEvent(QGraphicsSceneHelpEvent*)
            cppSelf->QGraphicsScene::helpEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_helpEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneHelpEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.helpEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            cppSelf->QGraphicsScene::inputMethodEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.inputMethodEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter<Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cpp_arg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = cppSelf->QGraphicsScene::inputMethodQuery(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.inputMethodQuery", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_invalidate(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "layers", "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.invalidate(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.invalidate(): too many arguments");
        return 0;
    } else if (numArgs == 3)
        goto SbkQGraphicsSceneFunc_invalidate_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:invalidate", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    // 1: invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
    if (numArgs == 0) {
        overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 1; // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
        } else if (Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::isConvertible(pyargs[4])) {
            overloadId = 1; // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        } else if (Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::isConvertible(pyargs[1])) {
            overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_invalidate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else
                            pyargs[0] = value;
                    }
                    value = PyDict_GetItemString(kwds, "layers");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "layers";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.invalidate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF cpp_arg0_tmp = QRectF();
                QRectF* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
                if (pyargs[0] && !Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                QFlags<QGraphicsScene::SceneLayer> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::toCpp(pyargs[1]) : QGraphicsScene::AllLayers;

                if(!PyErr_Occurred()) {
                // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
                cppSelf->QGraphicsScene::invalidate(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "layers");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "layers";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.invalidate(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                QFlags<QGraphicsScene::SceneLayer> cpp_arg4 = pyargs[4] ? Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::toCpp(pyargs[4]) : QGraphicsScene::AllLayers;

                if(!PyErr_Occurred()) {
                // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
                cppSelf->QGraphicsScene::invalidate(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_invalidate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF(), PySide.QtGui.QGraphicsScene.SceneLayers = QGraphicsScene.AllLayers", "float, float, float, float, PySide.QtGui.QGraphicsScene.SceneLayers = QGraphicsScene.AllLayers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.invalidate", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_isActive(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isActive()const
            bool cppResult = cppSelf->QGraphicsScene::isActive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_isSortCacheEnabled(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isSortCacheEnabled()const
            bool cppResult = cppSelf->QGraphicsScene::isSortCacheEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_itemAt(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(QPointF)const
    // 1: itemAt(QPointF,QTransform)const
    // 2: itemAt(qreal,qreal)const
    // 3: itemAt(qreal,qreal,QTransform)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // itemAt(qreal,qreal)const
        } else if (numArgs == 3 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[2])) {
            overloadId = 3; // itemAt(qreal,qreal,QTransform)const
        }
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // itemAt(QPointF)const
        } else if (numArgs == 2 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[1])) {
            overloadId = 1; // itemAt(QPointF,QTransform)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // itemAt(QPointF)const
                QGraphicsItem * cppResult = cppSelf->QGraphicsScene::itemAt(*cpp_arg0);
                pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // itemAt(QPointF,QTransform)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTransform* cpp_arg1 = Shiboken::Converter<QTransform* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // itemAt(QPointF,QTransform)const
                QGraphicsItem * cppResult = cppSelf->QGraphicsScene::itemAt(*cpp_arg0, *cpp_arg1);
                pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 2: // itemAt(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // itemAt(qreal,qreal)const
                QGraphicsItem * cppResult = cppSelf->QGraphicsScene::itemAt(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 3: // itemAt(qreal,qreal,QTransform)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QTransform* cpp_arg2 = Shiboken::Converter<QTransform* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // itemAt(qreal,qreal,QTransform)const
                QGraphicsItem * cppResult = cppSelf->QGraphicsScene::itemAt(cpp_arg0, cpp_arg1, *cpp_arg2);
                pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_itemAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "PySide.QtCore.QPointF, PySide.QtGui.QTransform", "float, float", "float, float, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.itemAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_itemIndexMethod(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // itemIndexMethod()const
            QGraphicsScene::ItemIndexMethod cppResult = cppSelf->QGraphicsScene::itemIndexMethod();
            pyResult = Shiboken::Converter<QGraphicsScene::ItemIndexMethod >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_items(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "deviceTransform", "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOO:items", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: items()const
    // 1: items(Qt::SortOrder)const
    // 2: items(QPainterPath,Qt::ItemSelectionMode)const
    // 3: items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 4: items(QPointF)const
    // 5: items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 6: items(QPolygonF,Qt::ItemSelectionMode)const
    // 7: items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 8: items(QRectF,Qt::ItemSelectionMode)const
    // 9: items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    // 10: items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
    // 11: items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
    if (numArgs == 0) {
        overloadId = 0; // items()const
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 8; // items(QRectF,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 8; // items(QRectF,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 9; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[3])) {
                    overloadId = 9; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 6; // items(QPolygonF,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 6; // items(QPolygonF,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 7; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[3])) {
                    overloadId = 7; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // items(QPointF)const
        } else if (numArgs >= 3 && Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1]) && Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 5; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            } else if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[3])) {
                overloadId = 5; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            }
        }
    } else if (Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // items(QPainterPath,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // items(QPainterPath,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 3; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[3])) {
                    overloadId = 3; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[0])) {
        overloadId = 1; // items(Qt::SortOrder)const
    } else if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 10; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 10; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter<Qt::SortOrder >::isConvertible(pyargs[5])) {
                if (numArgs == 6) {
                    overloadId = 11; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[6])) {
                    overloadId = 11; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_items_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // items()const
            {

                if(!PyErr_Occurred()) {
                // items()const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items();
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 1: // items(Qt::SortOrder)const
            {
                Qt::SortOrder cpp_arg0 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // items(Qt::SortOrder)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(cpp_arg0);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 2: // items(QPainterPath,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(QPainterPath,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 3: // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cpp_arg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cpp_arg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QTransform cpp_arg3_tmp = QTransform();
                QTransform* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QTransform* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;

                if(!PyErr_Occurred()) {
                // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 4: // items(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // items(QPointF)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 5: // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                Qt::ItemSelectionMode cpp_arg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cpp_arg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QTransform cpp_arg3_tmp = QTransform();
                QTransform* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QTransform* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;

                if(!PyErr_Occurred()) {
                // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 6: // items(QPolygonF,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);
                Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(QPolygonF,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 7: // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);
                Qt::ItemSelectionMode cpp_arg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cpp_arg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QTransform cpp_arg3_tmp = QTransform();
                QTransform* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QTransform* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;

                if(!PyErr_Occurred()) {
                // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 8: // items(QRectF,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(QRectF,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 9: // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "deviceTransform";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                Qt::ItemSelectionMode cpp_arg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                Qt::SortOrder cpp_arg2 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[2]);
                if (Shiboken::cppObjectIsInvalid(pyargs[3]))
                    return 0;
                QTransform cpp_arg3_tmp = QTransform();
                QTransform* cpp_arg3 = pyargs[3] ? Shiboken::Converter<QTransform* >::toCpp(pyargs[3]) : &cpp_arg3_tmp;

                if(!PyErr_Occurred()) {
                // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(*cpp_arg0, cpp_arg1, cpp_arg2, *cpp_arg3);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 10: // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "mode";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                Qt::ItemSelectionMode cpp_arg4 = pyargs[4] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[4]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 11: // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "deviceTransform");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "deviceTransform";
                        else
                            pyargs[6] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                Qt::ItemSelectionMode cpp_arg4 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[4]);
                Qt::SortOrder cpp_arg5 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[5]);
                if (Shiboken::cppObjectIsInvalid(pyargs[6]))
                    return 0;
                QTransform cpp_arg6_tmp = QTransform();
                QTransform* cpp_arg6 = pyargs[6] ? Shiboken::Converter<QTransform* >::toCpp(pyargs[6]) : &cpp_arg6_tmp;

                if(!PyErr_Occurred()) {
                // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::items(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, *cpp_arg6);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_items_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.SortOrder", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "PySide.QtCore.QPointF", "PySide.QtCore.QPointF, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "PySide.QtGui.QPolygonF, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtGui.QPolygonF, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "PySide.QtCore.QRectF, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtCore.QRectF, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", "float, float, float, float, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "float, float, float, float, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtCore.Qt.SortOrder, PySide.QtGui.QTransform = QTransform()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.items", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_itemsBoundingRect(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // itemsBoundingRect()const
            QRectF cppResult = cppSelf->QGraphicsScene::itemsBoundingRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QGraphicsScene::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyReleaseEvent(QKeyEvent*)
            cppSelf->QGraphicsScene::keyReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsScene::mouseDoubleClickEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_mouseGrabberItem(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mouseGrabberItem()const
            QGraphicsItem * cppResult = cppSelf->QGraphicsScene::mouseGrabberItem();
            pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseMoveEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsScene::mouseMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mousePressEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsScene::mousePressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mousePressEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    if (Shiboken::Converter<QGraphicsSceneMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneMouseEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
            cppSelf->QGraphicsScene::mouseReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_palette(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // palette()const
            QPalette cppResult = cppSelf->QGraphicsScene::palette();
            pyResult = Shiboken::Converter<QPalette >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_removeItem(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeItem(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // removeItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_removeItem_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeItem(QGraphicsItem*)
            cppSelf->QGraphicsScene::removeItem(cpp_arg0);
            Shiboken::setParent(Py_None, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_removeItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.removeItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "aspectRatioMode", "source", "target" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.render(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
    if (Shiboken::Converter<QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
        } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
            } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
                } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[3])) {
                    overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_render_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "target");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "target";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "source");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "source";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "aspectRatioMode");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "aspectRatioMode";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.render(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF cpp_arg1_tmp = QRectF();
            QRectF* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg2_auto_ptr;
            QRectF cpp_arg2_tmp = QRectF();
            QRectF* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            if (pyargs[2] && !Shiboken::Converter<QRectF >::checkType(pyargs[2]))
                cpp_arg2_auto_ptr = std::auto_ptr<QRectF >(cpp_arg2);
            Qt::AspectRatioMode cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[3]) : Qt::KeepAspectRatio;

            if(!PyErr_Occurred()) {
            // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
            cppSelf->QGraphicsScene::render(cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF = QRectF(), PySide.QtCore.QRectF = QRectF(), PySide.QtCore.Qt.AspectRatioMode = Qt.KeepAspectRatio", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.render", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_sceneRect(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sceneRect()const
            QRectF cppResult = cppSelf->QGraphicsScene::sceneRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_selectedItems(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectedItems()const
            QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsScene::selectedItems();
            pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_selectionArea(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectionArea()const
            QPainterPath cppResult = cppSelf->QGraphicsScene::selectionArea();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_sendEvent(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sendEvent", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sendEvent(QGraphicsItem*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter<QGraphicsItem * >::isConvertible(pyargs[0]) && Shiboken::Converter<QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // sendEvent(QGraphicsItem*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_sendEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QEvent* cpp_arg1 = Shiboken::Converter<QEvent* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // sendEvent(QGraphicsItem*,QEvent*)
            bool cppResult = cppSelf->QGraphicsScene::sendEvent(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsSceneFunc_sendEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.sendEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setActivePanel(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActivePanel(QGraphicsItem*)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(arg)) {
        overloadId = 0; // setActivePanel(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setActivePanel_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setActivePanel(QGraphicsItem*)
            cppSelf->QGraphicsScene::setActivePanel(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setActivePanel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setActivePanel", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setActiveWindow(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActiveWindow(QGraphicsWidget*)
    if (Shiboken::Converter<QGraphicsWidget * >::isConvertible(arg)) {
        overloadId = 0; // setActiveWindow(QGraphicsWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setActiveWindow_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsWidget* cpp_arg0 = Shiboken::Converter<QGraphicsWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setActiveWindow(QGraphicsWidget*)
            cppSelf->QGraphicsScene::setActiveWindow(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setActiveWindow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setActiveWindow", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setBackgroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundBrush(QBrush)
    if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setBackgroundBrush_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
            QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
            if (!Shiboken::Converter<QBrush >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBackgroundBrush(QBrush)
            cppSelf->QGraphicsScene::setBackgroundBrush(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setBackgroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setBackgroundBrush", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setBspTreeDepth(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBspTreeDepth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBspTreeDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setBspTreeDepth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBspTreeDepth(int)
            cppSelf->QGraphicsScene::setBspTreeDepth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setBspTreeDepth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setBspTreeDepth", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setFocus(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "focusReason" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocus(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocus(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setFocus", &arg))
        return 0;


    // Overloaded function decisor
    // 0: setFocus(Qt::FocusReason)
    if (numArgs == 0) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    } else if (Shiboken::Converter<Qt::FocusReason >::isConvertible(arg)) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setFocus_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "focusReason");
                if (value) {
                    if (arg)
                        errorArgName = "focusReason";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocus(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::FocusReason cpp_arg0 = arg ? Shiboken::Converter<Qt::FocusReason >::toCpp(arg) : Qt::OtherFocusReason;

            if(!PyErr_Occurred()) {
            // setFocus(Qt::FocusReason)
            cppSelf->QGraphicsScene::setFocus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setFocus_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.FocusReason = Qt.OtherFocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setFocus", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setFocusItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "focusReason" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocusItem(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocusItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocusItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setFocusItem", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFocusItem(QGraphicsItem*,Qt::FocusReason)
    if (Shiboken::Converter<QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setFocusItem(QGraphicsItem*,Qt::FocusReason)
        } else if (Shiboken::Converter<Qt::FocusReason >::isConvertible(pyargs[1])) {
            overloadId = 0; // setFocusItem(QGraphicsItem*,Qt::FocusReason)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setFocusItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "focusReason");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "focusReason";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.setFocusItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
            Qt::FocusReason cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::FocusReason >::toCpp(pyargs[1]) : Qt::OtherFocusReason;

            if(!PyErr_Occurred()) {
            // setFocusItem(QGraphicsItem*,Qt::FocusReason)
            cppSelf->QGraphicsScene::setFocusItem(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[0]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setFocusItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.Qt.FocusReason = Qt.OtherFocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.setFocusItem", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setFont(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFont(QFont)
            cppSelf->QGraphicsScene::setFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setFont", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setForegroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForegroundBrush(QBrush)
    if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 0; // setForegroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setForegroundBrush_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
            QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
            if (!Shiboken::Converter<QBrush >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setForegroundBrush(QBrush)
            cppSelf->QGraphicsScene::setForegroundBrush(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setForegroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setForegroundBrush", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setItemIndexMethod(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
    if (Shiboken::Converter<QGraphicsScene::ItemIndexMethod >::isConvertible(arg)) {
        overloadId = 0; // setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setItemIndexMethod_TypeError;

    // Call function/method
    {
        {
            QGraphicsScene::ItemIndexMethod cpp_arg0 = Shiboken::Converter<QGraphicsScene::ItemIndexMethod >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
            cppSelf->QGraphicsScene::setItemIndexMethod(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setItemIndexMethod_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsScene.ItemIndexMethod", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setItemIndexMethod", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setPalette(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPalette(QPalette)
    if (Shiboken::Converter<const QPalette & >::isConvertible(arg)) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPalette > cpp_arg0_auto_ptr;
            QPalette* cpp_arg0 = Shiboken::Converter<QPalette* >::toCpp(arg);
            if (!Shiboken::Converter<QPalette >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPalette >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPalette(QPalette)
            cppSelf->QGraphicsScene::setPalette(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setPalette", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setSceneRect(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsSceneFunc_setSceneRect_TypeError;

    if (!PyArg_UnpackTuple(args, "setSceneRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setSceneRect(QRectF)
    // 1: setSceneRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setSceneRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSceneRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setSceneRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSceneRect(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setSceneRect(QRectF)
                cppSelf->QGraphicsScene::setSceneRect(*cpp_arg0);
                }
                break;
            }
            case 1: // setSceneRect(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setSceneRect(qreal,qreal,qreal,qreal)
                cppSelf->QGraphicsScene::setSceneRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setSceneRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.setSceneRect", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setSelectionArea(PyObject* self, PyObject* args)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSelectionArea", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setSelectionArea(QPainterPath)
    // 1: setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
    // 2: setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
    // 3: setSelectionArea(QPainterPath,QTransform)
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setSelectionArea(QPainterPath)
        } else if (numArgs == 2 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[1])) {
            overloadId = 3; // setSelectionArea(QPainterPath,QTransform)
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
            } else if (numArgs == 3 && Shiboken::Converter<const QTransform & >::isConvertible(pyargs[2])) {
                overloadId = 2; // setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setSelectionArea_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSelectionArea(QPainterPath)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setSelectionArea(QPainterPath)
                cppSelf->QGraphicsScene::setSelectionArea(*cpp_arg0);
                }
                break;
            }
            case 1: // setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cpp_arg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setSelectionArea(QPainterPath,Qt::ItemSelectionMode)
                cppSelf->QGraphicsScene::setSelectionArea(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cpp_arg1 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QTransform* cpp_arg2 = Shiboken::Converter<QTransform* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // setSelectionArea(QPainterPath,Qt::ItemSelectionMode,QTransform)
                cppSelf->QGraphicsScene::setSelectionArea(*cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 3: // setSelectionArea(QPainterPath,QTransform)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTransform* cpp_arg1 = Shiboken::Converter<QTransform* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setSelectionArea(QPainterPath,QTransform)
                cppSelf->QGraphicsScene::setSelectionArea(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setSelectionArea_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode, PySide.QtGui.QTransform", "PySide.QtGui.QPainterPath, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.setSelectionArea", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setSortCacheEnabled(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSortCacheEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSortCacheEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setSortCacheEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setSortCacheEnabled(bool)
            cppSelf->QGraphicsScene::setSortCacheEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setSortCacheEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setSortCacheEnabled", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setStickyFocus(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStickyFocus(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStickyFocus(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setStickyFocus_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStickyFocus(bool)
            cppSelf->QGraphicsScene::setStickyFocus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setStickyFocus_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setStickyFocus", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_setStyle(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QStyle*)
    if (Shiboken::Converter<QStyle * >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QStyle*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QStyle* cpp_arg0 = Shiboken::Converter<QStyle* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStyle(QStyle*)
            cppSelf->QGraphicsScene::setStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.setStyle", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_stickyFocus(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // stickyFocus()const
            bool cppResult = cppSelf->QGraphicsScene::stickyFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_style(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()const
            QStyle * cppResult = cppSelf->QGraphicsScene::style();
            pyResult = Shiboken::Converter<QStyle * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_update(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.update(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.update(): too many arguments");
        return 0;
    } else if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsSceneFunc_update_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:update", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: update(QRectF)
    // 1: update(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // update(QRectF)
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // update(qreal,qreal,qreal,qreal)
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // update(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_update_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // update(QRectF)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsScene.update(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF cpp_arg0_tmp = QRectF();
                QRectF* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
                if (pyargs[0] && !Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // update(QRectF)
                cppSelf->QGraphicsScene::update(*cpp_arg0);
                }
                break;
            }
            case 1: // update(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // update(qreal,qreal,qreal,qreal)
                cppSelf->QGraphicsScene::update(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_update_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF()", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsScene.update", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_views(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // views()const
            QList<QGraphicsView * > cppResult = cppSelf->QGraphicsScene::views();
            pyResult = Shiboken::Converter<QList<QGraphicsView * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsSceneFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QGraphicsSceneWheelEvent*)
    if (Shiboken::Converter<QGraphicsSceneWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QGraphicsSceneWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsSceneFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsSceneWheelEvent* cpp_arg0 = Shiboken::Converter<QGraphicsSceneWheelEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // wheelEvent(QGraphicsSceneWheelEvent*)
            cppSelf->QGraphicsScene::wheelEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsSceneFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsSceneWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsScene.wheelEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsSceneFunc_width(PyObject* self)
{
    QGraphicsScene* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsScene* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            qreal cppResult = cppSelf->QGraphicsScene::width();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQGraphicsScene_methods[] = {
    {"activePanel", (PyCFunction)SbkQGraphicsSceneFunc_activePanel, METH_NOARGS},
    {"activeWindow", (PyCFunction)SbkQGraphicsSceneFunc_activeWindow, METH_NOARGS},
    {"addEllipse", (PyCFunction)SbkQGraphicsSceneFunc_addEllipse, METH_VARARGS|METH_KEYWORDS},
    {"addItem", (PyCFunction)SbkQGraphicsSceneFunc_addItem, METH_O},
    {"addLine", (PyCFunction)SbkQGraphicsSceneFunc_addLine, METH_VARARGS|METH_KEYWORDS},
    {"addPath", (PyCFunction)SbkQGraphicsSceneFunc_addPath, METH_VARARGS|METH_KEYWORDS},
    {"addPixmap", (PyCFunction)SbkQGraphicsSceneFunc_addPixmap, METH_O},
    {"addPolygon", (PyCFunction)SbkQGraphicsSceneFunc_addPolygon, METH_VARARGS|METH_KEYWORDS},
    {"addRect", (PyCFunction)SbkQGraphicsSceneFunc_addRect, METH_VARARGS|METH_KEYWORDS},
    {"addSimpleText", (PyCFunction)SbkQGraphicsSceneFunc_addSimpleText, METH_VARARGS|METH_KEYWORDS},
    {"addText", (PyCFunction)SbkQGraphicsSceneFunc_addText, METH_VARARGS|METH_KEYWORDS},
    {"addWidget", (PyCFunction)SbkQGraphicsSceneFunc_addWidget, METH_VARARGS|METH_KEYWORDS},
    {"advance", (PyCFunction)SbkQGraphicsSceneFunc_advance, METH_NOARGS},
    {"backgroundBrush", (PyCFunction)SbkQGraphicsSceneFunc_backgroundBrush, METH_NOARGS},
    {"bspTreeDepth", (PyCFunction)SbkQGraphicsSceneFunc_bspTreeDepth, METH_NOARGS},
    {"clearFocus", (PyCFunction)SbkQGraphicsSceneFunc_clearFocus, METH_NOARGS},
    {"clearSelection", (PyCFunction)SbkQGraphicsSceneFunc_clearSelection, METH_NOARGS},
    {"collidingItems", (PyCFunction)SbkQGraphicsSceneFunc_collidingItems, METH_VARARGS|METH_KEYWORDS},
    {"contextMenuEvent", (PyCFunction)SbkQGraphicsSceneFunc_contextMenuEvent, METH_O},
    {"dragEnterEvent", (PyCFunction)SbkQGraphicsSceneFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)SbkQGraphicsSceneFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)SbkQGraphicsSceneFunc_dragMoveEvent, METH_O},
    {"drawBackground", (PyCFunction)SbkQGraphicsSceneFunc_drawBackground, METH_VARARGS},
    {"drawForeground", (PyCFunction)SbkQGraphicsSceneFunc_drawForeground, METH_VARARGS},
    {"dropEvent", (PyCFunction)SbkQGraphicsSceneFunc_dropEvent, METH_O},
    {"event", (PyCFunction)SbkQGraphicsSceneFunc_event, METH_O},
    {"eventFilter", (PyCFunction)SbkQGraphicsSceneFunc_eventFilter, METH_VARARGS},
    {"focusInEvent", (PyCFunction)SbkQGraphicsSceneFunc_focusInEvent, METH_O},
    {"focusItem", (PyCFunction)SbkQGraphicsSceneFunc_focusItem, METH_NOARGS},
    {"focusNextPrevChild", (PyCFunction)SbkQGraphicsSceneFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)SbkQGraphicsSceneFunc_focusOutEvent, METH_O},
    {"font", (PyCFunction)SbkQGraphicsSceneFunc_font, METH_NOARGS},
    {"foregroundBrush", (PyCFunction)SbkQGraphicsSceneFunc_foregroundBrush, METH_NOARGS},
    {"hasFocus", (PyCFunction)SbkQGraphicsSceneFunc_hasFocus, METH_NOARGS},
    {"height", (PyCFunction)SbkQGraphicsSceneFunc_height, METH_NOARGS},
    {"helpEvent", (PyCFunction)SbkQGraphicsSceneFunc_helpEvent, METH_O},
    {"inputMethodEvent", (PyCFunction)SbkQGraphicsSceneFunc_inputMethodEvent, METH_O},
    {"inputMethodQuery", (PyCFunction)SbkQGraphicsSceneFunc_inputMethodQuery, METH_O},
    {"invalidate", (PyCFunction)SbkQGraphicsSceneFunc_invalidate, METH_VARARGS|METH_KEYWORDS},
    {"isActive", (PyCFunction)SbkQGraphicsSceneFunc_isActive, METH_NOARGS},
    {"isSortCacheEnabled", (PyCFunction)SbkQGraphicsSceneFunc_isSortCacheEnabled, METH_NOARGS},
    {"itemAt", (PyCFunction)SbkQGraphicsSceneFunc_itemAt, METH_VARARGS},
    {"itemIndexMethod", (PyCFunction)SbkQGraphicsSceneFunc_itemIndexMethod, METH_NOARGS},
    {"items", (PyCFunction)SbkQGraphicsSceneFunc_items, METH_VARARGS|METH_KEYWORDS},
    {"itemsBoundingRect", (PyCFunction)SbkQGraphicsSceneFunc_itemsBoundingRect, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)SbkQGraphicsSceneFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)SbkQGraphicsSceneFunc_keyReleaseEvent, METH_O},
    {"mouseDoubleClickEvent", (PyCFunction)SbkQGraphicsSceneFunc_mouseDoubleClickEvent, METH_O},
    {"mouseGrabberItem", (PyCFunction)SbkQGraphicsSceneFunc_mouseGrabberItem, METH_NOARGS},
    {"mouseMoveEvent", (PyCFunction)SbkQGraphicsSceneFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)SbkQGraphicsSceneFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)SbkQGraphicsSceneFunc_mouseReleaseEvent, METH_O},
    {"palette", (PyCFunction)SbkQGraphicsSceneFunc_palette, METH_NOARGS},
    {"removeItem", (PyCFunction)SbkQGraphicsSceneFunc_removeItem, METH_O},
    {"render", (PyCFunction)SbkQGraphicsSceneFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"sceneRect", (PyCFunction)SbkQGraphicsSceneFunc_sceneRect, METH_NOARGS},
    {"selectedItems", (PyCFunction)SbkQGraphicsSceneFunc_selectedItems, METH_NOARGS},
    {"selectionArea", (PyCFunction)SbkQGraphicsSceneFunc_selectionArea, METH_NOARGS},
    {"sendEvent", (PyCFunction)SbkQGraphicsSceneFunc_sendEvent, METH_VARARGS},
    {"setActivePanel", (PyCFunction)SbkQGraphicsSceneFunc_setActivePanel, METH_O},
    {"setActiveWindow", (PyCFunction)SbkQGraphicsSceneFunc_setActiveWindow, METH_O},
    {"setBackgroundBrush", (PyCFunction)SbkQGraphicsSceneFunc_setBackgroundBrush, METH_O},
    {"setBspTreeDepth", (PyCFunction)SbkQGraphicsSceneFunc_setBspTreeDepth, METH_O},
    {"setFocus", (PyCFunction)SbkQGraphicsSceneFunc_setFocus, METH_VARARGS|METH_KEYWORDS},
    {"setFocusItem", (PyCFunction)SbkQGraphicsSceneFunc_setFocusItem, METH_VARARGS|METH_KEYWORDS},
    {"setFont", (PyCFunction)SbkQGraphicsSceneFunc_setFont, METH_O},
    {"setForegroundBrush", (PyCFunction)SbkQGraphicsSceneFunc_setForegroundBrush, METH_O},
    {"setItemIndexMethod", (PyCFunction)SbkQGraphicsSceneFunc_setItemIndexMethod, METH_O},
    {"setPalette", (PyCFunction)SbkQGraphicsSceneFunc_setPalette, METH_O},
    {"setSceneRect", (PyCFunction)SbkQGraphicsSceneFunc_setSceneRect, METH_VARARGS},
    {"setSelectionArea", (PyCFunction)SbkQGraphicsSceneFunc_setSelectionArea, METH_VARARGS},
    {"setSortCacheEnabled", (PyCFunction)SbkQGraphicsSceneFunc_setSortCacheEnabled, METH_O},
    {"setStickyFocus", (PyCFunction)SbkQGraphicsSceneFunc_setStickyFocus, METH_O},
    {"setStyle", (PyCFunction)SbkQGraphicsSceneFunc_setStyle, METH_O},
    {"stickyFocus", (PyCFunction)SbkQGraphicsSceneFunc_stickyFocus, METH_NOARGS},
    {"style", (PyCFunction)SbkQGraphicsSceneFunc_style, METH_NOARGS},
    {"update", (PyCFunction)SbkQGraphicsSceneFunc_update, METH_VARARGS|METH_KEYWORDS},
    {"views", (PyCFunction)SbkQGraphicsSceneFunc_views, METH_NOARGS},
    {"wheelEvent", (PyCFunction)SbkQGraphicsSceneFunc_wheelEvent, METH_O},
    {"width", (PyCFunction)SbkQGraphicsSceneFunc_width, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsScene_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsScene",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsScene_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsScene_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsScene >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsScene*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsScene_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsScene*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGraphicsScene_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsScene::SceneLayers >::checkType(self) && Shiboken::Converter<QGraphicsScene::SceneLayers >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        Shiboken::Converter<QGraphicsScene::SceneLayers>::toCpp(self)
        & Shiboken::Converter< QGraphicsScene::SceneLayers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsScene::SceneLayers >::checkType(self) && Shiboken::Converter<QGraphicsScene::SceneLayers >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        Shiboken::Converter<QGraphicsScene::SceneLayers>::toCpp(self)
        | Shiboken::Converter< QGraphicsScene::SceneLayers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsScene::SceneLayers >::checkType(self) && Shiboken::Converter<QGraphicsScene::SceneLayers >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        Shiboken::Converter<QGraphicsScene::SceneLayers>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsScene::SceneLayers >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsScene::SceneLayers >::toPython(
        ~Shiboken::Converter<QGraphicsScene::SceneLayers >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsScene_SceneLayer_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsScene_SceneLayer___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsScene_SceneLayer_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SceneLayer",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsScene_SceneLayer_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsScene_SceneLayer_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsScene_SceneLayer_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsScene_SceneLayer_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "SceneLayers",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ItemIndexMethod",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QGraphicsScene(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENE_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsScene_Type);

    SbkQGraphicsScene_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    // Fill type discovery information
    SbkQGraphicsScene_Type.type_discovery = &SbkQGraphicsScene_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQGraphicsScene_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsScene_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsScene_Type));
    PyModule_AddObject(module, "QGraphicsScene",
        ((PyObject*)&SbkQGraphicsScene_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: SceneLayer
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENE_SCENELAYER_IDX] = &SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type);
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
            "SceneLayer",((PyObject*)&SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type));

    // init flags class: QFlags<QGraphicsScene::SceneLayer>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSSCENE_SCENELAYER__IDX] = &SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type);
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
            "SceneLayers",((PyObject*)&SbkPySide_QtGui_QGraphicsScene_SceneLayers_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type,
        (long) QGraphicsScene::ItemLayer, "ItemLayer");
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
        "ItemLayer", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type.tp_dict,
        "ItemLayer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type,
        (long) QGraphicsScene::BackgroundLayer, "BackgroundLayer");
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
        "BackgroundLayer", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type.tp_dict,
        "BackgroundLayer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type,
        (long) QGraphicsScene::ForegroundLayer, "ForegroundLayer");
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
        "ForegroundLayer", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type.tp_dict,
        "ForegroundLayer", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type,
        (long) QGraphicsScene::AllLayers, "AllLayers");
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
        "AllLayers", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_SceneLayer_Type.tp_dict,
        "AllLayers", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsScene::SceneLayer");

    // init enum class: ItemIndexMethod
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENE_ITEMINDEXMETHOD_IDX] = &SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type);
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
            "ItemIndexMethod",((PyObject*)&SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type,
        (long) QGraphicsScene::BspTreeIndex, "BspTreeIndex");
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
        "BspTreeIndex", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type.tp_dict,
        "BspTreeIndex", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type,
        (long) QGraphicsScene::NoIndex, "NoIndex");
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict,
        "NoIndex", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsScene_ItemIndexMethod_Type.tp_dict,
        "NoIndex", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsScene::ItemIndexMethod");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("sceneRectChanged", "const QRectF&", NULL);
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict, "sceneRectChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("selectionChanged", "void", NULL);
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict, "selectionChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("changed", "const QList<QRectF>&", NULL);
    PyDict_SetItemString(SbkQGraphicsScene_Type.super.ht_type.tp_dict, "changed", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsScene >("QGraphicsScene*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsScene >(typeid(QGraphicsScene).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsScene >(typeid(QGraphicsSceneWrapper).name());
    PySide::initQtMetaType<QGraphicsScene* >();
}

