/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qgraphicsview_wrapper.h"

// Extra includes
#include <QList>
#include <QPainterPath>
#include <QVarLengthArray>
#include <autoarraypointer.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbrush.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsitem.h>
#include <qgraphicsproxywidget.h>
#include <qgraphicsscene.h>
#include <qgraphicsview.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmatrix.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qtransform.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QGraphicsViewWrapper::QGraphicsViewWrapper(QGraphicsScene * scene, QWidget * parent) : QGraphicsView(scene, parent), m_metaObject(0) {
    // ... middle
}

QGraphicsViewWrapper::QGraphicsViewWrapper(QWidget * parent) : QGraphicsView(parent), m_metaObject(0) {
    // ... middle
}

void QGraphicsViewWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QFrame::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsViewWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsViewWrapper::contextMenuEvent(QContextMenuEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QGraphicsViewWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsViewWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::drawBackground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "drawBackground"));
    if (py_override.isNull()) {
        return this->QGraphicsView::drawBackground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        Shiboken::Converter<const QRectF & >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::drawForeground(QPainter * painter, const QRectF & rect)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "drawForeground"));
    if (py_override.isNull()) {
        return this->QGraphicsView::drawForeground(painter, rect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        Shiboken::Converter<const QRectF & >::toPython(rect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::drawItems(QPainter * painter, int numItems, QGraphicsItem ** items, const QStyleOptionGraphicsItem * options)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "drawItems"));
    if (py_override.isNull()) {
        return this->QGraphicsView::drawItems(painter, numItems, items, options);
    }

    // Begin code injection
    
    Shiboken::AutoDecRef object(PyList_New(0));
    for (int i=0, max=numItems; i < max; i++) {
        PyList_Append(object, Shiboken::Converter<QGraphicsItem* >::toPython(items[i]));
    }
    PyObject *items_out = object.object();
    
    // End of code injection
    // Begin code injection
    
    Shiboken::AutoDecRef option_object(PyList_New(0));
    for (int i=0, max=numItems; i < max; i++) {
        PyList_Append(option_object, Shiboken::Converter<QStyleOptionGraphicsItem >::toPython(options[i]));
    }
    PyObject *options_out = option_object.object();
    
    // End of code injection
    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter<QPainter * >::toPython(painter),
        items_out,
        options_out
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsViewWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QGraphicsViewWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QGraphicsView::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QGraphicsViewWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QGraphicsViewWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QGraphicsView::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QGraphicsViewWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QGraphicsViewWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QGraphicsView::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsViewWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QGraphicsViewWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QGraphicsViewWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QGraphicsViewWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QGraphicsView.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QGraphicsViewWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        return this->QGraphicsView::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsViewWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QGraphicsViewWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QGraphicsViewWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QGraphicsView::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsViewWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsViewWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QGraphicsViewWrapper::viewportEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::viewportEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsView.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

void QGraphicsViewWrapper::wheelEvent(QWheelEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QGraphicsView::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsViewWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QGraphicsView::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QGraphicsViewWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsViewWrapper::~QGraphicsViewWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQGraphicsView_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsView >()))
        return -1;

    QGraphicsViewWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QGraphicsView", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsView(QGraphicsScene*,QWidget*)
    // 1: QGraphicsView(QWidget*)
    if (numArgs == 0) {
        overloadId = 1; // QGraphicsView(QWidget*)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QGraphicsView(QWidget*)
    } else if (Shiboken::Converter<QGraphicsScene * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QGraphicsView(QGraphicsScene*,QWidget*)
        } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QGraphicsView(QGraphicsScene*,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsView_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGraphicsView(QGraphicsScene*,QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QGraphicsScene* cpp_arg0 = Shiboken::Converter<QGraphicsScene* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QWidget* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QGraphicsView(QGraphicsScene*,QWidget*)
                cptr = new QGraphicsViewWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
            case 1: // QGraphicsView(QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QGraphicsView(QWidget*)
                cptr = new QGraphicsViewWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQGraphicsView_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQGraphicsView_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsScene, PySide.QtGui.QWidget = None", "PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView", overloads);
        return -1;
}

static PyObject* SbkQGraphicsViewFunc_alignment(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alignment()const
            QFlags<Qt::AlignmentFlag> cppResult = cppSelf->QGraphicsView::alignment();
            pyResult = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_backgroundBrush(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundBrush()const
            QBrush cppResult = cppSelf->QGraphicsView::backgroundBrush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_cacheMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cacheMode()const
            QFlags<QGraphicsView::CacheModeFlag> cppResult = cppSelf->QGraphicsView::cacheMode();
            pyResult = Shiboken::Converter<QFlags<QGraphicsView::CacheModeFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_centerOn(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "centerOn", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: centerOn(const QGraphicsItem*)
    // 1: centerOn(QPointF)
    // 2: centerOn(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // centerOn(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // centerOn(QPointF)
    } else if (numArgs == 1 && Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        overloadId = 0; // centerOn(const QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_centerOn_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // centerOn(const QGraphicsItem*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // centerOn(const QGraphicsItem*)
                cppSelf->QGraphicsView::centerOn(cpp_arg0);
                }
                break;
            }
            case 1: // centerOn(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // centerOn(QPointF)
                cppSelf->QGraphicsView::centerOn(*cpp_arg0);
                }
                break;
            }
            case 2: // centerOn(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // centerOn(qreal,qreal)
                cppSelf->QGraphicsView::centerOn(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_centerOn_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem", "PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.centerOn", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter<QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QContextMenuEvent* cpp_arg0 = Shiboken::Converter<QContextMenuEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contextMenuEvent(QContextMenuEvent*)
            cppSelf->QGraphicsView::contextMenuEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.contextMenuEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QDragEnterEvent*)
    if (Shiboken::Converter<QDragEnterEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragEnterEvent* cpp_arg0 = Shiboken::Converter<QDragEnterEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragEnterEvent(QDragEnterEvent*)
            cppSelf->QGraphicsView::dragEnterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragEnterEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dragEnterEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter<QDragLeaveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragLeaveEvent* cpp_arg0 = Shiboken::Converter<QDragLeaveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragLeaveEvent(QDragLeaveEvent*)
            cppSelf->QGraphicsView::dragLeaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_dragMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // dragMode()const
            QGraphicsView::DragMode cppResult = cppSelf->QGraphicsView::dragMode();
            pyResult = Shiboken::Converter<QGraphicsView::DragMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter<QDragMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragMoveEvent* cpp_arg0 = Shiboken::Converter<QDragMoveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragMoveEvent(QDragMoveEvent*)
            cppSelf->QGraphicsView::dragMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dragMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_drawBackground(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawBackground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawBackground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawBackground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_drawBackground_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // drawBackground(QPainter*,QRectF)
            cppSelf->QGraphicsView::drawBackground(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_drawBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.drawBackground", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_drawForeground(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawForeground", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawForeground(QPainter*,QRectF)
    if (numArgs == 2 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawForeground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_drawForeground_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF* cpp_arg1 = Shiboken::Converter<QRectF* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // drawForeground(QPainter*,QRectF)
            cppSelf->QGraphicsView::drawForeground(cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_drawForeground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.drawForeground", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_drawItems(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawItems", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawItems(QPainter*,int,QGraphicsItem**,const QStyleOptionGraphicsItem*)
    if (numArgs == 3 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && PySequence_Check(pyargs[1]) && PySequence_Check(pyargs[2])) {
        overloadId = 0; // drawItems(QPainter*,int,QGraphicsItem**,const QStyleOptionGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_drawItems_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
            // drawItems(QPainter*,int,QGraphicsItem**,const QStyleOptionGraphicsItem*)
            // Begin code injection
            
            int numItems_out = PySequence_Size(pyargs[1-1]);
            
            // End of code injection
            // Begin code injection
            
            int numItems = PySequence_Size(pyargs[1-1]);
            PySide::AutoArrayPointer<QGraphicsItem*> items_out(numItems);
            for (int i=0; i < numItems; i++) {
                items_out[i] = Shiboken::Converter<QGraphicsItem* >::toCpp(PySequence_Fast_GET_ITEM(pyargs[1-1], i));
            }
            
            // End of code injection
            // Begin code injection
            
            int numOptions = PySequence_Size(pyargs[2-1]);
            PySide::AutoArrayPointer<QStyleOptionGraphicsItem> options_out(numOptions);
            for (int i=0; i < numOptions; i++) {
                options_out[i] = Shiboken::Converter<QStyleOptionGraphicsItem >::toCpp(PySequence_Fast_GET_ITEM(pyargs[1-1], i));
            }
            
            // End of code injection
            cppSelf->QGraphicsView::drawItems(cpp_arg0, numItems_out, items_out, options_out);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_drawItems_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, int, PySide.QtGui.QGraphicsItem, PySide.QtGui.QStyleOptionGraphicsItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.drawItems", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter<QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDropEvent* cpp_arg0 = Shiboken::Converter<QDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dropEvent(QDropEvent*)
            cppSelf->QGraphicsView::dropEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.dropEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_ensureVisible(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "xmargin", "ymargin" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:ensureVisible", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: ensureVisible(const QGraphicsItem*,int,int)
    // 1: ensureVisible(QRectF,int,int)
    // 2: ensureVisible(qreal,qreal,qreal,qreal,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 2; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            } else if (SbkNumber_Check(pyargs[5])) {
                overloadId = 2; // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            }
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // ensureVisible(QRectF,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // ensureVisible(QRectF,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // ensureVisible(QRectF,int,int)
            }
        }
    } else if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // ensureVisible(const QGraphicsItem*,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // ensureVisible(const QGraphicsItem*,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // ensureVisible(const QGraphicsItem*,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_ensureVisible_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // ensureVisible(const QGraphicsItem*,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xmargin";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "ymargin";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 50;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 50;

                if(!PyErr_Occurred()) {
                // ensureVisible(const QGraphicsItem*,int,int)
                cppSelf->QGraphicsView::ensureVisible(cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // ensureVisible(QRectF,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xmargin";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "ymargin";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 50;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 50;

                if(!PyErr_Occurred()) {
                // ensureVisible(QRectF,int,int)
                cppSelf->QGraphicsView::ensureVisible(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // ensureVisible(qreal,qreal,qreal,qreal,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xmargin");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "xmargin";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "ymargin");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "ymargin";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.ensureVisible(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 50;
                int cpp_arg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 50;

                if(!PyErr_Occurred()) {
                // ensureVisible(qreal,qreal,qreal,qreal,int,int)
                cppSelf->QGraphicsView::ensureVisible(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_ensureVisible_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, int = 50, int = 50", "PySide.QtCore.QRectF, int = 50, int = 50", "float, float, float, float, int = 50, int = 50", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.ensureVisible", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_event(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QGraphicsView::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.event", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_fitInView(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "aspectRadioMode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): not enough arguments");
        return 0;
    } else if (numArgs == 3)
        goto SbkQGraphicsViewFunc_fitInView_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:fitInView", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
    // 1: fitInView(QRectF,Qt::AspectRatioMode)
    // 2: fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
        } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[4])) {
            overloadId = 2; // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // fitInView(QRectF,Qt::AspectRatioMode)
        } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // fitInView(QRectF,Qt::AspectRatioMode)
        }
    } else if (Shiboken::Converter< QGraphicsItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
        } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_fitInView_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectRadioMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aspectRadioMode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QGraphicsItem* cpp_arg0 = Shiboken::Converter<QGraphicsItem* >::toCpp(pyargs[0]);
                Qt::AspectRatioMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]) : Qt::IgnoreAspectRatio;

                if(!PyErr_Occurred()) {
                // fitInView(const QGraphicsItem*,Qt::AspectRatioMode)
                cppSelf->QGraphicsView::fitInView(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // fitInView(QRectF,Qt::AspectRatioMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectRadioMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aspectRadioMode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                Qt::AspectRatioMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]) : Qt::IgnoreAspectRatio;

                if(!PyErr_Occurred()) {
                // fitInView(QRectF,Qt::AspectRatioMode)
                cppSelf->QGraphicsView::fitInView(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectRadioMode");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "aspectRadioMode";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.fitInView(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                Qt::AspectRatioMode cpp_arg4 = pyargs[4] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[4]) : Qt::IgnoreAspectRatio;

                if(!PyErr_Occurred()) {
                // fitInView(qreal,qreal,qreal,qreal,Qt::AspectRatioMode)
                cppSelf->QGraphicsView::fitInView(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_fitInView_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsItem, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio", "PySide.QtCore.QRectF, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio", "float, float, float, float, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.fitInView", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusInEvent(QFocusEvent*)
            cppSelf->QGraphicsView::focusInEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.focusInEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusNextPrevChild(bool)
            bool cppResult = cppSelf->QGraphicsView::focusNextPrevChild(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusOutEvent(QFocusEvent*)
            cppSelf->QGraphicsView::focusOutEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.focusOutEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_foregroundBrush(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // foregroundBrush()const
            QBrush cppResult = cppSelf->QGraphicsView::foregroundBrush();
            pyResult = Shiboken::Converter<QBrush >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            cppSelf->QGraphicsView::inputMethodEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.inputMethodEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter<Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cpp_arg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = cppSelf->QGraphicsView::inputMethodQuery(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.inputMethodQuery", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_invalidateScene(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "layers", "rect" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.invalidateScene(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.invalidateScene(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:invalidateScene", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    if (numArgs == 0) {
        overloadId = 0; // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        } else if (Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::isConvertible(pyargs[1])) {
            overloadId = 0; // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_invalidateScene_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "rect");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "rect";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "layers");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "layers";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.invalidateScene(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF cpp_arg0_tmp = QRectF();
            QRectF* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[0]) : &cpp_arg0_tmp;
            if (pyargs[0] && !Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
            QFlags<QGraphicsScene::SceneLayer> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QGraphicsScene::SceneLayer> >::toCpp(pyargs[1]) : QGraphicsScene::AllLayers;

            if(!PyErr_Occurred()) {
            // invalidateScene(QRectF,QFlags<QGraphicsScene::SceneLayer>)
            cppSelf->QGraphicsView::invalidateScene(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_invalidateScene_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF = QRectF(), PySide.QtGui.QGraphicsScene.SceneLayers = QGraphicsScene.AllLayers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.invalidateScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_isInteractive(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isInteractive()const
            bool cppResult = cppSelf->QGraphicsView::isInteractive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_isTransformed(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isTransformed()const
            bool cppResult = cppSelf->QGraphicsView::isTransformed();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_itemAt(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(QPoint)const
    // 1: itemAt(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // itemAt(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // itemAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // itemAt(QPoint)const
                QGraphicsItem * cppResult = cppSelf->QGraphicsView::itemAt(*cpp_arg0);
                pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // itemAt(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // itemAt(int,int)const
                QGraphicsItem * cppResult = cppSelf->QGraphicsView::itemAt(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QGraphicsItem * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_itemAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.itemAt", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_items(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): too many arguments");
        return 0;
    } else if (numArgs == 3)
        goto SbkQGraphicsViewFunc_items_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:items", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: items()const
    // 1: items(QPainterPath,Qt::ItemSelectionMode)const
    // 2: items(QPoint)const
    // 3: items(QPolygon,Qt::ItemSelectionMode)const
    // 4: items(QRect,Qt::ItemSelectionMode)const
    // 5: items(int,int)const
    // 6: items(int,int,int,int,Qt::ItemSelectionMode)const
    if (numArgs == 0) {
        overloadId = 0; // items()const
    } else if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 5; // items(int,int)const
        } else if (numArgs >= 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 6; // items(int,int,int,int,Qt::ItemSelectionMode)const
            } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[4])) {
                overloadId = 6; // items(int,int,int,int,Qt::ItemSelectionMode)const
            }
        }
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 4; // items(QRect,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 4; // items(QRect,Qt::ItemSelectionMode)const
        }
    } else if (Shiboken::Converter<const QPolygon & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // items(QPolygon,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 3; // items(QPolygon,Qt::ItemSelectionMode)const
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 2; // items(QPoint)const
    } else if (Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode)const
        } else if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_items_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // items()const
            {

                if(!PyErr_Occurred()) {
                // items()const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsView::items();
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 1: // items(QPainterPath,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(QPainterPath,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsView::items(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 2: // items(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // items(QPoint)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsView::items(*cpp_arg0);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 3: // items(QPolygon,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygon >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);
                Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(QPolygon,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsView::items(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 4: // items(QRect,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                Qt::ItemSelectionMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[1]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(QRect,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsView::items(*cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 5: // items(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // items(int,int)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsView::items(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
            case 6: // items(int,int,int,int,Qt::ItemSelectionMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "mode";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.items(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::ItemSelectionMode cpp_arg4 = pyargs[4] ? Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(pyargs[4]) : Qt::IntersectsItemShape;

                if(!PyErr_Occurred()) {
                // items(int,int,int,int,Qt::ItemSelectionMode)const
                QList<QGraphicsItem * > cppResult = cppSelf->QGraphicsView::items(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                pyResult = Shiboken::Converter<QList<QGraphicsItem * > >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_items_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtCore.QPoint", "PySide.QtGui.QPolygon, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "PySide.QtCore.QRect, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", "int, int", "int, int, int, int, PySide.QtCore.Qt.ItemSelectionMode = Qt.IntersectsItemShape", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.items", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QGraphicsView::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyReleaseEvent(QKeyEvent*)
            cppSelf->QGraphicsView::keyReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_mapFromScene(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQGraphicsViewFunc_mapFromScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapFromScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapFromScene(QPainterPath)const
    // 1: mapFromScene(QPointF)const
    // 2: mapFromScene(QPolygonF)const
    // 3: mapFromScene(QRectF)const
    // 4: mapFromScene(qreal,qreal)const
    // 5: mapFromScene(qreal,qreal,qreal,qreal)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapFromScene(qreal,qreal)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapFromScene(qreal,qreal,qreal,qreal)const
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapFromScene(QRectF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapFromScene(QPolygonF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapFromScene(QPointF)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapFromScene(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_mapFromScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapFromScene(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapFromScene(QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsView::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapFromScene(QPointF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromScene(QPointF)const
                QPoint cppResult = cppSelf->QGraphicsView::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapFromScene(QPolygonF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromScene(QPolygonF)const
                QPolygon cppResult = cppSelf->QGraphicsView::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapFromScene(QRectF)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapFromScene(QRectF)const
                QPolygon cppResult = cppSelf->QGraphicsView::mapFromScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapFromScene(qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapFromScene(qreal,qreal)const
                QPoint cppResult = cppSelf->QGraphicsView::mapFromScene(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapFromScene(qreal,qreal,qreal,qreal)const
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapFromScene(qreal,qreal,qreal,qreal)const
                QPolygon cppResult = cppSelf->QGraphicsView::mapFromScene(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPolygon >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_mapFromScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "float, float", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.mapFromScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_mapToScene(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQGraphicsViewFunc_mapToScene_TypeError;

    if (!PyArg_UnpackTuple(args, "mapToScene", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: mapToScene(QPainterPath)const
    // 1: mapToScene(QPoint)const
    // 2: mapToScene(QPolygon)const
    // 3: mapToScene(QRect)const
    // 4: mapToScene(int,int)const
    // 5: mapToScene(int,int,int,int)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // mapToScene(int,int)const
        } else if (numArgs == 4 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // mapToScene(int,int,int,int)const
        }
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 3; // mapToScene(QRect)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPolygon & >::isConvertible(pyargs[0])) {
        overloadId = 2; // mapToScene(QPolygon)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 1; // mapToScene(QPoint)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        overloadId = 0; // mapToScene(QPainterPath)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_mapToScene_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapToScene(QPainterPath)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapToScene(QPainterPath)const
                QPainterPath cppResult = cppSelf->QGraphicsView::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapToScene(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapToScene(QPoint)const
                QPointF cppResult = cppSelf->QGraphicsView::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 2: // mapToScene(QPolygon)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygon >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // mapToScene(QPolygon)const
                QPolygonF cppResult = cppSelf->QGraphicsView::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 3: // mapToScene(QRect)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // mapToScene(QRect)const
                QPolygonF cppResult = cppSelf->QGraphicsView::mapToScene(*cpp_arg0);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 4: // mapToScene(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // mapToScene(int,int)const
                QPointF cppResult = cppSelf->QGraphicsView::mapToScene(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // mapToScene(int,int,int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // mapToScene(int,int,int,int)const
                QPolygonF cppResult = cppSelf->QGraphicsView::mapToScene(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                pyResult = Shiboken::Converter<QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_mapToScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", "PySide.QtCore.QPoint", "PySide.QtGui.QPolygon", "PySide.QtCore.QRect", "int, int", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.mapToScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_matrix(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // matrix()const
            QMatrix cppResult = cppSelf->QGraphicsView::matrix();
            pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseDoubleClickEvent(QMouseEvent*)
            cppSelf->QGraphicsView::mouseDoubleClickEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseMoveEvent(QMouseEvent*)
            cppSelf->QGraphicsView::mouseMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mousePressEvent(QMouseEvent*)
            cppSelf->QGraphicsView::mousePressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mousePressEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseReleaseEvent(QMouseEvent*)
            cppSelf->QGraphicsView::mouseReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_optimizationFlags(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // optimizationFlags()const
            QFlags<QGraphicsView::OptimizationFlag> cppResult = cppSelf->QGraphicsView::optimizationFlags();
            pyResult = Shiboken::Converter<QFlags<QGraphicsView::OptimizationFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter<QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintEvent* cpp_arg0 = Shiboken::Converter<QPaintEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // paintEvent(QPaintEvent*)
            cppSelf->QGraphicsView::paintEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.paintEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "aspectRatioMode", "source", "target" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.render(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
    if (Shiboken::Converter<QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
        } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
            } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
                } else if (Shiboken::Converter<Qt::AspectRatioMode >::isConvertible(pyargs[3])) {
                    overloadId = 0; // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_render_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "target");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "target";
                    else
                        pyargs[1] = value;
                }
                value = PyDict_GetItemString(kwds, "source");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "source";
                    else
                        pyargs[2] = value;
                }
                value = PyDict_GetItemString(kwds, "aspectRatioMode");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "aspectRatioMode";
                    else
                        pyargs[3] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.render(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QRectF > cpp_arg1_auto_ptr;
            QRectF cpp_arg1_tmp = QRectF();
            QRectF* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QRectF* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
            if (pyargs[1] && !Shiboken::Converter<QRectF >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QRectF >(cpp_arg1);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QRect cpp_arg2_tmp = QRect();
            QRect* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRect* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
            Qt::AspectRatioMode cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[3]) : Qt::KeepAspectRatio;

            if(!PyErr_Occurred()) {
            // render(QPainter*,QRectF,QRect,Qt::AspectRatioMode)
            cppSelf->QGraphicsView::render(cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF = QRectF(), PySide.QtCore.QRect = QRect(), PySide.QtCore.Qt.AspectRatioMode = Qt.KeepAspectRatio", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.render", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_renderHints(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // renderHints()const
            QFlags<QPainter::RenderHint> cppResult = cppSelf->QGraphicsView::renderHints();
            pyResult = Shiboken::Converter<QFlags<QPainter::RenderHint> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_resetCachedContent(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetCachedContent()
            cppSelf->QGraphicsView::resetCachedContent();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsViewFunc_resetMatrix(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetMatrix()
            cppSelf->QGraphicsView::resetMatrix();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsViewFunc_resetTransform(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetTransform()
            cppSelf->QGraphicsView::resetTransform();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQGraphicsViewFunc_resizeAnchor(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resizeAnchor()const
            QGraphicsView::ViewportAnchor cppResult = cppSelf->QGraphicsView::resizeAnchor();
            pyResult = Shiboken::Converter<QGraphicsView::ViewportAnchor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter<QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QResizeEvent* cpp_arg0 = Shiboken::Converter<QResizeEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resizeEvent(QResizeEvent*)
            cppSelf->QGraphicsView::resizeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.resizeEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_rotate(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_rotate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rotate(qreal)
            cppSelf->QGraphicsView::rotate(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_rotate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.rotate", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_rubberBandSelectionMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rubberBandSelectionMode()const
            Qt::ItemSelectionMode cppResult = cppSelf->QGraphicsView::rubberBandSelectionMode();
            pyResult = Shiboken::Converter<Qt::ItemSelectionMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_scale(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_scale_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scale(qreal,qreal)
            cppSelf->QGraphicsView::scale(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.scale", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_scene(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // scene()const
            QGraphicsScene * cppResult = cppSelf->QGraphicsView::scene();
            pyResult = Shiboken::Converter<QGraphicsScene * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_sceneRect(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sceneRect()const
            QRectF cppResult = cppSelf->QGraphicsView::sceneRect();
            pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_scrollContentsBy(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollContentsBy(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_scrollContentsBy_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scrollContentsBy(int,int)
            cppSelf->QGraphicsView::scrollContentsBy(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_scrollContentsBy_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.scrollContentsBy", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setAlignment(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->QGraphicsView::setAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setAlignment", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setBackgroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundBrush(QBrush)
    if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setBackgroundBrush_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
            QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
            if (!Shiboken::Converter<QBrush >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBackgroundBrush(QBrush)
            cppSelf->QGraphicsView::setBackgroundBrush(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setBackgroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setBackgroundBrush", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setCacheMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCacheMode(QFlags<QGraphicsView::CacheModeFlag>)
    if (Shiboken::Converter<QFlags<QGraphicsView::CacheModeFlag> >::isConvertible(arg)) {
        overloadId = 0; // setCacheMode(QFlags<QGraphicsView::CacheModeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setCacheMode_TypeError;

    // Call function/method
    {
        {
            QFlags<QGraphicsView::CacheModeFlag> cpp_arg0 = Shiboken::Converter<QFlags<QGraphicsView::CacheModeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCacheMode(QFlags<QGraphicsView::CacheModeFlag>)
            cppSelf->QGraphicsView::setCacheMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setCacheMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.CacheMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setCacheMode", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setDragMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDragMode(QGraphicsView::DragMode)
    if (Shiboken::Converter<QGraphicsView::DragMode >::isConvertible(arg)) {
        overloadId = 0; // setDragMode(QGraphicsView::DragMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setDragMode_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::DragMode cpp_arg0 = Shiboken::Converter<QGraphicsView::DragMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDragMode(QGraphicsView::DragMode)
            cppSelf->QGraphicsView::setDragMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setDragMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.DragMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setDragMode", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setForegroundBrush(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForegroundBrush(QBrush)
    if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 0; // setForegroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setForegroundBrush_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
            QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
            if (!Shiboken::Converter<QBrush >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setForegroundBrush(QBrush)
            cppSelf->QGraphicsView::setForegroundBrush(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setForegroundBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setForegroundBrush", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setInteractive(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInteractive(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setInteractive(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setInteractive_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInteractive(bool)
            cppSelf->QGraphicsView::setInteractive(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setInteractive_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setInteractive", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setMatrix(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "combine" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setMatrix(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setMatrix(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setMatrix(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setMatrix", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMatrix(QMatrix,bool)
    if (Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setMatrix(QMatrix,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setMatrix(QMatrix,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setMatrix_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setMatrix(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // setMatrix(QMatrix,bool)
            cppSelf->QGraphicsView::setMatrix(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setMatrix", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setOptimizationFlag(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "enabled" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setOptimizationFlag(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setOptimizationFlag(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setOptimizationFlag(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setOptimizationFlag", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
    if (Shiboken::Converter<QGraphicsView::OptimizationFlag >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setOptimizationFlag_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enabled");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enabled";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setOptimizationFlag(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QGraphicsView::OptimizationFlag cpp_arg0 = Shiboken::Converter<QGraphicsView::OptimizationFlag >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setOptimizationFlag(QGraphicsView::OptimizationFlag,bool)
            cppSelf->QGraphicsView::setOptimizationFlag(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setOptimizationFlag_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.OptimizationFlag, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setOptimizationFlag", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setOptimizationFlags(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOptimizationFlags(QFlags<QGraphicsView::OptimizationFlag>)
    if (Shiboken::Converter<QFlags<QGraphicsView::OptimizationFlag> >::isConvertible(arg)) {
        overloadId = 0; // setOptimizationFlags(QFlags<QGraphicsView::OptimizationFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setOptimizationFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<QGraphicsView::OptimizationFlag> cpp_arg0 = Shiboken::Converter<QFlags<QGraphicsView::OptimizationFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOptimizationFlags(QFlags<QGraphicsView::OptimizationFlag>)
            cppSelf->QGraphicsView::setOptimizationFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setOptimizationFlags_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.OptimizationFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setOptimizationFlags", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setRenderHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "enabled" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setRenderHint(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setRenderHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setRenderHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setRenderHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRenderHint(QPainter::RenderHint,bool)
    if (Shiboken::Converter<QPainter::RenderHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setRenderHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enabled");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enabled";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setRenderHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QPainter::RenderHint cpp_arg0 = Shiboken::Converter<QPainter::RenderHint >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setRenderHint(QPainter::RenderHint,bool)
            cppSelf->QGraphicsView::setRenderHint(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setRenderHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHint, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setRenderHint", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setRenderHints(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRenderHints(QFlags<QPainter::RenderHint>)
    if (Shiboken::Converter<QFlags<QPainter::RenderHint> >::isConvertible(arg)) {
        overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setRenderHints_TypeError;

    // Call function/method
    {
        {
            QFlags<QPainter::RenderHint> cpp_arg0 = Shiboken::Converter<QFlags<QPainter::RenderHint> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRenderHints(QFlags<QPainter::RenderHint>)
            cppSelf->QGraphicsView::setRenderHints(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setRenderHints_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHints", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setRenderHints", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setResizeAnchor(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setResizeAnchor(QGraphicsView::ViewportAnchor)
    if (Shiboken::Converter<QGraphicsView::ViewportAnchor >::isConvertible(arg)) {
        overloadId = 0; // setResizeAnchor(QGraphicsView::ViewportAnchor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setResizeAnchor_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::ViewportAnchor cpp_arg0 = Shiboken::Converter<QGraphicsView::ViewportAnchor >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setResizeAnchor(QGraphicsView::ViewportAnchor)
            cppSelf->QGraphicsView::setResizeAnchor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setResizeAnchor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.ViewportAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setResizeAnchor", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setRubberBandSelectionMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRubberBandSelectionMode(Qt::ItemSelectionMode)
    if (Shiboken::Converter<Qt::ItemSelectionMode >::isConvertible(arg)) {
        overloadId = 0; // setRubberBandSelectionMode(Qt::ItemSelectionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setRubberBandSelectionMode_TypeError;

    // Call function/method
    {
        {
            Qt::ItemSelectionMode cpp_arg0 = Shiboken::Converter<Qt::ItemSelectionMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setRubberBandSelectionMode(Qt::ItemSelectionMode)
            cppSelf->QGraphicsView::setRubberBandSelectionMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setRubberBandSelectionMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ItemSelectionMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setRubberBandSelectionMode", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setScene(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScene(QGraphicsScene*)
    if (Shiboken::Converter<QGraphicsScene * >::isConvertible(arg)) {
        overloadId = 0; // setScene(QGraphicsScene*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setScene_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsScene* cpp_arg0 = Shiboken::Converter<QGraphicsScene* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setScene(QGraphicsScene*)
            cppSelf->QGraphicsView::setScene(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setScene_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsScene", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setSceneRect(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQGraphicsViewFunc_setSceneRect_TypeError;

    if (!PyArg_UnpackTuple(args, "setSceneRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setSceneRect(QRectF)
    // 1: setSceneRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setSceneRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSceneRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setSceneRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSceneRect(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setSceneRect(QRectF)
                cppSelf->QGraphicsView::setSceneRect(*cpp_arg0);
                }
                break;
            }
            case 1: // setSceneRect(qreal,qreal,qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cpp_arg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setSceneRect(qreal,qreal,qreal,qreal)
                cppSelf->QGraphicsView::setSceneRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setSceneRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setSceneRect", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "combine" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setTransform(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTransform(QTransform,bool)
    if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setTransform(QTransform,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsView.setTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // setTransform(QTransform,bool)
            cppSelf->QGraphicsView::setTransform(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.setTransform", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setTransformationAnchor(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransformationAnchor(QGraphicsView::ViewportAnchor)
    if (Shiboken::Converter<QGraphicsView::ViewportAnchor >::isConvertible(arg)) {
        overloadId = 0; // setTransformationAnchor(QGraphicsView::ViewportAnchor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setTransformationAnchor_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::ViewportAnchor cpp_arg0 = Shiboken::Converter<QGraphicsView::ViewportAnchor >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTransformationAnchor(QGraphicsView::ViewportAnchor)
            cppSelf->QGraphicsView::setTransformationAnchor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setTransformationAnchor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.ViewportAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setTransformationAnchor", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setViewportUpdateMode(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewportUpdateMode(QGraphicsView::ViewportUpdateMode)
    if (Shiboken::Converter<QGraphicsView::ViewportUpdateMode >::isConvertible(arg)) {
        overloadId = 0; // setViewportUpdateMode(QGraphicsView::ViewportUpdateMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setViewportUpdateMode_TypeError;

    // Call function/method
    {
        {
            QGraphicsView::ViewportUpdateMode cpp_arg0 = Shiboken::Converter<QGraphicsView::ViewportUpdateMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setViewportUpdateMode(QGraphicsView::ViewportUpdateMode)
            cppSelf->QGraphicsView::setViewportUpdateMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setViewportUpdateMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsView.ViewportUpdateMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setViewportUpdateMode", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_setupViewport(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setupViewport(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setupViewport(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_setupViewport_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setupViewport(QWidget*)
            cppSelf->QGraphicsView::setupViewport(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_setupViewport_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.setupViewport", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_shear(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // shear(qreal,qreal)
            cppSelf->QGraphicsView::shear(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.shear", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_showEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: showEvent(QShowEvent*)
    if (Shiboken::Converter<QShowEvent * >::isConvertible(arg)) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_showEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QShowEvent* cpp_arg0 = Shiboken::Converter<QShowEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // showEvent(QShowEvent*)
            cppSelf->QGraphicsView::showEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_showEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QShowEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.showEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_sizeHint(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizeHint()const
            QSize cppResult = cppSelf->QGraphicsView::sizeHint();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_transform(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transform()const
            QTransform cppResult = cppSelf->QGraphicsView::transform();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_transformationAnchor(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transformationAnchor()const
            QGraphicsView::ViewportAnchor cppResult = cppSelf->QGraphicsView::transformationAnchor();
            pyResult = Shiboken::Converter<QGraphicsView::ViewportAnchor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_translate(PyObject* self, PyObject* args)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_translate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // translate(qreal,qreal)
            cppSelf->QGraphicsView::translate(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_translate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsView.translate", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_updateScene(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updateScene(QList<QRectF>)
    if (Shiboken::Converter< QList<QRectF >  >::isConvertible(arg)) {
        overloadId = 0; // updateScene(QList<QRectF>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_updateScene_TypeError;

    // Call function/method
    {
        {
            QList<QRectF > cpp_arg0 = Shiboken::Converter<QList<QRectF > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // updateScene(QList<QRectF>)
            cppSelf->QGraphicsView::updateScene(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_updateScene_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.updateScene", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_updateSceneRect(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updateSceneRect(QRectF)
    if (Shiboken::Converter<const QRectF & >::isConvertible(arg)) {
        overloadId = 0; // updateSceneRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_updateSceneRect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
            QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(arg);
            if (!Shiboken::Converter<QRectF >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // updateSceneRect(QRectF)
            cppSelf->QGraphicsView::updateSceneRect(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_updateSceneRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.updateSceneRect", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_viewportEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: viewportEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // viewportEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_viewportEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // viewportEvent(QEvent*)
            bool cppResult = cppSelf->QGraphicsView::viewportEvent(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQGraphicsViewFunc_viewportEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.viewportEvent", overloads);
        return 0;
}

static PyObject* SbkQGraphicsViewFunc_viewportTransform(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewportTransform()const
            QTransform cppResult = cppSelf->QGraphicsView::viewportTransform();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_viewportUpdateMode(PyObject* self)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewportUpdateMode()const
            QGraphicsView::ViewportUpdateMode cppResult = cppSelf->QGraphicsView::viewportUpdateMode();
            pyResult = Shiboken::Converter<QGraphicsView::ViewportUpdateMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQGraphicsViewFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QGraphicsView* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QGraphicsView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QWheelEvent*)
    if (Shiboken::Converter<QWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQGraphicsViewFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWheelEvent* cpp_arg0 = Shiboken::Converter<QWheelEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // wheelEvent(QWheelEvent*)
            cppSelf->QGraphicsView::wheelEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQGraphicsViewFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsView.wheelEvent", overloads);
        return 0;
}

static PyMethodDef SbkQGraphicsView_methods[] = {
    {"alignment", (PyCFunction)SbkQGraphicsViewFunc_alignment, METH_NOARGS},
    {"backgroundBrush", (PyCFunction)SbkQGraphicsViewFunc_backgroundBrush, METH_NOARGS},
    {"cacheMode", (PyCFunction)SbkQGraphicsViewFunc_cacheMode, METH_NOARGS},
    {"centerOn", (PyCFunction)SbkQGraphicsViewFunc_centerOn, METH_VARARGS},
    {"contextMenuEvent", (PyCFunction)SbkQGraphicsViewFunc_contextMenuEvent, METH_O},
    {"dragEnterEvent", (PyCFunction)SbkQGraphicsViewFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)SbkQGraphicsViewFunc_dragLeaveEvent, METH_O},
    {"dragMode", (PyCFunction)SbkQGraphicsViewFunc_dragMode, METH_NOARGS},
    {"dragMoveEvent", (PyCFunction)SbkQGraphicsViewFunc_dragMoveEvent, METH_O},
    {"drawBackground", (PyCFunction)SbkQGraphicsViewFunc_drawBackground, METH_VARARGS},
    {"drawForeground", (PyCFunction)SbkQGraphicsViewFunc_drawForeground, METH_VARARGS},
    {"drawItems", (PyCFunction)SbkQGraphicsViewFunc_drawItems, METH_VARARGS},
    {"dropEvent", (PyCFunction)SbkQGraphicsViewFunc_dropEvent, METH_O},
    {"ensureVisible", (PyCFunction)SbkQGraphicsViewFunc_ensureVisible, METH_VARARGS|METH_KEYWORDS},
    {"event", (PyCFunction)SbkQGraphicsViewFunc_event, METH_O},
    {"fitInView", (PyCFunction)SbkQGraphicsViewFunc_fitInView, METH_VARARGS|METH_KEYWORDS},
    {"focusInEvent", (PyCFunction)SbkQGraphicsViewFunc_focusInEvent, METH_O},
    {"focusNextPrevChild", (PyCFunction)SbkQGraphicsViewFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)SbkQGraphicsViewFunc_focusOutEvent, METH_O},
    {"foregroundBrush", (PyCFunction)SbkQGraphicsViewFunc_foregroundBrush, METH_NOARGS},
    {"inputMethodEvent", (PyCFunction)SbkQGraphicsViewFunc_inputMethodEvent, METH_O},
    {"inputMethodQuery", (PyCFunction)SbkQGraphicsViewFunc_inputMethodQuery, METH_O},
    {"invalidateScene", (PyCFunction)SbkQGraphicsViewFunc_invalidateScene, METH_VARARGS|METH_KEYWORDS},
    {"isInteractive", (PyCFunction)SbkQGraphicsViewFunc_isInteractive, METH_NOARGS},
    {"isTransformed", (PyCFunction)SbkQGraphicsViewFunc_isTransformed, METH_NOARGS},
    {"itemAt", (PyCFunction)SbkQGraphicsViewFunc_itemAt, METH_VARARGS},
    {"items", (PyCFunction)SbkQGraphicsViewFunc_items, METH_VARARGS|METH_KEYWORDS},
    {"keyPressEvent", (PyCFunction)SbkQGraphicsViewFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)SbkQGraphicsViewFunc_keyReleaseEvent, METH_O},
    {"mapFromScene", (PyCFunction)SbkQGraphicsViewFunc_mapFromScene, METH_VARARGS},
    {"mapToScene", (PyCFunction)SbkQGraphicsViewFunc_mapToScene, METH_VARARGS},
    {"matrix", (PyCFunction)SbkQGraphicsViewFunc_matrix, METH_NOARGS},
    {"mouseDoubleClickEvent", (PyCFunction)SbkQGraphicsViewFunc_mouseDoubleClickEvent, METH_O},
    {"mouseMoveEvent", (PyCFunction)SbkQGraphicsViewFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)SbkQGraphicsViewFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)SbkQGraphicsViewFunc_mouseReleaseEvent, METH_O},
    {"optimizationFlags", (PyCFunction)SbkQGraphicsViewFunc_optimizationFlags, METH_NOARGS},
    {"paintEvent", (PyCFunction)SbkQGraphicsViewFunc_paintEvent, METH_O},
    {"render", (PyCFunction)SbkQGraphicsViewFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"renderHints", (PyCFunction)SbkQGraphicsViewFunc_renderHints, METH_NOARGS},
    {"resetCachedContent", (PyCFunction)SbkQGraphicsViewFunc_resetCachedContent, METH_NOARGS},
    {"resetMatrix", (PyCFunction)SbkQGraphicsViewFunc_resetMatrix, METH_NOARGS},
    {"resetTransform", (PyCFunction)SbkQGraphicsViewFunc_resetTransform, METH_NOARGS},
    {"resizeAnchor", (PyCFunction)SbkQGraphicsViewFunc_resizeAnchor, METH_NOARGS},
    {"resizeEvent", (PyCFunction)SbkQGraphicsViewFunc_resizeEvent, METH_O},
    {"rotate", (PyCFunction)SbkQGraphicsViewFunc_rotate, METH_O},
    {"rubberBandSelectionMode", (PyCFunction)SbkQGraphicsViewFunc_rubberBandSelectionMode, METH_NOARGS},
    {"scale", (PyCFunction)SbkQGraphicsViewFunc_scale, METH_VARARGS},
    {"scene", (PyCFunction)SbkQGraphicsViewFunc_scene, METH_NOARGS},
    {"sceneRect", (PyCFunction)SbkQGraphicsViewFunc_sceneRect, METH_NOARGS},
    {"scrollContentsBy", (PyCFunction)SbkQGraphicsViewFunc_scrollContentsBy, METH_VARARGS},
    {"setAlignment", (PyCFunction)SbkQGraphicsViewFunc_setAlignment, METH_O},
    {"setBackgroundBrush", (PyCFunction)SbkQGraphicsViewFunc_setBackgroundBrush, METH_O},
    {"setCacheMode", (PyCFunction)SbkQGraphicsViewFunc_setCacheMode, METH_O},
    {"setDragMode", (PyCFunction)SbkQGraphicsViewFunc_setDragMode, METH_O},
    {"setForegroundBrush", (PyCFunction)SbkQGraphicsViewFunc_setForegroundBrush, METH_O},
    {"setInteractive", (PyCFunction)SbkQGraphicsViewFunc_setInteractive, METH_O},
    {"setMatrix", (PyCFunction)SbkQGraphicsViewFunc_setMatrix, METH_VARARGS|METH_KEYWORDS},
    {"setOptimizationFlag", (PyCFunction)SbkQGraphicsViewFunc_setOptimizationFlag, METH_VARARGS|METH_KEYWORDS},
    {"setOptimizationFlags", (PyCFunction)SbkQGraphicsViewFunc_setOptimizationFlags, METH_O},
    {"setRenderHint", (PyCFunction)SbkQGraphicsViewFunc_setRenderHint, METH_VARARGS|METH_KEYWORDS},
    {"setRenderHints", (PyCFunction)SbkQGraphicsViewFunc_setRenderHints, METH_O},
    {"setResizeAnchor", (PyCFunction)SbkQGraphicsViewFunc_setResizeAnchor, METH_O},
    {"setRubberBandSelectionMode", (PyCFunction)SbkQGraphicsViewFunc_setRubberBandSelectionMode, METH_O},
    {"setScene", (PyCFunction)SbkQGraphicsViewFunc_setScene, METH_O},
    {"setSceneRect", (PyCFunction)SbkQGraphicsViewFunc_setSceneRect, METH_VARARGS},
    {"setTransform", (PyCFunction)SbkQGraphicsViewFunc_setTransform, METH_VARARGS|METH_KEYWORDS},
    {"setTransformationAnchor", (PyCFunction)SbkQGraphicsViewFunc_setTransformationAnchor, METH_O},
    {"setViewportUpdateMode", (PyCFunction)SbkQGraphicsViewFunc_setViewportUpdateMode, METH_O},
    {"setupViewport", (PyCFunction)SbkQGraphicsViewFunc_setupViewport, METH_O},
    {"shear", (PyCFunction)SbkQGraphicsViewFunc_shear, METH_VARARGS},
    {"showEvent", (PyCFunction)SbkQGraphicsViewFunc_showEvent, METH_O},
    {"sizeHint", (PyCFunction)SbkQGraphicsViewFunc_sizeHint, METH_NOARGS},
    {"transform", (PyCFunction)SbkQGraphicsViewFunc_transform, METH_NOARGS},
    {"transformationAnchor", (PyCFunction)SbkQGraphicsViewFunc_transformationAnchor, METH_NOARGS},
    {"translate", (PyCFunction)SbkQGraphicsViewFunc_translate, METH_VARARGS},
    {"updateScene", (PyCFunction)SbkQGraphicsViewFunc_updateScene, METH_O},
    {"updateSceneRect", (PyCFunction)SbkQGraphicsViewFunc_updateSceneRect, METH_O},
    {"viewportEvent", (PyCFunction)SbkQGraphicsViewFunc_viewportEvent, METH_O},
    {"viewportTransform", (PyCFunction)SbkQGraphicsViewFunc_viewportTransform, METH_NOARGS},
    {"viewportUpdateMode", (PyCFunction)SbkQGraphicsViewFunc_viewportUpdateMode, METH_NOARGS},
    {"wheelEvent", (PyCFunction)SbkQGraphicsViewFunc_wheelEvent, METH_O},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQGraphicsViewSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QGraphicsView* me = reinterpret_cast<QGraphicsView*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQGraphicsView_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsView",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQGraphicsView_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQGraphicsView_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQGraphicsViewSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QGraphicsView >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QGraphicsView*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQGraphicsView_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsView*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQGraphicsView_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QGraphicsView*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQGraphicsView_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsView::OptimizationFlags >::checkType(self) && Shiboken::Converter<QGraphicsView::OptimizationFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        Shiboken::Converter<QGraphicsView::OptimizationFlags>::toCpp(self)
        & Shiboken::Converter< QGraphicsView::OptimizationFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsView::OptimizationFlags >::checkType(self) && Shiboken::Converter<QGraphicsView::OptimizationFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        Shiboken::Converter<QGraphicsView::OptimizationFlags>::toCpp(self)
        | Shiboken::Converter< QGraphicsView::OptimizationFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsView::OptimizationFlags >::checkType(self) && Shiboken::Converter<QGraphicsView::OptimizationFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        Shiboken::Converter<QGraphicsView::OptimizationFlags>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsView::OptimizationFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::OptimizationFlags >::toPython(
        ~Shiboken::Converter<QGraphicsView::OptimizationFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsView_OptimizationFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsView_OptimizationFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsView_OptimizationFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "OptimizationFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsView_OptimizationFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsView_OptimizationFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsView_OptimizationFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsView_OptimizationFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "OptimizationFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsView_ViewportAnchor_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsView_ViewportAnchor_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ViewportAnchor",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsView_ViewportAnchor_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsView_ViewportAnchor_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsView_ViewportAnchor_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

static PyGetSetDef SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ViewportUpdateMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsView::CacheMode >::checkType(self) && Shiboken::Converter<QGraphicsView::CacheMode >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        Shiboken::Converter<QGraphicsView::CacheMode>::toCpp(self)
        & Shiboken::Converter< QGraphicsView::CacheMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsView::CacheMode >::checkType(self) && Shiboken::Converter<QGraphicsView::CacheMode >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        Shiboken::Converter<QGraphicsView::CacheMode>::toCpp(self)
        | Shiboken::Converter< QGraphicsView::CacheMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QGraphicsView::CacheMode >::checkType(self) && Shiboken::Converter<QGraphicsView::CacheMode >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        Shiboken::Converter<QGraphicsView::CacheMode>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsView::CacheMode >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsView::CacheMode >::toPython(
        ~Shiboken::Converter<QGraphicsView::CacheMode >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsView_CacheModeFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsView_CacheModeFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsView_CacheModeFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CacheModeFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsView_CacheModeFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsView_CacheModeFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsView_CacheModeFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsView_CacheModeFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsView_CacheMode_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CacheMode",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QGraphicsView_DragMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QGraphicsView_DragMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QGraphicsView_DragMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DragMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QGraphicsView_DragMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QGraphicsView_DragMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QGraphicsView_DragMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QGraphicsView(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQGraphicsView_Type);

    SbkQGraphicsView_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX];
    SbkQGraphicsView_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX])->mi_init;

    // Fill type discovery information
    SbkQGraphicsView_Type.type_discovery = &SbkQGraphicsView_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]), &SbkQGraphicsView_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQGraphicsView_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQGraphicsView_Type));
    PyModule_AddObject(module, "QGraphicsView",
        ((PyObject*)&SbkQGraphicsView_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: OptimizationFlag
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_OPTIMIZATIONFLAG_IDX] = &SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type);
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
            "OptimizationFlag",((PyObject*)&SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type));

    // init flags class: QFlags<QGraphicsView::OptimizationFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSVIEW_OPTIMIZATIONFLAG__IDX] = &SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type);
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
            "OptimizationFlags",((PyObject*)&SbkPySide_QtGui_QGraphicsView_OptimizationFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type,
        (long) QGraphicsView::DontClipPainter, "DontClipPainter");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "DontClipPainter", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type.tp_dict,
        "DontClipPainter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type,
        (long) QGraphicsView::DontSavePainterState, "DontSavePainterState");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "DontSavePainterState", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type.tp_dict,
        "DontSavePainterState", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type,
        (long) QGraphicsView::DontAdjustForAntialiasing, "DontAdjustForAntialiasing");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "DontAdjustForAntialiasing", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type.tp_dict,
        "DontAdjustForAntialiasing", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type,
        (long) QGraphicsView::IndirectPainting, "IndirectPainting");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "IndirectPainting", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_OptimizationFlag_Type.tp_dict,
        "IndirectPainting", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::OptimizationFlag");

    // init enum class: ViewportAnchor
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_VIEWPORTANCHOR_IDX] = &SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type);
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
            "ViewportAnchor",((PyObject*)&SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type,
        (long) QGraphicsView::NoAnchor, "NoAnchor");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "NoAnchor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type.tp_dict,
        "NoAnchor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type,
        (long) QGraphicsView::AnchorViewCenter, "AnchorViewCenter");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "AnchorViewCenter", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type.tp_dict,
        "AnchorViewCenter", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type,
        (long) QGraphicsView::AnchorUnderMouse, "AnchorUnderMouse");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "AnchorUnderMouse", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportAnchor_Type.tp_dict,
        "AnchorUnderMouse", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::ViewportAnchor");

    // init enum class: ViewportUpdateMode
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_VIEWPORTUPDATEMODE_IDX] = &SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type);
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
            "ViewportUpdateMode",((PyObject*)&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type,
        (long) QGraphicsView::FullViewportUpdate, "FullViewportUpdate");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "FullViewportUpdate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type.tp_dict,
        "FullViewportUpdate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type,
        (long) QGraphicsView::MinimalViewportUpdate, "MinimalViewportUpdate");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "MinimalViewportUpdate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type.tp_dict,
        "MinimalViewportUpdate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type,
        (long) QGraphicsView::SmartViewportUpdate, "SmartViewportUpdate");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "SmartViewportUpdate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type.tp_dict,
        "SmartViewportUpdate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type,
        (long) QGraphicsView::NoViewportUpdate, "NoViewportUpdate");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "NoViewportUpdate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type.tp_dict,
        "NoViewportUpdate", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type,
        (long) QGraphicsView::BoundingRectViewportUpdate, "BoundingRectViewportUpdate");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "BoundingRectViewportUpdate", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_ViewportUpdateMode_Type.tp_dict,
        "BoundingRectViewportUpdate", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::ViewportUpdateMode");

    // init enum class: CacheModeFlag
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_CACHEMODEFLAG_IDX] = &SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type);
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
            "CacheModeFlag",((PyObject*)&SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type));

    // init flags class: QFlags<QGraphicsView::CacheModeFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSVIEW_CACHEMODEFLAG__IDX] = &SbkPySide_QtGui_QGraphicsView_CacheMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_CacheMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsView_CacheMode_Type);
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
            "CacheMode",((PyObject*)&SbkPySide_QtGui_QGraphicsView_CacheMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type,
        (long) QGraphicsView::CacheNone, "CacheNone");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "CacheNone", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type.tp_dict,
        "CacheNone", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type,
        (long) QGraphicsView::CacheBackground, "CacheBackground");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "CacheBackground", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_CacheModeFlag_Type.tp_dict,
        "CacheBackground", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::CacheModeFlag");

    // init enum class: DragMode
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSVIEW_DRAGMODE_IDX] = &SbkPySide_QtGui_QGraphicsView_DragMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsView_DragMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QGraphicsView_DragMode_Type);
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
            "DragMode",((PyObject*)&SbkPySide_QtGui_QGraphicsView_DragMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_DragMode_Type,
        (long) QGraphicsView::NoDrag, "NoDrag");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "NoDrag", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_DragMode_Type.tp_dict,
        "NoDrag", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_DragMode_Type,
        (long) QGraphicsView::ScrollHandDrag, "ScrollHandDrag");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "ScrollHandDrag", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_DragMode_Type.tp_dict,
        "ScrollHandDrag", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QGraphicsView_DragMode_Type,
        (long) QGraphicsView::RubberBandDrag, "RubberBandDrag");
    PyDict_SetItemString(SbkQGraphicsView_Type.super.ht_type.tp_dict,
        "RubberBandDrag", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsView_DragMode_Type.tp_dict,
        "RubberBandDrag", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsView::DragMode");


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsView >("QGraphicsView*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsView >(typeid(QGraphicsView).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsView >(typeid(QGraphicsViewWrapper).name());
    PySide::initQtMetaType<QGraphicsView* >();
}

